(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   4710527,      89774]
NotebookOptionsPosition[   4692710,      89519]
NotebookOutlinePosition[   4693130,      89536]
CellTagsIndexPosition[   4693087,      89533]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f9f3d752-5402-4b81-a8ff-9dd01713a6b4"],

Cell["Chapter 8, Section 8.9, Figures 8.16-8.18", "Section",
 CellChangeTimes->{{3.880188877576757*^9, 3.880188885961117*^9}, {
  3.88035462991748*^9, 3.880354630470961*^9}, {3.880443082114377*^9, 
  3.880443086702951*^9}, {3.880443664365138*^9, 3.880443665849351*^9}, {
  3.880613412793536*^9, 
  3.880613437048091*^9}},ExpressionUUID->"31cd5343-8984-4f97-9cf6-\
28b1dc5d8ffc"],

Cell[TextData[{
 "Define the function ",
 StyleBox["CRTBP", "Input"],
 " to solve the planar circular restricted three-body problem for a given \
mass ",
 StyleBox["mu",
  FontSlant->"Italic"],
 ", initial position (",
 StyleBox["x0,y0",
  FontSlant->"Italic"],
 "), initial velocity (",
 StyleBox["xd0,yd0",
  FontSlant->"Italic"],
 ") (both in the rotating frame) for times between ",
 StyleBox["ctmin",
  FontSlant->"Italic"],
 " and ",
 StyleBox["ctmax",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"93f2da43-cf6b-49db-a25a-c6c8249f81b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CRTBP", "[", 
   RowBox[{"mu_", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_", ",", "xd0_", ",", "yd0_"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"ctmin_", ",", " ", "ctmax_"}], "}"}]}], "]"}], ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", "=", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", 
      RowBox[{"mu2", "=", "mu"}]}], "}"}], ",", "\n", " ", 
    RowBox[{
     RowBox[{"eqns", "=", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"r1", "[", "t_", "]"}], " ", ":=", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Apply", "[", 
            RowBox[{"Plus", ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"x", "[", "t", "]"}], "+", "mu2"}], ",", " ", 
                RowBox[{"y", "[", "t", "]"}]}], "}"}], "^", "2"}]}], "]"}], 
           "]"}]}], ";", 
         RowBox[{
          RowBox[{"r2", "[", "t_", "]"}], " ", ":=", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Apply", "[", 
            RowBox[{"Plus", ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"x", "[", "t", "]"}], "-", "mu1"}], ",", " ", 
                RowBox[{"y", "[", "t", "]"}]}], "}"}], "^", "2"}]}], "]"}], 
           "]"}]}], ";", 
         RowBox[{
          RowBox[{
           RowBox[{"xd", "'"}], "[", "t", "]"}], " ", "==", " ", 
          RowBox[{
           RowBox[{"2", "*", 
            RowBox[{
             RowBox[{"y", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
           RowBox[{"x", "[", "t", "]"}], " ", "-", " ", 
           RowBox[{"mu1", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "[", "t", "]"}], "+", "mu2"}], ")"}], "/", 
             RowBox[{
              RowBox[{"r1", "[", "t", "]"}], "^", "3"}]}]}], " ", "-", " ", 
           RowBox[{"mu2", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "[", "t", "]"}], "-", "mu1"}], ")"}], "/", 
             RowBox[{
              RowBox[{"r2", "[", "t", "]"}], "^", "3"}]}]}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"yd", "'"}], "[", "t", "]"}], " ", "==", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "*", 
           RowBox[{
            RowBox[{"x", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
          RowBox[{"y", "[", "t", "]"}], " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"mu1", "/", 
              RowBox[{
               RowBox[{"r1", "[", "t", "]"}], "^", "3"}]}], " ", "+", " ", 
             RowBox[{"mu2", "/", 
              RowBox[{
               RowBox[{"r2", "[", "t", "]"}], "^", "3"}]}]}], ")"}], "*", 
           RowBox[{"y", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"xd", "[", "t", "]"}], " ", "==", " ", 
         RowBox[{
          RowBox[{"x", "'"}], "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"yd", "[", "t", "]"}], " ", "==", " ", 
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"x", "[", "0", "]"}], "  ", "==", " ", "x0"}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"y", "[", "0", "]"}], "  ", "==", " ", "y0"}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"xd", "[", "0", "]"}], " ", "==", " ", "xd0"}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"yd", "[", "0", "]"}], " ", "==", " ", "yd0"}]}], "}"}]}], 
     ";", 
     RowBox[{"NDSolve", "[", 
      RowBox[{"eqns", ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "xd", ",", "yd"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"t", ",", "ctmin", ",", "ctmax"}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8804366768491917`*^9, 3.880436676861392*^9}, {
  3.880443947178686*^9, 3.880444016805253*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"1392616a-5db1-4b66-984d-5a0335c49f68"],

Cell[TextData[{
 "Define the function ",
 StyleBox["Jacobi", "Input"],
 " to calculate the value of the Jacobi constant for a given mass ",
 StyleBox["mu",
  FontSlant->"Italic"],
 ", initial position (",
 StyleBox["x0,y0",
  FontSlant->"Italic"],
 "), and initial velocity (",
 StyleBox["xd0,yd0",
  FontSlant->"Italic"],
 ") in the rotating frame."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.880443610664982*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5e2e41f5-db7b-434d-9ad0-1c5a56971b5b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Jacobi", "[", 
   RowBox[{"mu_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "xd_", ",", "yd_"}], "}"}]}], "]"}], ":=", 
  " ", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", "=", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", 
      RowBox[{"mu2", "=", "mu"}], ",", " ", "r1", ",", " ", "r2"}], "}"}], 
    ",", 
    RowBox[{
     RowBox[{"r1", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "+", "mu2"}], ",", " ", "y"}], "}"}], "^", "2"}]}], 
        "]"}], "]"}]}], ";", 
     RowBox[{"r2", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "-", "mu1"}], ",", " ", "y"}], "}"}], "^", "2"}]}], 
        "]"}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"x", "^", "2"}], "+", 
      RowBox[{"y", "^", "2"}], "+", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"mu1", "/", "r1"}], "+", 
         RowBox[{"mu2", "/", "r2"}]}], ")"}]}], "-", 
      RowBox[{"xd", "^", "2"}], "-", 
      RowBox[{"yd", "^", "2"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8804440259119062`*^9, 3.8804440338445377`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"15727f76-f1e1-43ca-952b-d268301d2fe7"],

Cell[TextData[{
 "Define the function ",
 StyleBox["xy2ae", "Input"],
 " to calculate the value of the semi-major axis, eccentricity, longitude of \
periapse and mean longitude from given values of the time, ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", position and velocity in the rotating frame."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.880443639509601*^9}, {3.880443698640009*^9, 
  3.880443781275136*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0d099452-0a30-46f2-af6f-659a088a8cec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xy2ae", "[", 
   RowBox[{"mu_", ",", " ", "tposvel_List"}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", " ", "=", " ", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", "t", ",", " ", "x", ",", " ", 
      "y", ",", " ", "xd", ",", " ", "yd", ",", " ", "ct", ",", "st", ",", 
      "rx", ",", "ry", ",", "r2", ",", "r", ",", "vx", ",", "vy", ",", "v2", 
      ",", "v", ",", "a", ",", "h", ",", "h2", ",", "rdot", ",", "e", ",", 
      "xor", ",", "yor", ",", "cpf", ",", "sf", ",", "cf", ",", "f", ",", 
      "cp", ",", "ce", ",", "se", ",", "cpdeg", ",", "ea", ",", "ma", ",", 
      "lam"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "t", ",", " ", "x", ",", " ", "y", ",", " ", "xd", ",", " ", "yd"}], 
       "}"}], " ", "=", " ", "tposvel"}], ";", 
     RowBox[{"ct", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"st", " ", "=", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"rx", " ", "=", " ", 
      RowBox[{
       RowBox[{"ct", "*", "x"}], "-", 
       RowBox[{"st", "*", "y"}]}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"ry", " ", "=", " ", 
      RowBox[{
       RowBox[{"st", "*", "x"}], "+", 
       RowBox[{"ct", "*", "y"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r2", " ", "=", " ", 
      RowBox[{
       RowBox[{"x", "*", "x"}], "+", 
       RowBox[{"y", "*", "y"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"r", " ", "=", " ", 
      RowBox[{"Sqrt", "[", "r2", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vx", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xd", "-", "y"}], ")"}], "*", "ct"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"yd", "+", "x"}], ")"}], "*", "st"}]}]}], ";", 
     RowBox[{"vy", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xd", "-", "y"}], ")"}], "*", "st"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"yd", "+", "x"}], ")"}], "*", "ct"}]}]}], ";", 
     RowBox[{"v2", " ", "=", " ", 
      RowBox[{
       RowBox[{"vx", "*", "vx"}], " ", "+", " ", 
       RowBox[{"vy", "*", "vy"}]}]}], ";", 
     RowBox[{"v", " ", "=", " ", 
      RowBox[{"Sqrt", "[", "v2", "]"}]}], ";", 
     RowBox[{"a", " ", "=", " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "/", "r"}], " ", "-", " ", 
         RowBox[{"v2", "/", "mu1"}]}], ")"}]}]}], ";", 
     RowBox[{"h", " ", "=", " ", 
      RowBox[{
       RowBox[{"rx", "*", "vy"}], " ", "-", " ", 
       RowBox[{"ry", "*", "vx"}]}]}], ";", 
     RowBox[{"h2", " ", "=", " ", 
      RowBox[{"h", "*", "h"}]}], ";", 
     RowBox[{"rdot", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"rx", "*", "vx"}], "+", 
         RowBox[{"ry", "*", "vy"}]}], ")"}], "/", "r"}]}], ";", 
     RowBox[{"e", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"h2", "/", "mu1"}], "/", "a"}]}], "]"}]}], ";", 
     RowBox[{"cpf", " ", "=", " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"rx", ",", " ", "ry"}], "]"}]}], ";", 
     RowBox[{"cf", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"e", "*", "e"}]}], ")"}], "/", "r"}]}], "-", "1"}], 
        ")"}], "/", "e"}]}], ";", 
     RowBox[{"sf", " ", "=", " ", 
      RowBox[{"a", "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"e", "*", "e"}]}], ")"}], "*", 
       RowBox[{
        RowBox[{"rdot", "/", "h"}], "/", "e"}]}]}], ";", 
     RowBox[{"f", " ", "=", " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"cf", ",", " ", "sf"}], "]"}]}], ";", 
     RowBox[{"cp", " ", "=", " ", 
      RowBox[{"cpf", " ", "-", " ", "f"}]}], ";", 
     RowBox[{"cpdeg", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"cp", "/", "Degree"}], "]"}]}], ";", 
     RowBox[{"cpdeg", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{"cpdeg", ",", " ", "360"}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"cpdeg", " ", "<", " ", "0"}], ",", " ", 
       RowBox[{"cpdeg", " ", "=", " ", 
        RowBox[{"cpdeg", " ", "+", " ", "360"}]}]}], "]"}], ";", 
     RowBox[{"ce", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"r", "/", "a"}]}], ")"}], "/", "e"}]}], ";", 
     RowBox[{"se", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "*", 
         RowBox[{"rdot", "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"mu1", "*", "a"}], "]"}]}]}], ")"}], "/", "e"}]}], ";", 
     RowBox[{"ea", " ", "=", " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"ce", ",", "se"}], "]"}]}], ";", 
     RowBox[{"ma", " ", "=", " ", 
      RowBox[{"ea", " ", "-", " ", 
       RowBox[{"e", "*", 
        RowBox[{"Sin", "[", "ea", "]"}]}]}]}], ";", 
     RowBox[{"lam", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ma", "+", "cp"}], ")"}], "/", "Degree"}], "]"}], ",", " ",
         "360"}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"lam", " ", "<", " ", "0"}], ",", " ", 
       RowBox[{"lam", " ", "=", " ", 
        RowBox[{"lam", " ", "+", " ", "360"}]}]}], "]"}], ";", 
     RowBox[{"{", 
      RowBox[{"t", ",", "a", ",", "e", ",", "cpdeg", ",", "lam"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.880436703820685*^9, 3.880436703832116*^9}, {
  3.880444039428233*^9, 3.880444288081476*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"c0b4869e-7e92-42d1-bde3-9b80b551156c"],

Cell[TextData[{
 "Define the function ",
 StyleBox["xy2ae", "Input"],
 " to calculate the value of the position and velocity in the rotating frame \
from given values of the semi-major axis, eccentricity, longitude of periapse \
and mean longitude."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.880443639509601*^9}, {3.880443698640009*^9, 
  3.880443781275136*^9}, {3.880443832846168*^9, 3.880443850933923*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"223874b6-2d96-4b96-96f8-67cdd09b0246"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ae2xy", "[", 
   RowBox[{"mu_", ",", " ", "elements_List"}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", " ", "=", " ", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", "t", ",", " ", "a", ",", " ", 
      "e", ",", " ", "cpd", ",", " ", "lamd", ",", " ", "cp", ",", "lam", ",",
       "n", ",", "ma", ",", "ea", ",", "rx", ",", "ry", ",", "r", ",", "ccp", 
      ",", "scp", ",", "eca", ",", "cea", ",", "sea", ",", "xdz", ",", "ydz", 
      ",", "xdi", ",", "ydi", ",", "ct", ",", "st", ",", "fe", ",", "x", ",", 
      "y", ",", "xd", ",", "yd", ",", "xi", ",", "yi"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "t", ",", " ", "a", ",", " ", "e", ",", " ", "cpd", ",", " ", "lamd"}],
        "}"}], " ", "=", " ", "elements"}], ";", 
     RowBox[{"ct", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"st", " ", "=", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"fe", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{"e", "^", "2"}]}], "]"}]}], ";", 
     RowBox[{"cp", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"cpd", "*", "Degree"}], "]"}]}], ";", 
     RowBox[{"ccp", " ", "=", " ", 
      RowBox[{"Cos", "[", "cp", "]"}]}], ";", 
     RowBox[{"scp", " ", "=", " ", 
      RowBox[{"Sin", "[", "cp", "]"}]}], ";", 
     RowBox[{"lam", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"lamd", "*", "Degree"}], "]"}]}], ";", 
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"mu1", "/", 
        RowBox[{"a", "^", "3"}]}], "]"}]}], ";", 
     RowBox[{"ma", " ", "=", " ", 
      RowBox[{"lam", "-", "cp"}]}], ";", 
     RowBox[{"eca", " ", "=", " ", 
      RowBox[{"ea", " ", "/.", " ", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ea", " ", "-", " ", 
           RowBox[{"e", " ", 
            RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "ma"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{"ea", ",", "ma"}], "}"}]}], "]"}]}]}], ";", 
     RowBox[{"cea", " ", "=", " ", 
      RowBox[{"Cos", "[", "eca", "]"}]}], ";", 
     RowBox[{"sea", " ", "=", " ", 
      RowBox[{"Sin", "[", "eca", "]"}]}], ";", 
     RowBox[{"rx", " ", "=", " ", 
      RowBox[{"a", "*", 
       RowBox[{"(", 
        RowBox[{"cea", "-", "e"}], ")"}]}]}], ";", 
     RowBox[{"ry", " ", "=", " ", 
      RowBox[{"a", "*", "fe", "*", "sea"}]}], ";", 
     RowBox[{"r", "  ", "=", " ", 
      RowBox[{"a", "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"e", "*", "cea"}]}], ")"}]}]}], ";", 
     RowBox[{"xdz", " ", "=", 
      RowBox[{
       RowBox[{"-", "n"}], "*", "a", "*", "a", "*", 
       RowBox[{"sea", "/", "r"}]}]}], ";", 
     RowBox[{"ydz", " ", "=", " ", 
      RowBox[{"n", "*", "a", "*", "a", "*", "fe", "*", 
       RowBox[{"cea", "/", "r"}]}]}], ";", 
     RowBox[{"xdi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"xdz", "*", "ccp"}], "-", 
       RowBox[{"ydz", "*", "scp"}]}]}], ";", 
     RowBox[{"ydi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"xdz", "*", "scp"}], "+", 
       RowBox[{"ydz", "*", "ccp"}]}]}], ";", 
     RowBox[{"xi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"rx", "*", "ccp"}], "-", 
       RowBox[{"ry", "*", "scp"}]}]}], ";", 
     RowBox[{"yi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"rx", "*", "scp"}], "+", 
       RowBox[{"ry", "*", "ccp"}]}]}], ";", 
     RowBox[{"x", " ", "=", "  ", 
      RowBox[{
       RowBox[{"xi", "*", "ct"}], "+", 
       RowBox[{"yi", "*", "st"}]}]}], ";", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "xi"}], "*", "st"}], "+", 
       RowBox[{"yi", "*", "ct"}]}]}], ";", 
     RowBox[{"xd", " ", "=", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xdi", "+", "yi"}], ")"}], "*", "ct"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ydi", "-", "xi"}], ")"}], "*", "st"}]}]}], ";", 
     RowBox[{"yd", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"xdi", "+", "yi"}], ")"}]}], "*", "st"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ydi", "-", "xi"}], ")"}], "*", "ct"}]}]}], ";", 
     RowBox[{"{", 
      RowBox[{"t", ",", "x", ",", "y", ",", "xd", ",", "yd"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.8804367165207033`*^9, 3.8804367165323687`*^9}, {
   3.8804444671821413`*^9, 3.880444657453745*^9}, 3.8804467123161383`*^9, {
   3.8804468135539017`*^9, 3.880446814450247*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"84b57475-adc6-480c-86a4-a72be2939c5d"],

Cell[TextData[{
 "Define the function ",
 StyleBox["CRTBPPosVel", "Input"],
 " to solve the planar circular restricted three-body problem for a given \
mass ",
 StyleBox["mu",
  FontSlant->"Italic"],
 ", initial position (",
 StyleBox["x0,y0",
  FontSlant->"Italic"],
 "), initial velocity (",
 StyleBox["xd0,yd0",
  FontSlant->"Italic"],
 ") (both in the rotating frame) for ",
 StyleBox["norb",
  FontSlant->"Italic"],
 " orbits times with ",
 StyleBox["npo",
  FontSlant->"Italic"],
 " output steps per orbit."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3de7be5c-01b7-4a05-8332-3a9f5efc9ed0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CRTBPPosVel", "[", 
   RowBox[{"mu_", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", " ", "y0_", ",", " ", "xd0_", ",", " ", "yd0_"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"norb_", ",", "npo_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"dt", "=", 
      RowBox[{"2", "*", 
       RowBox[{"Pi", "/", "npo"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"output", "=", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0", ",", "x0", ",", "y0", ",", "xd0", ",", "yd0"}], "}"}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "==", "1"}], ",", " ", 
          RowBox[{"start", "=", 
           RowBox[{"{", 
            RowBox[{"x0", ",", "y0", ",", "xd0", ",", "yd0"}], "}"}]}], ",", 
          " ", 
          RowBox[{"start", "=", "final"}]}], "]"}], ";", 
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"CRTBP", "[", 
          RowBox[{"mu", ",", " ", "start", ",", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}], ";", 
        RowBox[{"pv", " ", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"N", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x", "[", "t", "]"}], ",", " ", 
                RowBox[{"y", "[", "t", "]"}], ",", " ", 
                RowBox[{"xd", "[", "t", "]"}], ",", " ", 
                RowBox[{"yd", "[", "t", "]"}]}], "}"}], " ", "/.", " ", 
              "sol"}], "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"t", ",", " ", "0", ",", " ", 
             RowBox[{"2", "*", "Pi"}], ",", " ", "dt"}], "}"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"tpv", "=", "\[IndentingNewLine]", 
         RowBox[{"Transpose", "[", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"N", "[", "tp", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"tp", ",", 
                 RowBox[{"i", "-", "1"}], ",", "i", ",", 
                 RowBox[{"1", "/", "npo"}]}], "}"}]}], "]"}], "}"}], ",", 
            RowBox[{"Transpose", "[", "pv", "]"}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"output", "=", 
         RowBox[{"Join", "[", 
          RowBox[{"output", ",", " ", 
           RowBox[{"Drop", "[", 
            RowBox[{"tpv", ",", "1"}], "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"final", "=", 
         RowBox[{"Last", "[", "pv", "]"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "norb"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.880444671779043*^9, 3.880444777809566*^9}, {
  3.8804448123427763`*^9, 3.880444849582966*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"b96eb8de-4e05-4c8d-afc2-3902b3ff9ddb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"abox", " ", "=", " ", 
   RowBox[{"Line", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0.6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "0.6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "0.65"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.65"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.6"}], "}"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ares", " ", "=", " ", 
   RowBox[{"Line", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0.629961"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "0.629961"}], "}"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ebox", " ", "=", " ", 
   RowBox[{"Line", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "0.2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"cbox", " ", "=", " ", 
   RowBox[{"Line", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "360"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "360"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"pbox", " ", "=", " ", 
   RowBox[{"Line", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"-", "180"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", 
        RowBox[{"-", "180"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "180"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "180"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"-", "180"}]}], "}"}]}], "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.880438389324473*^9, 3.8804383893291903`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"07d5c0b6-c0f5-4175-8546-02adb5b9e0e6"],

Cell["Define the colour to be used for most of the contour lines.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8796757140272903`*^9, 3.8796757215269403`*^9}, {
   3.879675794112597*^9, 3.879675838798218*^9}, {3.8796758775878773`*^9, 
   3.87967591334838*^9}, 3.88027514163352*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"29c058af-db45-4739-a260-c62e35f9363b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"color1", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.880275131151478*^9, 3.880275132885696*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"c5778ee3-fb34-48e3-aa9e-efbac61e0c0e"],

Cell["Define the various labels to be used in the plots.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8796757140272903`*^9, 3.8796757215269403`*^9}, {
   3.879675794112597*^9, 3.879675838798218*^9}, {3.8796758775878773`*^9, 
   3.87967591334838*^9}, 3.88027514163352*^9, {3.8804571501364813`*^9, 
   3.8804571642808027`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"dee8a1dc-cd5c-4e82-be18-ba1bcd9a0b74"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<Time (Jupiter Periods)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabela", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
StyleBox[\"a\", \"TI\"], TraditionalForm], \"errors\" -> {}, \"input\" -> \"a\
\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "ylabele", "=", "\"\<\!\(\*StyleBox[\"e\",FontSlant->\"Italic\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "ylabelcp", "=", 
   "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[\"\[CurlyPi]\", \
TraditionalForm], \"errors\" -> {}, \"input\" -> \"\\\\varpi\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "ylabel\[CurlyPhi]", "=", 
   "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[\"\[CurlyPhi]\", \
TraditionalForm], \"errors\" -> {}, \"input\" -> \"\\\\varphi\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "xylabelx", "=", "\"\<\!\(\*StyleBox[\"x\",FontSlant->\"Italic\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "xylabely", "=", "\"\<\!\(\*StyleBox[\"y\",FontSlant->\"Italic\"]\)\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.880019503560896*^9, 3.880019506514798*^9}, {
  3.880447643640024*^9, 3.880447673579129*^9}, {3.880447706548963*^9, 
  3.88044771524949*^9}, {3.8804490313967943`*^9, 3.880449114074347*^9}, {
  3.880449195884664*^9, 3.8804491965733337`*^9}, {3.880457101542034*^9, 
  3.880457128807226*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"4ebe036c-3111-4e98-8435-980f046c97aa"],

Cell["\<\
Define the line for the exact resonance in the semi-major axis plot and the \
axes to be used in the x-y plots.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8796757140272903`*^9, 3.8796757215269403`*^9}, {
   3.879675794112597*^9, 3.879675838798218*^9}, {3.8796758775878773`*^9, 
   3.87967591334838*^9}, 3.88027514163352*^9, {3.8804571501364813`*^9, 
   3.8804571642808027`*^9}, {3.880459320959195*^9, 3.880459352309457*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c3378004-4b37-441e-8ebe-9a77ac1f8582"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ares", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"Dashed", ",", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0.629961"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"100", ",", "0.629961"}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"axesprolog", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Thickness", "[", "0.002", "]"}], ",", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "4"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}]}], "}"}], "]"}], ",", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.8804531802045307`*^9, 3.880453186160952*^9}, {
  3.8804533329381037`*^9, 3.880453335606188*^9}, {3.880453485113776*^9, 
  3.8804534901345177`*^9}, {3.880459284830727*^9, 3.8804593071901283`*^9}, {
  3.880459422739668*^9, 3.8804594519849977`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"056d257e-5c90-41d5-a339-c55794f61cc9"],

Cell["\<\
Set up the initial conditions for the six representative orbits.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
  3.880456541282578*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"999f0430-e7cc-4de1-b06b-b957e2990b03"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Almost", " ", "exact", " ", "2"}], ":", 
    RowBox[{"1", " ", "pericentric", " ", "resonance"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"init1", "=", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", " ", "0.625277", ",", " ", "0.128386", ",", " ", "0", ",", 
       " ", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"2", ":", 
     RowBox[{
     "1", " ", "resonance", " ", "medium", " ", "libration", " ", 
      "amplitude"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init2", "=", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", " ", "0.633424", ",", " ", "0.0725011", ",", " ", "0", ",", 
       " ", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"2", ":", 
     RowBox[{
     "1", " ", "resonance", " ", "large", " ", "libration", " ", 
      "amplitude"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init3", "=", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", " ", "0.637837", ",", " ", "0.0122862", ",", " ", "0", ",", 
       " ", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"2", ":", 
     RowBox[{"1", " ", "resonance", " ", "apocentric", " ", "libration"}]}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init4", "=", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", " ", "0.636705", ",", " ", "0.060146", ",", " ", "180", ",", 
       " ", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"2", ":", 
     RowBox[{"1", " ", "resonance", " ", "inner", " ", "circulation"}]}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init5", "=", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", " ", "0.638222", ",", " ", "0.0184545", ",", " ", "180", ",", 
       " ", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"2", ":", 
     RowBox[{"1", " ", "resonance", " ", "outer", " ", "circulation"}]}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init6", "=", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", " ", "0.610592", ",", " ", "0.1975", ",", " ", "0", ",", " ", 
       "0"}], "}"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.880453540011634*^9, 3.880453542620631*^9}, {
  3.880453576580188*^9, 3.880453625841289*^9}, {3.880453698589905*^9, 
  3.880453900684451*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"d1f01ac7-92a0-4ed0-b897-6ad99d3e9a9b"],

Cell["\<\
Check that they all have the same Jacobi constant ( = 3.163).\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
  3.880456577237422*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2e8a5990-ee2e-4c3a-b633-c1093c1610fe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Jacobi", "[", 
     RowBox[{"0.001", ",", 
      RowBox[{"Drop", "[", 
       RowBox[{
        RowBox[{"ae2xy", "[", 
         RowBox[{"0.001", ",", "#"}], "]"}], ",", "1"}], "]"}]}], "]"}], 
    "&"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "init1", ",", "init2", ",", "init3", ",", "init4", ",", "init5", ",", 
     "init6"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.880455061286441*^9, 3.8804551003444347`*^9}, {
   3.880455293140398*^9, 3.8804553119500513`*^9}, {3.88045540307687*^9, 
   3.880455455752944*^9}, 3.8804555007008247`*^9, {3.88045569241615*^9, 
   3.88045570109778*^9}, {3.8804557447031927`*^9, 3.880455745046961*^9}, {
   3.880455790858267*^9, 3.88045579525918*^9}, {3.880455831028957*^9, 
   3.880455843747635*^9}, {3.880455997304944*^9, 3.88045604072897*^9}, {
   3.880456314227867*^9, 3.880456385371722*^9}, {3.880456435802354*^9, 
   3.880456469432315*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"9b52191a-b163-4099-856a-ef8c39ac1938"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.162999612504894`", ",", "3.1629998758827895`", ",", 
   "3.1629995161426834`", ",", "3.1629996812559495`", ",", 
   "3.162999894815563`", ",", "3.1630004966422036`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.880455796112317*^9, {3.880455834876738*^9, 3.880455850093213*^9}, 
   3.880456042147908*^9, {3.880456323924067*^9, 3.88045638619387*^9}, {
   3.880456437387403*^9, 3.880456470671702*^9}, 3.880460506549612*^9, 
   3.880464063909316*^9, 3.880464205807282*^9, 3.880612706703063*^9, 
   3.880612962756578*^9, 3.880613094060096*^9, 3.880655514504752*^9, 
   3.88070273419705*^9, 3.880703449668316*^9, 3.890982075484326*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"6459a239-5e55-4a7c-a2a0-d87ff1183dbc"]
}, Open  ]],

Cell[TextData[{
 "Define a function ",
 StyleBox["FourPlot", "Input"],
 " that will produce a column of four plots containing ",
 StyleBox["a",
  FontSlant->"Italic"],
 " vs. ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", ",
 StyleBox["e",
  FontSlant->"Italic"],
 " vs ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", ",
 StyleBox["cp",
  FontSlant->"Italic"],
 " vs ",
 StyleBox["t",
  FontSlant->"Italic"],
 " and ",
 StyleBox["phi",
  FontSlant->"Italic"],
 " vs ",
 StyleBox["t",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
  3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f96eaf5b-d36c-4e2f-8b57-d3230c47d601"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FourPlot", "[", 
   RowBox[{"\[Mu]_", ",", "initial_List", ",", "norb_", ",", "npo_"}], "]"}], 
  ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "starting", ",", "data", ",", "tdata", ",", "time", ",", "a", ",", "e", 
      ",", "cp", ",", "lam", ",", "phi", ",", "aplot", ",", "eplot", ",", 
      "cpplot", ",", "phiplot", ",", "ares", ",", "xydata"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"starting", "=", 
      RowBox[{"ae2xy", "[", 
       RowBox[{"\[Mu]", ",", " ", "initial"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"data", "=", "\[IndentingNewLine]", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"xy2ae", "[", 
          RowBox[{"\[Mu]", ",", " ", "#"}], "]"}], "&"}], ",", " ", 
        RowBox[{"CRTBPPosVel", "[", 
         RowBox[{"\[Mu]", ",", " ", 
          RowBox[{"Drop", "[", 
           RowBox[{"starting", ",", "1"}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"norb", ",", " ", "npo"}], "}"}]}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tdata", "  ", "=", " ", 
      RowBox[{"Transpose", "[", "data", "]"}]}], ";", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "time", ",", " ", "a", ",", " ", "e", ",", " ", "cp", ",", " ", 
        "lam"}], "}"}], "=", "tdata"}], ";", 
     RowBox[{"phi", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", "*", "time", "*", "360"}], "-", "lam", "-", "cp"}], ",",
         "360"}], "]"}]}], ";", 
     RowBox[{"phi", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"#", ">", "180"}], ",", " ", 
           RowBox[{"#", "-", "360"}], ",", " ", "#"}], "]"}], "&"}], ",", " ",
         "phi"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ares", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0.629961"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"norb", ",", "0.629961"}], "}"}]}], "}"}], "]"}]}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"aplot", "=", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"time", ",", "a"}], "}"}], "]"}], ",", 
        RowBox[{"Prolog", "->", "ares"}], ",", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "norb"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.6", ",", "0.65"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameLabel", "->", 
         RowBox[{"{", 
          RowBox[{"xlabel", ",", 
           RowBox[{"Rotate", "[", 
            RowBox[{"ylabela", ",", 
             RowBox[{
              RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
        RowBox[{"PlotStyle", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "color1"}], 
          "}"}]}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
        RowBox[{"FrameTicks", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0.6", ",", "0.62", ",", "0.64"}], "}"}], ",", "None"}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameStyle", "->", 
         RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
        RowBox[{"Frame", "->", "True"}], ",", 
        RowBox[{"AspectRatio", "->", "0.2"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"eplot", "=", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"time", ",", "e"}], "}"}], "]"}], ",", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "norb"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0.2"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameLabel", "->", 
         RowBox[{"{", 
          RowBox[{"xlabel", ",", 
           RowBox[{"Rotate", "[", 
            RowBox[{"ylabele", ",", 
             RowBox[{
              RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
        RowBox[{"PlotStyle", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "color1"}], 
          "}"}]}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
        RowBox[{"FrameTicks", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0.1", ",", "0.2"}], "}"}], ",", "None"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameStyle", "->", 
         RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
        RowBox[{"Frame", "->", "True"}], ",", 
        RowBox[{"AspectRatio", "->", "0.2"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cpplot", "=", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"time", ",", "cp"}], "}"}], "]"}], ",", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "norb"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "360"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameLabel", "->", 
         RowBox[{"{", 
          RowBox[{"xlabel", ",", 
           RowBox[{"Rotate", "[", 
            RowBox[{"ylabelcp", ",", 
             RowBox[{
              RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
        RowBox[{"PlotStyle", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "color1"}], 
          "}"}]}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
        RowBox[{"FrameTicks", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "180", ",", "360"}], "}"}], ",", "None"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameStyle", "->", 
         RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
        RowBox[{"Frame", "->", "True"}], ",", 
        RowBox[{"AspectRatio", "->", "0.2"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"phiplot", "=", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"time", ",", "phi"}], "}"}], "]"}], ",", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "norb"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "180"}], ",", "180"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameLabel", "->", 
         RowBox[{"{", 
          RowBox[{"xlabel", ",", 
           RowBox[{"Rotate", "[", 
            RowBox[{"ylabel\[CurlyPhi]", ",", 
             RowBox[{
              RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
        RowBox[{"PlotStyle", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "color1"}], 
          "}"}]}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
        RowBox[{"FrameTicks", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "180"}], ",", "0", ",", "180"}], "}"}], ",", 
             "None"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameStyle", "->", 
         RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
        RowBox[{"Frame", "->", "True"}], ",", 
        RowBox[{"AspectRatio", "->", "0.2"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gc", "=", "\[IndentingNewLine]", 
      RowBox[{"GraphicsColumn", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"aplot", ",", "eplot", ",", "cpplot", ",", "phiplot"}], 
         "}"}], ",", 
        RowBox[{"Spacings", "->", "5"}], ",", 
        RowBox[{"ImageSize", "->", "Medium"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xydata", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"15.874", "*", "e", "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"phi", "*", "Degree"}], "]"}]}], ",", 
         RowBox[{"15.874", "*", "e", "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"phi", "*", "Degree"}], "]"}]}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xyplot", "=", "\[IndentingNewLine]", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"xydata", ",", "\[IndentingNewLine]", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Prolog", "->", "axesprolog"}], ",", 
        RowBox[{"FrameStyle", "->", 
         RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
        RowBox[{"Frame", "->", "True"}], ",", 
        RowBox[{"FrameLabel", "->", 
         RowBox[{"{", 
          RowBox[{"xylabelx", ",", 
           RowBox[{"Rotate", "[", 
            RowBox[{"xylabely", ",", 
             RowBox[{
              RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", "\n", "\t", 
        
        RowBox[{"AspectRatio", "->", "1"}], ",", 
        RowBox[{"Frame", "->", "True"}]}], "]"}]}], ";"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.880450656839304*^9, 3.880450661130259*^9}, {
   3.880450713323015*^9, 3.8804509051701307`*^9}, {3.880450993835266*^9, 
   3.880451084674034*^9}, {3.8804513912566137`*^9, 3.8804514446859083`*^9}, {
   3.8804515870493107`*^9, 3.880451629993454*^9}, {3.880451674827641*^9, 
   3.880452050805933*^9}, 3.880452149629677*^9, {3.880452564033949*^9, 
   3.880452610415131*^9}, {3.880452859812169*^9, 3.880452860648061*^9}, {
   3.880452934602398*^9, 3.880452937778243*^9}, 3.8804530493362827`*^9, {
   3.8804533895962553`*^9, 3.8804534553227262`*^9}, {3.8804568270288467`*^9, 
   3.8804569203222218`*^9}, {3.8804569532185173`*^9, 3.8804570867791653`*^9}, 
   3.8804572030053864`*^9, 3.8804572521064262`*^9, {3.880457355146224*^9, 
   3.88045735595079*^9}, {3.880458897262746*^9, 3.880458939975383*^9}, {
   3.880459018641618*^9, 3.880459029225855*^9}, {3.880459465792942*^9, 
   3.8804594776974297`*^9}, {3.8806126711521797`*^9, 
   3.8806126906515827`*^9}, {3.880612754038629*^9, 3.88061286164788*^9}, {
   3.880612903109145*^9, 3.8806129225186462`*^9}, 3.880613151646501*^9},
 CellLabel->"In[28]:=",ExpressionUUID->"51350a2c-8804-4876-af07-cbce72caeda8"],

Cell[TextData[{
 "Define a function ",
 StyleBox["FourPlotNoLabel", "Input"],
 " that will produce a column of four plots containing ",
 StyleBox["a",
  FontSlant->"Italic"],
 " vs. ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", ",
 StyleBox["e",
  FontSlant->"Italic"],
 " vs ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", ",
 StyleBox["cp",
  FontSlant->"Italic"],
 " vs ",
 StyleBox["t",
  FontSlant->"Italic"],
 " and ",
 StyleBox["phi",
  FontSlant->"Italic"],
 " vs ",
 StyleBox["t",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
  3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
  3.880462929743149*^9, 3.880462931722725*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7ea46e4e-cf88-4175-966b-c837cc36ba20"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FourPlotNoLabel", "[", 
   RowBox[{"\[Mu]_", ",", "initial_List", ",", "norb_", ",", "npo_"}], "]"}], 
  ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "starting", ",", "data", ",", "tdata", ",", "time", ",", "a", ",", "e", 
      ",", "cp", ",", "lam", ",", "phi", ",", "aplot", ",", "eplot", ",", 
      "cpplot", ",", "phiplot", ",", "ares", ",", "xydata"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"starting", "=", 
      RowBox[{"ae2xy", "[", 
       RowBox[{"\[Mu]", ",", " ", "initial"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"data", "=", "\[IndentingNewLine]", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"xy2ae", "[", 
          RowBox[{"\[Mu]", ",", " ", "#"}], "]"}], "&"}], ",", " ", 
        RowBox[{"CRTBPPosVel", "[", 
         RowBox[{"\[Mu]", ",", " ", 
          RowBox[{"Drop", "[", 
           RowBox[{"starting", ",", "1"}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"norb", ",", " ", "npo"}], "}"}]}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tdata", "  ", "=", " ", 
      RowBox[{"Transpose", "[", "data", "]"}]}], ";", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "time", ",", " ", "a", ",", " ", "e", ",", " ", "cp", ",", " ", 
        "lam"}], "}"}], "=", "tdata"}], ";", 
     RowBox[{"phi", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", "*", "time", "*", "360"}], "-", "lam", "-", "cp"}], ",",
         "360"}], "]"}]}], ";", 
     RowBox[{"phi", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"#", ">", "180"}], ",", " ", 
           RowBox[{"#", "-", "360"}], ",", " ", "#"}], "]"}], "&"}], ",", " ",
         "phi"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ares", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0.629961"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"norb", ",", "0.629961"}], "}"}]}], "}"}], "]"}]}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"aplot", " ", "=", " ", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.006", "]"}], ",", "abox", ",", " ", 
           "ares", ",", "color1", ",", 
           RowBox[{"Map", "[", 
            RowBox[{"Point", ",", 
             RowBox[{"Transpose", "[", 
              RowBox[{"{", 
               RowBox[{"time", ",", "a"}], "}"}], "]"}]}], "]"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "norb"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.6", ",", "0.65"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AspectRatio", "->", "0.2"}], ",", 
        RowBox[{"Prolog", "->", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
StyleBox[\"a\", \"TI\"], TraditionalForm], \"errors\" -> {}, \"input\" -> \"a\
\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "0.61"}], "}"}]}], "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"eplot", "=", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.006", "]"}], ",", "ebox", ",", " ", 
           "color1", ",", 
           RowBox[{"Map", "[", 
            RowBox[{"Point", ",", 
             RowBox[{"Transpose", "[", 
              RowBox[{"{", 
               RowBox[{"time", ",", "e"}], "}"}], "]"}]}], "]"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "norb"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0.2"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AspectRatio", "->", "0.2"}], ",", 
        RowBox[{"Prolog", "->", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
StyleBox[\"e\", \"TI\"], TraditionalForm], \"errors\" -> {}, \"input\" -> \"e\
\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "0.03"}], "}"}]}], "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cpplot", "=", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.006", "]"}], ",", "cbox", ",", 
           "color1", ",", 
           RowBox[{"Map", "[", 
            RowBox[{"Point", ",", 
             RowBox[{"Transpose", "[", 
              RowBox[{"{", 
               RowBox[{"time", ",", "cp"}], "}"}], "]"}]}], "]"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "norb"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "360"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AspectRatio", "->", "0.2"}], ",", 
        RowBox[{"Prolog", "->", 
         RowBox[{"Text", "[", 
          RowBox[{
          "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[\"\[CurlyPi]\", \
TraditionalForm], \"errors\" -> {}, \"input\" -> \"\\\\varpi\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "40"}], "}"}]}], "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"phiplot", "=", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.006", "]"}], ",", "pbox", ",", 
           "color1", ",", 
           RowBox[{"Map", "[", 
            RowBox[{"Point", ",", 
             RowBox[{"Transpose", "[", 
              RowBox[{"{", 
               RowBox[{"time", ",", "phi"}], "}"}], "]"}]}], "]"}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"PlotRange", "->", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "norb"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "180"}], ",", "180"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AspectRatio", "->", "0.2"}], ",", 
        RowBox[{"Prolog", "->", 
         RowBox[{"Text", "[", 
          RowBox[{
          "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[\"\[CurlyPhi]\", \
TraditionalForm], \"errors\" -> {}, \"input\" -> \"\\\\varphi\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", 
             RowBox[{"-", "140"}]}], "}"}]}], "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gcNL", "=", "\[IndentingNewLine]", 
      RowBox[{"GraphicsColumn", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"aplot", ",", "eplot", ",", "cpplot", ",", "phiplot"}], 
         "}"}], ",", 
        RowBox[{"Spacings", "->", "10"}], ",", 
        RowBox[{"ImageSize", "->", "Medium"}]}], "]"}]}], ";"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.880450656839304*^9, 3.880450661130259*^9}, {
   3.880450713323015*^9, 3.8804509051701307`*^9}, {3.880450993835266*^9, 
   3.880451084674034*^9}, {3.8804513912566137`*^9, 3.8804514446859083`*^9}, {
   3.8804515870493107`*^9, 3.880451629993454*^9}, {3.880451674827641*^9, 
   3.880452050805933*^9}, 3.880452149629677*^9, {3.880452564033949*^9, 
   3.880452610415131*^9}, {3.880452859812169*^9, 3.880452860648061*^9}, {
   3.880452934602398*^9, 3.880452937778243*^9}, 3.8804530493362827`*^9, {
   3.8804533895962553`*^9, 3.8804534553227262`*^9}, {3.8804568270288467`*^9, 
   3.8804569203222218`*^9}, {3.8804569532185173`*^9, 3.8804570867791653`*^9}, 
   3.8804572030053864`*^9, 3.8804572521064262`*^9, {3.880457355146224*^9, 
   3.88045735595079*^9}, {3.880458897262746*^9, 3.880458939975383*^9}, {
   3.880459018641618*^9, 3.880459029225855*^9}, {3.880459465792942*^9, 
   3.8804594776974297`*^9}, {3.8804598071047*^9, 3.880459823275004*^9}, {
   3.8804598741264353`*^9, 3.880459925905016*^9}, {3.880459971670081*^9, 
   3.880459987405149*^9}, {3.880460076632617*^9, 3.880460161030492*^9}, {
   3.880460365486157*^9, 3.8804603741680927`*^9}, {3.880460554947536*^9, 
   3.880460583718471*^9}, {3.880460839487527*^9, 3.880461144535884*^9}, {
   3.880461223891447*^9, 3.880461272515841*^9}, {3.880461541816972*^9, 
   3.8804616563298597`*^9}, {3.880461689093554*^9, 3.880461689731454*^9}, {
   3.880461821422696*^9, 3.880461824269335*^9}, {3.880461859672903*^9, 
   3.8804619214352617`*^9}, {3.880461987351734*^9, 3.880462055715788*^9}, {
   3.88046208938094*^9, 3.8804622201620283`*^9}, {3.880462254381967*^9, 
   3.88046225974575*^9}, {3.880462301317058*^9, 3.880462434508238*^9}, {
   3.880462466404909*^9, 3.880462566657576*^9}, {3.880462600622629*^9, 
   3.880462601306921*^9}, {3.880613061269669*^9, 3.880613078520611*^9}, {
   3.880613200907832*^9, 3.880613225699382*^9}, {3.880613280691641*^9, 
   3.8806133617980833`*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"542bd733-4057-4d3f-b518-8aa7ffed0e11"],

Cell["\<\
Produce the four unlabelled plots for the case of almost exact 2:1 \
pericentric resonance.  This is Fig.8.16a.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
  3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
  3.88045916902036*^9, 3.8804592043930492`*^9}, {3.88061346634433*^9, 
  3.880613492878437*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"510f47db-ab8f-4014-873c-c0e9edb444bb"],

Cell[BoxData[
 RowBox[{"FourPlotNoLabel", "[", 
  RowBox[{"0.001", ",", " ", "init1", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.880460040412767*^9, 3.880460042482559*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"d211517e-2ab9-4462-aebb-16e1dddc70a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcNLA", "=", "gcNL"}]], "Input",
 CellChangeTimes->{{3.880460055074711*^9, 3.880460059012425*^9}, {
  3.880462628440155*^9, 3.880462629820891*^9}, {3.880463042571228*^9, 
  3.880463058694118*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"39f248e0-7118-42ec-8beb-2152bcb7bd59"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
       {Dashing[{Small, Small}], LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.625277}], 
        PointBox[{0.1, 0.6259686355768492}], 
        PointBox[{0.2, 0.6273736511909047}], 
        PointBox[{0.3, 0.6286463214910968}], 
        PointBox[{0.4, 0.6305881194588028}], 
        PointBox[{0.5, 0.6324190644307863}], 
        PointBox[{0.6, 0.6304147131346407}], 
        PointBox[{0.7, 0.6285475652174198}], 
        PointBox[{0.8, 0.6272874038475243}], 
        PointBox[{0.9, 0.6258619053669047}], 
        PointBox[{1., 0.625274000481498}], 
        PointBox[{1.1, 0.6260750036549589}], 
        PointBox[{1.2, 0.627456974714097}], 
        PointBox[{1.3, 0.6287467855779384}], 
        PointBox[{1.4, 0.6307641985069974}], 
        PointBox[{1.5, 0.6323872052968448}], 
        PointBox[{1.6, 0.6302448297672972}], 
        PointBox[{1.7, 0.6284497330106544}], 
        PointBox[{1.8, 0.627198251028428}], 
        PointBox[{1.9, 0.6257555695049932}], 
        PointBox[{2., 0.6252665572741121}], 
        PointBox[{2.1, 0.6261797143744898}], 
        PointBox[{2.2, 0.6275378683660486}], 
        PointBox[{2.3, 0.6288493235641331}], 
        PointBox[{2.4, 0.6309420300812095}], 
        PointBox[{2.5, 0.6323242724624056}], 
        PointBox[{2.6, 0.6300786655850195}], 
        PointBox[{2.7, 0.6283525386810321}], 
        PointBox[{2.8, 0.627104873384124}], 
        PointBox[{2.9, 0.6256517346763191}], 
        PointBox[{3., 0.6252586493441133}], 
        PointBox[{3.1, 0.6262823952057137}], 
        PointBox[{3.2, 0.6276172264461802}], 
        PointBox[{3.3, 0.6289551892157544}], 
        PointBox[{3.4, 0.6311205713632864}], 
        PointBox[{3.5, 0.6322333976857769}], 
        PointBox[{3.6, 0.6299171703718282}], 
        PointBox[{3.7, 0.6282559029370294}], 
        PointBox[{3.8, 0.6270081079227489}], 
        PointBox[{3.9, 0.6255528896735832}], 
        PointBox[{4., 0.6252550491238453}], 
        PointBox[{4.1, 0.6263823418878793}], 
        PointBox[{4.2, 0.627695136711139}], 
        PointBox[{4.3, 0.6290644909467883}], 
        PointBox[{4.4, 0.6312973810482354}], 
        PointBox[{4.5, 0.6321160594767278}], 
        PointBox[{4.6, 0.6297598156542259}], 
        PointBox[{4.7, 0.6281592323828662}], 
        PointBox[{4.8, 0.6269074725759244}], 
        PointBox[{4.9, 0.62546100834877}], PointBox[{5., 0.6252603426790695}],
         PointBox[{5.1, 0.6264793900579759}], 
        PointBox[{5.2, 0.6277721464914303}], 
        PointBox[{5.3, 0.6291778467164263}], 
        PointBox[{5.4, 0.6314708978167086}], 
        PointBox[{5.5, 0.6319755724564486}], 
        PointBox[{5.6, 0.6296066730706238}], 
        PointBox[{5.7, 0.6280622173118305}], 
        PointBox[{5.8, 0.6268030197281277}], 
        PointBox[{5.9, 0.6253791685995661}], 
        PointBox[{6., 0.6252783534559848}], 
        PointBox[{6.1, 0.6265737407216837}], 
        PointBox[{6.2, 0.627849341579742}], 
        PointBox[{6.3, 0.6292958393107106}], 
        PointBox[{6.4, 0.6316375082443112}], 
        PointBox[{6.5, 0.6318160208457897}], 
        PointBox[{6.6, 0.6294580040805438}], 
        PointBox[{6.7, 0.6279648888546501}], 
        PointBox[{6.8, 0.6266940136962417}], 
        PointBox[{6.9, 0.625309742340656}], 
        PointBox[{7., 0.6253107080216136}], 
        PointBox[{7.1, 0.626665471984743}], 
        PointBox[{7.2, 0.6279267577208097}], 
        PointBox[{7.3, 0.6294200825255885}], 
        PointBox[{7.4, 0.6317948569939642}], 
        PointBox[{7.5, 0.6316410781141532}], 
        PointBox[{7.6, 0.6293139640502387}], 
        PointBox[{7.7, 0.6278671140756245}], 
        PointBox[{7.8, 0.6265815102326335}], 
        PointBox[{7.9, 0.6252546024409925}], 
        PointBox[{8., 0.6253578099044653}], 
        PointBox[{8.1, 0.6267549641394836}], 
        PointBox[{8.2, 0.6280054656921639}], 
        PointBox[{8.3, 0.6295509591517437}], 
        PointBox[{8.4, 0.631938219095616}], 
        PointBox[{8.5, 0.6314545676573985}], 
        PointBox[{8.6, 0.6291740074518709}], 
        PointBox[{8.7, 0.6277687427540464}], 
        PointBox[{8.8, 0.6264651995814693}], 
        PointBox[{8.9, 0.6252149266815534}], 
        PointBox[{9., 0.6254189723683116}], 
        PointBox[{9.1, 0.626842607954492}], 
        PointBox[{9.2, 0.628085928408874}], 
        PointBox[{9.3, 0.6296887590745461}], 
        PointBox[{9.4, 0.6320645317575988}], 
        PointBox[{9.5, 0.6312600936953636}], 
        PointBox[{9.6, 0.6290383151594051}], 
        PointBox[{9.7, 0.6276696714567026}], 
        PointBox[{9.8, 0.6263459776564863}], 
        PointBox[{9.9, 0.6251893325713853}], 
        PointBox[{10., 0.6254925890149102}], 
        PointBox[{10.1, 0.626928646045456}], 
        PointBox[{10.2, 0.6281689164716623}], 
        PointBox[{10.3, 0.629834289093246}], 
        PointBox[{10.4, 0.6321694090111833}], 
        PointBox[{10.5, 0.6310609957889173}], 
        PointBox[{10.6, 0.6289068536365496}], 
        PointBox[{10.7, 0.6275702147273109}], 
        PointBox[{10.8, 0.6262234395974359}], 
        PointBox[{10.9, 0.625175901143655}], 
        PointBox[{11., 0.6255767714851413}], 
        PointBox[{11.1, 0.6270137809657017}], 
        PointBox[{11.2, 0.6282550620835429}], 
        PointBox[{11.3, 0.6299875098161969}], 
        PointBox[{11.4, 0.6322483171414873}], 
        PointBox[{11.5, 0.630860339373956}], 
        PointBox[{11.6, 0.6287794812286063}], 
        PointBox[{11.7, 0.6274697935335826}], 
        PointBox[{11.8, 0.6260994269208858}], 
        PointBox[{11.9, 0.6251696726730801}], 
        PointBox[{12., 0.6256694471476292}], 
        PointBox[{12.1, 0.6270985085272257}], 
        PointBox[{12.2, 0.6283451819751166}], 
        PointBox[{12.3, 0.6301499722011702}], 
        PointBox[{12.4, 0.6322993713783158}], 
        PointBox[{12.5, 0.6306607060988447}], 
        PointBox[{12.6, 0.6286565426914302}], 
        PointBox[{12.7, 0.6273690151176777}], 
        PointBox[{12.8, 0.625974549968986}], 
        PointBox[{12.9, 0.6251653588678281}], 
        PointBox[{13., 0.6257685810625101}], 
        PointBox[{13.1, 0.6271829022987121}], 
        PointBox[{13.2, 0.6284393662062034}], 
        PointBox[{13.3, 0.6303193083152657}], 
        PointBox[{13.4, 0.6323192366571178}], 
        PointBox[{13.5, 0.630464454501701}], 
        PointBox[{13.6, 0.6285374056893103}], 
        PointBox[{13.7, 0.6272677632625103}], 
        PointBox[{13.8, 0.6258506491218634}], 
        PointBox[{13.9, 0.6251587224988588}], 
        PointBox[{14., 0.6258727627617396}], 
        PointBox[{14.1, 0.62726795863325}], 
        PointBox[{14.2, 0.6285391723575467}], 
        PointBox[{14.3, 0.6304967138520198}], 
        PointBox[{14.4, 0.6323070254650416}], 
        PointBox[{14.5, 0.6302730495769632}], 
        PointBox[{14.6, 0.6284226388346422}], 
        PointBox[{14.7, 0.6271656972750363}], 
        PointBox[{14.8, 0.625729213143763}], 
        PointBox[{14.9, 0.6251484927867732}], 
        PointBox[{15., 0.6259802072392873}], 
        PointBox[{15.1, 0.6273538122618584}], 
        PointBox[{15.2, 0.6286445086140849}], 
        PointBox[{15.3, 0.6306806793300203}], 
        PointBox[{15.4, 0.6322627786357484}], 
        PointBox[{15.5, 0.6300878529751109}], 
        PointBox[{15.6, 0.6283115533652035}], 
        PointBox[{15.7, 0.6270630886625642}], 
        PointBox[{15.8, 0.6256123614824746}], 
        PointBox[{15.9, 0.6251373105198229}], 
        PointBox[{16., 0.6260897646240345}], 
        PointBox[{16.1, 0.6274405979226908}], 
        PointBox[{16.2, 0.6287561157587417}], 
        PointBox[{16.3, 0.6308697955186632}], 
        PointBox[{16.4, 0.6321875135321108}], 
        PointBox[{16.5, 0.6299099517715178}], 
        PointBox[{16.6, 0.6282043431883877}], 
        PointBox[{16.7, 0.6269600875357854}], 
        PointBox[{16.8, 0.625502987921274}], 
        PointBox[{16.9, 0.6251303060579813}], 
        PointBox[{17., 0.6262006678348218}], 
        PointBox[{17.1, 0.6275292641010294}], 
        PointBox[{17.2, 0.6288739318055966}], 
        PointBox[{17.3, 0.6310616044169929}], 
        PointBox[{17.4, 0.6320839635928415}], 
        PointBox[{17.5, 0.6297401815868618}], 
        PointBox[{17.6, 0.6281009004891499}], 
        PointBox[{17.7, 0.6268565073997816}], 
        PointBox[{17.8, 0.6254037176191488}], 
        PointBox[{17.9, 0.6251330176350186}], 
        PointBox[{18., 0.6263120840618176}], 
        PointBox[{18.1, 0.62761973172378}], 
        PointBox[{18.2, 0.6289987847763239}], 
        PointBox[{18.3, 0.6312539885919216}], 
        PointBox[{18.4, 0.631955652525127}], 
        PointBox[{18.5, 0.6295786599515121}], 
        PointBox[{18.6, 0.6280012241974309}], 
        PointBox[{18.7, 0.6267522949674393}], 
        PointBox[{18.8, 0.6253176133601422}], 
        PointBox[{18.9, 0.6251509628284566}], 
        PointBox[{19., 0.6264233845836157}], 
        PointBox[{19.1, 0.6277123742414249}], 
        PointBox[{19.2, 0.6291314255446108}], 
        PointBox[{19.3, 0.6314429668861975}], 
        PointBox[{19.4, 0.6318066528444785}], 
        PointBox[{19.5, 0.6294257511543231}], 
        PointBox[{19.6, 0.627904919181402}], 
        PointBox[{19.7, 0.6266478128162255}], 
        PointBox[{19.8, 0.6252474279325356}], 
        PointBox[{19.9, 0.6251874391619241}], 
        PointBox[{20., 0.6265342833185197}], 
        PointBox[{20.1, 0.6278074248996299}], 
        PointBox[{20.2, 0.6292717904789623}], 
        PointBox[{20.3, 0.6316248825153564}], 
        PointBox[{20.4, 0.631641748191249}], 
        PointBox[{20.5, 0.629281293317855}], 
        PointBox[{20.6, 0.6278117323964516}], 
        PointBox[{20.7, 0.6265425598079263}], 
        PointBox[{20.8, 0.6251956162499229}], 
        PointBox[{20.9, 0.6252428406101335}], 
        PointBox[{21., 0.626644413180714}], 
        PointBox[{21.1, 0.627904916196575}], 
        PointBox[{21.2, 0.6294198389739062}], 
        PointBox[{21.3, 0.6317951138393799}], 
        PointBox[{21.4, 0.6314652871231166}], 
        PointBox[{21.5, 0.6291451143413948}], 
        PointBox[{21.6, 0.6277215822252494}], 
        PointBox[{21.7, 0.6264367687561441}], 
        PointBox[{21.8, 0.6251622427657583}], 
        PointBox[{21.9, 0.6253162054778026}], 
        PointBox[{22., 0.6267535529249795}], 
        PointBox[{22.1, 0.6280051695045364}], 
        PointBox[{22.2, 0.6295756876680865}], 
        PointBox[{22.3, 0.6319500834626514}], 
        PointBox[{22.4, 0.6312817059396447}], 
        PointBox[{22.5, 0.6290168222008018}], 
        PointBox[{22.6, 0.6276337111520325}], 
        PointBox[{22.7, 0.6263308584740874}], 
        PointBox[{22.8, 0.6251473071549289}], 
        PointBox[{22.9, 0.6254052925073794}], 
        PointBox[{23., 0.6268615544830349}], 
        PointBox[{23.1, 0.6281082163934578}], 
        PointBox[{23.2, 0.6297394483182991}], 
        PointBox[{23.3, 0.632083922844518}], 
        PointBox[{23.4, 0.6310947913075732}], 
        PointBox[{23.5, 0.6288962975347424}], 
        PointBox[{23.6, 0.6275482158520207}], 
        PointBox[{23.7, 0.6262247756130359}], 
        PointBox[{23.8, 0.6251474885174696}], 
        PointBox[{23.9, 0.6255073034259613}], 
        PointBox[{24., 0.6269685115549785}], 
        PointBox[{24.1, 0.6282141321792089}], 
        PointBox[{24.2, 0.6299109185013212}], 
        PointBox[{24.3, 0.6321938528897741}], 
        PointBox[{24.4, 0.6309081435843882}], 
        PointBox[{24.5, 0.6287828814830712}], 
        PointBox[{24.6, 0.6274647957367453}], 
        PointBox[{24.7, 0.6261193558096225}], 
        PointBox[{24.8, 0.6251579588222896}], 
        PointBox[{24.9, 0.6256189282105231}], 
        PointBox[{25., 0.6270741484358938}], 
        PointBox[{25.1, 0.6283231319211439}], 
        PointBox[{25.2, 0.6300897696775991}], 
        PointBox[{25.3, 0.6322751737317922}], 
        PointBox[{25.4, 0.6307240303751629}], 
        PointBox[{25.5, 0.6286759908462093}], 
        PointBox[{25.6, 0.6273825396366441}], 
        PointBox[{25.7, 0.6260144943196941}], 
        PointBox[{25.8, 0.6251717414279298}], 
        PointBox[{25.9, 0.6257370918917217}], 
        PointBox[{26., 0.6271783551823505}], 
        PointBox[{26.1, 0.6284349669895973}], 
        PointBox[{26.2, 0.6302744423124863}], 
        PointBox[{26.3, 0.6323261980836621}], 
        PointBox[{26.4, 0.6305444852103576}], 
        PointBox[{26.5, 0.6285748700923558}], 
        PointBox[{26.6, 0.6273015358408235}], 
        PointBox[{26.7, 0.6259113423804374}], 
        PointBox[{26.8, 0.6251851303064586}], 
        PointBox[{26.9, 0.6258593140768133}], 
        PointBox[{27., 0.6272811709759131}], 
        PointBox[{27.1, 0.6285497850152006}], 
        PointBox[{27.2, 0.6304647853516142}], 
        PointBox[{27.3, 0.6323451412004435}], 
        PointBox[{27.4, 0.6303709606773147}], 
        PointBox[{27.5, 0.6284789380827093}], 
        PointBox[{27.6, 0.6272201723114704}], 
        PointBox[{27.7, 0.6258107341796005}], 
        PointBox[{27.8, 0.625193958001334}], 
        PointBox[{27.9, 0.6259833413947833}], 
        PointBox[{28., 0.627382552397369}], 
        PointBox[{28.1, 0.6286676860485036}], 
        PointBox[{28.2, 0.6306593631956325}], 
        PointBox[{28.3, 0.6323315803857152}], 
        PointBox[{28.4, 0.6302042663063843}], 
        PointBox[{28.5, 0.6283875041409811}], 
        PointBox[{28.6, 0.6271395929559826}], 
        PointBox[{28.7, 0.625713859204983}], 
        PointBox[{28.8, 0.6251997078549709}], 
        PointBox[{28.9, 0.6261073929422083}], 
        PointBox[{29., 0.6274824729851642}], 
        PointBox[{29.1, 0.6287887524324549}], 
        PointBox[{29.2, 0.6308564759700133}], 
        PointBox[{29.3, 0.6322877419596127}], 
        PointBox[{29.4, 0.6300448580039396}], 
        PointBox[{29.5, 0.6282998241834433}], 
        PointBox[{29.6, 0.6270573618467157}], 
        PointBox[{29.7, 0.6256221296087536}], 
        PointBox[{29.8, 0.6252060883231673}], 
        PointBox[{29.9, 0.6262301143491222}], 
        PointBox[{30., 0.6275809369384284}], 
        PointBox[{30.1, 0.6289130343434469}], 
        PointBox[{30.2, 0.6310541864542025}], 
        PointBox[{30.3, 0.632214313987484}], 
        PointBox[{30.4, 0.6298928039558526}], 
        PointBox[{30.5, 0.6282153061702739}], 
        PointBox[{30.6, 0.6269747529567448}], 
        PointBox[{30.7, 0.625537561100585}], 
        PointBox[{30.8, 0.6252175436491388}], 
        PointBox[{30.9, 0.6263501646104851}], 
        PointBox[{31., 0.6276779746626598}], 
        PointBox[{31.1, 0.6290405328874806}], 
        PointBox[{31.2, 0.6312502019415567}], 
        PointBox[{31.3, 0.632115490923466}], 
        PointBox[{31.4, 0.6297479704325916}], 
        PointBox[{31.5, 0.6281333352130049}], 
        PointBox[{31.6, 0.6268898502269261}], 
        PointBox[{31.7, 0.6254619098979174}], 
        PointBox[{31.8, 0.6252388208611108}], 
        PointBox[{31.9, 0.6264668870672329}], 
        PointBox[{32., 0.6277736335980276}], 
        PointBox[{32.1, 0.6291714577787255}], 
        PointBox[{32.2, 0.6314417126267462}], 
        PointBox[{32.3, 0.6319938470082972}], 
        PointBox[{32.4, 0.6296097448517586}], 
        PointBox[{32.5, 0.6280528244201244}], 
        PointBox[{32.6, 0.6268030593774737}], 
        PointBox[{32.7, 0.6253966678380568}], 
        PointBox[{32.8, 0.6252730261533852}], 
        PointBox[{32.9, 0.6265797543320669}], 
        PointBox[{33., 0.6278680247922432}], 
        PointBox[{33.1, 0.6293059364451015}], 
        PointBox[{33.2, 0.6316256146531924}], 
        PointBox[{33.3, 0.6318537583620429}], 
        PointBox[{33.4, 0.6294778914999632}], 
        PointBox[{33.5, 0.6279733157849877}], 
        PointBox[{33.6, 0.626713048211822}], 
        PointBox[{33.7, 0.6253445985973126}], 
        PointBox[{33.8, 0.6253215313300619}], 
        PointBox[{33.9, 0.6266887112649715}], 
        PointBox[{34., 0.6279612838490402}], 
        PointBox[{34.1, 0.6294441511777721}], 
        PointBox[{34.2, 0.6317987882616894}], 
        PointBox[{34.3, 0.6316985877569511}], 
        PointBox[{34.4, 0.6293513957583867}], 
        PointBox[{34.5, 0.6278941838640454}], 
        PointBox[{34.6, 0.6266203727467936}], 
        PointBox[{34.7, 0.6253054939545251}], 
        PointBox[{34.8, 0.6253833146799669}], 
        PointBox[{34.9, 0.6267932028855605}], 
        PointBox[{35., 0.6280534935886081}], 
        PointBox[{35.1, 0.629586211835615}], 
        PointBox[{35.2, 0.6319571542867122}], 
        PointBox[{35.3, 0.6315322546818832}], 
        PointBox[{35.4, 0.6292298503871191}], 
        PointBox[{35.5, 0.6278148926016304}], 
        PointBox[{35.6, 0.6265238183693825}], 
        PointBox[{35.7, 0.6252801918210136}], 
        PointBox[{35.8, 0.6254572425692977}], 
        PointBox[{35.9, 0.6268932342095581}], 
        PointBox[{36., 0.6281449688636441}], 
        PointBox[{36.1, 0.629732417346695}], 
        PointBox[{36.2, 0.6320971992541154}], 
        PointBox[{36.3, 0.6313579027671532}], 
        PointBox[{36.4, 0.6291125205972528}], 
        PointBox[{36.5, 0.6277347269649088}], 
        PointBox[{36.6, 0.6264240152877877}], 
        PointBox[{36.7, 0.6252673202348611}], 
        PointBox[{36.8, 0.625541157647615}], 
        PointBox[{36.9, 0.626989220343891}], 
        PointBox[{37., 0.6282360589692755}], 
        PointBox[{37.1, 0.629882976496341}], 
        PointBox[{37.2, 0.6322156308205036}], 
        PointBox[{37.3, 0.631178553712583}], 
        PointBox[{37.4, 0.62899887288331}], 
        PointBox[{37.5, 0.627653267418638}], 
        PointBox[{37.6, 0.6263207781813807}], 
        PointBox[{37.7, 0.6252642446747129}], 
        PointBox[{37.8, 0.6256326951097695}], 
        PointBox[{37.9, 0.6270813118920682}], 
        PointBox[{38., 0.6283272737296953}], 
        PointBox[{38.1, 0.6300381015219804}], 
        PointBox[{38.2, 0.6323088461690796}], 
        PointBox[{38.3, 0.630996570903711}], 
        PointBox[{38.4, 0.6288882836762985}], 
        PointBox[{38.5, 0.6275698237857467}], 
        PointBox[{38.6, 0.6262140545506438}], 
        PointBox[{38.7, 0.6252662595260375}], 
        PointBox[{38.8, 0.6257296356144062}], 
        PointBox[{38.9, 0.6271700423469039}], 
        PointBox[{39., 0.6284189036158562}], 
        PointBox[{39.1, 0.6301976822011889}], 
        PointBox[{39.2, 0.6323739427602932}], 
        PointBox[{39.3, 0.6308139535786447}], 
        PointBox[{39.4, 0.6287800482535426}], 
        PointBox[{39.5, 0.6274843403427456}], 
        PointBox[{39.6, 0.6261044625105134}], 
        PointBox[{39.7, 0.6252693723162704}], 
        PointBox[{39.8, 0.6258298765287433}], 
        PointBox[{39.9, 0.6272553001213705}], 
        PointBox[{40., 0.6285114746885225}], 
        PointBox[{40.1, 0.6303618257947999}], 
        PointBox[{40.2, 0.6324093864034873}], 
        PointBox[{40.3, 0.6306322484890556}], 
        PointBox[{40.4, 0.628673854924566}], 
        PointBox[{40.5, 0.6273966865534492}], 
        PointBox[{40.6, 0.6259927891747602}], 
        PointBox[{40.7, 0.6252690550597316}], 
        PointBox[{40.8, 0.6259317552692534}], 
        PointBox[{40.9, 0.6273375714201653}], 
        PointBox[{41., 0.6286055463582995}], 
        PointBox[{41.1, 0.6305303702627363}], 
        PointBox[{41.2, 0.6324127290390402}], 
        PointBox[{41.3, 0.6304526744793307}], 
        PointBox[{41.4, 0.6285690266887345}], 
        PointBox[{41.5, 0.627305347735485}], 
        PointBox[{41.6, 0.6258798505745587}], 
        PointBox[{41.7, 0.6252626787938674}], 
        PointBox[{41.8, 0.62603395119248}], 
        PointBox[{41.9, 0.627417595488456}], 
        PointBox[{42., 0.6287016075818718}], 
        PointBox[{42.1, 0.6307024558268469}], 
        PointBox[{42.2, 0.6323843387901719}], 
        PointBox[{42.3, 0.6302761088376887}], 
        PointBox[{42.4, 0.6284653020623744}], 
        PointBox[{42.5, 0.6272112412686012}], 
        PointBox[{42.6, 0.6257672575799355}], 
        PointBox[{42.7, 0.625251725991091}], 
        PointBox[{42.8, 0.6261353400086823}], 
        PointBox[{42.9, 0.6274959591861565}], 
        PointBox[{43., 0.6288006010824109}], 
        PointBox[{43.1, 0.6308775621151368}], 
        PointBox[{43.2, 0.6323248354798295}], 
        PointBox[{43.3, 0.6301031057292874}], 
        PointBox[{43.4, 0.6283623719094718}], 
        PointBox[{43.5, 0.6271132079940116}], 
        PointBox[{43.6, 0.6256570255623439}], 
        PointBox[{43.7, 0.6252393295161293}], 
        PointBox[{43.8, 0.626235585231059}], 
        PointBox[{43.9, 0.6275728307076546}], 
        PointBox[{44., 0.6289030648327285}], 
        PointBox[{44.1, 0.6310543715988747}], 
        PointBox[{44.2, 0.6322358419277809}], 
        PointBox[{44.3, 0.629934712723784}], 
        PointBox[{44.4, 0.6282601124378251}], 
        PointBox[{44.5, 0.6270121552450123}], 
        PointBox[{44.6, 0.6255515149493769}], 
        PointBox[{44.7, 0.6252303985432834}], 
        PointBox[{44.8, 0.6263339734654039}], 
        PointBox[{44.9, 0.6276492922471715}], 
        PointBox[{45., 0.6290098850207153}], 
        PointBox[{45.1, 0.6312312231992101}], 
        PointBox[{45.2, 0.6321197568413043}], 
        PointBox[{45.3, 0.6297708360477868}], 
        PointBox[{45.4, 0.6281583231131491}], 
        PointBox[{45.5, 0.6269073950280031}], 
        PointBox[{45.6, 0.6254533923657883}], 
        PointBox[{45.7, 0.6252307019421374}], 
        PointBox[{45.8, 0.6264305756105687}], 
        PointBox[{45.9, 0.6277256581236014}], 
        PointBox[{46., 0.6291218861290704}], 
        PointBox[{46.1, 0.6314057818410698}], 
        PointBox[{46.2, 0.6319800533447513}], 
        PointBox[{46.3, 0.6296117477594104}], 
        PointBox[{46.4, 0.6280569732708143}], 
        PointBox[{46.5, 0.626799179399011}], 
        PointBox[{46.6, 0.6253656701672178}], 
        PointBox[{46.7, 0.6252436884248549}], 
        PointBox[{46.8, 0.6265252581360692}], 
        PointBox[{46.9, 0.6278028275737052}], 
        PointBox[{47., 0.6292398202469893}], 
        PointBox[{47.1, 0.6315753576926857}], 
        PointBox[{47.2, 0.6318203693547056}], 
        PointBox[{47.3, 0.6294580071906152}], 
        PointBox[{47.4, 0.6279559497537143}], 
        PointBox[{47.5, 0.6266877649155282}], 
        PointBox[{47.6, 0.6252911093595656}], 
        PointBox[{47.7, 0.6252723857168846}], 
        PointBox[{47.8, 0.6266184734917063}], 
        PointBox[{47.9, 0.6278813921185096}], 
        PointBox[{48., 0.6293645868570209}], 
        PointBox[{48.1, 0.6317364801740993}], 
        PointBox[{48.2, 0.6316447151872672}], 
        PointBox[{48.3, 0.6293094866091093}], 
        PointBox[{48.4, 0.6278553728826382}], 
        PointBox[{48.5, 0.626573829612991}], 
        PointBox[{48.6, 0.6252320893798513}], 
        PointBox[{48.7, 0.6253172790607122}], 
        PointBox[{48.8, 0.626710135856642}], 
        PointBox[{48.9, 0.6279616865388226}], 
        PointBox[{49., 0.6294966256645307}], 
        PointBox[{49.1, 0.6318851854001779}], 
        PointBox[{49.2, 0.6314570817183557}], 
        PointBox[{49.3, 0.6291660899648792}], 
        PointBox[{49.4, 0.6277548856654661}], 
        PointBox[{49.5, 0.6264555361003937}], 
        PointBox[{49.6, 0.6251894938526027}], 
        PointBox[{49.7, 0.6253776964279285}], 
        PointBox[{49.8, 0.6268006415081594}], 
        PointBox[{49.9, 0.628044786547352}], 
        PointBox[{50., 0.6296366208629351}], 
        PointBox[{50.1, 0.6320173651766751}], 
        PointBox[{50.2, 0.6312614561607177}], 
        PointBox[{50.3, 0.6290278635192506}], 
        PointBox[{50.4, 0.6276547230328519}], 
        PointBox[{50.5, 0.6263353788233007}], 
        PointBox[{50.6, 0.6251629571691038}], 
        PointBox[{50.7, 0.6254521860196024}], 
        PointBox[{50.8, 0.6268904560614669}], 
        PointBox[{50.9, 0.6281311186326227}], 
        PointBox[{51., 0.6297851481201718}], 
        PointBox[{51.1, 0.6321287382853035}], 
        PointBox[{51.2, 0.6310615579324252}], 
        PointBox[{51.3, 0.6288950624426297}], 
        PointBox[{51.4, 0.6275549576491679}], 
        PointBox[{51.5, 0.6262134026591756}], 
        PointBox[{51.6, 0.6251499436820572}], 
        PointBox[{51.7, 0.6255385964298734}], 
        PointBox[{51.8, 0.6269798632068595}], 
        PointBox[{51.9, 0.6282208215490171}], 
        PointBox[{52., 0.6299423694421203}], 
        PointBox[{52.1, 0.6322153919642782}], 
        PointBox[{52.2, 0.6308605071731482}], 
        PointBox[{52.3, 0.6287675391688112}], 
        PointBox[{52.4, 0.6274554125449351}], 
        PointBox[{52.5, 0.6260904349837787}], 
        PointBox[{52.6, 0.6251455459605065}], 
        PointBox[{52.7, 0.6256345950602422}], 
        PointBox[{52.8, 0.6270690799465841}], 
        PointBox[{52.9, 0.6283150095785687}], 
        PointBox[{53., 0.6301083205383798}], 
        PointBox[{53.1, 0.6322735320489146}], 
        PointBox[{53.2, 0.6306610424481338}], 
        PointBox[{53.3, 0.628645156905977}], 
        PointBox[{53.4, 0.6273561882796677}], 
        PointBox[{53.5, 0.6259677896408177}], 
        PointBox[{53.6, 0.6251444599410175}], 
        PointBox[{53.7, 0.6257382634097074}], 
        PointBox[{53.8, 0.6271586987902837}], 
        PointBox[{53.9, 0.6284142899110178}], 
        PointBox[{54., 0.6302828350348487}], 
        PointBox[{54.1, 0.6323014230861422}], 
        PointBox[{54.2, 0.6304657176083757}], 
        PointBox[{54.3, 0.6285277520136561}], 
        PointBox[{54.4, 0.627257332052563}], 
        PointBox[{54.5, 0.6258464794505367}], 
        PointBox[{54.6, 0.6251422055854434}], 
        PointBox[{54.7, 0.6258471114745995}], 
        PointBox[{54.8, 0.6272487848214213}], 
        PointBox[{54.9, 0.6285183518575831}], 
        PointBox[{55., 0.6304648657758885}], 
        PointBox[{55.1, 0.6322963049149041}], 
        PointBox[{55.2, 0.6302758039787899}], 
        PointBox[{55.3, 0.6284151109008057}], 
        PointBox[{55.4, 0.6271586597883865}], 
        PointBox[{55.5, 0.6257282972885373}], 
        PointBox[{55.6, 0.6251362384310791}], 
        PointBox[{55.7, 0.6259598369059354}], 
        PointBox[{55.8, 0.6273398418511601}], 
        PointBox[{55.9, 0.6286282539278039}], 
        PointBox[{56., 0.6306537427349317}], 
        PointBox[{56.1, 0.6322593570817396}], 
        PointBox[{56.2, 0.6300930607426155}], 
        PointBox[{56.3, 0.6283074114676068}], 
        PointBox[{56.4, 0.6270597732623368}], 
        PointBox[{56.5, 0.6256154197523911}], 
        PointBox[{56.6, 0.6251295579854625}], 
        PointBox[{56.7, 0.6260750949004319}], 
        PointBox[{56.8, 0.6274321455467042}], 
        PointBox[{56.9, 0.6287447614290214}], 
        PointBox[{57., 0.6308476440330374}], 
        PointBox[{57.1, 0.6321916726907697}], 
        PointBox[{57.2, 0.6299183889371638}], 
        PointBox[{57.3, 0.628204168867854}], 
        PointBox[{57.4, 0.6269613156890753}], 
        PointBox[{57.5, 0.6255100469074071}], 
        PointBox[{57.6, 0.6251265985815654}], 
        PointBox[{57.7, 0.6261913071457689}], 
        PointBox[{57.8, 0.6275257253734218}], 
        PointBox[{57.9, 0.6288669292235732}], 
        PointBox[{58., 0.6310443975039602}], 
        PointBox[{58.1, 0.6320952521526781}], 
        PointBox[{58.2, 0.6297521838470869}], 
        PointBox[{58.3, 0.6281052640149662}], 
        PointBox[{58.4, 0.6268627218541908}], 
        PointBox[{58.5, 0.6254152257633947}], 
        PointBox[{58.6, 0.6251332616277221}], 
        PointBox[{58.7, 0.6263078578725259}], 
        PointBox[{58.8, 0.6276208471692623}], 
        PointBox[{58.9, 0.6289962396121513}], 
        PointBox[{59., 0.6312411205475967}], 
        PointBox[{59.1, 0.6319739417079302}], 
        PointBox[{59.2, 0.6295949947754852}], 
        PointBox[{59.3, 0.6280103067597576}], 
        PointBox[{59.4, 0.626763898193568}], 
        PointBox[{59.5, 0.6253330680340581}], 
        PointBox[{59.6, 0.6251545612003034}], 
        PointBox[{59.7, 0.626423845832162}], 
        PointBox[{59.8, 0.6277176263614392}], 
        PointBox[{59.9, 0.6291319854850342}], 
        PointBox[{60., 0.6314344250719645}], 
        PointBox[{60.1, 0.63183191335584}], 
        PointBox[{60.2, 0.6294465188658606}], 
        PointBox[{60.3, 0.6279189913203116}], 
        PointBox[{60.4, 0.6266651802523441}], 
        PointBox[{60.5, 0.6252667631073807}], 
        PointBox[{60.6, 0.6251937769488503}], 
        PointBox[{60.7, 0.6265389489075306}], 
        PointBox[{60.8, 0.6278161914473495}], 
        PointBox[{60.9, 0.6292749766424149}], 
        PointBox[{61., 0.6316206376014678}], 
        PointBox[{61.1, 0.6316737615134603}], 
        PointBox[{61.2, 0.6293068116397788}], 
        PointBox[{61.3, 0.6278311403452154}], 
        PointBox[{61.4, 0.6265655814730624}], 
        PointBox[{61.5, 0.6252180743731299}], 
        PointBox[{61.6, 0.6252518922936363}], 
        PointBox[{61.7, 0.6266527704676409}], 
        PointBox[{61.8, 0.6279167993415645}], 
        PointBox[{61.9, 0.6294257304161828}], 
        PointBox[{62., 0.6317951996835367}], 
        PointBox[{62.1, 0.6315037052084107}], 
        PointBox[{62.2, 0.6291753321062122}], 
        PointBox[{62.3, 0.62774594674982}], 
        PointBox[{62.4, 0.6264652659931139}], 
        PointBox[{62.5, 0.6251866187924446}], 
        PointBox[{62.6, 0.625326780239378}], 
        PointBox[{62.7, 0.6267643586092904}], 
        PointBox[{62.8, 0.6280188341875392}], 
        PointBox[{62.9, 0.6295819876891767}], 
        PointBox[{63., 0.6319538508417114}], 
        PointBox[{63.1, 0.6313261143354633}], 
        PointBox[{63.2, 0.6290515796598269}], 
        PointBox[{63.3, 0.6276629171598386}], 
        PointBox[{63.4, 0.6263643769138015}], 
        PointBox[{63.5, 0.625174285329232}], 
        PointBox[{63.6, 0.6254169444783199}], 
        PointBox[{63.7, 0.6268744718455953}], 
        PointBox[{63.8, 0.6281231471875254}], 
        PointBox[{63.9, 0.6297456455677503}], 
        PointBox[{64., 0.6320922482727134}], 
        PointBox[{64.1, 0.6311445483823801}], 
        PointBox[{64.2, 0.6289349549702961}], 
        PointBox[{64.3, 0.6275817313554778}], 
        PointBox[{64.4, 0.6262631091401072}], 
        PointBox[{64.5, 0.6251753899169392}], 
        PointBox[{64.6, 0.6255188289101931}], 
        PointBox[{64.7, 0.6269821197978492}], 
        PointBox[{64.8, 0.6282289307960657}], 
        PointBox[{64.9, 0.6299157650098026}], 
        PointBox[{65., 0.6322061479310909}], 
        PointBox[{65.1, 0.6309622890831014}], 
        PointBox[{65.2, 0.6288249047996973}], 
        PointBox[{65.3, 0.627502062741373}], 
        PointBox[{65.4, 0.6261612448641952}], 
        PointBox[{65.5, 0.6251867236171011}], 
        PointBox[{65.6, 0.6256297820336693}], 
        PointBox[{65.7, 0.62708763418133}], 
        PointBox[{65.8, 0.6283368723703688}], 
        PointBox[{65.9, 0.6300920292906368}], 
        PointBox[{66., 0.6322925337965671}], 
        PointBox[{66.1, 0.6307819636615242}], 
        PointBox[{66.2, 0.628720901544353}], 
        PointBox[{66.3, 0.6274231691637495}], 
        PointBox[{66.4, 0.6260596638847505}], 
        PointBox[{66.5, 0.6252018165823151}], 
        PointBox[{66.6, 0.625746670640664}], 
        PointBox[{66.7, 0.6271911409921342}], 
        PointBox[{66.8, 0.6284470978384927}], 
        PointBox[{66.9, 0.6302738683310682}], 
        PointBox[{67., 0.6323490542530772}], 
        PointBox[{67.1, 0.63060577866424}], 
        PointBox[{67.2, 0.6286224328050106}], 
        PointBox[{67.3, 0.6273448915187231}], 
        PointBox[{67.4, 0.625959160708103}], 
        PointBox[{67.5, 0.625215694567481}], 
        PointBox[{67.6, 0.6258672809127922}], 
        PointBox[{67.7, 0.6272925996713488}], 
        PointBox[{67.8, 0.6285594014004173}], 
        PointBox[{67.9, 0.630460862489159}], 
        PointBox[{68., 0.6323735732661013}], 
        PointBox[{68.1, 0.630434289367667}], 
        PointBox[{68.2, 0.6285280796169604}], 
        PointBox[{68.3, 0.6272661161496641}], 
        PointBox[{68.4, 0.6258596268960289}], 
        PointBox[{68.5, 0.625225269233854}], 
        PointBox[{68.6, 0.6259885692824704}], 
        PointBox[{68.7, 0.6273913750230188}], 
        PointBox[{68.8, 0.6286738459373178}], 
        PointBox[{68.9, 0.6306506783112844}], 
        PointBox[{69., 0.6323658488065045}], 
        PointBox[{69.1, 0.6302683550741613}], 
        PointBox[{69.2, 0.6284371357719479}], 
        PointBox[{69.3, 0.6271859747142743}], 
        PointBox[{69.4, 0.625762441048767}], 
        PointBox[{69.5, 0.6252304495925021}], 
        PointBox[{69.6, 0.6261092436359652}], 
        PointBox[{69.7, 0.627487953143369}], 
        PointBox[{69.8, 0.6287901125162315}], 
        PointBox[{69.9, 0.6308429405566096}], 
        PointBox[{70., 0.6323273567104799}], 
        PointBox[{70.1, 0.6301090485738252}], 
        PointBox[{70.2, 0.6283495716929424}], 
        PointBox[{70.3, 0.6271048302260762}], 
        PointBox[{70.4, 0.6256693735658754}], 
        PointBox[{70.5, 0.6252341739524692}], 
        PointBox[{70.6, 0.6262282154973507}], 
        PointBox[{70.7, 0.6275826188156424}], 
        PointBox[{70.8, 0.6289093661339474}], 
        PointBox[{70.9, 0.631035811779917}], 
        PointBox[{71., 0.6322590675069644}], 
        PointBox[{71.1, 0.6299557515669834}], 
        PointBox[{71.2, 0.628263994937003}], 
        PointBox[{71.3, 0.6270217438386502}], 
        PointBox[{71.4, 0.6255815493469358}], 
        PointBox[{71.5, 0.6252415531655232}], 
        PointBox[{71.6, 0.6263440936454611}], 
        PointBox[{71.7, 0.6276751569100288}], 
        PointBox[{71.8, 0.629030980494339}], 
        PointBox[{71.9, 0.6312270523312682}], 
        PointBox[{72., 0.6321639778209136}], 
        PointBox[{72.1, 0.6298085960426809}], 
        PointBox[{72.2, 0.6281800245035092}], 
        PointBox[{72.3, 0.6269359110990558}], 
        PointBox[{72.4, 0.6255009080697694}], 
        PointBox[{72.5, 0.6252563771961219}], 
        PointBox[{72.6, 0.6264562499373505}], 
        PointBox[{72.7, 0.6277657187574284}], 
        PointBox[{72.8, 0.6291552435104566}], 
        PointBox[{72.9, 0.6314140012317511}], 
        PointBox[{73., 0.6320452293690266}], 
        PointBox[{73.1, 0.6296670682012698}], 
        PointBox[{73.2, 0.6280967183779814}], 
        PointBox[{73.3, 0.6268466468677913}], 
        PointBox[{73.4, 0.6254294998420454}], 
        PointBox[{73.5, 0.6252827760910623}], 
        PointBox[{73.6, 0.62656449834113}], 
        PointBox[{73.7, 0.6278548387574174}], 
        PointBox[{73.8, 0.6292831847335976}], 
        PointBox[{73.9, 0.6315947224525338}], 
        PointBox[{74., 0.6319066508043297}], 
        PointBox[{74.1, 0.6295309787030017}], 
        PointBox[{74.2, 0.6280141730849096}], 
        PointBox[{74.3, 0.6267541225047375}], 
        PointBox[{74.4, 0.625369274019317}], 
        PointBox[{74.5, 0.6253221916119966}], 
        PointBox[{74.6, 0.6266684959377312}], 
        PointBox[{74.7, 0.6279426629477582}], 
        PointBox[{74.8, 0.6294142786422485}], 
        PointBox[{74.9, 0.6317651127918122}], 
        PointBox[{75., 0.6317516315075276}], 
        PointBox[{75.1, 0.6293996767090269}], 
        PointBox[{75.2, 0.6279309703064265}], 
        PointBox[{75.3, 0.6266579847413299}], 
        PointBox[{75.4, 0.6253217540174428}], 
        PointBox[{75.5, 0.6253750131614677}], 
        PointBox[{75.6, 0.6267682756108779}], 
        PointBox[{75.7, 0.6280293801049174}], 
        PointBox[{75.8, 0.6295497580074735}], 
        PointBox[{75.9, 0.6319223440485449}], 
        PointBox[{76., 0.631584099436863}], 
        PointBox[{76.1, 0.6292729152195575}], 
        PointBox[{76.2, 0.627847536750531}], 
        PointBox[{76.3, 0.6265584467434923}], 
        PointBox[{76.4, 0.6252877497285801}], 
        PointBox[{76.5, 0.6254404903846223}], 
        PointBox[{76.6, 0.6268643389653361}], 
        PointBox[{76.7, 0.6281158757521951}], 
        PointBox[{76.8, 0.6296896472280773}], 
        PointBox[{76.9, 0.6320629241702396}], 
        PointBox[{77., 0.6314072015558978}], 
        PointBox[{77.1, 0.6291498878154871}], 
        PointBox[{77.2, 0.6277626404687076}], 
        PointBox[{77.3, 0.626454308511872}], 
        PointBox[{77.4, 0.625266382968329}], 
        PointBox[{77.5, 0.6255164902731436}], 
        PointBox[{77.6, 0.6269563323812944}], 
        PointBox[{77.7, 0.6282020553726341}], 
        PointBox[{77.8, 0.6298342395281944}], 
        PointBox[{77.9, 0.6321827216241692}], 
        PointBox[{78., 0.6312241678004362}], 
        PointBox[{78.1, 0.6290302096922418}], 
        PointBox[{78.2, 0.6276765104581228}], 
        PointBox[{78.3, 0.6263466530246877}], 
        PointBox[{78.4, 0.6252560412771496}], 
        PointBox[{78.5, 0.6256009810574681}], 
        PointBox[{78.6, 0.6270447859628991}], 
        PointBox[{78.7, 0.6282886883545105}], 
        PointBox[{78.8, 0.6299842618211589}], 
        PointBox[{78.9, 0.6322785712299237}], 
        PointBox[{79., 0.631037542908167}], 
        PointBox[{79.1, 0.6289135252861693}], 
        PointBox[{79.2, 0.6275883913574765}], 
        PointBox[{79.3, 0.6262349045003311}], 
        PointBox[{79.4, 0.6252522895530785}], 
        PointBox[{79.5, 0.6256920608275448}], 
        PointBox[{79.6, 0.6271301089714142}], 
        PointBox[{79.7, 0.6283764337217993}], 
        PointBox[{79.8, 0.6301391635863934}], 
        PointBox[{79.9, 0.6323477037583316}], 
        PointBox[{80., 0.6308493981042413}], 
        PointBox[{80.1, 0.628799287958849}], 
        PointBox[{80.2, 0.6274981662691156}], 
        PointBox[{80.3, 0.6261210614080192}], 
        PointBox[{80.4, 0.6252515234514122}], 
        PointBox[{80.5, 0.6257875547623808}], 
        PointBox[{80.6, 0.6272127369878295}], 
        PointBox[{80.7, 0.6284654581381739}], 
        PointBox[{80.8, 0.6302996352588817}], 
        PointBox[{80.9, 0.6323862371197548}], 
        PointBox[{81., 0.6306615761635831}], 
        PointBox[{81.1, 0.6286868717631054}], 
        PointBox[{81.2, 0.6274050784205537}], 
        PointBox[{81.3, 0.6260035600783177}], 
        PointBox[{81.4, 0.6252480770474017}], 
        PointBox[{81.5, 0.6258858698800032}], 
        PointBox[{81.6, 0.6272931456617714}], 
        PointBox[{81.7, 0.6285567529219107}], 
        PointBox[{81.8, 0.630465336157734}], 
        PointBox[{81.9, 0.6323947516753584}], 
        PointBox[{82., 0.6304759649095362}], 
        PointBox[{82.1, 0.6285765850982363}], 
        PointBox[{82.2, 0.627310009143674}], 
        PointBox[{82.3, 0.625885663217914}], 
        PointBox[{82.4, 0.6252406693921723}], 
        PointBox[{82.5, 0.6259860849622092}], 
        PointBox[{82.6, 0.6273722478789228}], 
        PointBox[{82.7, 0.6286509300563652}], 
        PointBox[{82.8, 0.6306362937010711}], 
        PointBox[{82.9, 0.632370976418707}], 
        PointBox[{83., 0.630293523068971}], 
        PointBox[{83.1, 0.6284680379562758}], 
        PointBox[{83.2, 0.6272120892393841}], 
        PointBox[{83.3, 0.6257683917613023}], 
        PointBox[{83.4, 0.6252278060870233}], 
        PointBox[{83.5, 0.6260865502140683}], 
        PointBox[{83.6, 0.62745001465485}], 
        PointBox[{83.7, 0.628748914469027}], 
        PointBox[{83.8, 0.630811155839414}], 
        PointBox[{83.9, 0.6323152543335193}], 
        PointBox[{84., 0.6301151708785787}], 
        PointBox[{84.1, 0.6283606914183918}], 
        PointBox[{84.2, 0.6271112917204208}], 
        PointBox[{84.3, 0.6256539376611816}], 
        PointBox[{84.4, 0.6252133070114959}], 
        PointBox[{84.5, 0.6261867983611337}], 
        PointBox[{84.6, 0.6275275495117261}], 
        PointBox[{84.7, 0.6288512387602029}], 
        PointBox[{84.8, 0.6309889648603644}], 
        PointBox[{84.9, 0.6322299684865086}], 
        PointBox[{85., 0.6299415022063583}], 
        PointBox[{85.1, 0.6282547043760007}], 
        PointBox[{85.2, 0.6270075387169616}], 
        PointBox[{85.3, 0.6255441884820238}], 
        PointBox[{85.4, 0.6252021334697159}], 
        PointBox[{85.5, 0.6262863408350269}], 
        PointBox[{85.6, 0.627604904679983}], 
        PointBox[{85.7, 0.6289586591870958}], 
        PointBox[{85.8, 0.63116816715813}], 
        PointBox[{85.9, 0.6321166794178142}], 
        PointBox[{86., 0.6297732699986635}], 
        PointBox[{86.1, 0.6281500093759559}], 
        PointBox[{86.2, 0.6269004647914596}], 
        PointBox[{86.3, 0.6254423531146395}], 
        PointBox[{86.4, 0.6251997584632862}], 
        PointBox[{86.5, 0.6263850378427918}], 
        PointBox[{86.6, 0.6276831718706594}], 
        PointBox[{86.7, 0.6290718051797489}], 
        PointBox[{86.8, 0.6313461591340819}], 
        PointBox[{86.9, 0.6319791463623049}], 
        PointBox[{87., 0.6296106131473543}], 
        PointBox[{87.1, 0.6280464038246182}], 
        PointBox[{87.2, 0.6267909851499942}], 
        PointBox[{87.3, 0.625351564979271}], 
        PointBox[{87.4, 0.6252109192445888}], 
        PointBox[{87.5, 0.6264824594766576}], 
        PointBox[{87.6, 0.6277626459458338}], 
        PointBox[{87.7, 0.6291918018112386}], 
        PointBox[{87.8, 0.631520183077752}], 
        PointBox[{87.9, 0.6318210321236379}], 
        PointBox[{88., 0.6294538772986349}], 
        PointBox[{88.1, 0.6279439551415659}], 
        PointBox[{88.2, 0.6266790196705138}], 
        PointBox[{88.3, 0.62527444263742}], 
        PointBox[{88.4, 0.6252383970529054}], 
        PointBox[{88.5, 0.626578976100028}], 
        PointBox[{88.6, 0.6278441122483992}], 
        PointBox[{88.7, 0.6293193205905613}], 
        PointBox[{88.8, 0.6316864147925034}], 
        PointBox[{88.9, 0.631646587400848}], 
        PointBox[{89., 0.6293032996598641}], 
        PointBox[{89.1, 0.6278425825036512}], 
        PointBox[{89.2, 0.6265639991237035}], 
        PointBox[{89.3, 0.6252137530987832}], 
        PointBox[{89.4, 0.6252831759260113}], 
        PointBox[{89.5, 0.6266744774795953}], 
        PointBox[{89.6, 0.6279279285894396}], 
        PointBox[{89.7, 0.6294541340795905}], 
        PointBox[{89.8, 0.6318412666138488}], 
        PointBox[{89.9, 0.6314601323988024}], 
        PointBox[{90., 0.6291589670281746}], 
        PointBox[{90.1, 0.6277424483401086}], 
        PointBox[{90.2, 0.6264476948249466}], 
        PointBox[{90.3, 0.625170770330138}], 
        PointBox[{90.4, 0.6253449604504022}], 
        PointBox[{90.5, 0.6267693582730601}], 
        PointBox[{90.6, 0.6280148144824339}], 
        PointBox[{90.7, 0.6295975835326599}], 
        PointBox[{90.8, 0.6319801397858834}], 
        PointBox[{90.9, 0.6312654725360427}], 
        PointBox[{91., 0.6290206788068567}], 
        PointBox[{91.1, 0.6276433318541823}], 
        PointBox[{91.2, 0.6263293866396245}], 
        PointBox[{91.3, 0.6251450094032788}], 
        PointBox[{91.4, 0.625421749178394}], 
        PointBox[{91.5, 0.6268637652709697}], 
        PointBox[{91.6, 0.6281051405039517}], 
        PointBox[{91.7, 0.6297498906358433}], 
        PointBox[{91.8, 0.6320983612877615}], 
        PointBox[{91.9, 0.6310668176554908}], 
        PointBox[{92., 0.6288886210091138}], 
        PointBox[{92.1, 0.6275452777469785}], 
        PointBox[{92.2, 0.6262093947656503}], 
        PointBox[{92.3, 0.6251339158396614}], 
        PointBox[{92.4, 0.6255115983749816}], 
        PointBox[{92.5, 0.6269579465229389}], 
        PointBox[{92.6, 0.6281995505736464}], 
        PointBox[{92.7, 0.62991130922246}], 
        PointBox[{92.8, 0.6321923419997983}], 
        PointBox[{92.9, 0.6308673830259482}], 
        PointBox[{93., 0.6287626291822278}], 
        PointBox[{93.1, 0.6274482223326767}], 
        PointBox[{93.2, 0.6260894767983626}], 
        PointBox[{93.3, 0.6251325861680909}], 
        PointBox[{93.4, 0.6256115716635974}], 
        PointBox[{93.5, 0.6270521299367073}], 
        PointBox[{93.6, 0.6282980758735782}], 
        PointBox[{93.7, 0.6300812585284722}], 
        PointBox[{93.8, 0.6322579136055524}], 
        PointBox[{93.9, 0.6306699544483019}], 
        PointBox[{94., 0.6286424681261874}], 
        PointBox[{94.1, 0.6273520931046772}], 
        PointBox[{94.2, 0.625969883963559}], 
        PointBox[{94.3, 0.6251355686279306}], 
        PointBox[{94.4, 0.6257195111859242}], 
        PointBox[{94.5, 0.6271465145014455}], 
        PointBox[{94.6, 0.6284018055802644}], 
        PointBox[{94.7, 0.6302597087640565}], 
        PointBox[{94.8, 0.6322933877433136}], 
        PointBox[{94.9, 0.6304769592808969}], 
        PointBox[{95., 0.6285280092484813}], 
        PointBox[{95.1, 0.6272567313423718}], 
        PointBox[{95.2, 0.6258523867653355}], 
        PointBox[{95.3, 0.6251375237064026}], 
        PointBox[{95.4, 0.6258331592229144}], 
        PointBox[{95.5, 0.6272413496381763}], 
        PointBox[{95.6, 0.6285097814640275}], 
        PointBox[{95.7, 0.6304457272756352}], 
        PointBox[{95.8, 0.6322964585266395}], 
        PointBox[{95.9, 0.6302901553406737}], 
        PointBox[{96., 0.6284190035922119}], 
        PointBox[{96.1, 0.6271620498551731}], 
        PointBox[{96.2, 0.6257384111326935}], 
        PointBox[{96.3, 0.6251359863139266}], 
        PointBox[{96.4, 0.6259505113661853}], 
        PointBox[{96.5, 0.627336806409107}], 
        PointBox[{96.6, 0.6286241102411907}], 
        PointBox[{96.7, 0.6306380777558349}], 
        PointBox[{96.8, 0.6322667679434766}], 
        PointBox[{96.9, 0.6301107469444536}], 
        PointBox[{97., 0.6283151504520813}], 
        PointBox[{97.1, 0.62706791456341}], 
        PointBox[{97.2, 0.625629732837334}], 
        PointBox[{97.3, 0.6251337023793091}], 
        PointBox[{97.4, 0.6260699343826621}], 
        PointBox[{97.5, 0.627433004371446}], 
        PointBox[{97.6, 0.6287431811302752}], 
        PointBox[{97.7, 0.6308350621510388}], 
        PointBox[{97.8, 0.632206173130412}], 
        PointBox[{97.9, 0.6299396235730527}], 
        PointBox[{98., 0.6282161065510056}], 
        PointBox[{98.1, 0.6269741075109452}], 
        PointBox[{98.2, 0.6255285421281975}], 
        PointBox[{98.3, 0.6251338383273123}], 
        PointBox[{98.4, 0.6261901238305466}], 
        PointBox[{98.5, 0.6275301272339404}], 
        PointBox[{98.6, 0.6288685751680253}], 
        PointBox[{98.7, 0.6310345349473232}], 
        PointBox[{98.8, 0.6321172289500661}], 
        PointBox[{98.9, 0.6297772737047116}], 
        PointBox[{99., 0.6281214999406219}], 
        PointBox[{99.1, 0.6268803219246503}], 
        PointBox[{99.2, 0.6254372910652852}], 
        PointBox[{99.3, 0.6251434471950595}], 
        PointBox[{99.4, 0.6263101114822107}], 
        PointBox[{99.5, 0.6276282629365149}], 
        PointBox[{99.6, 0.6289999987964845}], 
        PointBox[{99.7, 0.6312337571467997}], 
        PointBox[{99.8, 0.6320028525361713}], 
        PointBox[{99.9, 0.6296238839817937}], 
        PointBox[{100., 0.6280310025039963}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0.6, 0.65}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], 
        PointBox[{0, 0.12838599999999997`}], 
        PointBox[{0.1, 0.13152194666206846`}], 
        PointBox[{0.2, 0.1316563374627984}], 
        PointBox[{0.3, 0.12959517922368982`}], 
        PointBox[{0.4, 0.13000519748419267`}], 
        PointBox[{0.5, 0.13385964382219862`}], 
        PointBox[{0.6, 0.1297720236103665}], 
        PointBox[{0.7, 0.1297217005105911}], 
        PointBox[{0.8, 0.13177452296912948`}], 
        PointBox[{0.9, 0.1313073722194011}], 
        PointBox[{1., 0.12841657493830716`}], 
        PointBox[{1.1, 0.13171547889091897`}], 
        PointBox[{1.2, 0.13153857678786818`}], 
        PointBox[{1.3, 0.12948941241697162`}], 
        PointBox[{1.4, 0.1302850283400506}], 
        PointBox[{1.5, 0.13379014350206456`}], 
        PointBox[{1.6, 0.12958654402001124`}], 
        PointBox[{1.7, 0.12986773573759847`}], 
        PointBox[{1.8, 0.13189115749623928`}], 
        PointBox[{1.9, 0.1310739060236639}], 
        PointBox[{2., 0.12850940572291975`}], 
        PointBox[{2.1, 0.13188772687512526`}], 
        PointBox[{2.2, 0.13142293451705347`}], 
        PointBox[{2.3, 0.12940686919098768`}], 
        PointBox[{2.4, 0.13060996554324025`}], 
        PointBox[{2.5, 0.13365509039569154`}], 
        PointBox[{2.6, 0.1294487117901592}], 
        PointBox[{2.7, 0.13003171896035873`}], 
        PointBox[{2.8, 0.13200594677085797`}], 
        PointBox[{2.9, 0.13082466050594316`}], 
        PointBox[{3., 0.1286639637616213}], 
        PointBox[{3.1, 0.13203848078815317`}], 
        PointBox[{3.2, 0.13131014925386372`}], 
        PointBox[{3.3, 0.12934878878082595`}], 
        PointBox[{3.4, 0.13097576313588957`}], 
        PointBox[{3.5, 0.13346187839808826`}], 
        PointBox[{3.6, 0.12935710229188274`}], 
        PointBox[{3.7, 0.13021199975740008`}], 
        PointBox[{3.8, 0.13211576776133105`}], 
        PointBox[{3.9, 0.13056472637115932`}], 
        PointBox[{4., 0.12887811168500957`}], 
        PointBox[{4.1, 0.13216777549477826`}], 
        PointBox[{4.2, 0.131200941091498}], 
        PointBox[{4.3, 0.12931707473793327`}], 
        PointBox[{4.4, 0.13137640820766175`}], 
        PointBox[{4.5, 0.133219062830096}], 
        PointBox[{4.6, 0.1293093873248356}], 
        PointBox[{4.7, 0.13040603551575286`}], 
        PointBox[{4.8, 0.13221743370473946`}], 
        PointBox[{4.9, 0.13029954512458145`}], 
        PointBox[{5., 0.12914670712765333`}], 
        PointBox[{5.1, 0.13227572677623448`}], 
        PointBox[{5.2, 0.13109533788281164`}], 
        PointBox[{5.3, 0.129313103636764}], 
        PointBox[{5.4, 0.13180268477002277`}], 
        PointBox[{5.5, 0.13293712192902282`}], 
        PointBox[{5.6, 0.12930228529157986`}], 
        PointBox[{5.7, 0.13061150900391996`}], 
        PointBox[{5.8, 0.13230749543078513`}], 
        PointBox[{5.9, 0.13003649577515958`}], 
        PointBox[{6., 0.12946144845618962`}], 
        PointBox[{6.1, 0.132362518235856}], 
        PointBox[{6.2, 0.13099286413613043`}], 
        PointBox[{6.3, 0.1293385101130139}], 
        PointBox[{6.4, 0.13224393482071584`}], 
        PointBox[{6.5, 0.13262866381967053`}], 
        PointBox[{6.6, 0.12933246287458808`}], 
        PointBox[{6.7, 0.13082568685585116`}], 
        PointBox[{6.8, 0.13238292267697221`}], 
        PointBox[{6.9, 0.12978481908021156`}], 
        PointBox[{7., 0.12981150799641222`}], 
        PointBox[{7.1, 0.13242837239348457`}], 
        PointBox[{7.2, 0.13089378207579075`}], 
        PointBox[{7.3, 0.12939378311813807`}], 
        PointBox[{7.4, 0.13268706338201172`}], 
        PointBox[{7.5, 0.13230530515559208`}], 
        PointBox[{7.6, 0.12939574585950592`}], 
        PointBox[{7.7, 0.13104566650827865`}], 
        PointBox[{7.8, 0.1324388411914163}], 
        PointBox[{7.9, 0.12955447351478164`}], 
        PointBox[{8., 0.1301844681083588}], 
        PointBox[{8.1, 0.1324735713519455}], 
        PointBox[{8.2, 0.13079727735066046`}], 
        PointBox[{8.3, 0.12948088233069444`}], 
        PointBox[{8.4, 0.13311666664674796`}], 
        PointBox[{8.5, 0.13197916446516972`}], 
        PointBox[{8.6, 0.12948883870657846`}], 
        PointBox[{8.7, 0.13126881645431354`}], 
        PointBox[{8.8, 0.13247169559763308`}], 
        PointBox[{8.9, 0.129355682164761}], 
        PointBox[{9., 0.13056726536217245`}], 
        PointBox[{9.1, 0.13249838627436206`}], 
        PointBox[{9.2, 0.1307034783947848}], 
        PointBox[{9.3, 0.12960143553616005`}], 
        PointBox[{9.4, 0.1335168790931208}], 
        PointBox[{9.5, 0.1316601032836814}], 
        PointBox[{9.6, 0.12960699594286149`}], 
        PointBox[{9.7, 0.13149162652333227`}], 
        PointBox[{9.8, 0.13247656961523716`}], 
        PointBox[{9.9, 0.12919663484594393`}], 
        PointBox[{10., 0.1309472534909155}], 
        PointBox[{10.1, 0.13250311905898413`}], 
        PointBox[{10.2, 0.13061183754518768`}], 
        PointBox[{10.3, 0.12975659556389235`}], 
        PointBox[{10.4, 0.13387102043733945`}], 
        PointBox[{10.5, 0.13135739784893238`}], 
        PointBox[{10.6, 0.12974650642383964`}], 
        PointBox[{10.7, 0.13171079199560456`}], 
        PointBox[{10.8, 0.1324498301770732}], 
        PointBox[{10.9, 0.12908452502498552`}], 
        PointBox[{11., 0.13131290585715974`}], 
        PointBox[{11.1, 0.13248760217966501`}], 
        PointBox[{11.2, 0.13052220183752564`}], 
        PointBox[{11.3, 0.12994730718580783`}], 
        PointBox[{11.4, 0.1341621627816046}], 
        PointBox[{11.5, 0.13107774281426737`}], 
        PointBox[{11.6, 0.129903076525852}], 
        PointBox[{11.7, 0.1319234617336822}], 
        PointBox[{11.8, 0.13238743864294325`}], 
        PointBox[{11.9, 0.12902230711842502`}], 
        PointBox[{12., 0.13165470186003933`}], 
        PointBox[{12.1, 0.13245205544444916`}], 
        PointBox[{12.2, 0.1304344734377745}], 
        PointBox[{12.3, 0.1301744655486561}], 
        PointBox[{12.4, 0.13437798228273662`}], 
        PointBox[{12.5, 0.13082632951321752`}], 
        PointBox[{12.6, 0.13007251648145138`}], 
        PointBox[{12.7, 0.1321256341199981}], 
        PointBox[{12.8, 0.13228640507965778`}], 
        PointBox[{12.9, 0.12901048466152468`}], 
        PointBox[{13., 0.13196493891088734`}], 
        PointBox[{13.1, 0.13239714096216088`}], 
        PointBox[{13.2, 0.13034966009896018`}], 
        PointBox[{13.3, 0.13043747153367347`}], 
        PointBox[{13.4, 0.1345067579480802}], 
        PointBox[{13.5, 0.13060634700884594`}], 
        PointBox[{13.6, 0.13025168704505646`}], 
        PointBox[{13.7, 0.13231398844407138`}], 
        PointBox[{13.8, 0.13214457695797185`}], 
        PointBox[{13.9, 0.12904710099933395`}], 
        PointBox[{14., 0.13223771167963755`}], 
        PointBox[{14.1, 0.13232279600218047`}], 
        PointBox[{14.2, 0.13026741118865795`}], 
        PointBox[{14.3, 0.13073569020150355`}], 
        PointBox[{14.4, 0.1345424762162907}], 
        PointBox[{14.5, 0.13041897337709465`}], 
        PointBox[{14.6, 0.13043595153268986`}], 
        PointBox[{14.7, 0.132485306804487}], 
        PointBox[{14.8, 0.1319612134721859}], 
        PointBox[{14.9, 0.12913107133262555`}], 
        PointBox[{15., 0.13246894466411485`}], 
        PointBox[{15.1, 0.13222935532078128`}], 
        PointBox[{15.2, 0.13018913979351723`}], 
        PointBox[{15.3, 0.13106687579036225`}], 
        PointBox[{15.4, 0.13448420107317643`}], 
        PointBox[{15.5, 0.13026458240551592`}], 
        PointBox[{15.6, 0.1306227506171739}], 
        PointBox[{15.7, 0.1326357908911194}], 
        PointBox[{15.8, 0.1317374969346222}], 
        PointBox[{15.9, 0.1292619620816215}], 
        PointBox[{16., 0.1326565043230766}], 
        PointBox[{16.1, 0.13211806090192546`}], 
        PointBox[{16.2, 0.13011620650681668`}], 
        PointBox[{16.3, 0.13142696321919523`}], 
        PointBox[{16.4, 0.13433487679825676`}], 
        PointBox[{16.5, 0.13014186489655177`}], 
        PointBox[{16.6, 0.13080868641999047`}], 
        PointBox[{16.7, 0.13276198772602954`}], 
        PointBox[{16.8, 0.13147673232967647`}], 
        PointBox[{16.9, 0.1294382149520655}], 
        PointBox[{17., 0.13279932912713335`}], 
        PointBox[{17.1, 0.13198901452363468`}], 
        PointBox[{17.2, 0.13005110346599003`}], 
        PointBox[{17.3, 0.1318097118431683}], 
        PointBox[{17.4, 0.13410337736796335`}], 
        PointBox[{17.5, 0.13004910569631456`}], 
        PointBox[{17.6, 0.13099116052937726`}], 
        PointBox[{17.7, 0.13286106199992895`}], 
        PointBox[{17.8, 0.131185105178444}], 
        PointBox[{17.9, 0.1296565691659563}], 
        PointBox[{18., 0.13289792000489967`}], 
        PointBox[{18.1, 0.13184394086640075`}], 
        PointBox[{18.2, 0.12999558377469422`}], 
        PointBox[{18.3, 0.13220739897056358`}], 
        PointBox[{18.4, 0.13380145348324057`}], 
        PointBox[{18.5, 0.1299835079570703}], 
        PointBox[{18.6, 0.1311673123828926}], 
        PointBox[{18.7, 0.13292982001999273`}], 
        PointBox[{18.8, 0.1308706715605631}], 
        PointBox[{18.9, 0.12991118042710526`}], 
        PointBox[{19., 0.13295345207435508`}], 
        PointBox[{19.1, 0.13168383035399572`}], 
        PointBox[{19.2, 0.12995174624242967`}], 
        PointBox[{19.3, 0.1326094512626441}], 
        PointBox[{19.4, 0.1334443364497979}], 
        PointBox[{19.5, 0.12994259697209223`}], 
        PointBox[{19.6, 0.1313354647022849}], 
        PointBox[{19.7, 0.13296530609814947`}], 
        PointBox[{19.8, 0.13054467802332426`}], 
        PointBox[{19.9, 0.1301928363364809}], 
        PointBox[{20., 0.13296821216990906`}], 
        PointBox[{20.1, 0.13151071346109441`}], 
        PointBox[{20.2, 0.12992329331103492`}], 
        PointBox[{20.3, 0.1330035793253429}], 
        PointBox[{20.4, 0.13304813734804205`}], 
        PointBox[{20.5, 0.1299232875368943}], 
        PointBox[{20.6, 0.1314937036643119}], 
        PointBox[{20.7, 0.13296524624654085`}], 
        PointBox[{20.8, 0.13021967549522756`}], 
        PointBox[{20.9, 0.13048901827094458`}], 
        PointBox[{21., 0.13294439427923438`}], 
        PointBox[{21.1, 0.13132617815195338`}], 
        PointBox[{21.2, 0.1299131241662458}], 
        PointBox[{21.3, 0.1333751867328834}], 
        PointBox[{21.4, 0.13262866154616398`}], 
        PointBox[{21.5, 0.12992251127576232`}], 
        PointBox[{21.6, 0.13164003945591915`}], 
        PointBox[{21.7, 0.13292711730398404`}], 
        PointBox[{21.8, 0.12990853376618544`}], 
        PointBox[{21.9, 0.13078775538830822`}], 
        PointBox[{22., 0.1328855555872885}], 
        PointBox[{22.1, 0.13113260954757183`}], 
        PointBox[{22.2, 0.12992497916050968`}], 
        PointBox[{22.3, 0.133710006389511}], 
        PointBox[{22.4, 0.13220097583616608`}], 
        PointBox[{22.5, 0.12993778319808721`}], 
        PointBox[{22.6, 0.13177418619109565`}], 
        PointBox[{22.7, 0.13284924476902962`}], 
        PointBox[{22.8, 0.12962417104596433`}], 
        PointBox[{22.9, 0.13107671220436623`}], 
        PointBox[{23., 0.13279474241186487`}], 
        PointBox[{23.1, 0.13093224763874703`}], 
        PointBox[{23.2, 0.12996194657087856`}], 
        PointBox[{23.3, 0.13399187198114126`}], 
        PointBox[{23.4, 0.1317784614261312}], 
        PointBox[{23.5, 0.12996653731487043`}], 
        PointBox[{23.6, 0.1318946921111864}], 
        PointBox[{23.7, 0.1327305790207622}], 
        PointBox[{23.8, 0.12937651006827636`}], 
        PointBox[{23.9, 0.13134579745338987`}], 
        PointBox[{24., 0.13267566534922173`}], 
        PointBox[{24.1, 0.13072820376094732`}], 
        PointBox[{24.2, 0.13002753364920544`}], 
        PointBox[{24.3, 0.13420797237798776`}], 
        PointBox[{24.4, 0.13137213627027927`}], 
        PointBox[{24.5, 0.1300069415525443}], 
        PointBox[{24.6, 0.1320009445882247}], 
        PointBox[{24.7, 0.1325706183212571}], 
        PointBox[{24.8, 0.12917306225536554`}], 
        PointBox[{24.9, 0.1315872663351731}], 
        PointBox[{25., 0.132532214356959}], 
        PointBox[{25.1, 0.13052315911448467`}], 
        PointBox[{25.2, 0.13012494790600107`}], 
        PointBox[{25.3, 0.13434613403329326`}], 
        PointBox[{25.4, 0.13099084296293637`}], 
        PointBox[{25.5, 0.13005728850012677`}], 
        PointBox[{25.6, 0.1320930862249099}], 
        PointBox[{25.7, 0.1323698261532206}], 
        PointBox[{25.8, 0.1290165848705013}], 
        PointBox[{25.9, 0.131795715703944}], 
        PointBox[{26., 0.132368039343116}], 
        PointBox[{26.1, 0.13032047545627357`}], 
        PointBox[{26.2, 0.1302561914319324}], 
        PointBox[{26.3, 0.13439925079758816`}], 
        PointBox[{26.4, 0.1306408546662235}], 
        PointBox[{26.5, 0.13011613366175695`}], 
        PointBox[{26.6, 0.1321698004348548}], 
        PointBox[{26.7, 0.13212939311804672`}], 
        PointBox[{26.8, 0.12891043661241122`}], 
        PointBox[{26.9, 0.13196824880726646`}], 
        PointBox[{27., 0.13218703764722226`}], 
        PointBox[{27.1, 0.13012360216955746`}], 
        PointBox[{27.2, 0.13042318429963007`}], 
        PointBox[{27.3, 0.134363504632502}], 
        PointBox[{27.4, 0.13032666999378598`}], 
        PointBox[{27.5, 0.13018271530706388`}], 
        PointBox[{27.6, 0.13223281414523966`}], 
        PointBox[{27.7, 0.13185210543502696`}], 
        PointBox[{27.8, 0.12885421247133902`}], 
        PointBox[{27.9, 0.13210415225913574`}], 
        PointBox[{28., 0.13199298279779742`}], 
        PointBox[{28.1, 0.12993602192514828`}], 
        PointBox[{28.2, 0.1306263863261076}], 
        PointBox[{28.3, 0.13423985684768902`}], 
        PointBox[{28.4, 0.13005096454976756`}], 
        PointBox[{28.5, 0.130256439259612}], 
        PointBox[{28.6, 0.13227989326540368`}], 
        PointBox[{28.7, 0.13154196131893722`}], 
        PointBox[{28.8, 0.12885048183430525`}], 
        PointBox[{28.9, 0.13220433702603998`}], 
        PointBox[{29., 0.13178954862255488`}], 
        PointBox[{29.1, 0.12976139620222987`}], 
        PointBox[{29.2, 0.13086478954653266`}], 
        PointBox[{29.3, 0.13403552158265056`}], 
        PointBox[{29.4, 0.12981509343304382`}], 
        PointBox[{29.5, 0.1303370599347134}], 
        PointBox[{29.6, 0.1323135413335269}], 
        PointBox[{29.7, 0.1312043355619112}], 
        PointBox[{29.8, 0.1289009089263708}], 
        PointBox[{29.9, 0.1322709539093704}], 
        PointBox[{30., 0.1315802879659247}], 
        PointBox[{30.1, 0.12960357897758482`}], 
        PointBox[{30.2, 0.1311358839817626}], 
        PointBox[{30.3, 0.13375873349328793`}], 
        PointBox[{30.4, 0.12961934724996638`}], 
        PointBox[{30.5, 0.13042431875475036`}], 
        PointBox[{30.6, 0.13233153437342743`}], 
        PointBox[{30.7, 0.13084687331403771`}], 
        PointBox[{30.8, 0.12900504286929626`}], 
        PointBox[{30.9, 0.132306991064313}], 
        PointBox[{31., 0.1313685440864738}], 
        PointBox[{31.1, 0.12946650119427333`}], 
        PointBox[{31.2, 0.13143518369054227`}], 
        PointBox[{31.3, 0.13342376213747334`}], 
        PointBox[{31.4, 0.12946321359130164`}], 
        PointBox[{31.5, 0.13051812317503492`}], 
        PointBox[{31.6, 0.13233542639169932`}], 
        PointBox[{31.7, 0.13047842911132201`}], 
        PointBox[{31.8, 0.1291605345687171}], 
        PointBox[{31.9, 0.13231605280468792`}], 
        PointBox[{32., 0.1311574903676441}], 
        PointBox[{32.1, 0.12935393720479338`}], 
        PointBox[{32.2, 0.13175667492096155`}], 
        PointBox[{32.3, 0.1330446523520809}], 
        PointBox[{32.4, 0.12934577265826985`}], 
        PointBox[{32.5, 0.13061916360733042`}], 
        PointBox[{32.6, 0.1323240318645982}], 
        PointBox[{32.7, 0.13010953706192363`}], 
        PointBox[{32.8, 0.1293619344556918}], 
        PointBox[{32.9, 0.13230216253769395`}], 
        PointBox[{33., 0.13095027245401225`}], 
        PointBox[{33.1, 0.12926994941173894`}], 
        PointBox[{33.2, 0.13209215555664774`}], 
        PointBox[{33.3, 0.13263784081376626`}], 
        PointBox[{33.4, 0.1292657301558782}], 
        PointBox[{33.5, 0.13072744883643034`}], 
        PointBox[{33.6, 0.13229792765906892`}], 
        PointBox[{33.7, 0.1297519465853703}], 
        PointBox[{33.8, 0.12960057897418736`}], 
        PointBox[{33.9, 0.13226864849098166`}], 
        PointBox[{34., 0.13074931755541902`}], 
        PointBox[{34.1, 0.12921798795960038`}], 
        PointBox[{34.2, 0.1324314797886258}], 
        PointBox[{34.3, 0.13221816464302166`}], 
        PointBox[{34.4, 0.12922131532048536`}], 
        PointBox[{34.5, 0.13084260146606366`}], 
        PointBox[{34.6, 0.1322554226680197}], 
        PointBox[{34.7, 0.12941770617117188`}], 
        PointBox[{34.8, 0.12986651638180016`}], 
        PointBox[{34.9, 0.13221930841395738`}], 
        PointBox[{35., 0.13055698728788837`}], 
        PointBox[{35.1, 0.12920154286483887`}], 
        PointBox[{35.2, 0.13276306622131817`}], 
        PointBox[{35.3, 0.13180032354516982`}], 
        PointBox[{35.4, 0.12921090465309257`}], 
        PointBox[{35.5, 0.13096478027134786`}], 
        PointBox[{35.6, 0.13219658841771992`}], 
        PointBox[{35.7, 0.12911911793757694`}], 
        PointBox[{35.8, 0.13014975797547626`}], 
        PointBox[{35.9, 0.13215769143760628`}], 
        PointBox[{36., 0.13037562766395652`}], 
        PointBox[{36.1, 0.12922411793154556`}], 
        PointBox[{36.2, 0.13307477090257971`}], 
        PointBox[{36.3, 0.13139697504738804`}], 
        PointBox[{36.4, 0.12923263143186234`}], 
        PointBox[{36.5, 0.1310937726113514}], 
        PointBox[{36.6, 0.13211987704766515`}], 
        PointBox[{36.7, 0.12886653538534065`}], 
        PointBox[{36.8, 0.13044044908136276`}], 
        PointBox[{36.9, 0.13208643922908636`}], 
        PointBox[{37., 0.13020705856475198`}], 
        PointBox[{37.1, 0.12928865103658677`}], 
        PointBox[{37.2, 0.13335417322616816`}], 
        PointBox[{37.3, 0.13101870952654224`}], 
        PointBox[{37.4, 0.12928463154100645`}], 
        PointBox[{37.5, 0.13122919392218974`}], 
        PointBox[{37.6, 0.1320244944058594}], 
        PointBox[{37.7, 0.1286682920840929}], 
        PointBox[{37.8, 0.13073015252940295`}], 
        PointBox[{37.9, 0.1320082086423036}], 
        PointBox[{38., 0.13005287586900013`}], 
        PointBox[{38.1, 0.12939762055839005`}], 
        PointBox[{38.2, 0.13358875226944428`}], 
        PointBox[{38.3, 0.13067361165241304`}], 
        PointBox[{38.4, 0.1293645511860508}], 
        PointBox[{38.5, 0.13137013336144335`}], 
        PointBox[{38.6, 0.13190893631693992`}], 
        PointBox[{38.7, 0.12852895172107165`}], 
        PointBox[{38.8, 0.13101168274510866`}], 
        PointBox[{38.9, 0.1319247509140769}], 
        PointBox[{39., 0.1299146933544891}], 
        PointBox[{39.1, 0.1295531028740669}], 
        PointBox[{39.2, 0.13376805319111576`}], 
        PointBox[{39.3, 0.13036811439344495`}], 
        PointBox[{39.4, 0.1294706545103891}], 
        PointBox[{39.5, 0.13151506241920227`}], 
        PointBox[{39.6, 0.13177229283651398`}], 
        PointBox[{39.7, 0.1284517820448388}], 
        PointBox[{39.8, 0.13127940216443426`}], 
        PointBox[{39.9, 0.1318382425691512}], 
        PointBox[{40., 0.12979370532930853`}], 
        PointBox[{40.1, 0.12975622996399727`}], 
        PointBox[{40.2, 0.13388430098729195`}], 
        PointBox[{40.3, 0.13010612800737978`}], 
        PointBox[{40.4, 0.12960050335687154`}], 
        PointBox[{40.5, 0.1316620961920453}], 
        PointBox[{40.6, 0.13161384689457198`}], 
        PointBox[{40.7, 0.12843672700290085`}], 
        PointBox[{40.8, 0.13152920078932415`}], 
        PointBox[{40.9, 0.13174993332003565`}], 
        PointBox[{41., 0.12969111511976586`}], 
        PointBox[{41.1, 0.13000739720768364`}], 
        PointBox[{41.2, 0.1339307365136705}], 
        PointBox[{41.3, 0.12988997746945383`}], 
        PointBox[{41.4, 0.12975213029287294`}], 
        PointBox[{41.5, 0.13181096507981307`}], 
        PointBox[{41.6, 0.13143330185238758`}], 
        PointBox[{41.7, 0.12848263627413503`}], 
        PointBox[{41.8, 0.131757974403741}], 
        PointBox[{41.9, 0.1316601905722038}], 
        PointBox[{42., 0.12960803012674227`}], 
        PointBox[{42.1, 0.1303055318322327}], 
        PointBox[{42.2, 0.13390631745240722`}], 
        PointBox[{42.3, 0.12972037738707173`}], 
        PointBox[{42.4, 0.1299228787221933}], 
        PointBox[{42.5, 0.1319575953670399}], 
        PointBox[{42.6, 0.13123131994259002`}], 
        PointBox[{42.7, 0.1285897075688546}], 
        PointBox[{42.8, 0.13196356613289004`}], 
        PointBox[{42.9, 0.1315695129770948}], 
        PointBox[{43., 0.12954519076087243`}], 
        PointBox[{43.1, 0.13064787126385938`}], 
        PointBox[{43.2, 0.13381192162948463`}], 
        PointBox[{43.3, 0.1295961312404058}], 
        PointBox[{43.4, 0.13010993842213378`}], 
        PointBox[{43.5, 0.1321001543753936}], 
        PointBox[{43.6, 0.13100938592002262`}], 
        PointBox[{43.7, 0.12875613382605258`}], 
        PointBox[{43.8, 0.13214421421385592`}], 
        PointBox[{43.9, 0.13147836500843602`}], 
        PointBox[{44., 0.12950357597893175`}], 
        PointBox[{44.1, 0.13103029768080995`}], 
        PointBox[{44.2, 0.1336526790565551}], 
        PointBox[{44.3, 0.1295159247906867}], 
        PointBox[{44.4, 0.1303110022530478}], 
        PointBox[{44.5, 0.13223469795412907`}], 
        PointBox[{44.6, 0.1307712383576199}], 
        PointBox[{44.7, 0.1289797882661882}], 
        PointBox[{44.8, 0.1322992424776394}], 
        PointBox[{44.9, 0.13138609808098345`}], 
        PointBox[{45., 0.12948415224566592`}], 
        PointBox[{45.1, 0.1314459873766058}], 
        PointBox[{45.2, 0.13343616429354657`}], 
        PointBox[{45.3, 0.12947677737543098`}], 
        PointBox[{45.4, 0.13052301803042565`}], 
        PointBox[{45.5, 0.13235811973229789`}], 
        PointBox[{45.6, 0.1305216189797579}], 
        PointBox[{45.7, 0.12925624041041153`}], 
        PointBox[{45.8, 0.13242805800566868`}], 
        PointBox[{45.9, 0.13129298427684805`}], 
        PointBox[{46., 0.1294880303018846}], 
        PointBox[{46.1, 0.13188643603756944`}], 
        PointBox[{46.2, 0.13317298826057394`}], 
        PointBox[{46.3, 0.12947554898578192`}], 
        PointBox[{46.4, 0.13074292311288646`}], 
        PointBox[{46.5, 0.1324662345249697}], 
        PointBox[{46.6, 0.13026761386508}], 
        PointBox[{46.7, 0.12957689545472212`}], 
        PointBox[{46.8, 0.13253046028819673`}], 
        PointBox[{46.9, 0.13119821120010627`}], 
        PointBox[{47., 0.12951641079734935`}], 
        PointBox[{47.1, 0.13234026963726103`}], 
        PointBox[{47.2, 0.13287485553144765`}], 
        PointBox[{47.3, 0.1295084312571413}], 
        PointBox[{47.4, 0.13096787256282882`}], 
        PointBox[{47.5, 0.1325548804122664}], 
        PointBox[{47.6, 0.13001824123049632`}], 
        PointBox[{47.7, 0.12993132401522867`}], 
        PointBox[{47.8, 0.13260630202568302`}], 
        PointBox[{47.9, 0.1311015679553164}], 
        PointBox[{48., 0.1295705174228006}], 
        PointBox[{48.1, 0.13279383173500287`}], 
        PointBox[{48.2, 0.13255395960494196`}], 
        PointBox[{48.3, 0.12957113917701055`}], 
        PointBox[{48.4, 0.1311941220067462}], 
        PointBox[{48.5, 0.13261904524426468`}], 
        PointBox[{48.6, 0.12978328665479313`}], 
        PointBox[{48.7, 0.1303063459967065}], 
        PointBox[{48.8, 0.1326557551883149}], 
        PointBox[{48.9, 0.1310029645637543}], 
        PointBox[{49., 0.12965200237980345`}], 
        PointBox[{49.1, 0.13323186442046986`}], 
        PointBox[{49.2, 0.132222847368207}], 
        PointBox[{49.3, 0.12965980136208602`}], 
        PointBox[{49.4, 0.13141905410339225`}], 
        PointBox[{49.5, 0.13265576294244624`}], 
        PointBox[{49.6, 0.1295734902582249}], 
        PointBox[{49.7, 0.1306886487226928}], 
        PointBox[{49.8, 0.13267917921442043`}], 
        PointBox[{49.9, 0.13090156128177213`}], 
        PointBox[{50., 0.12976234891622293`}], 
        PointBox[{50.1, 0.13363752321520642`}], 
        PointBox[{50.2, 0.13189266586769122`}], 
        PointBox[{50.3, 0.1297701957285554}], 
        PointBox[{50.4, 0.13163913364069013`}], 
        PointBox[{50.5, 0.1326594674724837}], 
        PointBox[{50.6, 0.12939835434937716`}], 
        PointBox[{50.7, 0.13106519519192172`}], 
        PointBox[{50.8, 0.13267708601079856`}], 
        PointBox[{50.9, 0.13079791770131813`}], 
        PointBox[{51., 0.12990325305086978`}], 
        PointBox[{51.1, 0.13399368247452056`}], 
        PointBox[{51.2, 0.13157331464444494`}], 
        PointBox[{51.3, 0.12989821450520678`}], 
        PointBox[{51.4, 0.13185139215966296`}], 
        PointBox[{51.5, 0.13262664049538742`}], 
        PointBox[{51.6, 0.12926538099360496`}], 
        PointBox[{51.7, 0.13142398804178895`}], 
        PointBox[{51.8, 0.13264984269002575`}], 
        PointBox[{51.9, 0.13069255351542983`}], 
        PointBox[{52., 0.1300758906376967}], 
        PointBox[{52.1, 0.13428404300551916`}], 
        PointBox[{52.2, 0.13127251813327145`}], 
        PointBox[{52.3, 0.13003969106129729`}], 
        PointBox[{52.4, 0.13205261632585702`}], 
        PointBox[{52.5, 0.13255357349376895`}], 
        PointBox[{52.6, 0.1291783886040068}], 
        PointBox[{52.7, 0.1317551140725517}], 
        PointBox[{52.8, 0.1325982946701035}], 
        PointBox[{52.9, 0.13058511814900733`}], 
        PointBox[{53., 0.13028125949107064`}], 
        PointBox[{53.1, 0.13449408270771954`}], 
        PointBox[{53.2, 0.13099617682938144`}], 
        PointBox[{53.3, 0.1301907977904752}], 
        PointBox[{53.4, 0.1322393848567269}], 
        PointBox[{53.5, 0.13243742943086514`}], 
        PointBox[{53.6, 0.12913822124093632`}], 
        PointBox[{53.7, 0.1320508031073647}], 
        PointBox[{53.8, 0.13252310120276595`}], 
        PointBox[{53.9, 0.13047646027460372`}], 
        PointBox[{54., 0.13051967823925117`}], 
        PointBox[{54.1, 0.13461387431688848`}], 
        PointBox[{54.2, 0.130748273674872}], 
        PointBox[{54.3, 0.1303482470099655}], 
        PointBox[{54.4, 0.13240875567321075`}], 
        PointBox[{54.5, 0.13227691338760889`}], 
        PointBox[{54.6, 0.12914479252411704`}], 
        PointBox[{54.7, 0.13230550576217756`}], 
        PointBox[{54.8, 0.13242532296537776`}], 
        PointBox[{54.9, 0.13036852499170926`}], 
        PointBox[{55., 0.13079077831618366`}], 
        PointBox[{55.1, 0.13463630127313975`}], 
        PointBox[{55.2, 0.13053111785846538`}], 
        PointBox[{55.3, 0.13050861991500992`}], 
        PointBox[{55.4, 0.13255764806171672`}], 
        PointBox[{55.5, 0.1320717809993851}], 
        PointBox[{55.6, 0.12919601974433606`}], 
        PointBox[{55.7, 0.13251587782528454`}], 
        PointBox[{55.8, 0.13230619862414922`}], 
        PointBox[{55.9, 0.13026237145880082`}], 
        PointBox[{56., 0.13109265732172623`}], 
        PointBox[{56.1, 0.13456121470393434`}], 
        PointBox[{56.2, 0.13034524014263976`}], 
        PointBox[{56.3, 0.13066893792361325`}], 
        PointBox[{56.4, 0.132684071290779}], 
        PointBox[{56.5, 0.13182384515747764`}], 
        PointBox[{56.6, 0.1292926289457918}], 
        PointBox[{56.7, 0.1326803153986696}], 
        PointBox[{56.8, 0.13216756083533746`}], 
        PointBox[{56.9, 0.1301599757582354}], 
        PointBox[{57., 0.1314223572274545}], 
        PointBox[{57.1, 0.13439330065924407`}], 
        PointBox[{57.2, 0.1301906398925734}], 
        PointBox[{57.3, 0.13082731041532678`}], 
        PointBox[{57.4, 0.1327847088381545}], 
        PointBox[{57.5, 0.13153761851195908`}], 
        PointBox[{57.6, 0.12943425258838556`}], 
        PointBox[{57.7, 0.13279889690455138`}], 
        PointBox[{57.8, 0.1320109584281187}], 
        PointBox[{57.9, 0.1300649501715927}], 
        PointBox[{58., 0.13177440711196117`}], 
        PointBox[{58.1, 0.134140828316157}], 
        PointBox[{58.2, 0.1300655983774922}], 
        PointBox[{58.3, 0.1309809228360747}], 
        PointBox[{58.4, 0.13285727697009606`}], 
        PointBox[{58.5, 0.13121919568488477`}], 
        PointBox[{58.6, 0.12961786262812094`}], 
        PointBox[{58.7, 0.13287232849569597`}], 
        PointBox[{58.8, 0.1318379546962399}], 
        PointBox[{58.9, 0.12997850095407182`}], 
        PointBox[{59., 0.13214124295070515`}], 
        PointBox[{59.1, 0.13381699538688765`}], 
        PointBox[{59.2, 0.12996803271253887`}], 
        PointBox[{59.3, 0.131128210166918}], 
        PointBox[{59.4, 0.13289955752242952`}], 
        PointBox[{59.5, 0.13087795116055817`}], 
        PointBox[{59.6, 0.12983892656996393`}], 
        PointBox[{59.7, 0.1329033840837078}], 
        PointBox[{59.8, 0.13165121544349973`}], 
        PointBox[{59.9, 0.12990532089652795`}], 
        PointBox[{60., 0.13251392980579693`}], 
        PointBox[{60.1, 0.13343792294061152`}], 
        PointBox[{60.2, 0.12989630568353916`}], 
        PointBox[{60.3, 0.1312682194182265}], 
        PointBox[{60.4, 0.13290975950036354`}], 
        PointBox[{60.5, 0.13052548382379167`}], 
        PointBox[{60.6, 0.13008880145666055`}], 
        PointBox[{60.7, 0.13289471600615216`}], 
        PointBox[{60.8, 0.13145289065671342`}], 
        PointBox[{60.9, 0.12984806680471464`}], 
        PointBox[{61., 0.13288073713240486`}], 
        PointBox[{61.1, 0.133020023607045}], 
        PointBox[{61.2, 0.12984763049912532`}], 
        PointBox[{61.3, 0.13139932876475097`}], 
        PointBox[{61.4, 0.13288657772137916`}], 
        PointBox[{61.5, 0.1301743437625177}], 
        PointBox[{61.6, 0.13035646374538656`}], 
        PointBox[{61.7, 0.13284997841524843`}], 
        PointBox[{61.8, 0.1312457910191116}], 
        PointBox[{61.9, 0.12981067193269355`}], 
        PointBox[{62., 0.1332287430390332}], 
        PointBox[{62.1, 0.13258021631349612`}], 
        PointBox[{62.2, 0.12981980313088967`}], 
        PointBox[{62.3, 0.1315211540619721}], 
        PointBox[{62.4, 0.13282843198819758`}], 
        PointBox[{62.5, 0.1298380457646456}], 
        PointBox[{62.6, 0.13063000160398688`}], 
        PointBox[{62.7, 0.13277285705048728`}], 
        PointBox[{62.8, 0.13103238585294033`}], 
        PointBox[{62.9, 0.12979753705130542`}], 
        PointBox[{63., 0.13354392849826435`}], 
        PointBox[{63.1, 0.13213396391237833`}], 
        PointBox[{63.2, 0.129810727878853}], 
        PointBox[{63.3, 0.1316334454505071}], 
        PointBox[{63.4, 0.13273431006572953`}], 
        PointBox[{63.5, 0.12953092195296453`}], 
        PointBox[{63.6, 0.1308983053955393}], 
        PointBox[{63.7, 0.13266723496122163`}], 
        PointBox[{63.8, 0.13081563371368543`}], 
        PointBox[{63.9, 0.12981191807046408`}], 
        PointBox[{64., 0.13381227734523896`}], 
        PointBox[{64.1, 0.1316947050124147}], 
        PointBox[{64.2, 0.12981816891009856`}], 
        PointBox[{64.3, 0.13173523298473216`}], 
        PointBox[{64.4, 0.13260339297297857`}], 
        PointBox[{64.5, 0.12926178821415663`}], 
        PointBox[{64.6, 0.13115162838747205`}], 
        PointBox[{64.7, 0.13253728955296326`}], 
        PointBox[{64.8, 0.13059883195946895`}], 
        PointBox[{64.9, 0.12985742628314328`}], 
        PointBox[{65., 0.13402080531163707`}], 
        PointBox[{65.1, 0.13127423706662256`}], 
        PointBox[{65.2, 0.12984096608201987`}], 
        PointBox[{65.3, 0.13182682817086622`}], 
        PointBox[{65.4, 0.13243614337210888`}], 
        PointBox[{65.5, 0.12903937388004236`}], 
        PointBox[{65.6, 0.13138270840246621`}], 
        PointBox[{65.7, 0.13238734119791248`}], 
        PointBox[{65.8, 0.13038504724292566`}], 
        PointBox[{65.9, 0.12993764571124936`}], 
        PointBox[{66., 0.13415887486682748`}], 
        PointBox[{66.1, 0.1308814213338612}], 
        PointBox[{66.2, 0.12987768046898207`}], 
        PointBox[{66.3, 0.13190863592132496`}], 
        PointBox[{66.4, 0.13223320298151225`}], 
        PointBox[{66.5, 0.1288676980133094}], 
        PointBox[{66.6, 0.13158663958087452`}], 
        PointBox[{66.7, 0.13222110315581959`}], 
        PointBox[{66.8, 0.13017738673537232`}], 
        PointBox[{66.9, 0.13005517454182913`}], 
        PointBox[{67., 0.13421912701006977`}], 
        PointBox[{67.1, 0.13052337916799947`}], 
        PointBox[{67.2, 0.12992768815146116`}], 
        PointBox[{67.3, 0.131980901557305}], 
        PointBox[{67.4, 0.13199631220920624`}], 
        PointBox[{67.5, 0.12874899847516708`}], 
        PointBox[{67.6, 0.13176078761451746`}], 
        PointBox[{67.7, 0.1320431316138953}], 
        PointBox[{67.8, 0.12998032008491886`}], 
        PointBox[{67.9, 0.1302124663207749}], 
        PointBox[{68., 0.13419757953425188`}], 
        PointBox[{68.1, 0.13020433590916722`}], 
        PointBox[{68.2, 0.12999000409674966`}], 
        PointBox[{68.3, 0.13204334042747712`}], 
        PointBox[{68.4, 0.13172784801909526`}], 
        PointBox[{68.5, 0.1286852757756321}], 
        PointBox[{68.6, 0.13190398744074822`}], 
        PointBox[{68.7, 0.1318565270676999}], 
        PointBox[{68.8, 0.1297958188051084}], 
        PointBox[{68.9, 0.13040964237874653`}], 
        PointBox[{69., 0.13409509754758495`}], 
        PointBox[{69.1, 0.12992743090709838`}], 
        PointBox[{69.2, 0.13006442627355258`}], 
        PointBox[{69.3, 0.1320968115385489}], 
        PointBox[{69.4, 0.13143131203512012`}], 
        PointBox[{69.5, 0.12867740488703922`}], 
        PointBox[{69.6, 0.13201696231073853`}], 
        PointBox[{69.7, 0.13166494310280227`}], 
        PointBox[{69.8, 0.12962867416971652`}], 
        PointBox[{69.9, 0.13064607403453626`}], 
        PointBox[{70., 0.13391618922955656`}], 
        PointBox[{70.1, 0.12969386997339954`}], 
        PointBox[{70.2, 0.1301503939279608}], 
        PointBox[{70.3, 0.13214078324503462`}], 
        PointBox[{70.4, 0.13111172252160042`}], 
        PointBox[{70.5, 0.12872671064785068`}], 
        PointBox[{70.6, 0.13210153030106417`}], 
        PointBox[{70.7, 0.13147155094137863`}], 
        PointBox[{70.8, 0.1294813221955896}], 
        PointBox[{70.9, 0.13092018869575517`}], 
        PointBox[{71., 0.13366927338693574`}], 
        PointBox[{71.1, 0.12950399797756307`}], 
        PointBox[{71.2, 0.13024762987447475`}], 
        PointBox[{71.3, 0.1321747328108965}], 
        PointBox[{71.4, 0.13077535005704438`}], 
        PointBox[{71.5, 0.1288342859454984}], 
        PointBox[{71.6, 0.132160158667151}], 
        PointBox[{71.7, 0.13127944816822656`}], 
        PointBox[{71.8, 0.12935795857479354`}], 
        PointBox[{71.9, 0.1312280727769153}], 
        PointBox[{72., 0.13336622241895787`}], 
        PointBox[{72.1, 0.12935751543996393`}], 
        PointBox[{72.2, 0.1303561487702934}], 
        PointBox[{72.3, 0.13219925297263316`}], 
        PointBox[{72.4, 0.13043028336451945`}], 
        PointBox[{72.5, 0.12899729129205234`}], 
        PointBox[{72.6, 0.13219568806272963`}], 
        PointBox[{72.7, 0.13109093154350318`}], 
        PointBox[{72.8, 0.12926152760095289`}], 
        PointBox[{72.9, 0.13156322939808943`}], 
        PointBox[{73., 0.13302022116362938`}], 
        PointBox[{73.1, 0.12925301310077794`}], 
        PointBox[{73.2, 0.13047587157210092`}], 
        PointBox[{73.3, 0.13221354353187995`}], 
        PointBox[{73.4, 0.1300855164637204}], 
        PointBox[{73.5, 0.12921068709249517`}], 
        PointBox[{73.6, 0.13221125195047426`}], 
        PointBox[{73.7, 0.13090864119764167`}], 
        PointBox[{73.8, 0.12919525784217684`}], 
        PointBox[{73.9, 0.13191814955496775`}], 
        PointBox[{74., 0.13264559668786882`}], 
        PointBox[{74.1, 0.12918876698520015`}], 
        PointBox[{74.2, 0.13060568184914884`}], 
        PointBox[{74.3, 0.1322161723957864}], 
        PointBox[{74.4, 0.12975160411118253`}], 
        PointBox[{74.5, 0.1294661979949047}], 
        PointBox[{74.6, 0.1322094407367716}], 
        PointBox[{74.7, 0.13073398082804197`}], 
        PointBox[{74.8, 0.12916239284789585`}], 
        PointBox[{74.9, 0.13228261508395772`}], 
        PointBox[{75., 0.13225700685479352`}], 
        PointBox[{75.1, 0.12916291008293015`}], 
        PointBox[{75.2, 0.13074609301161902`}], 
        PointBox[{75.3, 0.1322058044827936}], 
        PointBox[{75.4, 0.12944007969503887`}], 
        PointBox[{75.5, 0.1297539727958715}], 
        PointBox[{75.6, 0.13219323032847907`}], 
        PointBox[{75.7, 0.1305693205422184}], 
        PointBox[{75.8, 0.12916560363197133`}], 
        PointBox[{75.9, 0.13264494086301631`}], 
        PointBox[{76., 0.1318677080424533}], 
        PointBox[{76.1, 0.12917285383453933`}], 
        PointBox[{76.2, 0.13089512772202072`}], 
        PointBox[{76.3, 0.13218053796788734`}], 
        PointBox[{76.4, 0.1291619199947478}], 
        PointBox[{76.5, 0.13006331998554602`}], 
        PointBox[{76.6, 0.13216488630117773`}], 
        PointBox[{76.7, 0.13041557778225632`}], 
        PointBox[{76.8, 0.12920811114309186`}], 
        PointBox[{76.9, 0.13299277532297846`}], 
        PointBox[{77., 0.13149025342683718`}], 
        PointBox[{77.1, 0.12921657458008742`}], 
        PointBox[{77.2, 0.13105296716250142`}], 
        PointBox[{77.3, 0.13213925654055542`}], 
        PointBox[{77.4, 0.12892761228460756`}], 
        PointBox[{77.5, 0.13038352176683257`}], 
        PointBox[{77.6, 0.1321265815942741}], 
        PointBox[{77.7, 0.13027411762747776`}], 
        PointBox[{77.8, 0.12929186884256397`}], 
        PointBox[{77.9, 0.1333116548349074}], 
        PointBox[{78., 0.13113464295949573`}], 
        PointBox[{78.1, 0.12929130366400637`}], 
        PointBox[{78.2, 0.13121735750907848`}], 
        PointBox[{78.3, 0.13207918873096544`}], 
        PointBox[{78.4, 0.12874563078665627`}], 
        PointBox[{78.5, 0.13070465158611472`}], 
        PointBox[{78.6, 0.132079715716736}], 
        PointBox[{78.7, 0.1301454023256908}], 
        PointBox[{78.8, 0.1294189997108134}], 
        PointBox[{78.9, 0.133588683721474}], 
        PointBox[{79., 0.13080922702168188`}], 
        PointBox[{79.1, 0.12939427854170088`}], 
        PointBox[{79.2, 0.13138727307500056`}], 
        PointBox[{79.3, 0.13199842199973513`}], 
        PointBox[{79.4, 0.12862074980095894`}], 
        PointBox[{79.5, 0.13101876187269576`}], 
        PointBox[{79.6, 0.13202603196808368`}], 
        PointBox[{79.7, 0.13003057385178615`}], 
        PointBox[{79.8, 0.12959151729488722`}], 
        PointBox[{79.9, 0.1338122631252337}], 
        PointBox[{80., 0.13052027588880552`}], 
        PointBox[{80.1, 0.12952279704727057`}], 
        PointBox[{80.2, 0.1315604020095666}], 
        PointBox[{80.3, 0.13189499541649455`}], 
        PointBox[{80.4, 0.12855682044372255`}], 
        PointBox[{80.5, 0.13131880047990066`}], 
        PointBox[{80.6, 0.1319663132272711}], 
        PointBox[{80.7, 0.12993069011112382`}], 
        PointBox[{80.8, 0.1298101343399092}], 
        PointBox[{80.9, 0.1339703034989869}], 
        PointBox[{81., 0.13027170652543157`}], 
        PointBox[{81.1, 0.12967413609352316`}], 
        PointBox[{81.2, 0.13173498305463122`}], 
        PointBox[{81.3, 0.13176638923608808`}], 
        PointBox[{81.4, 0.12855205240846995`}], 
        PointBox[{81.5, 0.13159885839899985`}], 
        PointBox[{81.6, 0.13190082705259434`}], 
        PointBox[{81.7, 0.12984550265252207`}], 
        PointBox[{81.8, 0.13007439640748905`}], 
        PointBox[{81.9, 0.13405755840505498`}], 
        PointBox[{82., 0.13006579908272659`}], 
        PointBox[{82.1, 0.12984511377207622`}], 
        PointBox[{82.2, 0.1319074344159671}], 
        PointBox[{82.3, 0.13161192853637954`}], 
        PointBox[{82.4, 0.1286071753447869}], 
        PointBox[{82.5, 0.1318550879668773}], 
        PointBox[{82.6, 0.13183014638594823`}], 
        PointBox[{82.7, 0.12977648686933582`}], 
        PointBox[{82.8, 0.13038387034478008`}], 
        PointBox[{82.9, 0.13406854818621763`}], 
        PointBox[{83., 0.12990334700167996`}], 
        PointBox[{83.1, 0.13003270320013252`}], 
        PointBox[{83.2, 0.13207557553551202`}], 
        PointBox[{83.3, 0.13143159841030141`}], 
        PointBox[{83.4, 0.12871958862453398`}], 
        PointBox[{83.5, 0.13208431743665486`}], 
        PointBox[{83.6, 0.13175460393133787`}], 
        PointBox[{83.7, 0.12972344590908882`}], 
        PointBox[{83.8, 0.13073538137055793`}], 
        PointBox[{83.9, 0.13400320324732026`}], 
        PointBox[{84., 0.12978360379418555`}], 
        PointBox[{84.1, 0.13023429555288987`}], 
        PointBox[{84.2, 0.13223595390020149`}], 
        PointBox[{84.3, 0.13122622108055573`}], 
        PointBox[{84.4, 0.12888839135050667`}], 
        PointBox[{84.5, 0.13228397554147223`}], 
        PointBox[{84.6, 0.13167321282750136`}], 
        PointBox[{84.7, 0.12968725540960607`}], 
        PointBox[{84.8, 0.13112452624370688`}], 
        PointBox[{84.9, 0.1338661450256824}], 
        PointBox[{85., 0.12970438879627133`}], 
        PointBox[{85.1, 0.13044583126161707`}], 
        PointBox[{85.2, 0.13238450212862266`}], 
        PointBox[{85.3, 0.13099819236947619`}], 
        PointBox[{85.4, 0.12911173026127795`}], 
        PointBox[{85.5, 0.13245297916224094`}], 
        PointBox[{85.6, 0.13158655550741777`}], 
        PointBox[{85.7, 0.12966886815472153`}], 
        PointBox[{85.8, 0.13154498796332667`}], 
        PointBox[{85.9, 0.13366359787056692`}], 
        PointBox[{86., 0.12966315026754804`}], 
        PointBox[{86.1, 0.13066458417108523`}], 
        PointBox[{86.2, 0.1325180942765353}], 
        PointBox[{86.3, 0.13075242393588077`}], 
        PointBox[{86.4, 0.12938475013418851`}], 
        PointBox[{86.5, 0.1325903397314447}], 
        PointBox[{86.6, 0.13149379913416173`}], 
        PointBox[{86.7, 0.12966958828826797`}], 
        PointBox[{86.8, 0.13198801664540688`}], 
        PointBox[{86.9, 0.13340666175131197`}], 
        PointBox[{87., 0.12965668868465494`}], 
        PointBox[{87.1, 0.13088734017152728`}], 
        PointBox[{87.2, 0.13263153951370038`}], 
        PointBox[{87.3, 0.1304959663250922}], 
        PointBox[{87.4, 0.12969999001075944`}], 
        PointBox[{87.5, 0.13269589144518382`}], 
        PointBox[{87.6, 0.1313950661017856}], 
        PointBox[{87.7, 0.12969028131565719`}], 
        PointBox[{87.8, 0.13244221292857766`}], 
        PointBox[{87.9, 0.13310688381632246`}], 
        PointBox[{88., 0.1296809349498669}], 
        PointBox[{88.1, 0.13111058092066594`}], 
        PointBox[{88.2, 0.13272069574281375`}], 
        PointBox[{88.3, 0.1302374774725365}], 
        PointBox[{88.4, 0.13004687871916135`}], 
        PointBox[{88.5, 0.13276969677737674`}], 
        PointBox[{88.6, 0.13128993857231575`}], 
        PointBox[{88.7, 0.1297326143861445}], 
        PointBox[{88.8, 0.1328941536073291}], 
        PointBox[{88.9, 0.1327778430775772}], 
        PointBox[{89., 0.12973237475023366`}], 
        PointBox[{89.1, 0.13133185038229153`}], 
        PointBox[{89.2, 0.13278237648806934`}], 
        PointBox[{89.3, 0.12998813014012411`}], 
        PointBox[{89.4, 0.13041288421486763`}], 
        PointBox[{89.5, 0.13281230533885516`}], 
        PointBox[{89.6, 0.13117850234997447`}], 
        PointBox[{89.7, 0.12979880747593614`}], 
        PointBox[{89.8, 0.1333284090992723}], 
        PointBox[{89.9, 0.1324325179764413}], 
        PointBox[{90., 0.12980677161477103`}], 
        PointBox[{90.1, 0.13154766956998865`}], 
        PointBox[{90.2, 0.13281115803097943`}], 
        PointBox[{90.3, 0.12975858590465453`}], 
        PointBox[{90.4, 0.13078377596647991`}], 
        PointBox[{90.5, 0.13282415548310433`}], 
        PointBox[{90.6, 0.13106080107437076`}], 
        PointBox[{90.7, 0.12989010445997604`}], 
        PointBox[{90.8, 0.1337280504545036}], 
        PointBox[{90.9, 0.13208293164404014`}], 
        PointBox[{91., 0.12989980689025535`}], 
        PointBox[{91.1, 0.13175476283283818`}], 
        PointBox[{91.2, 0.1328034146964474}], 
        PointBox[{91.3, 0.12955929595776883`}], 
        PointBox[{91.4, 0.13114652477469893`}], 
        PointBox[{91.5, 0.13280632892908142`}], 
        PointBox[{91.6, 0.13093741656048086`}], 
        PointBox[{91.7, 0.13000861056774624`}], 
        PointBox[{91.8, 0.13407551717963762`}], 
        PointBox[{91.9, 0.13173990644707662`}], 
        PointBox[{92., 0.1300076959707462}], 
        PointBox[{92.1, 0.13195061800744315`}], 
        PointBox[{92.2, 0.13275569385239624`}], 
        PointBox[{92.3, 0.12939838079566424`}], 
        PointBox[{92.4, 0.13148922870906243`}], 
        PointBox[{92.5, 0.13276014067332503`}], 
        PointBox[{92.6, 0.13080901533789352`}], 
        PointBox[{92.7, 0.13015621811767178`}], 
        PointBox[{92.8, 0.13435516443253337`}], 
        PointBox[{92.9, 0.13141239297117865`}], 
        PointBox[{93., 0.1301267320562365}], 
        PointBox[{93.1, 0.13213237524210517`}], 
        PointBox[{93.2, 0.13266489981153892`}], 
        PointBox[{93.3, 0.12928112016742532`}], 
        PointBox[{93.4, 0.13180217123920243`}], 
        PointBox[{93.5, 0.13268672741002657`}], 
        PointBox[{93.6, 0.13067686149220453`}], 
        PointBox[{93.7, 0.13033431840060958`}], 
        PointBox[{93.8, 0.13455258137016207`}], 
        PointBox[{93.9, 0.13110723261301482`}], 
        PointBox[{94., 0.13025354780915308`}], 
        PointBox[{94.1, 0.13229740984574748`}], 
        PointBox[{94.2, 0.13252872869649285`}], 
        PointBox[{94.3, 0.1292091849138332}], 
        PointBox[{94.4, 0.13207778027022588`}], 
        PointBox[{94.5, 0.13258782408390285`}], 
        PointBox[{94.6, 0.1305415725533947}], 
        PointBox[{94.7, 0.13054388183466809`}], 
        PointBox[{94.8, 0.13465847470831702`}], 
        PointBox[{94.9, 0.1308292277164276}], 
        PointBox[{95., 0.13038507088481177`}], 
        PointBox[{95.1, 0.13244343425048666`}], 
        PointBox[{95.2, 0.13234652512947676`}], 
        PointBox[{95.3, 0.1291821989070602}], 
        PointBox[{95.4, 0.13231112750904395`}], 
        PointBox[{95.5, 0.13246527014844256`}], 
        PointBox[{95.6, 0.13040684618123322`}], 
        PointBox[{95.7, 0.13078498494105228`}], 
        PointBox[{95.8, 0.13466618407466738`}], 
        PointBox[{95.9, 0.13058129485595807`}], 
        PointBox[{96., 0.13051862385164542`}], 
        PointBox[{96.1, 0.13256814617185522`}], 
        PointBox[{96.2, 0.1321189873396689}], 
        PointBox[{96.3, 0.1291994642351795}], 
        PointBox[{96.4, 0.1324993399721817}], 
        PointBox[{96.5, 0.1323210978007976}], 
        PointBox[{96.6, 0.13027248491113275`}], 
        PointBox[{96.7, 0.1310564703440681}], 
        PointBox[{96.8, 0.13457500460340144`}], 
        PointBox[{96.9, 0.13036479233791565`}], 
        PointBox[{97., 0.13065192928833502`}], 
        PointBox[{97.1, 0.13266946728018053`}], 
        PointBox[{97.2, 0.13184858724846593`}], 
        PointBox[{97.3, 0.1292626895296717}], 
        PointBox[{97.4, 0.13264153416970823`}], 
        PointBox[{97.5, 0.1321575871054905}], 
        PointBox[{97.6, 0.13014357541737143`}], 
        PointBox[{97.7, 0.13135566828532338`}], 
        PointBox[{97.8, 0.13439057283478378`}], 
        PointBox[{97.9, 0.13017992915040696`}], 
        PointBox[{98., 0.13078312988920002`}], 
        PointBox[{98.1, 0.1327456244040199}], 
        PointBox[{98.2, 0.13154005795990287`}], 
        PointBox[{98.3, 0.12937051343203398`}], 
        PointBox[{98.4, 0.13273841930842678`}], 
        PointBox[{98.5, 0.13197703474018566`}], 
        PointBox[{98.6, 0.13002138805817182`}], 
        PointBox[{98.7, 0.13167813295229866`}], 
        PointBox[{98.8, 0.13412260275769156`}], 
        PointBox[{98.9, 0.13002591451165676`}], 
        PointBox[{99., 0.13091071825287295`}], 
        PointBox[{99.1, 0.13279508695363995`}], 
        PointBox[{99.2, 0.1312003143962034}], 
        PointBox[{99.3, 0.12952296832046575`}], 
        PointBox[{99.4, 0.1327919158031773}], 
        PointBox[{99.5, 0.1317820380464768}], 
        PointBox[{99.6, 0.12990990785153714`}], 
        PointBox[{99.7, 0.13201754148944114`}], 
        PointBox[{99.8, 0.13378397401600647`}], 
        PointBox[{99.9, 0.1299013719277646}], 
        PointBox[{100., 0.13103352621476244`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 0.2}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
        PointBox[{0.1, 358.3502079336781}], 
        PointBox[{0.2, 359.2793241430707}], 
        PointBox[{0.3, 359.1604036957593}], 
        PointBox[{0.4, 357.8390521842123}], 
        PointBox[{0.5, 358.77709198859844`}], 
        PointBox[{0.6, 359.4361414904088}], PointBox[{0.7, 358.147309015734}],
         PointBox[{0.8, 358.12888783242124`}], 
        PointBox[{0.9, 359.0578619902845}], PointBox[{1., 357.0988497752025}],
         PointBox[{1.1, 355.77056834689006`}], 
        PointBox[{1.2, 356.6812151505747}], 
        PointBox[{1.3, 356.46078065339805`}], 
        PointBox[{1.4, 355.12631912826265`}], 
        PointBox[{1.5, 356.3280290493072}], 
        PointBox[{1.6, 356.7026095048906}], 
        PointBox[{1.7, 355.4625329282155}], 
        PointBox[{1.8, 355.5431730050033}], 
        PointBox[{1.9, 356.4507438601889}], PointBox[{2., 354.2052298419656}],
         PointBox[{2.1, 353.2004747943116}], 
        PointBox[{2.2, 354.0770076752774}], 
        PointBox[{2.3, 353.7543142628952}], 
        PointBox[{2.4, 352.42914171754353`}], 
        PointBox[{2.5, 353.8694687968902}], 
        PointBox[{2.6, 353.96347006667986`}], 
        PointBox[{2.7, 352.7858547620251}], 
        PointBox[{2.8, 352.96418471193175`}], 
        PointBox[{2.9, 353.825246371384}], PointBox[{3., 351.326470075411}], 
        PointBox[{3.1, 350.63770522385397`}], 
        PointBox[{3.2, 351.4669894959734}], 
        PointBox[{3.3, 351.04151677089646`}], 
        PointBox[{3.4, 349.75129592120516`}], 
        PointBox[{3.5, 351.39580050490355`}], 
        PointBox[{3.6, 351.2214924871311}], 
        PointBox[{3.7, 350.11739686529427`}], 
        PointBox[{3.8, 350.3914448239327}], 
        PointBox[{3.9, 351.1777989140354}], 
        PointBox[{4., 348.46929152111085`}], 
        PointBox[{4.1, 348.08024063678994`}], 
        PointBox[{4.2, 348.8512678622046}], 
        PointBox[{4.3, 348.32301427755675`}], 
        PointBox[{4.4, 347.0965063761202}], PointBox[{4.5, 348.902254189753}],
         PointBox[{4.6, 348.47925256718105`}], 
        PointBox[{4.7, 347.45770301957623`}], 
        PointBox[{4.8, 347.82499465116}], PointBox[{4.9, 348.5053682507056}], 
        PointBox[{5., 345.63939154548746`}], 
        PointBox[{5.1, 345.5264810980627}], 
        PointBox[{5.2, 346.23005263587567`}], 
        PointBox[{5.3, 345.59960218847823`}], 
        PointBox[{5.4, 344.46750763957385`}], 
        PointBox[{5.5, 346.38506082683836`}], 
        PointBox[{5.6, 345.7387380606798}], 
        PointBox[{5.7, 344.8069252958759}], 
        PointBox[{5.8, 345.26435069482517`}], 
        PointBox[{5.9, 345.8045369775848}], PointBox[{6., 342.8407132498639}],
         PointBox[{6.1, 342.9745879789635}], 
        PointBox[{6.2, 343.60314339304375`}], 
        PointBox[{6.3, 342.8720528041634}], 
        PointBox[{6.4, 341.8675082960006}], 
        PointBox[{6.5, 343.84195230795416`}], 
        PointBox[{6.6, 343.0019005422334}], PointBox[{6.7, 342.165307751132}],
         PointBox[{6.8, 342.70948238162924`}], 
        PointBox[{6.9, 343.07313775826543`}], 
        PointBox[{7., 340.0760685477161}], 
        PointBox[{7.1, 340.42361718366107`}], 
        PointBox[{7.2, 340.97076819058566`}], 
        PointBox[{7.3, 340.1409425511375}], 
        PointBox[{7.4, 339.2978797850032}], 
        PointBox[{7.5, 341.2717595181899}], PointBox[{7.6, 340.270324991596}],
         PointBox[{7.7, 339.5329931869483}], 
        PointBox[{7.8, 340.1590591716513}], 
        PointBox[{7.9, 340.3097975609615}], 
        PointBox[{8., 337.34632149718607`}], 
        PointBox[{8.1, 337.87247420677164`}], 
        PointBox[{8.2, 338.3328546046783}], 
        PointBox[{8.3, 337.4075391816423}], 
        PointBox[{8.4, 336.75987164846833`}], 
        PointBox[{8.5, 338.67477399371023`}], 
        PointBox[{8.6, 337.54515627873326`}], 
        PointBox[{8.7, 336.9102049342179}], 
        PointBox[{8.8, 337.61235499791854`}], 
        PointBox[{8.9, 337.5144353864925}], 
        PointBox[{9., 334.65071724817045`}], 
        PointBox[{9.1, 335.3200429983023}], 
        PointBox[{9.2, 335.68921567896774`}], 
        PointBox[{9.3, 334.6734346479212}], 
        PointBox[{9.4, 334.25238835785893`}], 
        PointBox[{9.5, 336.05208205134784`}], 
        PointBox[{9.6, 334.82741041452095`}], 
        PointBox[{9.7, 334.296923285003}], PointBox[{9.8, 335.0675759687187}],
         PointBox[{9.9, 334.68911274824995`}], 
        PointBox[{10., 331.9874946302054}], 
        PointBox[{10.1, 332.76557139776514`}], 
        PointBox[{10.2, 333.03980928442945`}], 
        PointBox[{10.3, 331.9401920585522}], 
        PointBox[{10.4, 331.7734743263253}], 
        PointBox[{10.5, 333.40586485127017`}], 
        PointBox[{10.6, 332.11800177435964`}], 
        PointBox[{10.7, 331.6932514272252}], 
        PointBox[{10.8, 332.52364455840694`}], 
        PointBox[{10.9, 331.83724883942796`}], 
        PointBox[{11., 329.3537436861166}], 
        PointBox[{11.1, 330.20835418546665`}], 
        PointBox[{11.2, 330.3844271850195}], 
        PointBox[{11.3, 329.21008696905506`}], 
        PointBox[{11.4, 329.31941519404546`}], 
        PointBox[{11.5, 330.7389053720917}], 
        PointBox[{11.6, 329.4174378498699}], 
        PointBox[{11.7, 329.09907025595834`}], 
        PointBox[{11.8, 329.9773774753127}], 
        PointBox[{11.9, 328.9642575120795}], 
        PointBox[{12., 326.745857085319}], 
        PointBox[{12.1, 327.6475949734674}], 
        PointBox[{12.2, 327.7227308168254}], 
        PointBox[{12.3, 326.48458867892384`}], 
        PointBox[{12.4, 326.8844083480491}], 
        PointBox[{12.5, 328.05422936764813`}], 
        PointBox[{12.6, 326.72615768417097`}], 
        PointBox[{12.7, 326.5141480263653}], 
        PointBox[{12.8, 327.42639672343586`}], 
        PointBox[{12.9, 326.0772202461855}], 
        PointBox[{13., 324.16024450304656`}], 
        PointBox[{13.1, 325.082768989981}], 
        PointBox[{13.2, 325.0548145703278}], 
        PointBox[{13.3, 323.7679763178753}], 
        PointBox[{13.4, 324.4619625978213}], 
        PointBox[{13.5, 325.35538655525846`}], 
        PointBox[{13.6, 324.04426290388824`}], 
        PointBox[{13.7, 323.93822976538667`}], 
        PointBox[{13.8, 324.8670707002202}], 
        PointBox[{13.9, 323.18370868991684`}], 
        PointBox[{14., 321.59269070671104`}], 
        PointBox[{14.1, 322.5130451803078}], 
        PointBox[{14.2, 322.38001756196167`}], 
        PointBox[{14.3, 321.0621964336155}], 
        PointBox[{14.4, 322.04416973543806`}], 
        PointBox[{14.5, 322.6454458748488}], 
        PointBox[{14.6, 321.37192540702114`}], 
        PointBox[{14.7, 321.37098516353905`}], 
        PointBox[{14.8, 322.2957187611045}], 
        PointBox[{14.9, 320.29219965338484`}], 
        PointBox[{15., 319.0395945147182}], 
        PointBox[{15.1, 319.93806046464374`}], 
        PointBox[{15.2, 319.6984788215101}], 
        PointBox[{15.3, 318.37106524565036`}], 
        PointBox[{15.4, 319.623234577781}], 
        PointBox[{15.5, 319.92791406997924`}], 
        PointBox[{15.6, 318.7091751634237}], 
        PointBox[{15.7, 318.81193425489926`}], 
        PointBox[{15.8, 319.708135456955}], 
        PointBox[{15.9, 317.4111024074101}], 
        PointBox[{16., 316.49728115228567`}], 
        PointBox[{16.1, 317.35712085810985`}], 
        PointBox[{16.2, 317.00998194654863`}], 
        PointBox[{16.3, 315.6981301963324}], 
        PointBox[{16.4, 317.1911030585373}], 
        PointBox[{16.5, 317.2054982328199}], 
        PointBox[{16.6, 316.05573281312377`}], 
        PointBox[{16.7, 316.2602619673967}], 
        PointBox[{16.8, 317.0995547535383}], 
        PointBox[{16.9, 314.54826555651493`}], 
        PointBox[{17., 313.9622531702352}], 
        PointBox[{17.1, 314.769578242792}], 
        PointBox[{17.2, 314.31463171309406`}], 
        PointBox[{17.3, 313.0470290741567}], 
        PointBox[{17.4, 314.7406862796836}], 
        PointBox[{17.5, 314.48088372481385`}], 
        PointBox[{17.6, 313.41140434809995`}], 
        PointBox[{17.7, 313.7153286299096}], 
        PointBox[{17.8, 314.46569896500915`}], 
        PointBox[{17.9, 311.71083761663016`}], 
        PointBox[{18., 311.4317709693296}], 
        PointBox[{18.1, 312.175094720217}], 
        PointBox[{18.2, 311.61265534894994`}], 
        PointBox[{18.3, 310.4210015148353}], 
        PointBox[{18.4, 312.2661877100583}], 
        PointBox[{18.5, 311.7560767916115}], 
        PointBox[{18.6, 310.77588702985173`}], 
        PointBox[{18.7, 311.1761600059232}], 
        PointBox[{18.8, 311.8021311123006}], 
        PointBox[{18.9, 308.90436104678395`}], 
        PointBox[{19., 308.90312446430306`}], 
        PointBox[{19.1, 309.5731031604098}], 
        PointBox[{19.2, 308.90402928685967`}], 
        PointBox[{19.3, 307.8230352280747}], 
        PointBox[{19.4, 309.76343459710745`}], 
        PointBox[{19.5, 309.03317123889127`}], 
        PointBox[{19.6, 308.14885874523577`}], 
        PointBox[{19.7, 308.64141299361575`}], 
        PointBox[{19.8, 309.1053731688687}], 
        PointBox[{19.9, 306.1323074429031}], 
        PointBox[{20., 306.3739703643249}], 
        PointBox[{20.1, 306.9630448320607}], 
        PointBox[{20.2, 306.18941493609543`}], 
        PointBox[{20.3, 305.2548931752382}], 
        PointBox[{20.4, 307.22997192030635`}], 
        PointBox[{20.5, 306.31345320007205`}], 
        PointBox[{20.6, 305.5298524041207}], 
        PointBox[{20.7, 306.10996115338304`}], 
        PointBox[{20.8, 306.3728946846317}], 
        PointBox[{20.9, 303.39584911868354`}], 
        PointBox[{21., 303.84238461466015`}], 
        PointBox[{21.1, 304.3445049212851}], 
        PointBox[{21.2, 303.46969962065447`}], 
        PointBox[{21.3, 302.71739262237907`}], 
        PointBox[{21.4, 304.6650142836361}], 
        PointBox[{21.5, 303.59812871052725`}], 
        PointBox[{21.6, 302.9184712401066}], 
        PointBox[{21.7, 303.58012661737564`}], 
        PointBox[{21.8, 303.60447194460573`}], 
        PointBox[{21.9, 300.6945234723111}], 
        PointBox[{22., 301.30695220033454`}], 
        PointBox[{22.1, 301.7172987368868}], 
        PointBox[{22.2, 300.7461848901797}], 
        PointBox[{22.3, 300.20957075455283`}], 
        PointBox[{22.4, 302.06935078111275`}], 
        PointBox[{22.5, 300.8879602465453}], 
        PointBox[{22.6, 300.31430066628155`}], 
        PointBox[{22.7, 301.04989279138886`}], 
        PointBox[{22.8, 300.800915028909}], 
        PointBox[{22.9, 298.0258460072547}], 
        PointBox[{23., 298.7661341627095}], 
        PointBox[{23.1, 299.08089320995816`}], 
        PointBox[{23.2, 298.01997519015424`}], 
        PointBox[{23.3, 297.7294957451959}], 
        PointBox[{23.4, 299.44483672863544`}], 
        PointBox[{23.5, 298.1836129827985}], 
        PointBox[{23.6, 297.716839962288}], 
        PointBox[{23.7, 298.517306801637}], 
        PointBox[{23.8, 297.9657843540017}], 
        PointBox[{23.9, 295.3862553191743}], 
        PointBox[{24., 296.21883267998874`}], 
        PointBox[{24.1, 296.43499950426974`}], 
        PointBox[{24.2, 295.2928988385356}], 
        PointBox[{24.3, 295.2725970795984}], 
        PointBox[{24.4, 296.79420523803486`}], 
        PointBox[{24.5, 295.48507533338363`}], 
        PointBox[{24.6, 295.12538062287985`}], 
        PointBox[{24.7, 295.9794610039158}], 
        PointBox[{24.8, 295.10429212124063`}], 
        PointBox[{24.9, 292.77146715702685`}], 
        PointBox[{25., 293.6640890548902}], 
        PointBox[{25.1, 293.7793715757623}], 
        PointBox[{25.2, 292.56698474730456`}], 
        PointBox[{25.3, 292.83371008229904`}], 
        PointBox[{25.4, 294.1209354069697}], 
        PointBox[{25.5, 292.7927875802915}], 
        PointBox[{25.6, 292.5396860304821}], 
        PointBox[{25.7, 293.43406804567945`}], 
        PointBox[{25.8, 292.22362218565235`}], 
        PointBox[{25.9, 290.17715691160896`}], 
        PointBox[{26., 291.1014096742194}], 
        PointBox[{26.1, 291.11406679675673`}], 
        PointBox[{26.2, 289.845395968811}], 
        PointBox[{26.3, 290.4060054584818}], 
        PointBox[{26.4, 291.42876148853384`}], 
        PointBox[{26.5, 290.10681157126385`}], 
        PointBox[{26.6, 289.9591941709009}], 
        PointBox[{26.7, 290.87782816430274`}], 
        PointBox[{26.8, 289.3313970090737}], 
        PointBox[{26.9, 287.5988995975648}], 
        PointBox[{27., 288.5302249171775}], 
        PointBox[{27.1, 288.4389969217781}], 
        PointBox[{27.2, 287.13049821345703`}], 
        PointBox[{27.3, 287.9820189294353}], 
        PointBox[{27.4, 288.7212959474466}], 
        PointBox[{27.5, 287.4270802779515}], 
        PointBox[{27.6, 287.3836974100771}], 
        PointBox[{27.7, 288.307507225387}], 
        PointBox[{27.8, 286.43592981063045`}], 
        PointBox[{27.9, 285.0325750279003}], 
        PointBox[{28., 285.9501824649849}], 
        PointBox[{28.1, 285.75423170463125`}], 
        PointBox[{28.2, 284.4255460482707}], 
        PointBox[{28.3, 285.5539927210415}], 
        PointBox[{28.4, 286.0020074056032}], 
        PointBox[{28.5, 284.75352580530506`}], 
        PointBox[{28.6, 284.8122672237623}], PointBox[{28.7, 285.7196111655}],
         PointBox[{28.8, 283.5453233376518}], 
        PointBox[{28.9, 282.4745367071527}], 
        PointBox[{29., 283.3610622408474}], 
        PointBox[{29.1, 283.05995972461983`}], 
        PointBox[{29.2, 281.7339066088973}], 
        PointBox[{29.3, 283.11464948410594`}], 
        PointBox[{29.4, 283.27410144108694`}], 
        PointBox[{29.5, 282.0860285478823}], 
        PointBox[{29.6, 282.2450402560779}], 
        PointBox[{29.7, 283.11052826201865`}], 
        PointBox[{29.8, 280.66730129519505`}], 
        PointBox[{29.9, 279.9216052082134}], 
        PointBox[{30., 280.76270752603483`}], 
        PointBox[{30.1, 280.35647279163084`}], 
        PointBox[{30.2, 279.0588779464245}], 
        PointBox[{30.3, 280.6572312038646}], 
        PointBox[{30.4, 280.5404206670406}], 
        PointBox[{30.5, 279.4244981443479}], 
        PointBox[{30.6, 279.68088034471003`}], 
        PointBox[{30.7, 280.4765607852566}], 
        PointBox[{30.8, 277.80865255465284`}], 
        PointBox[{30.9, 277.3709822121359}], 
        PointBox[{31., 278.15513432223685`}], 
        PointBox[{31.1, 277.6443326847554}], 
        PointBox[{31.2, 276.4036740008294}], 
        PointBox[{31.3, 278.17668595963767`}], 
        PointBox[{31.4, 277.8035216882221}], 
        PointBox[{31.5, 276.76888594558903`}], 
        PointBox[{31.6, 277.1198579781413}], 
        PointBox[{31.7, 277.8145005328924}], 
        PointBox[{31.8, 274.9750232514074}], 
        PointBox[{31.9, 274.8205864491447}], 
        PointBox[{32., 275.5384123257761}], 
        PointBox[{32.1, 274.924140926527}], 
        PointBox[{32.2, 273.7712871489956}], 
        PointBox[{32.3, 275.6689156046957}], 
        PointBox[{32.4, 275.0654614463366}], 
        PointBox[{32.5, 274.11913597441236`}], 
        PointBox[{32.6, 274.56103233379946`}], 
        PointBox[{32.7, 275.1218049379088}], 
        PointBox[{32.8, 272.17049180686803`}], 
        PointBox[{32.9, 272.2687549008361}], 
        PointBox[{33., 272.91272436004715`}], 
        PointBox[{33.1, 272.19680582203495`}], 
        PointBox[{33.2, 271.16412063975145`}], 
        PointBox[{33.3, 273.1318564941738}], 
        PointBox[{33.4, 272.3282945243469}], 
        PointBox[{33.5, 271.4753487831774}], 
        PointBox[{33.6, 272.00430814274216`}], 
        PointBox[{33.7, 272.3958019355332}], 
        PointBox[{33.8, 269.3973197503127}], 
        PointBox[{33.9, 269.71419803795357`}], 
        PointBox[{34., 270.27813959991204`}], 
        PointBox[{34.1, 269.4632442039911}], 
        PointBox[{34.2, 268.5834662355545}], 
        PointBox[{34.3, 270.5643879236461}], 
        PointBox[{34.4, 269.5932177862132}], 
        PointBox[{34.5, 268.8374526769515}], 
        PointBox[{34.6, 269.4482882740403}], 
        PointBox[{34.7, 269.6362861436416}], 
        PointBox[{34.8, 266.6559196808144}], 
        PointBox[{34.9, 267.1558866163378}], 
        PointBox[{35., 267.63496382348853`}], 
        PointBox[{35.1, 266.72478304604743`}], 
        PointBox[{35.2, 266.0302344838898}], 
        PointBox[{35.3, 267.96719605794857`}], 
        PointBox[{35.4, 266.86168559086343`}], 
        PointBox[{35.5, 266.2056445481513}], 
        PointBox[{35.6, 266.8927898727196}], 
        PointBox[{35.7, 266.8434752489871}], 
        PointBox[{35.8, 263.9457526383793}], 
        PointBox[{35.9, 264.59320961949004`}], 
        PointBox[{36., 264.98355798015535`}], 
        PointBox[{36.1, 263.9830304532801}], 
        PointBox[{36.2, 263.5039150763507}], 
        PointBox[{36.3, 265.3419616084346}], 
        PointBox[{36.4, 264.13487888853746`}], 
        PointBox[{36.5, 263.5801244472978}], 
        PointBox[{36.6, 264.33628425166853`}], 
        PointBox[{36.7, 264.0194812163187}], 
        PointBox[{36.8, 261.26477357913865`}], 
        PointBox[{36.9, 262.02573243104735`}], 
        PointBox[{37., 262.3240785017744}], 
        PointBox[{37.1, 261.2396731726385}], 
        PointBox[{37.2, 261.002477063164}], 
        PointBox[{37.3, 262.69105841776224`}], 
        PointBox[{37.4, 261.41360602767475`}], 
        PointBox[{37.5, 260.9610224422102}], 
        PointBox[{37.6, 261.77759049745634`}], 
        PointBox[{37.7, 261.1678616791415}], 
        PointBox[{37.8, 258.6101987141471}], 
        PointBox[{37.9, 259.4530592338936}], 
        PointBox[{38., 259.65677329943526`}], 
        PointBox[{38.1, 258.49681380512396`}], 
        PointBox[{38.2, 258.5229232715662}], 
        PointBox[{38.3, 260.0174344382603}], 
        PointBox[{38.4, 258.6985611291806}], 
        PointBox[{38.5, 258.34851100440255`}], 
        PointBox[{38.6, 259.2152272221544}], 
        PointBox[{38.7, 258.2939093813947}], 
        PointBox[{38.8, 255.97911133429096`}], 
        PointBox[{38.9, 256.87521866767503`}], 
        PointBox[{39., 256.9819858102196}], 
        PointBox[{39.1, 255.75693308987792`}], 
        PointBox[{39.2, 256.0609074352036}], 
        PointBox[{39.3, 257.3245837841518}], 
        PointBox[{39.4, 255.99044303785126`}], 
        PointBox[{39.5, 255.74282651354008`}], 
        PointBox[{39.6, 256.64725471653924`}], 
        PointBox[{39.7, 255.40376100937}], PointBox[{39.8, 253.368287965977}],
         PointBox[{39.9, 254.29200707216927`}], 
        PointBox[{40., 254.30004537991013`}], 
        PointBox[{40.1, 253.02270682647304`}], 
        PointBox[{40.2, 253.61104045873677`}], 
        PointBox[{40.3, 254.61602174438588`}], 
        PointBox[{40.4, 253.28987619421716`}], 
        PointBox[{40.5, 253.14408486654625`}], 
        PointBox[{40.6, 254.07132411059808`}], 
        PointBox[{40.7, 252.50460240210145`}], 
        PointBox[{40.8, 250.77454175854405`}], 
        PointBox[{40.9, 251.70346012149622`}], 
        PointBox[{41., 251.6112298064572}], 
        PointBox[{41.1, 250.29711687540967`}], 
        PointBox[{41.2, 251.16726735440002`}], 
        PointBox[{41.3, 251.89524231341107`}], 
        PointBox[{41.4, 250.59726832420557`}], 
        PointBox[{41.5, 250.55276152400208`}], 
        PointBox[{41.6, 251.48494214358468`}], 
        PointBox[{41.7, 249.60398947597753`}], 
        PointBox[{41.8, 248.19496524132927`}], 
        PointBox[{41.9, 249.10976100022168`}], 
        PointBox[{42., 248.9158912728089}], 
        PointBox[{42.1, 247.58366751060416`}], 
        PointBox[{42.2, 248.7230319890951}], 
        PointBox[{42.3, 249.16568999957104`}], 
        PointBox[{42.4, 247.9131509359598}], 
        PointBox[{42.5, 247.96868144107927`}], 
        PointBox[{42.6, 248.88493848999892`}], 
        PointBox[{42.7, 246.70951972459446`}], 
        PointBox[{42.8, 245.62661727701345`}], 
        PointBox[{42.9, 246.51090959824234`}], 
        PointBox[{43., 246.2143461290805}], 
        PointBox[{43.1, 244.88586404886266`}], 
        PointBox[{43.2, 246.27185886396302`}], 
        PointBox[{43.3, 246.43036474980585`}], 
        PointBox[{43.4, 245.23787784047147`}], 
        PointBox[{43.5, 245.392280177993}], 
        PointBox[{43.6, 246.26797942458595`}], 
        PointBox[{43.7, 243.82884339578948`}], 
        PointBox[{43.8, 243.06727340634905`}], 
        PointBox[{43.9, 243.9069306293825}], 
        PointBox[{44., 243.50703174658068`}], 
        PointBox[{44.1, 242.20742391720822`}], 
        PointBox[{44.2, 243.80762249537761`}], 
        PointBox[{44.3, 243.69235642285176`}], 
        PointBox[{44.4, 242.57171970831493`}], 
        PointBox[{44.5, 242.823072548858}], 
        PointBox[{44.6, 243.63038459184656`}], 
        PointBox[{44.7, 240.96882380724387`}], 
        PointBox[{44.8, 240.51442904622974`}], 
        PointBox[{44.9, 241.29782031030595`}], 
        PointBox[{45., 240.79427536599292`}], 
        PointBox[{45.1, 239.55187232273744`}], 
        PointBox[{45.2, 241.32489019252336`}], 
        PointBox[{45.3, 240.95386932522638`}], 
        PointBox[{45.4, 239.91490247829427`}], 
        PointBox[{45.5, 240.2610748063128}], 
        PointBox[{45.6, 240.96845484713367`}], 
        PointBox[{45.7, 238.1357023406295}], 
        PointBox[{45.8, 237.96619692689643`}], 
        PointBox[{45.9, 238.6834654390662}], 
        PointBox[{46., 238.07657893239798`}], 
        PointBox[{46.1, 236.92267782966627`}], 
        PointBox[{46.2, 238.81947700216568`}], 
        PointBox[{46.3, 238.2171043987271}], 
        PointBox[{46.4, 237.26761381247903`}], 
        PointBox[{46.5, 237.7057703182964}], 
        PointBox[{46.6, 238.2786565093689}], 
        PointBox[{46.7, 235.33395143000018`}], 
        PointBox[{46.8, 235.42078091979616`}], 
        PointBox[{46.9, 236.06379547266692`}], 
        PointBox[{47., 235.35456174243927`}], 
        PointBox[{47.1, 234.32252656948708`}], 
        PointBox[{47.2, 236.2883667950531}], 
        PointBox[{47.3, 235.4841189653429}], 
        PointBox[{47.4, 234.62996677063302`}], 
        PointBox[{47.5, 235.15643829198845`}], 
        PointBox[{47.6, 235.55820492555068`}], 
        PointBox[{47.7, 232.56670237279053`}], 
        PointBox[{47.8, 232.87671411111978`}], 
        PointBox[{47.9, 233.43857652009652`}], 
        PointBox[{48., 232.62894815174153`}], 
        PointBox[{48.1, 231.75352361213993`}], 
        PointBox[{48.2, 233.72984905595018`}], 
        PointBox[{48.3, 232.7562137148418}], 
        PointBox[{48.4, 232.00193964216658`}], 
        PointBox[{48.5, 232.6118264682792}], 
        PointBox[{48.6, 232.80515658383788`}], 
        PointBox[{48.7, 229.83512793104472`}], 
        PointBox[{48.8, 230.33256682956466`}], 
        PointBox[{48.9, 230.80765163003832`}], 
        PointBox[{49., 229.90078438373652`}], 
        PointBox[{49.1, 229.21648975311066`}], 
        PointBox[{49.2, 231.1437623051617}], 
        PointBox[{49.3, 230.03469592378167`}], 
        PointBox[{49.4, 229.38358322746922`}], 
        PointBox[{49.5, 230.07188602964314`}], 
        PointBox[{49.6, 230.01927096884776`}], 
        PointBox[{49.7, 227.1387468118555}], 
        PointBox[{49.8, 227.78724092714967`}], 
        PointBox[{49.9, 228.17078389652497`}], 
        PointBox[{50., 227.17134335054982`}], 
        PointBox[{50.1, 226.71089676873785`}], 
        PointBox[{50.2, 228.53106152743132`}], 
        PointBox[{50.3, 227.32052368623442`}], 
        PointBox[{50.4, 226.7748240760156}], 
        PointBox[{50.5, 227.53389697505725`}], 
        PointBox[{50.6, 227.20194876448045`}], 
        PointBox[{50.7, 224.4755512410636}], 
        PointBox[{50.8, 225.2396319077804}], 
        PointBox[{50.9, 225.52768050336945`}], 
        PointBox[{51., 224.44218777260247`}], 
        PointBox[{51.1, 224.2345925812267}], 
        PointBox[{51.2, 225.89363995815518`}], 
        PointBox[{51.3, 224.61447601631795`}], 
        PointBox[{51.4, 224.17549397802634`}], 
        PointBox[{51.5, 224.99620145513867`}], 
        PointBox[{51.6, 224.356604968723}], 
        PointBox[{51.7, 221.8426179179819}], 
        PointBox[{51.8, 222.6888210226586}], 
        PointBox[{51.9, 222.87809468261642`}], 
        PointBox[{52., 221.7152529780911}], 
        PointBox[{52.1, 221.7835788662339}], 
        PointBox[{52.2, 223.23417164014393`}], 
        PointBox[{52.3, 221.9170568647748}], 
        PointBox[{52.4, 221.58542065676895`}], 
        PointBox[{52.5, 222.4563284314039}], 
        PointBox[{52.6, 221.4887299720348}], 
        PointBox[{52.7, 219.23629798403528`}], 
        PointBox[{52.8, 220.1340104615061}], 
        PointBox[{52.9, 220.22175770390987`}], 
        PointBox[{53., 218.99294458868698`}], 
        PointBox[{53.1, 219.35244531337278`}], 
        PointBox[{53.2, 220.55586889813486`}], 
        PointBox[{53.3, 219.22858276727592`}], 
        PointBox[{53.4, 219.0042473662064}], 
        PointBox[{53.5, 219.91110829415294`}], 
        PointBox[{53.6, 218.60498328549207`}], 
        PointBox[{53.7, 216.65228449026202`}], 
        PointBox[{53.8, 217.5742055221148}], 
        PointBox[{53.9, 217.55813533132402`}], 
        PointBox[{54., 216.27777861373906`}], 
        PointBox[{54.1, 216.93396214779074`}], 
        PointBox[{54.2, 217.86207384797336`}], 
        PointBox[{54.3, 216.5490199881044}], 
        PointBox[{54.4, 216.43148366411964`}], 
        PointBox[{54.5, 217.35728094251698`}], 
        PointBox[{54.6, 215.71343016784374`}], 
        PointBox[{54.7, 214.08641521446094`}], 
        PointBox[{54.8, 215.00882789105103`}], 
        PointBox[{54.9, 214.88720643589326`}], 
        PointBox[{55., 213.5729762662331}], 
        PointBox[{55.1, 214.52043897748598`}], 
        PointBox[{55.2, 215.15621140585475`}], 
        PointBox[{55.3, 213.87855164322983`}], 
        PointBox[{55.4, 213.86669617261776`}], 
        PointBox[{55.5, 214.79086221707553`}], 
        PointBox[{55.6, 212.8224983423702}], 
        PointBox[{55.7, 211.53475784977016`}], 
        PointBox[{55.8, 212.4372434391528}], 
        PointBox[{55.9, 212.2086545744383}], 
        PointBox[{56., 210.88174674732747`}], 
        PointBox[{56.1, 212.103423918013}], 
        PointBox[{56.2, 212.441409051845}], 
        PointBox[{56.3, 211.21688808485692`}], 
        PointBox[{56.4, 211.30935339039328`}], 
        PointBox[{56.5, 212.2075623098377}], 
        PointBox[{56.6, 209.94061209684938`}], 
        PointBox[{56.7, 208.9932635448455}], 
        PointBox[{56.8, 209.8586449766629}], 
        PointBox[{56.9, 209.52211574589535`}], 
        PointBox[{57., 208.20768078745598`}], 
        PointBox[{57.1, 209.67495493082328`}], 
        PointBox[{57.2, 209.72077882277821`}], 
        PointBox[{57.3, 208.56385652961345`}], 
        PointBox[{57.4, 208.75854729746877`}], 
        PointBox[{57.5, 209.6029985901462}], 
        PointBox[{57.6, 207.07609499916168`}], 
        PointBox[{57.7, 206.45864406179433`}], 
        PointBox[{57.8, 207.27275653044032`}], 
        PointBox[{57.9, 206.828237597405}], 
        PointBox[{58., 205.5543899268923}], 
        PointBox[{58.1, 207.22781289713708`}], 
        PointBox[{58.2, 206.99694660851543`}], 
        PointBox[{58.3, 205.9192079413389}], 
        PointBox[{58.4, 206.2135183262945}], 
        PointBox[{58.5, 206.97237886631535`}], 
        PointBox[{58.6, 204.23562292006127`}], 
        PointBox[{58.7, 203.92748431997865`}], 
        PointBox[{58.8, 204.67864701900777`}], 
        PointBox[{58.9, 204.12630312821528`}], 
        PointBox[{59., 202.924838223034}], PointBox[{59.1, 204.75586433132}], 
        PointBox[{59.2, 204.2720229818693}], 
        PointBox[{59.3, 203.2823235555128}], 
        PointBox[{59.4, 203.6730989834395}], 
        PointBox[{59.5, 204.31178399237155`}], 
        PointBox[{59.6, 201.4251077784165}], 
        PointBox[{59.7, 201.39751255288013`}], 
        PointBox[{59.8, 202.07634750996297`}], 
        PointBox[{59.9, 201.41752096684132`}], 
        PointBox[{60., 200.32221511588136`}], 
        PointBox[{60.1, 202.25530570874798`}], 
        PointBox[{60.2, 201.54812442875743`}], 
        PointBox[{60.3, 200.653243150918}], 
        PointBox[{60.4, 201.13627862889103`}], 
        PointBox[{60.5, 201.61773587233185`}], 
        PointBox[{60.6, 198.64798568573468`}], 
        PointBox[{60.7, 198.8663398194687}], 
        PointBox[{60.8, 199.46522791156255`}], 
        PointBox[{60.9, 198.70193383479977`}], 
        PointBox[{61., 197.74815859882813`}], 
        PointBox[{61.1, 199.72335542167954`}], 
        PointBox[{61.2, 198.82652623843}], 
        PointBox[{61.3, 198.03126255664708`}], 
        PointBox[{61.4, 198.60200865938526`}], 
        PointBox[{61.5, 198.88793916139895`}], 
        PointBox[{61.6, 195.90561115415605`}], 
        PointBox[{61.7, 196.33188882027414`}], 
        PointBox[{61.8, 196.8449048077587}], 
        PointBox[{61.9, 195.98012692276401`}], 
        PointBox[{62., 195.20361289055398`}], 
        PointBox[{62.1, 197.15941638958336`}], 
        PointBox[{62.2, 196.10860344703178`}], 
        PointBox[{62.3, 195.4161389472864}], 
        PointBox[{62.4, 196.06867486397724`}], 
        PointBox[{62.5, 196.1223268618864}], 
        PointBox[{62.6, 193.19760814893928`}], 
        PointBox[{62.7, 193.79305039306462`}], 
        PointBox[{62.8, 194.21547321990764`}], 
        PointBox[{62.9, 193.25451277032548`}], 
        PointBox[{63., 192.68797159266677`}], 
        PointBox[{63.1, 194.56424934567042`}], 
        PointBox[{63.2, 193.39509865686514`}], 
        PointBox[{63.3, 192.8074169003768}], 
        PointBox[{63.4, 193.53443998268804`}], 
        PointBox[{63.5, 193.32069435035467`}], 
        PointBox[{63.6, 190.52127383491762`}], 
        PointBox[{63.7, 191.2481632642705}], 
        PointBox[{63.8, 191.57620568072682`}], 
        PointBox[{63.9, 190.52529151319547`}], 
        PointBox[{64., 190.1989927367695}], 
        PointBox[{64.1, 191.93964047142094`}], 
        PointBox[{64.2, 190.68650252041334`}], 
        PointBox[{64.3, 190.20451830146604`}], 
        PointBox[{64.4, 190.99704554983703`}], 
        PointBox[{64.5, 190.4875035468738}], 
        PointBox[{64.6, 187.87354621750032`}], 
        PointBox[{64.7, 188.69641323808352`}], 
        PointBox[{64.8, 188.92722270996282`}], 
        PointBox[{64.9, 187.79450018980538`}], 
        PointBox[{65., 187.73303318597664`}], 
        PointBox[{65.1, 189.28854183216416`}], 
        PointBox[{65.2, 187.98335238422743`}], 
        PointBox[{65.3, 187.60725278277275`}], 
        PointBox[{65.4, 188.4548849769371}], 
        PointBox[{65.5, 187.6274689053878}], 
        PointBox[{65.6, 185.25034281611153`}], 
        PointBox[{65.7, 186.13696002408463`}], 
        PointBox[{65.8, 186.26831077194083`}], 
        PointBox[{65.9, 185.0643577337282}], 
        PointBox[{66., 185.2848540712982}], 
        PointBox[{66.1, 186.61413376146675`}], 
        PointBox[{66.2, 185.28568009756623`}], 
        PointBox[{66.3, 185.01499243544734`}], 
        PointBox[{66.4, 185.9048113120269}], 
        PointBox[{66.5, 184.74711718921708`}], 
        PointBox[{66.6, 182.64740168358986`}], 
        PointBox[{66.7, 183.56945289774995`}], 
        PointBox[{66.8, 183.5995562493627}], 
        PointBox[{66.9, 182.3374958784367}], 
        PointBox[{67., 182.84836560552986`}], 
        PointBox[{67.1, 183.92025638880517`}], 
        PointBox[{67.2, 182.59380444115945`}], 
        PointBox[{67.3, 182.4275894815148}], 
        PointBox[{67.4, 183.34431570267188`}], 
        PointBox[{67.5, 181.85414932493038`}], 
        PointBox[{67.6, 180.06067998229284`}], 
        PointBox[{67.7, 180.99347138316006`}], 
        PointBox[{67.8, 180.9211628076504}], 
        PointBox[{67.9, 179.61656885633786`}], 
        PointBox[{68., 180.41673096677084`}], 
        PointBox[{68.1, 181.21078540434837`}], 
        PointBox[{68.2, 179.9080418772182}], 
        PointBox[{68.3, 179.8449229326018}], 
        PointBox[{68.4, 180.77077621610178`}], 
        PointBox[{68.5, 178.95668599113594`}], 
        PointBox[{68.6, 177.48636350068588`}], 
        PointBox[{68.7, 178.40900017988938`}], 
        PointBox[{68.8, 178.23328351968092`}], 
        PointBox[{68.9, 176.90514655334684`}], 
        PointBox[{69., 177.98263194513694`}], 
        PointBox[{69.1, 178.48916646212768`}], 
        PointBox[{69.2, 177.22836734080948`}], 
        PointBox[{69.3, 177.266731638423}], 
        PointBox[{69.4, 178.18071978867292`}], 
        PointBox[{69.5, 176.06230445721624`}], 
        PointBox[{69.6, 174.92067463678993`}], 
        PointBox[{69.7, 175.8156691720447}], 
        PointBox[{69.8, 175.53623892816316`}], 
        PointBox[{69.9, 174.2060000938221}], 
        PointBox[{70., 175.53866257256885`}], 
        PointBox[{70.1, 175.75827228203173`}], 
        PointBox[{70.2, 174.55443045526465`}], 
        PointBox[{70.3, 174.69225573010874`}], 
        PointBox[{70.4, 175.57055111935273`}], 
        PointBox[{70.5, 173.17866983777625`}], 
        PointBox[{70.6, 172.36081814411}], 
        PointBox[{70.7, 173.2136097070819}], 
        PointBox[{70.8, 172.83019692842015`}], 
        PointBox[{70.9, 171.52269382384594`}], 
        PointBox[{71., 173.07884490992532`}], 
        PointBox[{71.1, 173.02152167166898`}], 
        PointBox[{71.2, 171.8867693856918}], 
        PointBox[{71.3, 172.12158705166087`}], 
        PointBox[{71.4, 172.93733774738038`}], 
        PointBox[{71.5, 170.31299253607835`}], 
        PointBox[{71.6, 169.80427628830117`}], 
        PointBox[{71.7, 170.6030040735653}], 
        PointBox[{71.8, 170.11601204021645`}], 
        PointBox[{71.9, 168.85866268325915`}], 
        PointBox[{72., 170.59778144288927`}], 
        PointBox[{72.1, 170.28142357161778`}], 
        PointBox[{72.2, 169.22533037201694`}], 
        PointBox[{72.3, 169.554458382708}], 
        PointBox[{72.4, 170.27774223774085`}], 
        PointBox[{72.5, 167.470989398077}], 
        PointBox[{72.6, 167.24919158696298`}], 
        PointBox[{72.7, 167.98408303580385`}], 
        PointBox[{72.8, 167.39440240174994`}], 
        PointBox[{72.9, 166.21713469019033`}], 
        PointBox[{73., 168.0915805257898}], 
        PointBox[{73.1, 167.540261389033}], 
        PointBox[{73.2, 166.5703069080835}], 
        PointBox[{73.3, 166.99076374273542`}], 
        PointBox[{73.4, 167.5890460912106}], 
        PointBox[{73.5, 164.6571168476367}], 
        PointBox[{73.6, 164.6937462483405}], 
        PointBox[{73.7, 165.3569471952427}], 
        PointBox[{73.8, 164.66590358712628`}], 
        PointBox[{73.9, 163.6003048536495}], 
        PointBox[{74., 165.55743890853628`}], 
        PointBox[{74.1, 164.79975854474182`}], 
        PointBox[{74.2, 163.92165558080205`}], 
        PointBox[{74.3, 164.42969143449736`}], 
        PointBox[{74.4, 164.86884080314636`}], 
        PointBox[{74.5, 161.87420132289708`}], 
        PointBox[{74.6, 162.13681091163755`}], 
        PointBox[{74.7, 162.7218867421331}], 
        PointBox[{74.8, 161.9319314208456}], 
        PointBox[{74.9, 161.01068531637253`}], 
        PointBox[{75., 162.99448151816878`}], 
        PointBox[{75.1, 162.06196033071382`}], 
        PointBox[{75.2, 161.27982821079962`}], 
        PointBox[{75.3, 161.87084131336067`}], 
        PointBox[{75.4, 162.11603984782877`}], 
        PointBox[{75.5, 159.12347343317023`}], 
        PointBox[{75.6, 159.57739944007088`}], 
        PointBox[{75.7, 160.0791540333662}], 
        PointBox[{75.8, 159.193319533615}], 
        PointBox[{75.9, 158.44902334027364`}], 
        PointBox[{76., 160.4025849927736}], 
        PointBox[{76.1, 159.32796938036813`}], 
        PointBox[{76.2, 158.64477101251188`}], 
        PointBox[{76.3, 159.31313514839403`}], 
        PointBox[{76.4, 159.3304335273713}], 
        PointBox[{76.5, 156.40462646760494`}], 
        PointBox[{76.6, 157.01484267018884`}], 
        PointBox[{76.7, 157.42889980912454`}], 
        PointBox[{76.8, 156.45167556350296`}], 
        PointBox[{76.9, 155.91519487027608`}], 
        PointBox[{77., 157.78313705938612`}], 
        PointBox[{77.1, 156.599078503526}], 
        PointBox[{77.2, 156.01688571765436`}], 
        PointBox[{77.3, 156.75633227926204`}], 
        PointBox[{77.4, 156.51373616641027`}], 
        PointBox[{77.5, 153.7163140904196}], 
        PointBox[{77.6, 154.44865640853945`}], 
        PointBox[{77.7, 154.77155798192572`}], 
        PointBox[{77.8, 153.7088524483284}], 
        PointBox[{77.9, 153.40816661460633`}], 
        PointBox[{78., 155.13828416260486`}], 
        PointBox[{78.1, 153.87624018855533`}], 
        PointBox[{78.2, 153.39633819212463`}], 
        PointBox[{78.3, 154.19866847861465`}], 
        PointBox[{78.4, 153.66884922733516`}], 
        PointBox[{78.5, 151.0561439916964}], 
        PointBox[{78.6, 151.87848307292512`}], 
        PointBox[{78.7, 152.10723562160467`}], 
        PointBox[{78.8, 150.9664655383058}], 
        PointBox[{78.9, 150.92505204423176`}], 
        PointBox[{79., 152.47081633088675`}], 
        PointBox[{79.1, 151.160383680899}], 
        PointBox[{79.2, 150.7834013645706}], 
        PointBox[{79.3, 151.63908437161714`}], 
        PointBox[{79.4, 150.80062280559034`}], 
        PointBox[{79.5, 148.4212804220524}], 
        PointBox[{79.6, 149.3040783218962}], 
        PointBox[{79.7, 149.4361465088866}], 
        PointBox[{79.8, 148.22737803190202`}], 
        PointBox[{79.9, 148.46184535998262`}], 
        PointBox[{80., 149.78392184201928`}], 
        PointBox[{80.1, 148.4521847581865}], 
        PointBox[{80.2, 148.1782457802107}], 
        PointBox[{80.3, 149.07473034848147`}], 
        PointBox[{80.4, 147.9147893502138}], 
        PointBox[{80.5, 145.80859467883857`}], 
        PointBox[{80.6, 146.72538588796652`}], 
        PointBox[{80.7, 146.7586347556252}], 
        PointBox[{80.8, 145.4939189015497}], 
        PointBox[{80.9, 146.01361238822142`}], 
        PointBox[{81., 147.08109922597905`}], 
        PointBox[{81.1, 145.75220038609118`}], 
        PointBox[{81.2, 145.58121484599687`}], 
        PointBox[{81.3, 146.50479323645115`}], 
        PointBox[{81.4, 145.0184144035678}], 
        PointBox[{81.5, 143.21473908789403`}], 
        PointBox[{81.6, 144.14214540383284`}], 
        PointBox[{81.7, 144.07473173821523`}], 
        PointBox[{81.8, 142.76912583547858`}], 
        PointBox[{81.9, 143.57388372958204`}], 
        PointBox[{82., 144.3657152040876}], 
        PointBox[{82.1, 143.06090412567326`}], 
        PointBox[{82.2, 142.99218855834263`}], 
        PointBox[{82.3, 143.92534956264595`}], 
        PointBox[{82.4, 142.11902805359622`}], 
        PointBox[{82.5, 140.63674599858277`}], 
        PointBox[{82.6, 141.55435638078308`}], 
        PointBox[{82.7, 141.3847466203968}], 
        PointBox[{82.8, 140.056204971087}], 
        PointBox[{82.9, 141.1361097528283}], 
        PointBox[{83., 141.64113604108087`}], 
        PointBox[{83.1, 140.37870477657148`}], 
        PointBox[{83.2, 140.4113294059398}], 
        PointBox[{83.3, 141.33339046354075`}], 
        PointBox[{83.4, 139.2244580136908}], 
        PointBox[{83.5, 138.0714746239594}], 
        PointBox[{83.6, 138.9618665028708}], 
        PointBox[{83.7, 138.68878896496224`}], 
        PointBox[{83.8, 137.35891626603367`}], 
        PointBox[{83.9, 138.69330610067107`}], 
        PointBox[{84., 138.9105819710716}], 
        PointBox[{84.1, 137.70589663547318`}], 
        PointBox[{84.2, 137.83866176633683`}], 
        PointBox[{84.3, 138.72533749508406`}], 
        PointBox[{84.4, 136.34239289795084`}], 
        PointBox[{84.5, 135.5161405958296}], 
        PointBox[{84.6, 136.36453212103433`}], 
        PointBox[{84.7, 135.98707276237252`}], 
        PointBox[{84.8, 134.68078208708178`}], 
        PointBox[{84.9, 136.23899724160077`}], 
        PointBox[{85., 136.17688527086983`}], 
        PointBox[{85.1, 135.04274689560586`}], 
        PointBox[{85.2, 135.27391994195347`}], 
        PointBox[{85.3, 136.09745777928924`}], 
        PointBox[{85.4, 133.48036408782076`}], 
        PointBox[{85.5, 132.9684354699261}], 
        PointBox[{85.6, 133.76221973816416`}], 
        PointBox[{85.7, 133.2799328332417}], 
        PointBox[{85.8, 132.0253860291829}], 
        PointBox[{85.9, 133.76696434719972`}], 
        PointBox[{86., 133.4424681764031}], 
        PointBox[{86.1, 132.38923915027212`}], 
        PointBox[{86.2, 132.71692862499123`}], 
        PointBox[{86.3, 133.4455869237889}], 
        PointBox[{86.4, 130.6446731375327}], 
        PointBox[{86.5, 130.42597852506532`}], 
        PointBox[{86.6, 131.1546938107078}], 
        PointBox[{86.7, 130.56780003932053`}], 
        PointBox[{86.8, 129.3963457372823}], 
        PointBox[{86.9, 131.2727013266528}], 
        PointBox[{87., 130.70966822024147`}], 
        PointBox[{87.1, 129.74558653938007`}], 
        PointBox[{87.2, 130.16679894316985`}], 
        PointBox[{87.3, 130.76590418184006`}], 
        PointBox[{87.4, 127.84036662077031`}], 
        PointBox[{87.5, 127.88648941899524`}], 
        PointBox[{87.6, 128.5415796542848}], 
        PointBox[{87.7, 127.85086746646921`}], 
        PointBox[{87.8, 126.79636316499715`}], 
        PointBox[{87.9, 128.75251076018583`}], 
        PointBox[{88., 127.9801948451443}], 
        PointBox[{88.1, 127.11162980000358`}], 
        PointBox[{88.2, 127.62269202056942`}], 
        PointBox[{88.3, 128.055242754803}], 
        PointBox[{88.4, 125.07074695226954`}], 
        PointBox[{88.5, 125.34844126441197`}], 
        PointBox[{88.6, 125.92267356261667`}], 
        PointBox[{88.7, 125.12987522143949`}], 
        PointBox[{88.8, 124.22777733794068`}], 
        PointBox[{88.9, 126.20442911792509`}], 
        PointBox[{89., 125.2556409593821}], 
        PointBox[{89.1, 124.48736424389512`}], 
        PointBox[{89.2, 125.08408188126727`}], 
        PointBox[{89.3, 125.31135324254721`}], 
        PointBox[{89.4, 122.33747526327797`}], 
        PointBox[{89.5, 122.81038764431395`}], 
        PointBox[{89.6, 123.2977804955341}], 
        PointBox[{89.7, 122.40622575902357`}], 
        PointBox[{89.8, 121.69130850655935`}], 
        PointBox[{89.9, 123.62797156892712`}], 
        PointBox[{90., 122.53728833261891`}], 
        PointBox[{90.1, 121.87271980628141`}], 
        PointBox[{90.2, 122.54889420312692`}], 
        PointBox[{90.3, 122.53371113147561`}], 
        PointBox[{90.4, 119.63993980662187`}], 
        PointBox[{90.5, 120.27068881966738`}], 
        PointBox[{90.6, 120.66635982773796`}], 
        PointBox[{90.7, 119.68054937871854`}], 
        PointBox[{90.8, 119.18654924109381`}], 
        PointBox[{90.9, 121.02371482559127`}], 
        PointBox[{91., 119.82599437505442`}], 
        PointBox[{91.1, 119.26740599536531`}], 
        PointBox[{91.2, 120.01583347705733`}], 
        PointBox[{91.3, 119.72337488616715`}], 
        PointBox[{91.4, 116.97615259422432`}], 
        PointBox[{91.5, 117.72829968217175`}], 
        PointBox[{91.6, 118.0281968128926}], 
        PointBox[{91.7, 116.95448356785748`}], 
        PointBox[{91.8, 116.71141358183984`}], 
        PointBox[{91.9, 118.39361116913855`}], 
        PointBox[{92., 117.12241331488718`}], 
        PointBox[{92.1, 116.67114869171479`}], 
        PointBox[{92.2, 117.48307635359247`}], 
        PointBox[{92.3, 116.88368818919594`}], 
        PointBox[{92.4, 114.3429550764966}], 
        PointBox[{92.5, 115.18193172732731`}], 
        PointBox[{92.6, 115.38276335953026`}], 
        PointBox[{92.7, 114.22972216112133`}], 
        PointBox[{92.8, 114.26161593759599`}], 
        PointBox[{92.9, 115.74008397264646`}], 
        PointBox[{93., 114.42684987749018`}], 
        PointBox[{93.1, 114.08342836590711`}], 
        PointBox[{93.2, 114.94718824499749`}], 
        PointBox[{93.3, 114.01980978373419`}], 
        PointBox[{93.4, 111.73635237811283`}], 
        PointBox[{93.5, 112.63074769110253`}], 
        PointBox[{93.6, 112.72974199523958`}], 
        PointBox[{93.7, 111.50868476201538`}], 
        PointBox[{93.8, 111.83165082181101`}], 
        PointBox[{93.9, 113.06641519574018`}], 
        PointBox[{94., 111.73961958297232`}], 
        PointBox[{94.1, 111.50397196685111`}], 
        PointBox[{94.2, 112.40581568749664`}], 
        PointBox[{94.3, 111.13872143687063`}], 
        PointBox[{94.4, 109.15207488919035`}], 
        PointBox[{94.5, 110.07380811532943`}], 
        PointBox[{94.6, 110.06871379859535`}], 
        PointBox[{94.7, 108.7938939396636}], 
        PointBox[{94.8, 109.41445336700336`}], 
        PointBox[{94.9, 110.37608499792606`}], 
        PointBox[{95., 109.06080119444897`}], 
        PointBox[{95.1, 108.93227764435755`}], 
        PointBox[{95.2, 109.85514522898015`}], 
        PointBox[{95.3, 108.2484498491995}], 
        PointBox[{95.4, 106.58576460209332`}], 
        PointBox[{95.5, 107.51041669386146`}], 
        PointBox[{95.6, 107.39973917867631`}], 
        PointBox[{95.7, 106.08844047904891`}], 
        PointBox[{95.8, 107.00215290067295`}], 
        PointBox[{95.9, 107.67256436554703`}], 
        PointBox[{96., 106.39032264326704`}], 
        PointBox[{96.1, 106.36776219577654`}], 
        PointBox[{96.2, 107.29138354783808`}], 
        PointBox[{96.3, 105.35743240266618`}], 
        PointBox[{96.4, 104.03314821645961`}], 
        PointBox[{96.5, 104.93991441099882`}], 
        PointBox[{96.6, 104.72212555380864`}], 
        PointBox[{96.7, 103.39561937134592`}], 
        PointBox[{96.8, 104.58633454193478`}], 
        PointBox[{96.9, 104.95914219929764`}], 
        PointBox[{97., 103.72800810783616`}], 
        PointBox[{97.1, 103.80975887895225`}], 
        PointBox[{97.2, 104.71038507956864`}], 
        PointBox[{97.3, 102.47427529451784`}], 
        PointBox[{97.4, 101.4902523046348}], 
        PointBox[{97.5, 102.36169487344347`}], 
        PointBox[{97.6, 102.03634892870826`}], 
        PointBox[{97.7, 100.71886073052649`}], 
        PointBox[{97.8, 102.15891614061755`}], 
        PointBox[{97.9, 102.23887980254437`}], 
        PointBox[{98., 101.07358066937428`}], 
        PointBox[{98.1, 101.25750772864924`}], 
        PointBox[{98.2, 102.1077471857986}], 
        PointBox[{98.3, 99.60688723438551}], 
        PointBox[{98.4, 98.95356087542609}], 
        PointBox[{98.5, 99.77528095642583}], 
        PointBox[{98.6, 99.341991142704}], 
        PointBox[{98.7, 98.06157366827573}], 
        PointBox[{98.8, 99.71274334897967}], 
        PointBox[{98.9, 99.51449406193456}], 
        PointBox[{99., 98.42672801724393}], 
        PointBox[{99.1, 98.71021657945096}], 
        PointBox[{99.2, 99.47910769615861}], 
        PointBox[{99.3, 96.76262382317915}], 
        PointBox[{99.4, 96.4199949682951}], 
        PointBox[{99.5, 97.18021976841516}], 
        PointBox[{99.6, 96.6393917951635}], 
        PointBox[{99.7, 95.42699801652074}], 
        PointBox[{99.8, 97.24176542827745}], 
        PointBox[{99.9, 96.78827369160831}], 
        PointBox[{100., 95.78709309800837}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 360}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
        40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {0, -180}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
        PointBox[{0.1, 1.5119797898218508`}], 
        PointBox[{0.2, 0.19778021500053455`}], 
        PointBox[{0.3, -0.011912384163338174`}], 
        PointBox[{0.4, 1.0841340305275935`}], 
        PointBox[{0.5, -0.03852207638158234}], 
        PointBox[{0.6, -0.8815915943153527}], 
        PointBox[{0.7, 0.17530483139398712`}], 
        PointBox[{0.8, -0.1415932240767006}], 
        PointBox[{0.9, -1.4536683352553155`}], 
        PointBox[{1., 0.39932296459198824`}], 
        PointBox[{1.1, 1.5567503534749108`}], 
        PointBox[{1.2, 0.2600298527146947}], 
        PointBox[{1.3, 0.1584458821437238}], 
        PointBox[{1.4, 1.2736066934334076`}], 
        PointBox[{1.5, -0.11383465694359529`}], 
        PointBox[{1.6, -0.6724482509473546}], 
        PointBox[{1.7, 0.3284676470817658}], 
        PointBox[{1.8, -0.09431916203527635}], 
        PointBox[{1.9, -1.3818497351257975`}], 
        PointBox[{2., 0.786677597511698}], 
        PointBox[{2.1, 1.5876532553811558`}], 
        PointBox[{2.2, 0.32487312075431873`}], 
        PointBox[{2.3, 0.33200283261930963`}], 
        PointBox[{2.4, 1.443184521011517}], 
        PointBox[{2.5, -0.18439783863709636`}], 
        PointBox[{2.6, -0.463193962126752}], 
        PointBox[{2.7, 0.467498571353417}], 
        PointBox[{2.8, -0.05988034157326183}], 
        PointBox[{2.9, -1.2963190132788895`}], 
        PointBox[{3., 1.1505283729184157`}], 
        PointBox[{3.1, 1.603955585269432}], 
        PointBox[{3.2, 0.3889863917825096}], 
        PointBox[{3.3, 0.5052711052335326}], 
        PointBox[{3.4, 1.5861483250580477`}], 
        PointBox[{3.5, -0.2473239859559726}], 
        PointBox[{3.6, -0.25927281906160715`}], 
        PointBox[{3.7, 0.5897282695241302}], 
        PointBox[{3.8, -0.04023862672056566}], 
        PointBox[{3.9, -1.1956806066532408`}], 
        PointBox[{4., 1.4809928746367405`}], 
        PointBox[{4.1, 1.605363766922892}], 
        PointBox[{4.2, 0.4498052786225344}], 
        PointBox[{4.3, 0.6751101704112443}], 
        PointBox[{4.4, 1.6961132853853087`}], 
        PointBox[{4.5, -0.3004340321685959}], 
        PointBox[{4.6, -0.06602638813046724}], 
        PointBox[{4.7, 0.6918186818720642}], 
        PointBox[{4.8, -0.03823648800380397}], 
        PointBox[{4.9, -1.079407853173052}], 
        PointBox[{5., 1.7691060654187822`}], 
        PointBox[{5.1, 1.5907560877990363`}], 
        PointBox[{5.2, 0.5043149555763193}], 
        PointBox[{5.3, 0.837931609907173}], 
        PointBox[{5.4, 1.767682562202026}], 
        PointBox[{5.5, -0.3425948241151673}], 
        PointBox[{5.6, 0.11191265866864342`}], 
        PointBox[{5.7, 0.771077815685203}], 
        PointBox[{5.8, -0.055848144748779305`}], 
        PointBox[{5.9, -0.9461317107425202}], 
        PointBox[{6., 2.0084697304200745`}], 
        PointBox[{6.1, 1.5598353088180374`}], 
        PointBox[{6.2, 0.5505927661170062}], 
        PointBox[{6.3, 0.990915375984514}], 
        PointBox[{6.4, 1.7954428765960984`}], 
        PointBox[{6.5, -0.37353505807186593`}], 
        PointBox[{6.6, 0.2706238672180916}], 
        PointBox[{6.7, 0.8253569552762201}], 
        PointBox[{6.8, -0.09481695616432262}], 
        PointBox[{6.9, -0.7951127095948323}], 
        PointBox[{7., 2.1945544781183344`}], 
        PointBox[{7.1, 1.5118368374760394`}], 
        PointBox[{7.2, 0.586622467527377}], 
        PointBox[{7.3, 1.1316630599449127`}], 
        PointBox[{7.4, 1.7762984223727472`}], 
        PointBox[{7.5, -0.3937935163557995}], 
        PointBox[{7.6, 0.4068474653104204}], 
        PointBox[{7.7, 0.8529243653010781}], 
        PointBox[{7.8, -0.15531104233559745`}], 
        PointBox[{7.9, -0.626114182134188}], 
        PointBox[{8., 2.3252392461918134`}], 
        PointBox[{8.1, 1.4465097985676039`}], 
        PointBox[{8.2, 0.6111201647045164}], 
        PointBox[{8.3, 1.2575692232239817`}], 
        PointBox[{8.4, 1.7076123799506604`}], 
        PointBox[{8.5, -0.4049849727371111}], 
        PointBox[{8.6, 0.5181428684609273}], 
        PointBox[{8.7, 0.8523192991942778}], 
        PointBox[{8.8, -0.23771320571177057`}], 
        PointBox[{8.9, -0.4398240057807925}], 
        PointBox[{9., 2.400543131323502}], PointBox[{9.1, 1.364079085481535}],
         PointBox[{9.2, 0.6234003793797456}], 
        PointBox[{9.3, 1.3662174322516876`}], 
        PointBox[{9.4, 1.5897584649601413`}], 
        PointBox[{9.5, -0.4089220706546257}], 
        PointBox[{9.6, 0.6028479283322667}], 
        PointBox[{9.7, 0.8229985056368605}], 
        PointBox[{9.8, -0.34065414835367847`}], 
        PointBox[{9.9, -0.23860479014729208`}], 
        PointBox[{10., 2.4220789440441877`}], 
        PointBox[{10.1, 1.2649326076589205`}], 
        PointBox[{10.2, 0.6231239662456574}], 
        PointBox[{10.3, 1.4556425242781188`}], 
        PointBox[{10.4, 1.4243160141395492`}], 
        PointBox[{10.5, -0.408149983038129}], 
        PointBox[{10.6, 0.6597619496606058}], 
        PointBox[{10.7, 0.7646603223247439}], 
        PointBox[{10.8, -0.46302661359823105`}], 
        PointBox[{10.9, -0.025909733970365778`}], 
        PointBox[{11., 2.3931268838468895`}], 
        PointBox[{11.1, 1.1499391558936622`}], 
        PointBox[{11.2, 0.610678627622292}], 
        PointBox[{11.3, 1.5237719837023178`}], 
        PointBox[{11.4, 1.215267410450906}], 
        PointBox[{11.5, -0.4052109063950411}], 
        PointBox[{11.6, 0.6887183493063276}], 
        PointBox[{11.7, 0.6778220766091181}], 
        PointBox[{11.8, -0.6011400293782572}], 
        PointBox[{11.9, 0.19290584109876363`}], 
        PointBox[{12., 2.3180776894714654`}], 
        PointBox[{12.1, 1.0204587181615352`}], 
        PointBox[{12.2, 0.586975873568008}], 
        PointBox[{12.3, 1.5696390668690583`}], 
        PointBox[{12.4, 0.9691356875791826}], 
        PointBox[{12.5, -0.40248101834549743`}], 
        PointBox[{12.6, 0.6900472530232946}], 
        PointBox[{12.7, 0.5636048829092033}], 
        PointBox[{12.8, -0.7514571099673049}], 
        PointBox[{12.9, 0.41095457221308607`}], 
        PointBox[{13., 2.2018376068099315`}], 
        PointBox[{13.1, 0.8781191950129141}], 
        PointBox[{13.2, 0.5530086125745584}], 
        PointBox[{13.3, 1.5901436371386808`}], 
        PointBox[{13.4, 0.6935997290747764}], 
        PointBox[{13.5, -0.40237292401616287`}], 
        PointBox[{13.6, 0.6648897356590169}], 
        PointBox[{13.7, 0.42356956326511863`}], 
        PointBox[{13.8, -0.9088072826398275}], 
        PointBox[{13.9, 0.6209036210075283}], 
        PointBox[{14., 2.0504514859003393`}], 
        PointBox[{14.1, 0.7254549075369141}], 
        PointBox[{14.2, 0.5112043497574632}], 
        PointBox[{14.3, 1.5850314622402948`}], 
        PointBox[{14.4, 0.39851690785508254`}], 
        PointBox[{14.5, -0.4061288066459383}], 
        PointBox[{14.6, 0.6150193171870342}], 
        PointBox[{14.7, 0.26008816552348435`}], 
        PointBox[{14.8, -1.0672164436036837`}], 
        PointBox[{14.9, 0.8148279364468181}], 
        PointBox[{15., 1.8697677789004956`}], 
        PointBox[{15.1, 0.5648566772069898}], 
        PointBox[{15.2, 0.4633957933710917}], 
        PointBox[{15.3, 1.552350123089127}], 
        PointBox[{15.4, 0.09365211732620082}], 
        PointBox[{15.5, -0.41539113561884733`}], 
        PointBox[{15.6, 0.54233400724479}], 
        PointBox[{15.7, 0.07560761297463614}], 
        PointBox[{15.8, -1.2202260385893169`}], 
        PointBox[{15.9, 0.9848387986403395}], 
        PointBox[{16., 1.6657372713325458`}], 
        PointBox[{16.1, 0.3991538322534325}], 
        PointBox[{16.2, 0.4119409139002528}], 
        PointBox[{16.3, 1.4906907139957184`}], 
        PointBox[{16.4, -0.21060045415106288`}], 
        PointBox[{16.5, -0.4305964207069337}], 
        PointBox[{16.6, 0.4495170032751048}], 
        PointBox[{16.7, -0.12654205711260147`}], 
        PointBox[{16.8, -1.3602135822475248`}], 
        PointBox[{16.9, 1.1244656869530445`}], 
        PointBox[{17., 1.4447219012454298`}], 
        PointBox[{17.1, 0.2317507935113099}], 
        PointBox[{17.2, 0.35950597943156026`}], 
        PointBox[{17.3, 1.399162970663383}], 
        PointBox[{17.4, -0.5043164969702048}], 
        PointBox[{17.5, -0.4516675877966918}], 
        PointBox[{17.6, 0.3396055660050479}], 
        PointBox[{17.7, -0.3427859185849229}], 
        PointBox[{17.8, -1.4796601092039054`}], 
        PointBox[{17.9, 1.2286472154446528`}], 
        PointBox[{18., 1.2125244038506935`}], 
        PointBox[{18.1, 0.06590540377874277}], 
        PointBox[{18.2, 0.3087521428333275}], 
        PointBox[{18.3, 1.2773387227025523`}], 
        PointBox[{18.4, -0.7786925461205101}], 
        PointBox[{18.5, -0.4776667845690099}], 
        PointBox[{18.6, 0.21595381539555092`}], 
        PointBox[{18.7, -0.5690266874771623}], 
        PointBox[{18.8, -1.5705992543662433`}], 
        PointBox[{18.9, 1.2945395822207502`}], 
        PointBox[{19., 0.975097189846565}], 
        PointBox[{19.1, -0.09470629909810668}], 
        PointBox[{19.2, 0.2627611414882267}], 
        PointBox[{19.3, 1.1251908436788653`}], 
        PointBox[{19.4, -1.0265492876769713`}], 
        PointBox[{19.5, -0.5077364647077047}], 
        PointBox[{19.6, 0.08185692643019138}], 
        PointBox[{19.7, -0.8008966845482064}], 
        PointBox[{19.8, -1.6262169993588032`}], 
        PointBox[{19.9, 1.3216434258865775`}], 
        PointBox[{20., 0.7379370207509055}], 
        PointBox[{20.1, -0.24646465801743034`}], 
        PointBox[{20.2, 0.223909078129509}], 
        PointBox[{20.3, 0.9439751090794744}], 
        PointBox[{20.4, -1.2423633584003255`}], 
        PointBox[{20.5, -0.5401021311627119}], 
        PointBox[{20.6, -0.05909329773930949}], 
        PointBox[{20.7, -1.0340514157705911`}], 
        PointBox[{20.8, -1.64042384102504}], 
        PointBox[{20.9, 1.312142179820512}], 
        PointBox[{21., 0.5061764173660777}], 
        PointBox[{21.1, -0.38586672243400244`}], 
        PointBox[{21.2, 0.19433061885865754`}], 
        PointBox[{21.3, 0.7358143660512724}], 
        PointBox[{21.4, -1.4224136100401665`}], 
        PointBox[{21.5, -0.5730445839944878}], 
        PointBox[{21.6, -0.20354443266114686`}], 
        PointBox[{21.7, -1.2637971248477697`}], 
        PointBox[{21.8, -1.609807101005572}], 
        PointBox[{21.9, 1.2696962730351515`}], 
        PointBox[{22., 0.28413888465183845`}], 
        PointBox[{22.1, -0.5099262647090654}], 
        PointBox[{22.2, 0.175473222258006}], 
        PointBox[{22.3, 0.5044736708478013}], 
        PointBox[{22.4, -1.5647160465068737`}], 
        PointBox[{22.5, -0.6045123071598937}], 
        PointBox[{22.6, -0.3482215867334162}], 
        PointBox[{22.7, -1.48518018041068}], 
        PointBox[{22.8, -1.532070792032755}], 
        PointBox[{22.9, 1.2000615908218606`}], 
        PointBox[{23., 0.07629397104756208}], 
        PointBox[{23.1, -0.6152792503817182}], 
        PointBox[{23.2, 0.16897741156935808`}], 
        PointBox[{23.3, 0.2545347117957135}], 
        PointBox[{23.4, -1.668497509406734}], 
        PointBox[{23.5, -0.632511525425798}], 
        PointBox[{23.6, -0.4899412229497102}], 
        PointBox[{23.7, -1.6934558935572568`}], 
        PointBox[{23.8, -1.408157818554173}], 
        PointBox[{23.9, 1.109885794296133}], 
        PointBox[{24., -0.11353900015819818`}], 
        PointBox[{24.1, -0.6989897482926608}], 
        PointBox[{24.2, 0.175613492840057}], 
        PointBox[{24.3, -0.00671641866574646}], 
        PointBox[{24.4, -1.73388517895728}], 
        PointBox[{24.5, -0.654348856627621}], 
        PointBox[{24.6, -0.6252792088052956}], 
        PointBox[{24.7, -1.8829143691145873`}], 
        PointBox[{24.8, -1.2410077566128166`}], 
        PointBox[{24.9, 1.00641127934432}], 
        PointBox[{25., -0.28185679958187393`}], 
        PointBox[{25.1, -0.7583710601975326}], 
        PointBox[{25.2, 0.1956603622638795}], 
        PointBox[{25.3, -0.27181848593318136`}], 
        PointBox[{25.4, -1.76222390269686}], 
        PointBox[{25.5, -0.6683233863113855}], 
        PointBox[{25.6, -0.7518923515817733}], 
        PointBox[{25.7, -2.0490707035933156`}], 
        PointBox[{25.8, -1.0366146216911147`}], 
        PointBox[{25.9, 0.8962354464674718}], 
        PointBox[{26., -0.42627463018288836`}], 
        PointBox[{26.1, -0.7917045797948958}], 
        PointBox[{26.2, 0.2276740556844743}], 
        PointBox[{26.3, -0.5321917973342352}], 
        PointBox[{26.4, -1.7556569913140265`}], 
        PointBox[{26.5, -0.6728839304596477}], 
        PointBox[{26.6, -0.8676178514906496}], 
        PointBox[{26.7, -2.1869459407535032`}], 
        PointBox[{26.8, -0.8022655376080365}], 
        PointBox[{26.9, 0.7855610664737469}], 
        PointBox[{27., -0.5447527819924289}], 
        PointBox[{27.1, -0.7975080442156468}], 
        PointBox[{27.2, 0.27054061489980086`}], 
        PointBox[{27.3, -0.7789960422815057}], 
        PointBox[{27.4, -1.7165750992717221`}], 
        PointBox[{27.5, -0.6666861468256684}], 
        PointBox[{27.6, -0.9709765610496106}], 
        PointBox[{27.7, -2.2918889815264265`}], 
        PointBox[{27.8, -0.5465247594547691}], 
        PointBox[{27.9, 0.6799076211827924}], 
        PointBox[{28., -0.635855410440854}], 
        PointBox[{28.1, -0.7748572078089637}], 
        PointBox[{28.2, 0.32189909687440377`}], 
        PointBox[{28.3, -1.0035041436640313`}], 
        PointBox[{28.4, -1.6476552301137417`}], 
        PointBox[{28.5, -0.6488423281734867}], 
        PointBox[{28.6, -1.0602327063206758`}], 
        PointBox[{28.7, -2.3594659032933123`}], 
        PointBox[{28.8, -0.27825692864280427`}], 
        PointBox[{28.9, 0.5837710219493601}], 
        PointBox[{29., -0.6987903725930664}], 
        PointBox[{29.1, -0.7234554208771442}], 
        PointBox[{29.2, 0.37876862015764345`}], 
        PointBox[{29.3, -1.1979893084317155`}], 
        PointBox[{29.4, -1.5517969799730054`}], 
        PointBox[{29.5, -0.618910357101413}], 
        PointBox[{29.6, -1.1352255195561156`}], 
        PointBox[{29.7, -2.3855767660315905`}], 
        PointBox[{29.8, -0.006223039072210668}], 
        PointBox[{29.9, 0.5006501674797619}], 
        PointBox[{30., -0.7333242517779581}], 
        PointBox[{30.1, -0.6435993511986453}], 
        PointBox[{30.2, 0.4377377335658821}], 
        PointBox[{30.3, -1.3557156061433489`}], 
        PointBox[{30.4, -1.4320283624110743`}], 
        PointBox[{30.5, -0.5769758783862926}], 
        PointBox[{30.6, -1.1950061667412228`}], 
        PointBox[{30.7, -2.3665787844620354`}], 
        PointBox[{30.8, 0.26163064288994065`}], 
        PointBox[{30.9, 0.43309993178991135`}], 
        PointBox[{31., -0.7399148481199518}], 
        PointBox[{31.1, -0.5363684279545851}], 
        PointBox[{31.2, 0.4949911990224791}], 
        PointBox[{31.3, -1.4722112978779478`}], 
        PointBox[{31.4, -1.2915747745973931`}], 
        PointBox[{31.5, -0.5236551660200348}], 
        PointBox[{31.6, -1.2403268391353777`}], 
        PointBox[{31.7, -2.2997324804164236`}], 
        PointBox[{31.8, 0.5184157286894333}], 
        PointBox[{31.9, 0.38247491739093675`}], 
        PointBox[{32., -0.7195529182317841}], 
        PointBox[{32.1, -0.4033630841804552}], 
        PointBox[{32.2, 0.5463955351006007}], 
        PointBox[{32.3, -1.5444211438079947`}], 
        PointBox[{32.4, -1.1336698140221415`}], 
        PointBox[{32.5, -0.46007252643903485`}], 
        PointBox[{32.6, -1.27144576311548}], 
        PointBox[{32.7, -2.183528434827167}], 
        PointBox[{32.8, 0.758609811658971}], 
        PointBox[{32.9, 0.3491388898473815}], 
        PointBox[{33., -0.6738781257590745}], 
        PointBox[{33.1, -0.24701291854216834`}], 
        PointBox[{33.2, 0.5879700900804892}], 
        PointBox[{33.3, -1.5718810667422076`}], 
        PointBox[{33.4, -0.9620001432740537}], 
        PointBox[{33.5, -0.38797414171494893`}], 
        PointBox[{33.6, -1.2898955601922353`}], 
        PointBox[{33.7, -2.0165609598443552`}], 
        PointBox[{33.8, 0.9783886279510625}], 
        PointBox[{33.9, 0.3327411751342879}], 
        PointBox[{34., -0.6047328836102679}], 
        PointBox[{34.1, -0.07007176065235399}], 
        PointBox[{34.2, 0.6165519360547478}], 
        PointBox[{34.3, -1.5553587401627738`}], 
        PointBox[{34.4, -0.7797296794960857}], 
        PointBox[{34.5, -0.3092640481190756}], 
        PointBox[{34.6, -1.2962773428371293`}], 
        PointBox[{34.7, -1.8005831958835188`}], 
        PointBox[{34.8, 1.175435294124327}], 
        PointBox[{34.9, 0.33207514855166664`}], 
        PointBox[{35., -0.5147989346696704}], 
        PointBox[{35.1, 0.12367869640365825`}], 
        PointBox[{35.2, 0.6286751455445483}], 
        PointBox[{35.3, -1.4981037205470784`}], 
        PointBox[{35.4, -0.5908549503838003}], 
        PointBox[{35.5, -0.22667196784823318`}], 
        PointBox[{35.6, -1.292878157702944}], 
        PointBox[{35.7, -1.5380691244681657`}], 
        PointBox[{35.8, 1.3480316097920877`}], 
        PointBox[{35.9, 0.3452172901997983}], 
        PointBox[{36., -0.40704489495328744`}], 
        PointBox[{36.1, 0.32998061395119294`}], 
        PointBox[{36.2, 0.6222055938997073}], 
        PointBox[{36.3, -1.4044932680299098`}], 
        PointBox[{36.4, -0.3992732215556316}], 
        PointBox[{36.5, -0.14314626967097865`}], 
        PointBox[{36.6, -1.2809047509363154`}], 
        PointBox[{36.7, -1.2338182360799692`}], 
        PointBox[{36.8, 1.4957601283495023`}], 
        PointBox[{36.9, 0.3698190828290535}], 
        PointBox[{37., -0.2844788180445903}], 
        PointBox[{37.1, 0.5442547697639384}], 
        PointBox[{37.2, 0.5963107406932977}], 
        PointBox[{37.3, -1.2798339928522182`}], 
        PointBox[{37.4, -0.20867663163153338`}], 
        PointBox[{37.5, -0.061670511411648476`}], 
        PointBox[{37.6, -1.2619413658358098`}], 
        PointBox[{37.7, -0.8942766792170005}], 
        PointBox[{37.8, 1.6189109718688997`}], 
        PointBox[{37.9, 0.40345203921970096`}], 
        PointBox[{38., -0.1502070655078569}], 
        PointBox[{38.1, 0.7615237625723239}], 
        PointBox[{38.2, 0.5511516058577399}], 
        PointBox[{38.3, -1.1299623541272013`}], 
        PointBox[{38.4, -0.022620935978920897`}], 
        PointBox[{38.5, 0.014719785605848301`}], 
        PointBox[{38.6, -1.2372742218758503`}], 
        PointBox[{38.7, -0.5279737909404503}], 
        PointBox[{38.8, 1.7177499868812447`}], 
        PointBox[{38.9, 0.4431589148916828}], 
        PointBox[{39., -0.007554300496849464}], 
        PointBox[{39.1, 0.9762637457752135}], 
        PointBox[{39.2, 0.4880779865088698}], 
        PointBox[{39.3, -0.961487372755073}], 
        PointBox[{39.4, 0.1551137843998731}], 
        PointBox[{39.5, 0.08271531841091928}], 
        PointBox[{39.6, -1.2079244182095863`}], 
        PointBox[{39.7, -0.14471792283075047`}], 
        PointBox[{39.8, 1.7927114941594482`}], 
        PointBox[{39.9, 0.4860989947883354}], 
        PointBox[{40., 0.14008002600894542`}], 
        PointBox[{40.1, 1.1826892838653293`}], 
        PointBox[{40.2, 0.40947177302950877`}], 
        PointBox[{40.3, -0.7810398885339964}], 
        PointBox[{40.4, 0.3208627798703674}], 
        PointBox[{40.5, 0.1391831183937029}], 
        PointBox[{40.6, -1.1744296792203386`}], 
        PointBox[{40.7, 0.24430978266173042`}], 
        PointBox[{40.8, 1.8442080430650094`}], 
        PointBox[{40.9, 0.5292406072185258}], 
        PointBox[{41., 0.28940749132743804`}], 
        PointBox[{41.1, 1.3747624159113911`}], 
        PointBox[{41.2, 0.31844395844018436`}], 
        PointBox[{41.3, -0.5951503466712893}], 
        PointBox[{41.4, 0.47123381307392265`}], 
        PointBox[{41.5, 0.1806853159396269}], 
        PointBox[{41.6, -1.1370441640610807`}], 
        PointBox[{41.7, 0.6274311657325597}], 
        PointBox[{41.8, 1.8724273675543373`}], 
        PointBox[{41.9, 0.5694896208260616}], 
        PointBox[{42., 0.4371463136303646}], 
        PointBox[{42.1, 1.5460128887207247`}], 
        PointBox[{42.2, 0.21867836016826914`}], 
        PointBox[{42.3, -0.4102580035068968}], 
        PointBox[{42.4, 0.602743482675578}], 
        PointBox[{42.5, 0.20447652583243325`}], 
        PointBox[{42.6, -1.0953301925110281`}], 
        PointBox[{42.7, 0.9928866055342951}], 
        PointBox[{42.8, 1.8776184921516688`}], 
        PointBox[{42.9, 0.6040362696621742}], 
        PointBox[{43., 0.5802101886183664}], 
        PointBox[{43.1, 1.69017859016094}], 
        PointBox[{43.2, 0.1140626866799721}], 
        PointBox[{43.3, -0.23202729924742016`}], 
        PointBox[{43.4, 0.7124810744535353}], 
        PointBox[{43.5, 0.20763843579334207`}], 
        PointBox[{43.6, -1.0481579924999096`}], 
        PointBox[{43.7, 1.329467398019915}], 
        PointBox[{43.8, 1.8598035629584047`}], 
        PointBox[{43.9, 0.6305429311505577}], 
        PointBox[{44., 0.715844355217996}], 
        PointBox[{44.1, 1.801134426623321}], 
        PointBox[{44.2, 0.008476476883515716}], 
        PointBox[{44.3, -0.06582028265984263}], 
        PointBox[{44.4, 0.7979724110082316}], 
        PointBox[{44.5, 0.18852980954034138`}], 
        PointBox[{44.6, -0.9936534379703517}], 
        PointBox[{44.7, 1.6274008372129174`}], 
        PointBox[{44.8, 1.819606881308573}], 
        PointBox[{44.9, 0.6470477142029267}], 
        PointBox[{45., 0.8417891091958154}], 
        PointBox[{45.1, 1.8734699427513988`}], 
        PointBox[{45.2, -0.09441819127459894}], 
        PointBox[{45.3, 0.0843094525844208}], 
        PointBox[{45.4, 0.8572490994301916}], 
        PointBox[{45.5, 0.14547389233121066`}], 
        PointBox[{45.6, -0.9294107707792136}], 
        PointBox[{45.7, 1.878288677049568}], 
        PointBox[{45.8, 1.757502955792006}], 
        PointBox[{45.9, 0.6522060209717893}], 
        PointBox[{46., 0.9561188206716906}], 
        PointBox[{46.1, 1.9022219393809792`}], 
        PointBox[{46.2, -0.19176427018464892`}], 
        PointBox[{46.3, 0.2148235753447807}], 
        PointBox[{46.4, 0.8888585578970378}], 
        PointBox[{46.5, 0.07781815849011764}], 
        PointBox[{46.6, -0.8526705177064287}], 
        PointBox[{46.7, 2.076350622875907}], 
        PointBox[{46.8, 1.6743263845492038`}], 
        PointBox[{46.9, 0.6450799716549227}], 
        PointBox[{47., 1.0572235108047607`}], 
        PointBox[{47.1, 1.8837489953220938`}], 
        PointBox[{47.2, -0.2814283341940609}], 
        PointBox[{47.3, 0.3227986031852197}], 
        PointBox[{47.4, 0.8919095604287577}], 
        PointBox[{47.5, -0.014383254041604232`}], 
        PointBox[{47.6, -0.7609294957073871}], 
        PointBox[{47.7, 2.2178807771779248`}], 
        PointBox[{47.8, 1.5711337383763748`}], 
        PointBox[{47.9, 0.6254739010764752}], 
        PointBox[{48., 1.14399900691933}], 
        PointBox[{48.1, 1.8155597948498325`}], 
        PointBox[{48.2, -0.3619427658704808}], 
        PointBox[{48.3, 0.40670733983279206`}], 
        PointBox[{48.4, 0.8662889476545388}], 
        PointBox[{48.5, -0.12989309167460306`}], 
        PointBox[{48.6, -0.6518350110491156}], 
        PointBox[{48.7, 2.301907556473452}], 
        PointBox[{48.8, 1.4494733643441577`}], 
        PointBox[{48.9, 0.5936351526906947}], 
        PointBox[{49., 1.2154624097238411`}], 
        PointBox[{49.1, 1.696885728983034}], 
        PointBox[{49.2, -0.43309950234834105`}], 
        PointBox[{49.3, 0.46532008971553296`}], 
        PointBox[{49.4, 0.8120806875376729}], 
        PointBox[{49.5, -0.26837580402207095`}], 
        PointBox[{49.6, -0.5246102876626537}], 
        PointBox[{49.7, 2.3294333305821056`}], 
        PointBox[{49.8, 1.310797879646998}], 
        PointBox[{49.9, 0.5501308212042204}], 
        PointBox[{50., 1.2706900258199312`}], 
        PointBox[{50.1, 1.52865240907704}], 
        PointBox[{50.2, -0.4954194796664524}], 
        PointBox[{50.3, 0.49819885913893813`}], 
        PointBox[{50.4, 0.7299751688915421}], 
        PointBox[{50.5, -0.4263745227945037}], 
        PointBox[{50.6, -0.37965960794099374`}], 
        PointBox[{50.7, 2.303653795584978}], 
        PointBox[{50.8, 1.1571946312469663`}], 
        PointBox[{50.9, 0.4962594196695136}], 
        PointBox[{51., 1.3091439834461198`}], 
        PointBox[{51.1, 1.3141067762335297`}], 
        PointBox[{51.2, -0.5496785236900905}], 
        PointBox[{51.3, 0.5057883342451532}], 
        PointBox[{51.4, 0.6214657567979884}], 
        PointBox[{51.5, -0.6007028717212961}], 
        PointBox[{51.6, -0.21894065982633037`}], 
        PointBox[{51.7, 2.229293158350629}], 
        PointBox[{51.8, 0.9911440382202272}], 
        PointBox[{51.9, 0.43379434445523657`}], 
        PointBox[{52., 1.3303940214536851`}], 
        PointBox[{52.1, 1.0588259066134924`}], 
        PointBox[{52.2, -0.597039226697234}], 
        PointBox[{52.3, 0.4891779503595899}], 
        PointBox[{52.4, 0.488389274214569}], 
        PointBox[{52.5, -0.7870558021386387}], 
        PointBox[{52.6, -0.04658873004518682}], 
        PointBox[{52.7, 2.1120749599067494`}], 
        PointBox[{52.8, 0.8152722504892154}], 
        PointBox[{52.9, 0.36482393024198245`}], 
        PointBox[{53., 1.333824778732378}], 
        PointBox[{53.1, 0.7701100079430034}], 
        PointBox[{53.2, -0.6388833306773449}], 
        PointBox[{53.3, 0.44997324319410836`}], 
        PointBox[{53.4, 0.33308246881642845`}], 
        PointBox[{53.5, -0.9800860544637544}], 
        PointBox[{53.6, 0.132034684647806}], 
        PointBox[{53.7, 1.9588022204188746`}], 
        PointBox[{53.8, 0.6328608318654005}], 
        PointBox[{53.9, 0.29219383375311736`}], 
        PointBox[{54., 1.3192249416315462`}], 
        PointBox[{54.1, 0.45765058104734635`}], 
        PointBox[{54.2, -0.6761716527907993}], 
        PointBox[{54.3, 0.39071475715900306`}], 
        PointBox[{54.4, 0.15864042043540394`}], 
        PointBox[{54.5, -1.1737039840299985`}], 
        PointBox[{54.6, 0.3102390283966088}], 
        PointBox[{54.7, 1.7764886508812197`}], 
        PointBox[{54.8, 0.4470818520130706}], 
        PointBox[{54.9, 0.2184449070264236}], 
        PointBox[{55., 1.2857786245294847`}], 
        PointBox[{55.1, 0.13161342781677376`}], 
        PointBox[{55.2, -0.7100177152606193}], 
        PointBox[{55.3, 0.31357231523725204`}], 
        PointBox[{55.4, -0.032131457403011154`}], 
        PointBox[{55.5, -1.3613335954360082`}], 
        PointBox[{55.6, 0.480460002880136}], 
        PointBox[{55.7, 1.5717588805928244`}], 
        PointBox[{55.8, 0.26108258812018903`}], 
        PointBox[{55.9, 0.14641514149843715`}], 
        PointBox[{56., 1.232803153739951}], 
        PointBox[{56.1, -0.19679852351691807`}], 
        PointBox[{56.2, -0.7408466498745838}], 
        PointBox[{56.3, 0.22170342249592068`}], 
        PointBox[{56.4, -0.23571048148733098`}], 
        PointBox[{56.5, -1.535370389414311}], 
        PointBox[{56.6, 0.635839108392247}], 
        PointBox[{56.7, 1.352046139712911}], 
        PointBox[{56.8, 0.07891429392475402}], 
        PointBox[{56.9, 0.07971660655312007}], 
        PointBox[{57., 1.1598716026273905`}], 
        PointBox[{57.1, -0.5163496064196806}], 
        PointBox[{57.2, -0.7686229526952957}], 
        PointBox[{57.3, 0.1184827471151948}], 
        PointBox[{57.4, -0.44794310668658}], 
        PointBox[{57.5, -1.6879437279276317`}], 
        PointBox[{57.6, 0.769910473114578}], 
        PointBox[{57.7, 1.1239104515771032`}], 
        PointBox[{57.8, -0.09611504335771315}], 
        PointBox[{57.9, 0.020648316989536397`}], 
        PointBox[{58., 1.066239837979083}], 
        PointBox[{58.1, -0.8168121325797983}], 
        PointBox[{58.2, -0.7930878118568216}], 
        PointBox[{58.3, 0.007099400616425555}], 
        PointBox[{58.4, -0.6651003612350905}], 
        PointBox[{58.5, -1.8109588073639316`}], 
        PointBox[{58.6, 0.8781783399244887}], 
        PointBox[{58.7, 0.8940084243513411}], 
        PointBox[{58.8, -0.2599663692599279}], 
        PointBox[{58.9, -0.026988666286342777`}], 
        PointBox[{59., 0.9519438215720584}], 
        PointBox[{59.1, -1.0889685223883134`}], 
        PointBox[{59.2, -0.8133279860121547}], 
        PointBox[{59.3, -0.10873078485019505`}], 
        PointBox[{59.4, -0.8828453681489918}], 
        PointBox[{59.5, -1.8971070169864106`}], 
        PointBox[{59.6, 0.9572621163606527}], 
        PointBox[{59.7, 0.6676244095651782}], 
        PointBox[{59.8, -0.40981467821256956`}], 
        PointBox[{59.9, -0.06161201853683451}], 
        PointBox[{60., 0.8164952106817509}], 
        PointBox[{60.1, -1.326248209552432}], 
        PointBox[{60.2, -0.8287616938177962}], 
        PointBox[{60.3, -0.2263040664474829}], 
        PointBox[{60.4, -1.0973955094377743`}], 
        PointBox[{60.5, -1.9397250393303693`}], 
        PointBox[{60.6, 1.0065490935157868`}], 
        PointBox[{60.7, 0.45014294286374934`}], 
        PointBox[{60.8, -0.5421779952957877}], 
        PointBox[{60.9, -0.08046449610264972}], 
        PointBox[{61., 0.6610197332047392}], 
        PointBox[{61.1, -1.5230354959421675`}], 
        PointBox[{61.2, -0.8378452821270912}], 
        PointBox[{61.3, -0.3420546430788818}], 
        PointBox[{61.4, -1.3047453735489398`}], 
        PointBox[{61.5, -1.933305766659032}], 
        PointBox[{61.6, 1.0277345687063644`}], 
        PointBox[{61.7, 0.24658409701805795`}], 
        PointBox[{61.8, -0.6538058149453718}], 
        PointBox[{61.9, -0.08131613382283831}], 
        PointBox[{62., 0.48731699523341376`}], 
        PointBox[{62.1, -1.6760481202218216`}], 
        PointBox[{62.2, -0.8393296707436093}], 
        PointBox[{62.3, -0.45313973932206864`}], 
        PointBox[{62.4, -1.5006992206908762`}], 
        PointBox[{62.5, -1.8751221430284204`}], 
        PointBox[{62.6, 1.023794454340532}], 
        PointBox[{62.7, 0.06019669267698191}], 
        PointBox[{62.8, -0.7429200327242143}], 
        PointBox[{62.9, -0.06486358128313441}], 
        PointBox[{63., 0.29759953914617654`}], 
        PointBox[{63.1, -1.784463520765712}], 
        PointBox[{63.2, -0.8323473471609759}], 
        PointBox[{63.3, -0.5574656337921624}], 
        PointBox[{63.4, -1.6817111531127011`}], 
        PointBox[{63.5, -1.762984777604288}], 
        PointBox[{63.6, 0.9996248976094648}], 
        PointBox[{63.7, -0.1054086316289613}], 
        PointBox[{63.8, -0.8068196996027837}], 
        PointBox[{63.9, -0.029320355650270358`}], 
        PointBox[{64., 0.09616824991826434}], 
        PointBox[{64.1, -1.8480999782550498`}], 
        PointBox[{64.2, -0.815418766826042}], 
        PointBox[{64.3, -0.6525085623798077}], 
        PointBox[{64.4, -1.8435549499336048`}], 
        PointBox[{64.5, -1.599738823613734}], 
        PointBox[{64.6, 0.9602835527402931}], 
        PointBox[{64.7, -0.2479383815007168}], 
        PointBox[{64.8, -0.8443643013742985}], 
        PointBox[{64.9, 0.024346460617380217`}], 
        PointBox[{65., -0.11232679416571045`}], 
        PointBox[{65.1, -1.869025454070652}], 
        PointBox[{65.2, -0.7881575709252502}], 
        PointBox[{65.3, -0.7371196135281934}], 
        PointBox[{65.4, -1.9835301191269537`}], 
        PointBox[{65.5, -1.3893706439921516`}], 
        PointBox[{65.6, 0.9112971990034566}], 
        PointBox[{65.7, -0.36541658096393803`}], 
        PointBox[{65.8, -0.854233702266356}], 
        PointBox[{65.9, 0.09500884087901795}], 
        PointBox[{66., -0.32145493991993135`}], 
        PointBox[{66.1, -1.8493196820199955`}], 
        PointBox[{66.2, -0.7494344616206945}], 
        PointBox[{66.3, -0.8095230518301832}], 
        PointBox[{66.4, -2.097294861523551}], 
        PointBox[{66.5, -1.1381229728867766`}], 
        PointBox[{66.6, 0.8581482084919116}], 
        PointBox[{66.7, -0.4566796561484807}], 
        PointBox[{66.8, -0.8357994922916987}], 
        PointBox[{66.9, 0.18065432479488663`}], 
        PointBox[{67., -0.5244590878646704}], 
        PointBox[{67.1, -1.7922571398448781`}], 
        PointBox[{67.2, -0.6989420435638749}], 
        PointBox[{67.3, -0.8689138349946006}], 
        PointBox[{67.4, -2.181529968540417}], 
        PointBox[{67.5, -0.854095446804422}], 
        PointBox[{67.6, 0.8058774165765499}], 
        PointBox[{67.7, -0.5205788509992999}], 
        PointBox[{67.8, -0.7885967269103276}], 
        PointBox[{67.9, 0.27920175289182225`}], 
        PointBox[{68., -0.7138712241358007}], 
        PointBox[{68.1, -1.7013848382703145`}], 
        PointBox[{68.2, -0.6367420334136114}], 
        PointBox[{68.3, -0.9150535232329275}], 
        PointBox[{68.4, -2.2335278743994422`}], 
        PointBox[{68.5, -0.546970759431133}], 
        PointBox[{68.6, 0.7581525880959816}], 
        PointBox[{68.7, -0.5577014764130581}], 
        PointBox[{68.8, -0.7135924296380836}], 
        PointBox[{68.9, 0.3860641594219487}], 
        PointBox[{69., -0.8834196406969568}], 
        PointBox[{69.1, -1.5813402880376088`}], 
        PointBox[{69.2, -0.5639791743669775}], 
        PointBox[{69.3, -0.9488682807714213}], 
        PointBox[{69.4, -2.2508196689377655`}], 
        PointBox[{69.5, -0.22688775532878935`}], 
        PointBox[{69.6, 0.7177961693159887}], 
        PointBox[{69.7, -0.5688024552146089}], 
        PointBox[{69.8, -0.6122190804599086}], 
        PointBox[{69.9, 0.49738054713088786`}], 
        PointBox[{70., -1.0265669273358071`}], 
        PointBox[{70.1, -1.435900615855644}], 
        PointBox[{70.2, -0.4810753868150641}], 
        PointBox[{70.3, -0.9702761560256477}], 
        PointBox[{70.4, -2.2302702183296788`}], 
        PointBox[{70.5, 0.09655635194212664}], 
        PointBox[{70.6, 0.6870352301557432}], 
        PointBox[{70.7, -0.5547976166926674}], 
        PointBox[{70.8, -0.48548856924753636`}], 
        PointBox[{70.9, 0.6085895596916089}], 
        PointBox[{71., -1.138335942356207}], 
        PointBox[{71.1, -1.2697493470623158`}], 
        PointBox[{71.2, -0.3899468566160067}], 
        PointBox[{71.3, -0.9808758628059877}], 
        PointBox[{71.4, -2.1703837156892405`}], 
        PointBox[{71.5, 0.4135261921546771}], 
        PointBox[{71.6, 0.6667248057274264}], 
        PointBox[{71.7, -0.5177583991899155}], 
        PointBox[{71.8, -0.33625216109794565`}], 
        PointBox[{71.9, 0.7141368837765185}], 
        PointBox[{72., -1.215352599043399}], 
        PointBox[{72.1, -1.087489643781737}], 
        PointBox[{72.2, -0.29258489676431054`}], 
        PointBox[{72.3, -0.9824236246422515}], 
        PointBox[{72.4, -2.0695885748500586`}], 
        PointBox[{72.5, 0.7156970736759831}], 
        PointBox[{72.6, 0.6566581281731487}], 
        PointBox[{72.7, -0.46019389184220927`}], 
        PointBox[{72.8, -0.16757031135057332`}], 
        PointBox[{72.9, 0.8083876450546086}], 
        PointBox[{73., -1.2561096467688913`}], 
        PointBox[{73.1, -0.8938890828067088}], 
        PointBox[{73.2, -0.1916596775117796}], 
        PointBox[{73.3, -0.9772829745343188}], 
        PointBox[{73.4, -1.9274109650359605`}], 
        PointBox[{73.5, 0.995961670516408}], 
        PointBox[{73.6, 0.6563193145339028}], 
        PointBox[{73.7, -0.38458449689642293`}], 
        PointBox[{73.8, 0.017649493565841112`}], 
        PointBox[{73.9, 0.8868018137654872}], 
        PointBox[{74., -1.2600599644138128`}], 
        PointBox[{74.1, -0.6929414530677604}], 
        PointBox[{74.2, -0.08935049854335375}], 
        PointBox[{74.3, -0.966814258172235}], 
        PointBox[{74.4, -1.7433283831342123`}], 
        PointBox[{74.5, 1.24926550174132}], 
        PointBox[{74.6, 0.6645362107519759}], 
        PointBox[{74.7, -0.2936922914450406}], 
        PointBox[{74.8, 0.2154440358572174}], 
        PointBox[{74.9, 0.9441332770875306}], 
        PointBox[{75., -1.2290815273518092`}], 
        PointBox[{75.1, -0.48952559912140714`}], 
        PointBox[{75.2, 0.011011370814230759`}], 
        PointBox[{75.3, -0.9535186708380934}], 
        PointBox[{75.4, -1.518949640878418}], 
        PointBox[{75.5, 1.4716534765102551`}], 
        PointBox[{75.6, 0.6794250333477976}], 
        PointBox[{75.7, -0.19069188784487778`}], 
        PointBox[{75.8, 0.4220441540601314}], 
        PointBox[{75.9, 0.9767778119858121}], 
        PointBox[{76., -1.165838622553565}], 
        PointBox[{76.1, -0.2874833835157915}], 
        PointBox[{76.2, 0.10681069546262734`}], 
        PointBox[{76.3, -0.9388953439265606}], 
        PointBox[{76.4, -1.256365556459059}], 
        PointBox[{76.5, 1.6611267892076285`}], 
        PointBox[{76.6, 0.6991262614465086}], 
        PointBox[{76.7, -0.07830714085139334}], 
        PointBox[{76.8, 0.633254224601842}], 
        PointBox[{76.9, 0.9822507210410549}], 
        PointBox[{77., -1.0744264197201119`}], 
        PointBox[{77.1, -0.0908389912583516}], 
        PointBox[{77.2, 0.19489553311723284`}], 
        PointBox[{77.3, -0.9254001940498711}], 
        PointBox[{77.4, -0.9599256301662535}], 
        PointBox[{77.5, 1.8165117367971106`}], 
        PointBox[{77.6, 0.7212557583043235}], 
        PointBox[{77.7, 0.04006479883537395}], 
        PointBox[{77.8, 0.8442208014675998}], 
        PointBox[{77.9, 0.958576192278997}], 
        PointBox[{78., -0.9599693761847448}], 
        PointBox[{78.1, 0.09654794446396409}], 
        PointBox[{78.2, 0.2722387798712589}], 
        PointBox[{78.3, -0.9140397152659716}], 
        PointBox[{78.4, -0.6352896703610895}], 
        PointBox[{78.5, 1.9377147526320186`}], 
        PointBox[{78.6, 0.7434297599829733}], 
        PointBox[{78.7, 0.16154804353573127`}], 
        PointBox[{78.8, 1.0504960747202858`}], 
        PointBox[{78.9, 0.9058720672619529}], 
        PointBox[{79., -0.8281265297482605}], 
        PointBox[{79.1, 0.2709152429088135}], 
        PointBox[{79.2, 0.3357462461790419}], 
        PointBox[{79.3, -0.9064558944082819}], 
        PointBox[{79.4, -0.2903520205945824}], 
        PointBox[{79.5, 2.02510059139604}], 
        PointBox[{79.6, 0.7631595011553145}], 
        PointBox[{79.7, 0.2831947186423349}], 
        PointBox[{79.8, 1.2465123453148408`}], 
        PointBox[{79.9, 0.8254917005542666}], 
        PointBox[{80., -0.6848250240655034}], 
        PointBox[{80.1, 0.42888137500267476`}], 
        PointBox[{80.2, 0.38255667076737154`}], 
        PointBox[{80.3, -0.9024385175071075}], 
        PointBox[{80.4, 0.06596380739210872}], 
        PointBox[{80.5, 2.0793530226292205`}], 
        PointBox[{80.6, 0.7778198901723954}], 
        PointBox[{80.7, 0.4019529129436705}], 
        PointBox[{80.8, 1.4271811859071022`}], 
        PointBox[{80.9, 0.7197155025205575}], 
        PointBox[{81., -0.5362871746037854}], 
        PointBox[{81.1, 0.5672388875609613}], 
        PointBox[{81.2, 0.4097112284580362}], 
        PointBox[{81.3, -0.9034717782706139}], 
        PointBox[{81.4, 0.4231728647064301}], 
        PointBox[{81.5, 2.1015969464933733`}], 
        PointBox[{81.6, 0.785259019015939}], 
        PointBox[{81.7, 0.5153961446339963}], 
        PointBox[{81.8, 1.5870686335038044`}], 
        PointBox[{81.9, 0.5927542757854098}], 
        PointBox[{82., -0.38818848265509587`}], 
        PointBox[{82.1, 0.6833534562683781}], 
        PointBox[{82.2, 0.41529236628412036`}], 
        PointBox[{82.3, -0.9075155627579079}], 
        PointBox[{82.4, 0.7706684269214747}], 
        PointBox[{82.5, 2.093182288670505}], 
        PointBox[{82.6, 0.7837433372769738}], 
        PointBox[{82.7, 0.6215243122860556}], 
        PointBox[{82.8, 1.7212642450540443`}], 
        PointBox[{82.9, 0.44963066253694706`}], 
        PointBox[{83., -0.24552244856749894`}], 
        PointBox[{83.1, 0.7752319166247617}], 
        PointBox[{83.2, 0.397569229338842}], 
        PointBox[{83.3, -0.9129258141474565}], 
        PointBox[{83.4, 1.0977143902273383`}], 
        PointBox[{83.5, 2.055824097013101}], 
        PointBox[{83.6, 0.7718099266057834}], 
        PointBox[{83.7, 0.7185853980554384}], 
        PointBox[{83.8, 1.8243345638693427`}], 
        PointBox[{83.9, 0.29574615357705625`}], 
        PointBox[{84., -0.11319494365307037`}], 
        PointBox[{84.1, 0.8409868519811425}], 
        PointBox[{84.2, 0.3549991098770988}], 
        PointBox[{84.3, -0.9173193579481449}], 
        PointBox[{84.4, 1.3940088342351373`}], 
        PointBox[{84.5, 1.9911870147261652`}], 
        PointBox[{84.6, 0.7484075635948102}], 
        PointBox[{84.7, 0.8052117455445114}], 
        PointBox[{84.8, 1.8915637538011651`}], 
        PointBox[{84.9, 0.13654655903519597`}], 
        PointBox[{85., 0.004866055656748358}], 
        PointBox[{85.1, 0.87932606801769}], 
        PointBox[{85.2, 0.28688211854023393`}], 
        PointBox[{85.3, -0.9176316996017704}], 
        PointBox[{85.4, 1.6500030425013392`}], 
        PointBox[{85.5, 1.9007485351976356`}], 
        PointBox[{85.6, 0.7127150126034394}], 
        PointBox[{85.7, 0.8801104871454299}], 
        PointBox[{85.8, 1.9183894071247778`}], 
        PointBox[{85.9, -0.02251685097871814}], 
        PointBox[{86., 0.10544115611992311`}], 
        PointBox[{86.1, 0.8896034790886915}], 
        PointBox[{86.2, 0.19286820157867623`}], 
        PointBox[{86.3, -0.9098299232427962}], 
        PointBox[{86.4, 1.8583867087509134`}], 
        PointBox[{86.5, 1.7867303963575978`}], 
        PointBox[{86.6, 0.6647840291043394}], 
        PointBox[{86.7, 0.9427205013271305}], 
        PointBox[{86.8, 1.9010339277010644`}], 
        PointBox[{86.9, -0.17701682967162924`}], 
        PointBox[{87., 0.186065145113389}], 
        PointBox[{87.1, 0.8715291960106697}], 
        PointBox[{87.2, 0.07383057862170972}], 
        PointBox[{87.3, -0.889731611503521}], 
        PointBox[{87.4, 2.013854229102435}], 
        PointBox[{87.5, 1.6516176182340132`}], 
        PointBox[{87.6, 0.6051446908168145}], 
        PointBox[{87.7, 0.9930163683457067}], 
        PointBox[{87.8, 1.8369792749290355`}], 
        PointBox[{87.9, -0.3229452487503295}], 
        PointBox[{88., 0.24534668551495997`}], 
        PointBox[{88.1, 0.8256864895010949}], 
        PointBox[{88.2, -0.06884930395608535}], 
        PointBox[{88.3, -0.8532244417801849}], 
        PointBox[{88.4, 2.1136406855875975`}], 
        PointBox[{88.5, 1.4976423802581849`}], 
        PointBox[{88.6, 0.5346551443362841}], 
        PointBox[{88.7, 1.0309255252359435`}], 
        PointBox[{88.8, 1.7245005808072165`}], 
        PointBox[{88.9, -0.4576075625300291}], 
        PointBox[{89., 0.28245772347872844`}], 
        PointBox[{89.1, 0.7529471094385372}], 
        PointBox[{89.2, -0.23363368542050011`}], 
        PointBox[{89.3, -0.7966312795833801}], 
        PointBox[{89.4, 2.1572660893725697`}], 
        PointBox[{89.5, 1.3273642400745302`}], 
        PointBox[{89.6, 0.4545524630957516}], 
        PointBox[{89.7, 1.056076028595271}], 
        PointBox[{89.8, 1.5639523640929838`}], 
        PointBox[{89.9, -0.5794365179244778}], 
        PointBox[{90., 0.2972497937080334}], 
        PointBox[{90.1, 0.6546007029173779}], 
        PointBox[{90.2, -0.4171035720864893}], 
        PointBox[{90.3, -0.7177174580938299}], 
        PointBox[{90.4, 2.147127783333417}], 
        PointBox[{90.5, 1.144102853271761}], 
        PointBox[{90.6, 0.36708738400193397`}], 
        PointBox[{90.7, 1.0695740230366937`}], 
        PointBox[{90.8, 1.3574747021993971`}], 
        PointBox[{90.9, -0.6872235550181358}], 
        PointBox[{91., 0.29066091439744923`}], 
        PointBox[{91.1, 0.5327759385691024}], 
        PointBox[{91.2, -0.616006083379034}], 
        PointBox[{91.3, -0.6154476176889148}], 
        PointBox[{91.4, 2.0873826949173235`}], 
        PointBox[{91.5, 0.9507733251084574}], 
        PointBox[{91.6, 0.2742905222112313}], 
        PointBox[{91.7, 1.0715615549124777`}], 
        PointBox[{91.8, 1.1089952426991658`}], 
        PointBox[{91.9, -0.7810901631019078}], 
        PointBox[{92., 0.2640213272970868}], 
        PointBox[{92.1, 0.38984644089941867`}], 
        PointBox[{92.2, -0.8262044626462739}], 
        PointBox[{92.3, -0.49089119627024047`}], 
        PointBox[{92.4, 1.9838894013664685`}], 
        PointBox[{92.5, 0.751143991961726}], 
        PointBox[{92.6, 0.17916471112403087`}], 
        PointBox[{92.7, 1.0628097840817645`}], 
        PointBox[{92.8, 0.8253636330337031}], 
        PointBox[{92.9, -0.8609487104404252}], 
        PointBox[{93., 0.21958735267980956`}], 
        PointBox[{93.1, 0.22893949950230308`}], 
        PointBox[{93.2, -1.0415632038202602`}], 
        PointBox[{93.3, -0.3469694395607803}], 
        PointBox[{93.4, 1.8435261079721386`}], 
        PointBox[{93.5, 0.5486002703983104}], 
        PointBox[{93.6, 0.0844974380597705}], 
        PointBox[{93.7, 1.0433100112422835`}], 
        PointBox[{93.8, 0.5145270489738323}], 
        PointBox[{93.9, -0.9277495271817315}], 
        PointBox[{94., 0.15945765092328656`}], 
        PointBox[{94.1, 0.052813770656939596`}], 
        PointBox[{94.2, -1.2569913900224492`}], 
        PointBox[{94.3, -0.18886264454340562`}], 
        PointBox[{94.4, 1.673559561750153}], 
        PointBox[{94.5, 0.34684904156893026`}], 
        PointBox[{94.6, -0.006516006658785045}], 
        PointBox[{94.7, 1.0132654531480512`}], 
        PointBox[{94.8, 0.18642733972228598`}], 
        PointBox[{94.9, -0.9821850762527902}], 
        PointBox[{95., 0.08644304650078993}], 
        PointBox[{95.1, -0.1350831371091772}], 
        PointBox[{95.2, -1.4655711613449967`}], 
        PointBox[{95.3, -0.022892106775543652`}], 
        PointBox[{95.4, 1.4815888852463104`}], 
        PointBox[{95.5, 0.14956767979310825`}], 
        PointBox[{95.6, -0.09100653222412802}], 
        PointBox[{95.7, 0.9724632133584237}], 
        PointBox[{95.8, -0.14807437165291049`}], 
        PointBox[{95.9, -1.0248574239521986`}], 
        PointBox[{96., 0.003573482797946781}], 
        PointBox[{96.1, -0.33116061096370686`}], 
        PointBox[{96.2, -1.6602833618671866`}], 
        PointBox[{96.3, 0.14397926635865588`}], 
        PointBox[{96.4, 1.2751450131181628`}], 
        PointBox[{96.5, -0.03955902412417345}], 
        PointBox[{96.6, -0.16529358117259108`}], 
        PointBox[{96.7, 0.9205138109682593}], 
        PointBox[{96.8, -0.477524233632721}], 
        PointBox[{96.9, -1.0561608873686055`}], 
        PointBox[{97., -0.08600032987305894}], 
        PointBox[{97.1, -0.5317350592085859}], 
        PointBox[{97.2, -1.8337262587010628`}], 
        PointBox[{97.3, 0.3045738937216811}], 
        PointBox[{97.4, 1.0614194540830795`}], 
        PointBox[{97.5, -0.21692477761826012`}], 
        PointBox[{97.6, -0.2269095596857369}], 
        PointBox[{97.7, 0.8568572544609196}], 
        PointBox[{97.8, -0.7908505319792312}], 
        PointBox[{97.9, -1.0762888402387034`}], 
        PointBox[{98., -0.17907346272841096`}], 
        PointBox[{98.1, -0.7330824223899981}], 
        PointBox[{98.2, -1.9782876933022635`}], 
        PointBox[{98.3, 0.4526081597432494}], 
        PointBox[{98.4, 0.8470165978214936}], 
        PointBox[{98.5, -0.37917135638417676`}], 
        PointBox[{98.6, -0.2726058677653782}], 
        PointBox[{98.7, 0.7808210383082042}], 
        PointBox[{98.8, -1.0780597286939155`}], 
        PointBox[{98.9, -1.0852272207121132`}], 
        PointBox[{99., -0.2725493845064193}], 
        PointBox[{99.1, -0.9315911862649955}], 
        PointBox[{99.2, -2.0865031159337377`}], 
        PointBox[{99.3, 0.5825886369566433}], 
        PointBox[{99.4, 0.6379253604100086}], 
        PointBox[{99.5, -0.5231193167710444}], 
        PointBox[{99.6, -0.30006062968459446`}], 
        PointBox[{99.7, 0.6917267120588804}], 
        PointBox[{99.8, -1.3304155975056347`}], 
        PointBox[{99.9, -1.0826825691765407`}], 
        PointBox[{100., -0.36343950929585844`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {-180, 180}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \
\\\"input\\\" -> \\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-328., 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.880463059599176*^9, 3.880464065578113*^9, 3.88046420770853*^9, 
   3.8806127343027*^9, 3.880612964485507*^9, {3.880613087381782*^9, 
   3.8806130957934437`*^9}, 3.880613233904704*^9, 3.8806132965287247`*^9, 
   3.880613338117044*^9, 3.880613370531921*^9, 3.88065551654395*^9, 
   3.880702736164805*^9, 3.880703451955668*^9, 3.890982077186174*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"e191cfb3-2513-489b-9422-7055e958145e"]
}, Open  ]],

Cell["\<\
Produce the four labelled plots for the case of almost exact 2:1 pericentric \
resonance.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
  3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
  3.88045916902036*^9, 3.8804592043930492`*^9}, {3.88061346634433*^9, 
  3.880613517584133*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0bcf49db-b4a6-44ed-b9a8-c36cecffb3f0"],

Cell[BoxData[
 RowBox[{"FourPlot", "[", 
  RowBox[{"0.001", ",", " ", "init1", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.880452075209993*^9, 3.8804520778644047`*^9}, {
   3.880452108405514*^9, 3.880452119399235*^9}, 3.8804528078164167`*^9, {
   3.880452996402988*^9, 3.880453022180064*^9}, {3.8804530669149837`*^9, 
   3.880453088930623*^9}, {3.880453432357012*^9, 3.8804534325648947`*^9}, {
   3.880453917905594*^9, 3.880454011504031*^9}, 3.88045688256952*^9, {
   3.880458167540039*^9, 3.8804581679030027`*^9}, {3.880458961232695*^9, 
   3.880458964542954*^9}, {3.88045904343493*^9, 3.8804590448084507`*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"94091780-8049-46bf-af12-f944424c8602"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcA", "=", "gc"}]], "Input",
 CellChangeTimes->{{3.880456891479518*^9, 3.880456894354617*^9}, {
  3.880457193894134*^9, 3.880457195256897*^9}, {3.880457362685213*^9, 
  3.8804573637333384`*^9}, {3.88045807899999*^9, 3.8804580797777033`*^9}, {
  3.8804581179406424`*^9, 3.8804581762134523`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"d0043f5b-53e8-4ada-8894-2362e9238035"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.0055000000000000005`], Thickness[0.0075], PointBox[CompressedData["
1:eJxFm3dYU1nXxRHp0kEkgNIjSO9VsmihJEB6ghVxROwoYsOCDgoqVqyICqjY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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0.6000000000000013},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0.6, 
           FormBox["0.6`", TraditionalForm]}, {0.62, 
           FormBox["0.62`", TraditionalForm]}, {0.64, 
           FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0.6, 0.65}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Prolog->{
        Dashing[{Small, Small}], 
        LineBox[{{0, 0.629961}, {100, 0.629961}}]},
      Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
     ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.0055000000000000005`], Thickness[0.0075], PointBox[CompressedData["
1:eJxFe3c8lf//vgqlNERKhBQpEtnzXPbm7HNKOw0toT2kSEsqlUgiq2SUKKMl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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {0.1, 
           FormBox["0.1`", TraditionalForm]}, {0.2, 
           FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 0.2}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -159.99}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.0055000000000000005`], Thickness[0.0075], PointBox[CompressedData["
1:eJxd12lczfsb7vEkIYlUyI5Kc5FqaS7rap5WteZWaRKiRIjMCclQEpnKsFNE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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}, {360, 
           FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 360.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.0055000000000000005`], Thickness[0.0075], PointBox[CompressedData["
1:eJxdm3lcjen/xh+hsWRsGbJmy06EwaBji0hClkwRY1dIxjo4BmmIicaS7RuS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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[CurlyPhi]\
\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{-180, 
           FormBox[
            RowBox[{"-", "180"}], TraditionalForm]}, {0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {-180., 180.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -383.19}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-438.99, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.880456895113492*^9, {3.880457185276911*^9, 3.8804571958273478`*^9}, 
   3.8804572266308527`*^9, 3.880457264695498*^9, 3.8804573701758213`*^9, {
   3.880458081668655*^9, 3.880458098746015*^9}, 3.880458134742957*^9, 
   3.8804581782705297`*^9, 3.8804589738102627`*^9, {3.880459037265594*^9, 
   3.8804590489111233`*^9}, 3.8804626562007093`*^9, 3.880463067895451*^9, 
   3.880464066954792*^9, 3.880464209516212*^9, 3.880612742165921*^9, 
   3.880612832830274*^9, 3.880612884660523*^9, {3.880612941666154*^9, 
   3.880612965857891*^9}, 3.8806130971720543`*^9, 3.8806555181234903`*^9, 
   3.8807027381304007`*^9, 3.880703453835854*^9, 3.8909820790137978`*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"69dddac8-56a7-4ef6-83b9-592160b272b6"]
}, Open  ]],

Cell["\<\
Produce the x-y plot for the case of almost exact 2:1 pericentric resonance.  \
This is Fig.8.17a.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
  3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
  3.88045916902036*^9, 3.880459226173493*^9}, {3.8806135377142267`*^9, 
  3.880613544959393*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"eb06b93a-f904-44ed-8d25-cee056b7efd1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xyA", "=", "xyplot"}]], "Input",
 CellChangeTimes->{{3.880458186315967*^9, 3.8804581933130283`*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"98fc8bb3-b9b4-4def-a694-28959e645af4"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.0055000000000000005`],
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwtWnc4lt8bf2QrhRJCRH2VVfZIziOUVCoN2XtmVlaI7L333nsTKjo2lYak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     "]]}, {{}, {}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-4., 4.}, {-4., 4.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Prolog->{
    Thickness[0.002], 
    LineBox[{{0, -4}, {0, 4}}], 
    LineBox[{{-4, 0}, {4, 0}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8804581946036873`*^9, 3.880459488329492*^9, 3.880463075932872*^9, 
   3.8804640670196457`*^9, 3.880464209590558*^9, {3.880612945012594*^9, 
   3.88061296593466*^9}, 3.880613097237933*^9, 3.88065551818966*^9, 
   3.880702738189427*^9, 3.8807034539116793`*^9, 3.890982079074974*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"1ea8e1a6-12a9-4532-92c9-38240b531bd1"]
}, Open  ]],

Cell["\<\
Produce the four unlabelled plots for the case of 2:1 resonance medium \
libration amplitude.  This is Fig.8.16b.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
  3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
  3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
  3.880462756268464*^9}, {3.880613554439003*^9, 3.880613576894911*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e3891b8c-c533-407c-a5a8-7a2406a6546b"],

Cell[BoxData[
 RowBox[{"FourPlotNoLabel", "[", 
  RowBox[{"0.001", ",", " ", "init2", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.88046267960392*^9, 3.880462680234071*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"578be56b-2867-4e1a-b7ea-8aa00ef8f6d6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcNLB", "=", "gcNL"}]], "Input",
 CellChangeTimes->{{3.880463026210558*^9, 3.88046302986303*^9}, {
  3.880463083413727*^9, 3.880463090373127*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"6a79d4a4-a722-4f10-89d1-2d8c855eba61"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
       {Dashing[{Small, Small}], LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], 
        PointBox[{0, 0.6334239999999999}], 
        PointBox[{0.1, 0.6332498962087303}], 
        PointBox[{0.2, 0.6344668406907782}], 
        PointBox[{0.3, 0.635982153179724}], 
        PointBox[{0.4, 0.6379154938409733}], 
        PointBox[{0.5, 0.6394282925502547}], 
        PointBox[{0.6, 0.638392001099583}], 
        PointBox[{0.7, 0.6365302056747514}], 
        PointBox[{0.8, 0.6349471315809216}], 
        PointBox[{0.9, 0.6334498204093626}], 
        PointBox[{1., 0.6332112913511931}], 
        PointBox[{1.1, 0.6330684456009231}], 
        PointBox[{1.2, 0.6338831959061652}], 
        PointBox[{1.3, 0.6352525032256872}], 
        PointBox[{1.4, 0.6371782973986656}], 
        PointBox[{1.5, 0.6391049000088033}], 
        PointBox[{1.6, 0.6385830609328399}], 
        PointBox[{1.7, 0.6368545969916332}], 
        PointBox[{1.8, 0.6352744190962873}], 
        PointBox[{1.9, 0.6336208515406774}], 
        PointBox[{2., 0.6327465692788249}], 
        PointBox[{2.1, 0.6329099648788167}], 
        PointBox[{2.2, 0.6332389860744625}], 
        PointBox[{2.3, 0.6343898709501471}], 
        PointBox[{2.4, 0.6362224584976236}], 
        PointBox[{2.5, 0.6384755471851375}], 
        PointBox[{2.6, 0.6384832371001551}], 
        PointBox[{2.7, 0.6369262212502849}], 
        PointBox[{2.8, 0.6354028973590121}], 
        PointBox[{2.9, 0.6337020892676185}], 
        PointBox[{3., 0.6322468674020247}], 
        PointBox[{3.1, 0.632689795642041}], 
        PointBox[{3.2, 0.6325609980548488}], 
        PointBox[{3.3, 0.6334361795622722}], 
        PointBox[{3.4, 0.6351003048798219}], 
        PointBox[{3.5, 0.6375727815418756}], 
        PointBox[{3.6, 0.6381031272054718}], 
        PointBox[{3.7, 0.6367324399561531}], 
        PointBox[{3.8, 0.6352970333120203}], 
        PointBox[{3.9, 0.63363247527277}], PointBox[{4., 0.6317557866602451}],
         PointBox[{4.1, 0.6322405181030828}], 
        PointBox[{4.2, 0.6318550665272498}], 
        PointBox[{4.3, 0.6324217845603324}], 
        PointBox[{4.4, 0.633865295252233}], 
        PointBox[{4.5, 0.6364477877662101}], 
        PointBox[{4.6, 0.6374681481664235}], 
        PointBox[{4.7, 0.6362778095707823}], 
        PointBox[{4.8, 0.6349401869981492}], 
        PointBox[{4.9, 0.6333635650845298}], 
        PointBox[{5., 0.6312251053091821}], 
        PointBox[{5.1, 0.6314638567048276}], 
        PointBox[{5.2, 0.6311025722407306}], 
        PointBox[{5.3, 0.6313592694413815}], 
        PointBox[{5.4, 0.6325622562168242}], 
        PointBox[{5.5, 0.6351618651715573}], 
        PointBox[{5.6, 0.6366144301331003}], 
        PointBox[{5.7, 0.6355792801686836}], 
        PointBox[{5.8, 0.634332347868018}], 
        PointBox[{5.9, 0.6328642796694023}], 
        PointBox[{6., 0.6305881517730771}], 
        PointBox[{6.1, 0.6304297057976878}], 
        PointBox[{6.2, 0.6302647238221906}], 
        PointBox[{6.3, 0.6302487938594141}], 
        PointBox[{6.4, 0.6312241469107165}], 
        PointBox[{6.5, 0.633783747641372}], 
        PointBox[{6.6, 0.6355868410455616}], 
        PointBox[{6.7, 0.6346622403878545}], 
        PointBox[{6.8, 0.6334883223286049}], 
        PointBox[{6.9, 0.6321254203626127}], 
        PointBox[{7., 0.6297877592041969}], 
        PointBox[{7.1, 0.629252978413325}], 
        PointBox[{7.2, 0.6292974785930051}], 
        PointBox[{7.3, 0.6290827586738186}], 
        PointBox[{7.4, 0.6298724937197588}], 
        PointBox[{7.5, 0.6323829481996913}], 
        PointBox[{7.6, 0.6344334435654045}], 
        PointBox[{7.7, 0.6335563808032054}], 
        PointBox[{7.8, 0.6324336093249353}], 
        PointBox[{7.9, 0.6311555467905242}], 
        PointBox[{8., 0.6287841111666607}], 
        PointBox[{8.1, 0.6280003812658459}], 
        PointBox[{8.2, 0.6281722261675436}], 
        PointBox[{8.3, 0.6278563062529938}], 
        PointBox[{8.4, 0.6285271384196167}], 
        PointBox[{8.5, 0.6310256000321199}], 
        PointBox[{8.6, 0.6332002495219508}], 
        PointBox[{8.7, 0.6322929696264427}], 
        PointBox[{8.8, 0.6312002523598331}], 
        PointBox[{8.9, 0.6299766509614818}], 
        PointBox[{9., 0.6275586754952361}], 
        PointBox[{9.1, 0.6267102422737874}], 
        PointBox[{9.2, 0.6268935860981066}], 
        PointBox[{9.3, 0.626581821835137}], 
        PointBox[{9.4, 0.6272157876315276}], 
        PointBox[{9.5, 0.629782459029237}], 
        PointBox[{9.6, 0.6319217128684838}], 
        PointBox[{9.7, 0.6309052902865395}], 
        PointBox[{9.8, 0.6298264533182528}], 
        PointBox[{9.9, 0.6286196086720951}], 
        PointBox[{10., 0.6261143660015368}], 
        PointBox[{10.1, 0.6254206676942232}], 
        PointBox[{10.2, 0.6255050941245998}], 
        PointBox[{10.3, 0.6252966060398494}], 
        PointBox[{10.4, 0.6259837855402131}], 
        PointBox[{10.5, 0.6287220486135138}], 
        PointBox[{10.6, 0.6306121305429182}], 
        PointBox[{10.7, 0.6294295322301223}], 
        PointBox[{10.8, 0.6283557185978537}], 
        PointBox[{10.9, 0.6271221860920009}], 
        PointBox[{11., 0.6244817128078705}], 
        PointBox[{11.1, 0.6241583930715211}], 
        PointBox[{11.2, 0.6240914674977406}], 
        PointBox[{11.3, 0.6240647330523605}], 
        PointBox[{11.4, 0.6248977661206679}], 
        PointBox[{11.5, 0.6279043752661885}], 
        PointBox[{11.6, 0.6292647804056825}], 
        PointBox[{11.7, 0.6279073895860112}], 
        PointBox[{11.8, 0.6268348412453713}], 
        PointBox[{11.9, 0.6255200290308319}], 
        PointBox[{12., 0.6227387727676218}], 
        PointBox[{12.1, 0.6228891652979986}], 
        PointBox[{12.2, 0.6227684883026675}], 
        PointBox[{12.3, 0.6229667796766415}], 
        PointBox[{12.4, 0.6240427242950323}], 
        PointBox[{12.5, 0.6273436340818541}], 
        PointBox[{12.6, 0.6278672799105156}], 
        PointBox[{12.7, 0.6263856815828545}], 
        PointBox[{12.8, 0.6253108838320521}], 
        PointBox[{12.9, 0.6238442304138885}], 
        PointBox[{13., 0.6210522020282997}], 
        PointBox[{13.1, 0.6215821687327154}], 
        PointBox[{13.2, 0.6216488266012153}], 
        PointBox[{13.3, 0.6220838968343221}], 
        PointBox[{13.4, 0.6235121071861479}], 
        PointBox[{13.5, 0.6269438658482976}], 
        PointBox[{13.6, 0.6264278682908266}], 
        PointBox[{13.7, 0.6249120048227187}], 
        PointBox[{13.8, 0.623824108720507}], 
        PointBox[{13.9, 0.6221180645202896}], 
        PointBox[{14., 0.6196996314971734}], 
        PointBox[{14.1, 0.6204156954452044}], 
        PointBox[{14.2, 0.6208128451431258}], 
        PointBox[{14.3, 0.6214861036035972}], 
        PointBox[{14.4, 0.6233887847866301}], 
        PointBox[{14.5, 0.6264780772907141}], 
        PointBox[{14.6, 0.6249927424010909}], 
        PointBox[{14.7, 0.6235295674932002}], 
        PointBox[{14.8, 0.6224028506940628}], 
        PointBox[{14.9, 0.6203791429540494}], 
        PointBox[{15., 0.6188657818204438}], 
        PointBox[{15.1, 0.6196228412687154}], 
        PointBox[{15.2, 0.6202985587830376}], 
        PointBox[{15.3, 0.6212235102766082}], 
        PointBox[{15.4, 0.6237002708107418}], 
        PointBox[{15.5, 0.6257104832269197}], 
        PointBox[{15.6, 0.6236327636133016}], 
        PointBox[{15.7, 0.6222726276033614}], 
        PointBox[{15.8, 0.6210658491690395}], 
        PointBox[{15.9, 0.6187482519274405}], 
        PointBox[{16., 0.6182909928435837}], 
        PointBox[{16.1, 0.6192602969543334}], 
        PointBox[{16.2, 0.6201138680661427}], 
        PointBox[{16.3, 0.6213321370699321}], 
        PointBox[{16.4, 0.624325013090218}], 
        PointBox[{16.5, 0.6246103621603344}], 
        PointBox[{16.6, 0.6224157275994093}], 
        PointBox[{16.7, 0.6211669412548505}], 
        PointBox[{16.8, 0.6198283664128873}], 
        PointBox[{16.9, 0.6175359872605286}], 
        PointBox[{17., 0.6180114374520828}], 
        PointBox[{17.1, 0.6192750966170911}], 
        PointBox[{17.2, 0.6202496281688131}], 
        PointBox[{17.3, 0.621828932544787}], 
        PointBox[{17.4, 0.6248893612364672}], 
        PointBox[{17.5, 0.623378353730024}], 
        PointBox[{17.6, 0.6213927258325338}], 
        PointBox[{17.7, 0.6202342123082566}], 
        PointBox[{17.8, 0.6187279219132}], 
        PointBox[{17.9, 0.6170572494587445}], 
        PointBox[{18., 0.618261058612038}], 
        PointBox[{18.1, 0.6196013477162479}], 
        PointBox[{18.2, 0.6206906030006247}], 
        PointBox[{18.3, 0.6226897012813791}], 
        PointBox[{18.4, 0.6249144939125016}], 
        PointBox[{18.5, 0.6222594290069207}], 
        PointBox[{18.6, 0.620598078819143}], 
        PointBox[{18.7, 0.6194994312848597}], 
        PointBox[{18.8, 0.6178792346350072}], 
        PointBox[{18.9, 0.6170770489140859}], 
        PointBox[{19., 0.6189098700034703}], 
        PointBox[{19.1, 0.6201890755208733}], 
        PointBox[{19.2, 0.6214182146956576}], 
        PointBox[{19.3, 0.623794774566462}], 
        PointBox[{19.4, 0.6242859194000505}], 
        PointBox[{19.5, 0.6214079416640679}], 
        PointBox[{19.6, 0.6200580510047609}], 
        PointBox[{19.7, 0.6190009106463102}], 
        PointBox[{19.8, 0.6175119473611284}], 
        PointBox[{19.9, 0.6177114752136503}], 
        PointBox[{20., 0.6198038588445034}], 
        PointBox[{20.1, 0.6210029482155972}], 
        PointBox[{20.2, 0.6224049395932935}], 
        PointBox[{20.3, 0.6248651021393644}], 
        PointBox[{20.4, 0.6233875720991762}], 
        PointBox[{20.5, 0.620888018725721}], 
        PointBox[{20.6, 0.6197976510565971}], 
        PointBox[{20.7, 0.6188041000527336}], 
        PointBox[{20.8, 0.6176937466247931}], 
        PointBox[{20.9, 0.6189421626878003}], 
        PointBox[{21., 0.6208663411960083}], 
        PointBox[{21.1, 0.6220164461555461}], 
        PointBox[{21.2, 0.6236066215612092}], 
        PointBox[{21.3, 0.6255454370555696}], 
        PointBox[{21.4, 0.6226678503772843}], 
        PointBox[{21.5, 0.6207164851878437}], 
        PointBox[{21.6, 0.6198440361058691}], 
        PointBox[{21.7, 0.6190085246966784}], 
        PointBox[{21.8, 0.6181919941187436}], 
        PointBox[{21.9, 0.6204301789937887}], 
        PointBox[{22., 0.6220659561984948}], 
        PointBox[{22.1, 0.623205453461657}], 
        PointBox[{22.2, 0.62494190602397}], 
        PointBox[{22.3, 0.6257132813135763}], 
        PointBox[{22.4, 0.6223474202515312}], 
        PointBox[{22.5, 0.6208912381517957}], 
        PointBox[{22.6, 0.6202254101831072}], 
        PointBox[{22.7, 0.6196855295292819}], 
        PointBox[{22.8, 0.6193023828359389}], 
        PointBox[{22.9, 0.6219935915074173}], 
        PointBox[{23., 0.623384845567034}], 
        PointBox[{23.1, 0.6245406965433623}], 
        PointBox[{23.2, 0.6262984478025193}], 
        PointBox[{23.3, 0.6256299800577817}], 
        PointBox[{23.4, 0.6224618002335994}], 
        PointBox[{23.5, 0.6213975069864487}], 
        PointBox[{23.6, 0.6209606356468332}], 
        PointBox[{23.7, 0.6206788801285296}], 
        PointBox[{23.8, 0.6209646722254134}], 
        PointBox[{23.9, 0.6235792611779761}], 
        PointBox[{24., 0.6248034485070186}], 
        PointBox[{24.1, 0.6259846435360203}], 
        PointBox[{24.2, 0.6275702319777101}], 
        PointBox[{24.3, 0.6256681458301546}], 
        PointBox[{24.4, 0.6229662042269415}], 
        PointBox[{24.5, 0.6222048396501602}], 
        PointBox[{24.6, 0.6220366802296998}], 
        PointBox[{24.7, 0.6217002918834992}], 
        PointBox[{24.8, 0.6228198202573691}], 
        PointBox[{24.9, 0.6251702040442011}], 
        PointBox[{25., 0.6262935853051146}], 
        PointBox[{25.1, 0.627491630546836}], 
        PointBox[{25.2, 0.6287248499577497}], 
        PointBox[{25.3, 0.6260338957918725}], 
        PointBox[{25.4, 0.6237871700711861}], 
        PointBox[{25.5, 0.6232598680408403}], 
        PointBox[{25.6, 0.6233816969282711}], 
        PointBox[{25.7, 0.622821856547444}], 
        PointBox[{25.8, 0.6246424090115767}], 
        PointBox[{25.9, 0.6267452942435121}], 
        PointBox[{26., 0.6278158941753218}], 
        PointBox[{26.1, 0.6290123761511811}], 
        PointBox[{26.2, 0.6298150246987138}], 
        PointBox[{26.3, 0.6267512736947988}], 
        PointBox[{26.4, 0.6248411062971642}], 
        PointBox[{26.5, 0.6244860001063938}], 
        PointBox[{26.6, 0.6248609902381166}], 
        PointBox[{26.7, 0.624128899567727}], 
        PointBox[{26.8, 0.6263345317375065}], 
        PointBox[{26.9, 0.6282711435369815}], 
        PointBox[{27., 0.6293237513645397}], 
        PointBox[{27.1, 0.6305028814634527}], 
        PointBox[{27.2, 0.6309215499261476}], 
        PointBox[{27.3, 0.6277562387206986}], 
        PointBox[{27.4, 0.6260440559096518}], 
        PointBox[{27.5, 0.6257918628278233}], 
        PointBox[{27.6, 0.626332906814723}], 
        PointBox[{27.7, 0.6255214268369846}], 
        PointBox[{27.8, 0.6278513377666538}], 
        PointBox[{27.9, 0.6297063354244588}], 
        PointBox[{28., 0.6307686181007244}], 
        PointBox[{28.1, 0.6319276585545528}], 
        PointBox[{28.2, 0.6320921539674198}], 
        PointBox[{28.3, 0.6289644816632879}], 
        PointBox[{28.4, 0.6273229459744413}], 
        PointBox[{28.5, 0.627092894890826}], 
        PointBox[{28.6, 0.6277094213414295}], 
        PointBox[{28.7, 0.626880239730616}], 
        PointBox[{28.8, 0.6291648468053754}], 
        PointBox[{28.9, 0.6310082150115444}], 
        PointBox[{29., 0.6321053339575845}], 
        PointBox[{29.1, 0.6332576060672612}], 
        PointBox[{29.2, 0.6333232112801251}], 
        PointBox[{29.3, 0.6303021583433517}], 
        PointBox[{29.4, 0.6286245245606048}], 
        PointBox[{29.5, 0.6283300970526681}], 
        PointBox[{29.6, 0.6289451808949316}], 
        PointBox[{29.7, 0.6281404933791487}], 
        PointBox[{29.8, 0.6302555063852118}], 
        PointBox[{29.9, 0.6321367326727367}], 
        PointBox[{30., 0.6332936246292782}], 
        PointBox[{30.1, 0.6344643782087938}], 
        PointBox[{30.2, 0.6345735679220471}], 
        PointBox[{30.3, 0.6317110868014285}], 
        PointBox[{30.4, 0.6299173470050258}], 
        PointBox[{30.5, 0.6294770543966435}], 
        PointBox[{30.6, 0.6300060491424525}], 
        PointBox[{30.7, 0.6292914085002557}], 
        PointBox[{30.8, 0.6311148412031848}], 
        PointBox[{30.9, 0.6330584677094959}], 
        PointBox[{31., 0.6342983361351298}], 
        PointBox[{31.1, 0.6355178115707458}], 
        PointBox[{31.2, 0.6357829028870986}], 
        PointBox[{31.3, 0.6331428237963822}], 
        PointBox[{31.4, 0.6311870227588976}], 
        PointBox[{31.5, 0.6305366642015564}], 
        PointBox[{31.6, 0.6308695151818013}], 
        PointBox[{31.7, 0.6303510922001496}], 
        PointBox[{31.8, 0.6317497751955158}], 
        PointBox[{31.9, 0.6337481411465273}], 
        PointBox[{32., 0.635088513637285}], 
        PointBox[{32.1, 0.6363852406013507}], 
        PointBox[{32.2, 0.6368849536083219}], 
        PointBox[{32.3, 0.6345488593152702}], 
        PointBox[{32.4, 0.6324257069087716}], 
        PointBox[{32.5, 0.6315267055047036}], 
        PointBox[{32.6, 0.6315531360011423}], 
        PointBox[{32.7, 0.6313433697543029}], 
        PointBox[{32.8, 0.6321868144908234}], 
        PointBox[{32.9, 0.6341925676072548}], 
        PointBox[{33., 0.635639360756546}], 
        PointBox[{33.1, 0.6370341177849682}], 
        PointBox[{33.2, 0.6378167880845009}], 
        PointBox[{33.3, 0.6358746007960444}], 
        PointBox[{33.4, 0.6336222249134947}], 
        PointBox[{33.5, 0.632464733069582}], 
        PointBox[{33.6, 0.6321200022873912}], 
        PointBox[{33.7, 0.6322423235265241}], 
        PointBox[{33.8, 0.6324737092728252}], 
        PointBox[{33.9, 0.6343962010643173}], 
        PointBox[{34., 0.6359354891600729}], 
        PointBox[{34.1, 0.6374368297438144}], 
        PointBox[{34.2, 0.6385244266093189}], 
        PointBox[{34.3, 0.6370591987860487}], 
        PointBox[{34.4, 0.6347538770908222}], 
        PointBox[{34.5, 0.6333577391930458}], 
        PointBox[{34.6, 0.6326381186238835}], 
        PointBox[{34.7, 0.632907955152532}], 
        PointBox[{34.8, 0.6326739466407949}], 
        PointBox[{34.9, 0.634382357588541}], 
        PointBox[{35., 0.6359753514653956}], 
        PointBox[{35.1, 0.6375737986214182}], 
        PointBox[{35.2, 0.6389660145038529}], 
        PointBox[{35.3, 0.6380411935065629}], 
        PointBox[{35.4, 0.6357834108165977}], 
        PointBox[{35.5, 0.6341954927710366}], 
        PointBox[{35.6, 0.6331456432688961}], 
        PointBox[{35.7, 0.633184923588249}], 
        PointBox[{35.8, 0.6328573995895036}], 
        PointBox[{35.9, 0.6341926056325502}], 
        PointBox[{36., 0.635773841411017}], 
        PointBox[{36.1, 0.6374382096681591}], 
        PointBox[{36.2, 0.6391129953191236}], 
        PointBox[{36.3, 0.6387670529780242}], 
        PointBox[{36.4, 0.6366627294550673}], 
        PointBox[{36.5, 0.63495108254716}], 
        PointBox[{36.6, 0.6336433311900842}], 
        PointBox[{36.7, 0.6331677002102563}], 
        PointBox[{36.8, 0.6330731582766429}], 
        PointBox[{36.9, 0.6338799547180102}], 
        PointBox[{37., 0.6353626236833027}], 
        PointBox[{37.1, 0.6370396039598535}], 
        PointBox[{37.2, 0.6389520193843786}], 
        PointBox[{37.3, 0.6391989756366804}], 
        PointBox[{37.4, 0.6373417564493898}], 
        PointBox[{37.5, 0.6355828646162736}], 
        PointBox[{37.6, 0.6341038239036323}], 
        PointBox[{37.7, 0.6330844936325346}], 
        PointBox[{37.8, 0.6332836052042059}], 
        PointBox[{37.9, 0.6335007899889721}], 
        PointBox[{38., 0.6347863796822183}], 
        PointBox[{38.1, 0.6364062907380479}], 
        PointBox[{38.2, 0.638486605938082}], 
        PointBox[{38.3, 0.6393164471173187}], 
        PointBox[{38.4, 0.6377781751510279}], 
        PointBox[{38.5, 0.6360437939628976}], 
        PointBox[{38.6, 0.6344817796926845}], 
        PointBox[{38.7, 0.6330363891545516}], 
        PointBox[{38.8, 0.633283973575443}], 
        PointBox[{38.9, 0.6331020201205555}], 
        PointBox[{39., 0.6340925379849363}], 
        PointBox[{39.1, 0.6355803577611031}], 
        PointBox[{39.2, 0.6377389414820908}], 
        PointBox[{39.3, 0.6391178470138166}], 
        PointBox[{39.4, 0.637945462507085}], 
        PointBox[{39.5, 0.6362907813253612}], 
        PointBox[{39.6, 0.6347246679121329}], 
        PointBox[{39.7, 0.6330052267912051}], 
        PointBox[{39.8, 0.6328754559206918}], 
        PointBox[{39.9, 0.6327097260682802}], 
        PointBox[{40., 0.6333222222020942}], 
        PointBox[{40.1, 0.6346108007783284}], 
        PointBox[{40.2, 0.6367487625421234}], 
        PointBox[{40.3, 0.6386162967508817}], 
        PointBox[{40.4, 0.6378343808807926}], 
        PointBox[{40.5, 0.6362922245339554}], 
        PointBox[{40.6, 0.6347817010597001}], 
        PointBox[{40.7, 0.6329291101481397}], 
        PointBox[{40.8, 0.6321681196189334}], 
        PointBox[{40.9, 0.6323115628802132}], 
        PointBox[{41., 0.6325024340160761}], 
        PointBox[{41.1, 0.6335431450520396}], 
        PointBox[{41.2, 0.6355694991676583}], 
        PointBox[{41.3, 0.6378426766665706}], 
        PointBox[{41.4, 0.6374533424550866}], 
        PointBox[{41.5, 0.6360342947809898}], 
        PointBox[{41.6, 0.6346139358886391}], 
        PointBox[{41.7, 0.6327401933752129}], 
        PointBox[{41.8, 0.6313642761635812}], 
        PointBox[{41.9, 0.6318414118562339}], 
        PointBox[{42., 0.6316416570206504}], 
        PointBox[{42.1, 0.6324114488940439}], 
        PointBox[{42.2, 0.6342607326794093}], 
        PointBox[{42.3, 0.6368421292444428}], 
        PointBox[{42.4, 0.6368241759661569}], 
        PointBox[{42.5, 0.6355196464868128}], 
        PointBox[{42.6, 0.6342017378183681}], 
        PointBox[{42.7, 0.6323803205243925}], 
        PointBox[{42.8, 0.6305224724447508}], 
        PointBox[{42.9, 0.6312004489753061}], 
        PointBox[{43., 0.6307298131088771}], 
        PointBox[{43.1, 0.631234537237431}], 
        PointBox[{43.2, 0.6328771104319112}], 
        PointBox[{43.3, 0.6356711082793634}], 
        PointBox[{43.4, 0.6359769596229901}], 
        PointBox[{43.5, 0.6347638383925279}], 
        PointBox[{43.6, 0.6335416806148533}], 
        PointBox[{43.7, 0.6318081902509648}], 
        PointBox[{43.8, 0.629611694764778}], 
        PointBox[{43.9, 0.6303283853639553}], 
        PointBox[{44., 0.6297422113026148}], 
        PointBox[{44.1, 0.6300186056688656}], 
        PointBox[{44.2, 0.6314645520338357}], 
        PointBox[{44.3, 0.6343988600338498}], 
        PointBox[{44.4, 0.6349473249454258}], 
        PointBox[{44.5, 0.6337912119790124}], 
        PointBox[{44.6, 0.6326483625570001}], 
        PointBox[{44.7, 0.6310047049553117}], 
        PointBox[{44.8, 0.6285824362744097}], 
        PointBox[{44.9, 0.6292478363723094}], 
        PointBox[{45., 0.6286531671554745}], 
        PointBox[{45.1, 0.6287663941202398}], 
        PointBox[{45.2, 0.6300607733690823}], 
        PointBox[{45.3, 0.6330976025128873}], 
        PointBox[{45.4, 0.6337717081612069}], 
        PointBox[{45.5, 0.6326321814326474}], 
        PointBox[{45.6, 0.6315473027973836}], 
        PointBox[{45.7, 0.6299695648221016}], 
        PointBox[{45.8, 0.6273977587425196}], 
        PointBox[{45.9, 0.6280205642702421}], 
        PointBox[{46., 0.6274499947647039}], 
        PointBox[{46.1, 0.6274851861740677}], 
        PointBox[{46.2, 0.6287019296640644}], 
        PointBox[{46.3, 0.6318386983790429}], 
        PointBox[{46.4, 0.6324822341064136}], 
        PointBox[{46.5, 0.6313204558545705}], 
        PointBox[{46.6, 0.6302718862950798}], 
        PointBox[{46.7, 0.6287182207522329}], 
        PointBox[{46.8, 0.6260484609415189}], 
        PointBox[{46.9, 0.626693500050811}], 
        PointBox[{47., 0.6261501861747051}], 
        PointBox[{47.1, 0.6261992501359052}], 
        PointBox[{47.2, 0.6274339141357399}], 
        PointBox[{47.3, 0.630683660742261}], 
        PointBox[{47.4, 0.6311041592590995}], 
        PointBox[{47.5, 0.6298931297780687}], 
        PointBox[{47.6, 0.6288617371077381}], 
        PointBox[{47.7, 0.6272741790620401}], 
        PointBox[{47.8, 0.6245672199310615}], 
        PointBox[{47.9, 0.6252829602566323}], 
        PointBox[{48., 0.62480887654596}], 
        PointBox[{48.1, 0.6249557339643261}], 
        PointBox[{48.2, 0.6263201464519801}], 
        PointBox[{48.3, 0.6296665896865858}], 
        PointBox[{48.4, 0.629658097990782}], 
        PointBox[{48.5, 0.6283935039037596}], 
        PointBox[{48.6, 0.6273612948554047}], 
        PointBox[{48.7, 0.6256665970504918}], 
        PointBox[{48.8, 0.6230559550952102}], 
        PointBox[{48.9, 0.6238078523344932}], 
        PointBox[{49., 0.6235136611068618}], 
        PointBox[{49.1, 0.6238236548432999}], 
        PointBox[{49.2, 0.6254440339756023}], 
        PointBox[{49.3, 0.6287677507690487}], 
        PointBox[{49.4, 0.6281661097329257}], 
        PointBox[{49.5, 0.6268691295590649}], 
        PointBox[{49.6, 0.6258156564959755}], 
        PointBox[{49.7, 0.6239248506468223}], 
        PointBox[{49.8, 0.6216869461465437}], 
        PointBox[{49.9, 0.6223668267522929}], 
        PointBox[{50., 0.6223638588111846}], 
        PointBox[{50.1, 0.6228838892518002}], 
        PointBox[{50.2, 0.6248975745380311}], 
        PointBox[{50.3, 0.6278921404582491}], 
        PointBox[{50.4, 0.6266613335333631}], 
        PointBox[{50.5, 0.6253683429477134}], 
        PointBox[{50.6, 0.6242643832681911}], 
        PointBox[{50.7, 0.6220902652940811}], 
        PointBox[{50.8, 0.6206206510472978}], 
        PointBox[{50.9, 0.6211351877902815}], 
        PointBox[{51., 0.6214457812470764}], 
        PointBox[{51.1, 0.6222167587711502}], 
        PointBox[{51.2, 0.6247455371635382}], 
        PointBox[{51.3, 0.6269016433389596}], 
        PointBox[{51.4, 0.6251900599739922}], 
        PointBox[{51.5, 0.6239342565172221}], 
        PointBox[{51.6, 0.6227371828325629}], 
        PointBox[{51.7, 0.6202550767545267}], 
        PointBox[{51.8, 0.619748263535971}], 
        PointBox[{51.9, 0.6202466912776184}], 
        PointBox[{52., 0.6208180236060205}], 
        PointBox[{52.1, 0.6218926911900756}], 
        PointBox[{52.2, 0.6249497558831877}], 
        PointBox[{52.3, 0.6257217366867854}], 
        PointBox[{52.4, 0.6238052884313905}], 
        PointBox[{52.5, 0.6226012702715359}], 
        PointBox[{52.6, 0.6212490368482425}], 
        PointBox[{52.7, 0.6186562979644403}], 
        PointBox[{52.8, 0.61895743241399}], 
        PointBox[{52.9, 0.619738583485659}], 
        PointBox[{53., 0.6205116523178492}], 
        PointBox[{53.1, 0.6219676165143998}], 
        PointBox[{53.2, 0.6252630609908325}], 
        PointBox[{53.3, 0.6244154418319189}], 
        PointBox[{53.4, 0.6225546041255828}], 
        PointBox[{53.5, 0.6213935261342893}], 
        PointBox[{53.6, 0.6198185664078905}], 
        PointBox[{53.7, 0.6176760564695254}], 
        PointBox[{53.8, 0.6185557628038154}], 
        PointBox[{53.9, 0.6195884631445651}], 
        PointBox[{54., 0.6205375455033857}], 
        PointBox[{54.1, 0.622465728460601}], 
        PointBox[{54.2, 0.625253595255093}], 
        PointBox[{54.3, 0.6231347322796453}], 
        PointBox[{54.4, 0.6214761237660567}], 
        PointBox[{54.5, 0.6203297667338955}], 
        PointBox[{54.6, 0.6185091275490531}], 
        PointBox[{54.7, 0.6173237681102189}], 
        PointBox[{54.8, 0.6186366748679974}], 
        PointBox[{54.9, 0.619758332998838}], 
        PointBox[{55., 0.6208956167556613}], 
        PointBox[{55.1, 0.6233301642533039}], 
        PointBox[{55.2, 0.6246496502135371}], 
        PointBox[{55.3, 0.6220203961960347}], 
        PointBox[{55.4, 0.6205980136337548}], 
        PointBox[{55.5, 0.6194334351293611}], 
        PointBox[{55.6, 0.6175159247182276}], 
        PointBox[{55.7, 0.6173623213976962}], 
        PointBox[{55.8, 0.6190818369663009}], 
        PointBox[{55.9, 0.620211621824273}], 
        PointBox[{56., 0.6215759336031405}], 
        PointBox[{56.1, 0.624324991495882}], 
        PointBox[{56.2, 0.6236341913434867}], 
        PointBox[{56.3, 0.6211574539592067}], 
        PointBox[{56.4, 0.6199457119176912}], 
        PointBox[{56.5, 0.6187450192366519}], 
        PointBox[{56.6, 0.6171368165150019}], 
        PointBox[{56.7, 0.6180173716149523}], 
        PointBox[{56.8, 0.6197858165058928}], 
        PointBox[{56.9, 0.6209177891343495}], 
        PointBox[{57., 0.6225503095939571}], 
        PointBox[{57.1, 0.6250186789670104}], 
        PointBox[{57.2, 0.6226209383210896}], 
        PointBox[{57.3, 0.6205876459181223}], 
        PointBox[{57.4, 0.6195477064716148}], 
        PointBox[{57.5, 0.6183534531052856}], 
        PointBox[{57.6, 0.6172788596329417}], 
        PointBox[{57.7, 0.6191067873772513}], 
        PointBox[{57.8, 0.6206907122635884}], 
        PointBox[{57.9, 0.6218515352163901}], 
        PointBox[{58., 0.6237484984968219}], 
        PointBox[{58.1, 0.6250822118951576}], 
        PointBox[{58.2, 0.6219009899360439}], 
        PointBox[{58.3, 0.6203309466462572}], 
        PointBox[{58.4, 0.6194407683993168}], 
        PointBox[{58.5, 0.6184025447307039}], 
        PointBox[{58.6, 0.6179443738047214}], 
        PointBox[{58.7, 0.6203911513885975}], 
        PointBox[{58.8, 0.621765246232869}], 
        PointBox[{58.9, 0.6229856252742052}], 
        PointBox[{59., 0.6250283289898894}], 
        PointBox[{59.1, 0.6246668630402921}], 
        PointBox[{59.2, 0.6215805505000866}], 
        PointBox[{59.3, 0.6203982388849001}], 
        PointBox[{59.4, 0.6196716257068129}], 
        PointBox[{59.5, 0.6189419837311418}], 
        PointBox[{59.6, 0.6193268173191495}], 
        PointBox[{59.7, 0.6217710085122278}], 
        PointBox[{59.8, 0.6229884511067264}], 
        PointBox[{59.9, 0.6242851881142469}], 
        PointBox[{60., 0.6261946352763419}], 
        PointBox[{60.1, 0.6242348525657383}], 
        PointBox[{60.2, 0.6216636734382659}], 
        PointBox[{60.3, 0.620793402299342}], 
        PointBox[{60.4, 0.6202876516901863}], 
        PointBox[{60.5, 0.619679742991208}], 
        PointBox[{60.6, 0.6210749239842547}], 
        PointBox[{60.7, 0.6232187636771082}], 
        PointBox[{60.8, 0.6243392469980276}], 
        PointBox[{60.9, 0.6257012563676869}], 
        PointBox[{61., 0.6271123399294177}], 
        PointBox[{61.1, 0.6241252295871832}], 
        PointBox[{61.2, 0.6221153918681285}], 
        PointBox[{61.3, 0.6215074060460742}], 
        PointBox[{61.4, 0.6213034437923726}], 
        PointBox[{61.5, 0.6206090489589488}], 
        PointBox[{61.6, 0.6228912762999452}], 
        PointBox[{61.7, 0.6247204914268378}], 
        PointBox[{61.8, 0.6257880594283066}], 
        PointBox[{61.9, 0.6271769766070668}], 
        PointBox[{62., 0.6278235448860342}], 
        PointBox[{62.1, 0.62443593004817}], 
        PointBox[{62.2, 0.6228816158260936}], 
        PointBox[{62.3, 0.6225072708891513}], 
        PointBox[{62.4, 0.6226250808685994}], 
        PointBox[{62.5, 0.6219421421973529}], 
        PointBox[{62.6, 0.6246578119270514}], 
        PointBox[{62.7, 0.626254484090269}], 
        PointBox[{62.8, 0.6272981536496336}], 
        PointBox[{62.9, 0.6286570837472122}], 
        PointBox[{63., 0.6285050203086363}], 
        PointBox[{63.1, 0.6251250105682084}], 
        PointBox[{63.2, 0.6238936276712449}], 
        PointBox[{63.3, 0.62372846332552}], 
        PointBox[{63.4, 0.6240515213392918}], 
        PointBox[{63.5, 0.6235280783408268}], 
        PointBox[{63.6, 0.6263321874144369}], 
        PointBox[{63.7, 0.6277864471263596}], 
        PointBox[{63.8, 0.6288231766279934}], 
        PointBox[{63.9, 0.6301035485205815}], 
        PointBox[{64., 0.6293167904951246}], 
        PointBox[{64.1, 0.6261028975737802}], 
        PointBox[{64.2, 0.6250719058032759}], 
        PointBox[{64.3, 0.6250748722180192}], 
        PointBox[{64.4, 0.6254354346194202}], 
        PointBox[{64.5, 0.6251391080340074}], 
        PointBox[{64.6, 0.6278855200059992}], 
        PointBox[{64.7, 0.6292730354704459}], 
        PointBox[{64.8, 0.630314680806849}], 
        PointBox[{64.9, 0.6314987941300918}], 
        PointBox[{65., 0.6303215040972885}], 
        PointBox[{65.1, 0.6272773413841891}], 
        PointBox[{65.2, 0.626336330774203}], 
        PointBox[{65.3, 0.6264398677974}], 
        PointBox[{65.4, 0.6267675348748482}], 
        PointBox[{65.5, 0.6266312927419094}], 
        PointBox[{65.6, 0.6292870947990326}], 
        PointBox[{65.7, 0.6306675348109735}], 
        PointBox[{65.8, 0.6317275652821024}], 
        PointBox[{65.9, 0.6328344021516497}], 
        PointBox[{66., 0.6315011588068694}], 
        PointBox[{66.1, 0.628571364646479}], 
        PointBox[{66.2, 0.6276203130909346}], 
        PointBox[{66.3, 0.627734597393761}], 
        PointBox[{66.4, 0.6280637492428872}], 
        PointBox[{66.5, 0.6279389859667621}], 
        PointBox[{66.6, 0.6305040922690344}], 
        PointBox[{66.7, 0.6319255352714176}], 
        PointBox[{66.8, 0.633019942100492}], 
        PointBox[{66.9, 0.6340952734439254}], 
        PointBox[{67., 0.6327994154030748}], 
        PointBox[{67.1, 0.6299297364677008}], 
        PointBox[{67.2, 0.6288803849861394}], 
        PointBox[{67.3, 0.6289072857423924}], 
        PointBox[{67.4, 0.62930451582205}], 
        PointBox[{67.5, 0.6290480590422701}], 
        PointBox[{67.6, 0.6315091301485481}], 
        PointBox[{67.7, 0.6330083554401666}], 
        PointBox[{67.8, 0.6341577027650747}], 
        PointBox[{67.9, 0.6352548922886531}], 
        PointBox[{68., 0.6341470310489876}], 
        PointBox[{68.1, 0.6313155282119498}], 
        PointBox[{68.2, 0.6300977627614159}], 
        PointBox[{68.3, 0.6299469881659795}], 
        PointBox[{68.4, 0.6304352254314198}], 
        PointBox[{68.5, 0.6299757571419994}], 
        PointBox[{68.6, 0.6322831081942621}], 
        PointBox[{68.7, 0.6338823744108304}], 
        PointBox[{68.8, 0.6351075068742016}], 
        PointBox[{68.9, 0.6362767586888057}], 
        PointBox[{69., 0.6354708480491312}], 
        PointBox[{69.1, 0.6327000323317745}], 
        PointBox[{69.2, 0.6312693406351091}], 
        PointBox[{69.3, 0.6308734867541536}], 
        PointBox[{69.4, 0.6313711885570897}], 
        PointBox[{69.5, 0.6307642417881848}], 
        PointBox[{69.6, 0.6328215565770806}], 
        PointBox[{69.7, 0.6345223812040612}], 
        PointBox[{69.8, 0.6358401878408306}], 
        PointBox[{69.9, 0.6371207406647978}], 
        PointBox[{70., 0.6366978579676916}], 
        PointBox[{70.1, 0.6340536225004278}], 
        PointBox[{70.2, 0.632397613227377}], 
        PointBox[{70.3, 0.6317205475939536}], 
        PointBox[{70.4, 0.6320402686484782}], 
        PointBox[{70.5, 0.6314696886705667}], 
        PointBox[{70.6, 0.6331390136200185}], 
        PointBox[{70.7, 0.6349136244081495}], 
        PointBox[{70.8, 0.636330888249563}], 
        PointBox[{70.9, 0.6377475783668402}], 
        PointBox[{71., 0.6377584726021857}], 
        PointBox[{71.1, 0.6353367715971052}], 
        PointBox[{71.2, 0.6334792338481989}], 
        PointBox[{71.3, 0.6325179008780172}], 
        PointBox[{71.4, 0.6324688485280714}], 
        PointBox[{71.5, 0.6321470549496495}], 
        PointBox[{71.6, 0.6332710286523887}], 
        PointBox[{71.7, 0.6350568734492268}], 
        PointBox[{71.8, 0.6365631976113917}], 
        PointBox[{71.9, 0.6381239833967843}], 
        PointBox[{72., 0.6385918336350074}], 
        PointBox[{72.1, 0.6364985057501112}], 
        PointBox[{72.2, 0.6344978317829404}], 
        PointBox[{72.3, 0.633278603109726}], 
        PointBox[{72.4, 0.632777370418754}], 
        PointBox[{72.5, 0.632798941060443}], 
        PointBox[{72.6, 0.6332713091889584}], 
        PointBox[{72.7, 0.6349708094334697}], 
        PointBox[{72.8, 0.636533277659949}], 
        PointBox[{72.9, 0.6382266242760894}], 
        PointBox[{73., 0.6391506974269417}], 
        PointBox[{73.1, 0.6374820239323177}], 
        PointBox[{73.2, 0.6354214197256014}], 
        PointBox[{73.3, 0.6339955577689079}], 
        PointBox[{73.4, 0.6330705363774907}], 
        PointBox[{73.5, 0.6332818696330571}], 
        PointBox[{73.6, 0.633205083358932}], 
        PointBox[{73.7, 0.634692168201879}], 
        PointBox[{73.8, 0.6362547318806113}], 
        PointBox[{73.9, 0.6380464583876001}], 
        PointBox[{74., 0.6394046022948032}], 
        PointBox[{74.1, 0.638235037875992}], 
        PointBox[{74.2, 0.6362072535403867}], 
        PointBox[{74.3, 0.6346431320781124}], 
        PointBox[{74.4, 0.633382098471273}], 
        PointBox[{74.5, 0.6333700278558649}], 
        PointBox[{74.6, 0.633135988987496}], 
        PointBox[{74.7, 0.6342698359897582}], 
        PointBox[{74.8, 0.635758241355395}], 
        PointBox[{74.9, 0.6375905616977486}], 
        PointBox[{75., 0.6393369787552058}], 
        PointBox[{75.1, 0.6387152378630453}], 
        PointBox[{75.2, 0.6368058594284869}], 
        PointBox[{75.3, 0.6351785531533732}], 
        PointBox[{75.4, 0.6336903544022683}], 
        PointBox[{75.5, 0.6331153711240125}], 
        PointBox[{75.6, 0.6331018290680214}], 
        PointBox[{75.7, 0.6337542527120276}], 
        PointBox[{75.8, 0.6350857327801126}], 
        PointBox[{75.9, 0.6368848417856103}], 
        PointBox[{76., 0.6389499809423453}], 
        PointBox[{76.1, 0.638900111304503}], 
        PointBox[{76.2, 0.637175374396463}], 
        PointBox[{76.3, 0.6355546903168642}], 
        PointBox[{76.4, 0.6339473503339313}], 
        PointBox[{76.5, 0.6327723368698954}], 
        PointBox[{76.6, 0.633064638592519}], 
        PointBox[{76.7, 0.6331896687459213}], 
        PointBox[{76.8, 0.6342848809707403}], 
        PointBox[{76.9, 0.6359708514025991}], 
        PointBox[{77., 0.6382614093684826}], 
        PointBox[{77.1, 0.6387846535442171}], 
        PointBox[{77.2, 0.6372870599055759}], 
        PointBox[{77.3, 0.6357260858612375}], 
        PointBox[{77.4, 0.6340947225799485}], 
        PointBox[{77.5, 0.6324544655213868}], 
        PointBox[{77.6, 0.6328562167107051}], 
        PointBox[{77.7, 0.6326033860757643}], 
        PointBox[{77.8, 0.6333974545837107}], 
        PointBox[{77.9, 0.6349000955331263}], 
        PointBox[{78., 0.6373078323424803}], 
        PointBox[{78.1, 0.6383812140463282}], 
        PointBox[{78.2, 0.6371298903313839}], 
        PointBox[{78.3, 0.6356595425738588}], 
        PointBox[{78.4, 0.6340765481419617}], 
        PointBox[{78.5, 0.632138663753416}], 
        PointBox[{78.6, 0.6322945336337182}], 
        PointBox[{78.7, 0.6319992233712062}], 
        PointBox[{78.8, 0.632451304839629}], 
        PointBox[{78.9, 0.6337230215181024}], 
        PointBox[{79., 0.6361408096806818}], 
        PointBox[{79.1, 0.6377165275843106}], 
        PointBox[{79.2, 0.6367090121228511}], 
        PointBox[{79.3, 0.6353388005271909}], 
        PointBox[{79.4, 0.633848191396207}], 
        PointBox[{79.5, 0.6317582819298261}], 
        PointBox[{79.6, 0.6314108869612136}], 
        PointBox[{79.7, 0.6313507144819134}], 
        PointBox[{79.8, 0.6314583954511719}], 
        PointBox[{79.9, 0.632479279116795}], 
        PointBox[{80., 0.634822868864158}], 
        PointBox[{80.1, 0.6368304432989453}], 
        PointBox[{80.2, 0.6360430200991273}], 
        PointBox[{80.3, 0.6347654065453003}], 
        PointBox[{80.4, 0.6333831276079331}], 
        PointBox[{80.5, 0.6312470915855558}], 
        PointBox[{80.6, 0.6303575571946742}], 
        PointBox[{80.7, 0.630605777254823}], 
        PointBox[{80.8, 0.6304145902010628}], 
        PointBox[{80.9, 0.6311964212598697}], 
        PointBox[{81., 0.6334187234841773}], 
        PointBox[{81.1, 0.6357725489467752}], 
        PointBox[{81.2, 0.6351581039382818}], 
        PointBox[{81.3, 0.6339537716166368}], 
        PointBox[{81.4, 0.6326754525169326}], 
        PointBox[{81.5, 0.6305523335957071}], 
        PointBox[{81.6, 0.6292168778228943}], 
        PointBox[{81.7, 0.6297089649566748}], 
        PointBox[{81.8, 0.6293065780002675}], 
        PointBox[{81.9, 0.6298892241722561}], 
        PointBox[{82., 0.631989934837606}], 
        PointBox[{82.1, 0.6346001141860302}], 
        PointBox[{82.2, 0.6340849440183015}], 
        PointBox[{82.3, 0.6329291581644205}], 
        PointBox[{82.4, 0.6317357684270035}], 
        PointBox[{82.5, 0.6296409343635255}], 
        PointBox[{82.6, 0.6280016233845191}], 
        PointBox[{82.7, 0.6286313969225461}], 
        PointBox[{82.8, 0.6281233087268071}], 
        PointBox[{82.9, 0.628570799412655}], 
        PointBox[{83., 0.6305940124608995}], 
        PointBox[{83.1, 0.6333708106310918}], 
        PointBox[{83.2, 0.6328550716638375}], 
        PointBox[{83.3, 0.6317229903438702}], 
        PointBox[{83.4, 0.630588989750297}], 
        PointBox[{83.5, 0.628499601773753}], 
        PointBox[{83.6, 0.6267153594665027}], 
        PointBox[{83.7, 0.627378634482588}], 
        PointBox[{83.8, 0.6268678808857375}], 
        PointBox[{83.9, 0.627260520615682}], 
        PointBox[{84., 0.6292887420861195}], 
        PointBox[{84.1, 0.6321326205779291}], 
        PointBox[{84.2, 0.6314990238522707}], 
        PointBox[{84.3, 0.6303712838387313}], 
        PointBox[{84.4, 0.6292676447327391}], 
        PointBox[{84.5, 0.6271326530826102}], 
        PointBox[{84.6, 0.6253876035429193}], 
        PointBox[{84.7, 0.6259864372421351}], 
        PointBox[{84.8, 0.625571751989761}], 
        PointBox[{84.9, 0.6259952829287289}], 
        PointBox[{85., 0.6281409509089073}], 
        PointBox[{85.1, 0.6309122037905525}], 
        PointBox[{85.2, 0.6300488837392235}], 
        PointBox[{85.3, 0.6289161174258326}], 
        PointBox[{85.4, 0.627811136193076}], 
        PointBox[{85.5, 0.6255588915024096}], 
        PointBox[{85.6, 0.6240880708579246}], 
        PointBox[{85.7, 0.6245235659116072}], 
        PointBox[{85.8, 0.6242959902700602}], 
        PointBox[{85.9, 0.6248336462813643}], 
        PointBox[{86., 0.627226771230971}], 
        PointBox[{86.1, 0.6297006321992781}], 
        PointBox[{86.2, 0.628540224422624}], 
        PointBox[{86.3, 0.6274041891718}], 
        PointBox[{86.4, 0.6262603118721781}], 
        PointBox[{86.5, 0.6238158904284782}], 
        PointBox[{86.6, 0.6228899588681663}], 
        PointBox[{86.7, 0.6231019832828953}], 
        PointBox[{86.8, 0.6231231613517325}], 
        PointBox[{86.9, 0.6238528515163253}], 
        PointBox[{87., 0.6266135121132704}], 
        PointBox[{87.1, 0.6284562750751137}], 
        PointBox[{87.2, 0.6270142295930433}], 
        PointBox[{87.3, 0.6258831353133537}], 
        PointBox[{87.4, 0.6246515501497797}], 
        PointBox[{87.5, 0.6219845971284126}], 
        PointBox[{87.6, 0.6217569570881442}], 
        PointBox[{87.7, 0.6218547714863956}], 
        PointBox[{87.8, 0.6221391216301744}], 
        PointBox[{87.9, 0.6231407121836308}], 
        PointBox[{88., 0.6263115404076542}], 
        PointBox[{88.1, 0.6271381704795774}], 
        PointBox[{88.2, 0.6255188657449547}], 
        PointBox[{88.3, 0.6243979453675341}], 
        PointBox[{88.4, 0.6230132571294464}], 
        PointBox[{88.5, 0.6202461435460578}], 
        PointBox[{88.6, 0.6206057676118132}], 
        PointBox[{88.7, 0.620886967305227}], 
        PointBox[{88.8, 0.6214159769047533}], 
        PointBox[{88.9, 0.6227833690894014}], 
        PointBox[{89., 0.626191881954691}], 
        PointBox[{89.1, 0.6257514010773487}], 
        PointBox[{89.2, 0.6241009410998511}], 
        PointBox[{89.3, 0.6229835271697488}], 
        PointBox[{89.4, 0.6213638938291134}], 
        PointBox[{89.5, 0.6189189576662901}], 
        PointBox[{89.6, 0.6196419740220799}], 
        PointBox[{89.7, 0.6202499856347898}], 
        PointBox[{89.8, 0.6210051654310895}], 
        PointBox[{89.9, 0.6228504405997113}], 
        PointBox[{90., 0.6259587286178396}], 
        PointBox[{90.1, 0.624362810327135}], 
        PointBox[{90.2, 0.6228012595336927}], 
        PointBox[{90.3, 0.6216642316613997}], 
        PointBox[{90.4, 0.6197391415481932}], 
        PointBox[{90.5, 0.6182017447121492}], 
        PointBox[{90.6, 0.6191083166090017}], 
        PointBox[{90.7, 0.6199522866955253}], 
        PointBox[{90.8, 0.6209394361936706}], 
        PointBox[{90.9, 0.6233495537503905}], 
        PointBox[{91., 0.625322608387553}], 
        PointBox[{91.1, 0.6230663640438249}], 
        PointBox[{91.2, 0.6216516652108444}], 
        PointBox[{91.3, 0.6204557670346346}], 
        PointBox[{91.4, 0.6182689659101774}], 
        PointBox[{91.5, 0.6177959774967064}], 
        PointBox[{91.6, 0.6190111186473474}], 
        PointBox[{91.7, 0.6199795019641643}], 
        PointBox[{91.8, 0.621235554427211}], 
        PointBox[{91.9, 0.6241345712729547}], 
        PointBox[{92., 0.6242787839183408}], 
        PointBox[{92.1, 0.6219421929800494}], 
        PointBox[{92.2, 0.620676806832505}], 
        PointBox[{92.3, 0.6193794014890359}], 
        PointBox[{92.4, 0.6172724984967282}], 
        PointBox[{92.5, 0.6177937450804912}], 
        PointBox[{92.6, 0.6192658151900409}], 
        PointBox[{92.7, 0.6203104688458104}], 
        PointBox[{92.8, 0.6218947800525941}], 
        PointBox[{92.9, 0.6248105592344099}], 
        PointBox[{93., 0.6231010546712832}], 
        PointBox[{93.1, 0.6210432344936159}], 
        PointBox[{93.2, 0.6199005179571361}], 
        PointBox[{93.3, 0.6184856401231602}], 
        PointBox[{93.4, 0.6169870853150505}], 
        PointBox[{93.5, 0.6183338851157048}], 
        PointBox[{93.6, 0.6197980311667576}], 
        PointBox[{93.7, 0.6209223427545947}], 
        PointBox[{93.8, 0.6228765509493728}], 
        PointBox[{93.9, 0.6249066933555745}], 
        PointBox[{94., 0.6220774626332046}], 
        PointBox[{94.1, 0.62040195727219}], 
        PointBox[{94.2, 0.6193519522854725}], 
        PointBox[{94.3, 0.6179019479133572}], 
        PointBox[{94.4, 0.6171757278277935}], 
        PointBox[{94.5, 0.6192195589973004}], 
        PointBox[{94.6, 0.6205600301966765}], 
        PointBox[{94.7, 0.6217919465528752}], 
        PointBox[{94.8, 0.6240540459199507}], 
        PointBox[{94.9, 0.6243580827834468}], 
        PointBox[{95., 0.6213666446602887}], 
        PointBox[{95.1, 0.6200420169689858}], 
        PointBox[{95.2, 0.619075049606431}], 
        PointBox[{95.3, 0.6178292708088058}], 
        PointBox[{95.4, 0.6180513436386869}], 
        PointBox[{95.5, 0.6202986131996633}], 
        PointBox[{95.6, 0.6215205312215805}], 
        PointBox[{95.7, 0.6228885747579325}], 
        PointBox[{95.8, 0.6251723315752465}], 
        PointBox[{95.9, 0.623585690973215}], 
        PointBox[{96., 0.6210209591846552}], 
        PointBox[{96.1, 0.6199849563018763}], 
        PointBox[{96.2, 0.6191363841745845}], 
        PointBox[{96.3, 0.6182160942867151}], 
        PointBox[{96.4, 0.6194846781820406}], 
        PointBox[{96.5, 0.6215094378095987}], 
        PointBox[{96.6, 0.6226560866651746}], 
        PointBox[{96.7, 0.6241651240671485}], 
        PointBox[{96.8, 0.6259462754293563}], 
        PointBox[{96.9, 0.6230335669704763}], 
        PointBox[{97., 0.6210433073809684}], 
        PointBox[{97.1, 0.6202508812357874}], 
        PointBox[{97.2, 0.6196195428213443}], 
        PointBox[{97.3, 0.6188517276011517}], 
        PointBox[{97.4, 0.6211204932144052}], 
        PointBox[{97.5, 0.6228290392002795}], 
        PointBox[{97.6, 0.6239430366947631}], 
        PointBox[{97.7, 0.6255511893496322}], 
        PointBox[{97.8, 0.6263053941025112}], 
        PointBox[{97.9, 0.6228999931355392}], 
        PointBox[{98., 0.6214155938777364}], 
        PointBox[{98.1, 0.6208523004322558}], 
        PointBox[{98.2, 0.6205422724509766}], 
        PointBox[{98.3, 0.6200433845050777}], 
        PointBox[{98.4, 0.6227907848616568}], 
        PointBox[{98.5, 0.6242414810772641}], 
        PointBox[{98.6, 0.6253505035721563}], 
        PointBox[{98.7, 0.6269576851409322}], 
        PointBox[{98.8, 0.6264825975981547}], 
        PointBox[{98.9, 0.6231990992430818}], 
        PointBox[{99., 0.622105840046488}], 
        PointBox[{99.1, 0.6217823879717239}], 
        PointBox[{99.2, 0.6217171299186781}], 
        PointBox[{99.3, 0.6217094649340289}], 
        PointBox[{99.4, 0.6244472102857159}], 
        PointBox[{99.5, 0.6257251073338647}], 
        PointBox[{99.6, 0.6268402015687509}], 
        PointBox[{99.7, 0.6283139096090542}], 
        PointBox[{99.8, 0.6267812368293224}], 
        PointBox[{99.9, 0.6238675233150686}], 
        PointBox[{100., 0.6230629885851101}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0.6, 0.65}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], 
        PointBox[{0, 0.07250109999999833}], 
        PointBox[{0.1, 0.07492525989118362}], 
        PointBox[{0.2, 0.07568159991743756}], 
        PointBox[{0.3, 0.07340251056845964}], 
        PointBox[{0.4, 0.07388820516490957}], 
        PointBox[{0.5, 0.07746067546488739}], 
        PointBox[{0.6, 0.07436340448148457}], 
        PointBox[{0.7, 0.07312434526493018}], 
        PointBox[{0.8, 0.07546587921914504}], 
        PointBox[{0.9, 0.07557597736812857}], 
        PointBox[{1., 0.07315412664977412}], 
        PointBox[{1.1, 0.07596673139948219}], 
        PointBox[{1.2, 0.07763157486594136}], 
        PointBox[{1.3, 0.0756199014312367}], 
        PointBox[{1.4, 0.0753626530222707}], 
        PointBox[{1.5, 0.07917644110628048}], 
        PointBox[{1.6, 0.07674928360471313}], 
        PointBox[{1.7, 0.07480943537440353}], 
        PointBox[{1.8, 0.07702346383016827}], 
        PointBox[{1.9, 0.07791970681695323}], 
        PointBox[{2., 0.07531799456586312}], 
        PointBox[{2.1, 0.07854965584478972}], 
        PointBox[{2.2, 0.08114321425611394}], 
        PointBox[{2.3, 0.07959266979841036}], 
        PointBox[{2.4, 0.07867944391405121}], 
        PointBox[{2.5, 0.08247434527442062}], 
        PointBox[{2.6, 0.08086354769109758}], 
        PointBox[{2.7, 0.07832274008951423}], 
        PointBox[{2.8, 0.08025542073408994}], 
        PointBox[{2.9, 0.08181372124599702}], 
        PointBox[{3., 0.07917843088101834}], 
        PointBox[{3.1, 0.08241493072527863}], 
        PointBox[{3.2, 0.08595750551377243}], 
        PointBox[{3.3, 0.08502565223971824}], 
        PointBox[{3.4, 0.08361483108262978}], 
        PointBox[{3.5, 0.08713475973048443}], 
        PointBox[{3.6, 0.08642188682506965}], 
        PointBox[{3.7, 0.08340911680358798}], 
        PointBox[{3.8, 0.08496332892458063}], 
        PointBox[{3.9, 0.08702270048448679}], 
        PointBox[{4., 0.08459740187778829}], 
        PointBox[{4.1, 0.08730087468483891}], 
        PointBox[{4.2, 0.09179879570541605}], 
        PointBox[{4.3, 0.09158057986652197}], 
        PointBox[{4.4, 0.08987154275857721}], 
        PointBox[{4.5, 0.09291925070698494}], 
        PointBox[{4.6, 0.0930985365641698}], 
        PointBox[{4.7, 0.08975238116284513}], 
        PointBox[{4.8, 0.0908975099632994}], 
        PointBox[{4.9, 0.09328507081160067}], 
        PointBox[{5., 0.09125275645617416}], 
        PointBox[{5.1, 0.09307040764690926}], 
        PointBox[{5.2, 0.09842701787376724}], 
        PointBox[{5.3, 0.09893639133846197}], 
        PointBox[{5.4, 0.09712062717199549}], 
        PointBox[{5.5, 0.09960306135404907}], 
        PointBox[{5.6, 0.1005762274056247}], 
        PointBox[{5.7, 0.09702285061038346}], 
        PointBox[{5.8, 0.09779434054308503}], 
        PointBox[{5.9, 0.10035642438218949`}], 
        PointBox[{6., 0.09878339317794034}], 
        PointBox[{6.1, 0.09968377807309388}], 
        PointBox[{6.2, 0.10566256003990362`}], 
        PointBox[{6.3, 0.10681843436388591`}], 
        PointBox[{6.4, 0.10503579421118008`}], 
        PointBox[{6.5, 0.10698321452216863`}], 
        PointBox[{6.6, 0.10857332815450883`}], 
        PointBox[{6.7, 0.10490858663007069`}], 
        PointBox[{6.8, 0.10539670040263}], 
        PointBox[{6.9, 0.10802245170101231`}], 
        PointBox[{7., 0.10685532436428673`}], 
        PointBox[{7.1, 0.1070485971106568}], 
        PointBox[{7.2, 0.11337434550006534`}], 
        PointBox[{7.3, 0.11500184187362196`}], 
        PointBox[{7.4, 0.11331539863676586`}], 
        PointBox[{7.5, 0.1148666224145523}], 
        PointBox[{7.6, 0.11684309651495431`}], 
        PointBox[{7.7, 0.11312678109401751`}], 
        PointBox[{7.8, 0.11346001486151876`}], 
        PointBox[{7.9, 0.11608932293129423`}], 
        PointBox[{8., 0.11517767851689802`}], 
        PointBox[{8.1, 0.11499094644551835`}], 
        PointBox[{8.2, 0.121442624584545}], 
        PointBox[{8.3, 0.1232907090117487}], 
        PointBox[{8.4, 0.1216876366374642}], 
        PointBox[{8.5, 0.12306013754761899`}], 
        PointBox[{8.6, 0.1251545563108823}], 
        PointBox[{8.7, 0.12142606764516366`}], 
        PointBox[{8.8, 0.12175536445805231`}], 
        PointBox[{8.9, 0.12436705826141506`}], 
        PointBox[{9., 0.12348974043024213`}], 
        PointBox[{9.1, 0.12331415225666786`}], 
        PointBox[{9.2, 0.1297112565873786}], 
        PointBox[{9.3, 0.13148580234257073`}], 
        PointBox[{9.4, 0.12990524249125662`}], 
        PointBox[{9.5, 0.13137514904513958`}], 
        PointBox[{9.6, 0.13326062340947625`}], 
        PointBox[{9.7, 0.12958061277507835`}], 
        PointBox[{9.8, 0.1300626302185918}], 
        PointBox[{9.9, 0.13265097442956114`}], 
        PointBox[{10., 0.13153455040626938`}], 
        PointBox[{10.1, 0.13183293741115307`}], 
        PointBox[{10.2, 0.13795021510282302`}], 
        PointBox[{10.3, 0.13935986508968828`}], 
        PointBox[{10.4, 0.13773782893682748`}], 
        PointBox[{10.5, 0.13962687406087343`}], 
        PointBox[{10.6, 0.1408844520149188}], 
        PointBox[{10.7, 0.13739053974232304`}], 
        PointBox[{10.8, 0.13816681375127143`}], 
        PointBox[{10.9, 0.14070800086432517`}], 
        PointBox[{11., 0.1390519013523266}], 
        PointBox[{11.1, 0.14035350195834034`}], 
        PointBox[{11.2, 0.14585108387630333`}], 
        PointBox[{11.3, 0.14665881373626743`}], 
        PointBox[{11.4, 0.14498511799294803`}], 
        PointBox[{11.5, 0.14762751735448823`}], 
        PointBox[{11.6, 0.14774551163716165`}], 
        PointBox[{11.7, 0.14468738972344006`}], 
        PointBox[{11.8, 0.1458600420753345}], 
        PointBox[{11.9, 0.1482717221452726}], 
        PointBox[{12., 0.14582677960497906`}], 
        PointBox[{12.1, 0.14858968808427037`}], 
        PointBox[{12.2, 0.153062807794853}], 
        PointBox[{12.3, 0.15313417492408823`}], 
        PointBox[{12.4, 0.15151423879365652`}], 
        PointBox[{12.5, 0.15512855034510226`}], 
        PointBox[{12.6, 0.15364193277800411`}], 
        PointBox[{12.7, 0.15134376988580667`}], 
        PointBox[{12.8, 0.15294817127965551`}], 
        PointBox[{12.9, 0.15504062663922977`}], 
        PointBox[{13., 0.15182949022604078`}], 
        PointBox[{13.1, 0.15612400826925057`}], 
        PointBox[{13.2, 0.15926650296132416`}], 
        PointBox[{13.3, 0.15859384739663768`}], 
        PointBox[{13.4, 0.15731239191665325`}], 
        PointBox[{13.5, 0.16170567723765203`}], 
        PointBox[{13.6, 0.15853484449867913`}], 
        PointBox[{13.7, 0.15727327982367603`}], 
        PointBox[{13.8, 0.1592570228171368}], 
        PointBox[{13.9, 0.16068074792432055`}], 
        PointBox[{14., 0.15735634551351893`}], 
        PointBox[{14.1, 0.16254712151425613`}], 
        PointBox[{14.2, 0.16424189868539316`}], 
        PointBox[{14.3, 0.16294699006754304`}], 
        PointBox[{14.4, 0.16251371234898496`}], 
        PointBox[{14.5, 0.16674723791985693`}], 
        PointBox[{14.6, 0.16254587427236147`}], 
        PointBox[{14.7, 0.16241854111092566`}], 
        PointBox[{14.8, 0.16462832697468122`}], 
        PointBox[{14.9, 0.1648596826494777}], 
        PointBox[{15., 0.16273938219035874`}], 
        PointBox[{15.1, 0.16756860728164077`}], 
        PointBox[{15.2, 0.16789733330308454`}], 
        PointBox[{15.3, 0.16623356229805042`}], 
        PointBox[{15.4, 0.167316948367409}], 
        PointBox[{15.5, 0.16981311397235438`}], 
        PointBox[{15.6, 0.16584675502943125`}], 
        PointBox[{15.7, 0.16672973409818545`}], 
        PointBox[{15.8, 0.16889282482322504`}], 
        PointBox[{15.9, 0.1674084736217389}], 
        PointBox[{16., 0.16756793516753762`}], 
        PointBox[{16.1, 0.17104066098788195`}], 
        PointBox[{16.2, 0.1702594754529022}], 
        PointBox[{16.3, 0.16862468636412042`}], 
        PointBox[{16.4, 0.17167838360835283`}], 
        PointBox[{16.5, 0.17112677148543057`}], 
        PointBox[{16.6, 0.16853888998839675`}], 
        PointBox[{16.7, 0.17014038915461346`}], 
        PointBox[{16.8, 0.17184347399685018`}], 
        PointBox[{16.9, 0.1686957390309354}], 
        PointBox[{17., 0.17124966941586428`}], 
        PointBox[{17.1, 0.17296967765977447`}], 
        PointBox[{17.2, 0.17144202610485748`}], 
        PointBox[{17.3, 0.17040126796826674`}], 
        PointBox[{17.4, 0.17489113188025324`}], 
        PointBox[{17.5, 0.17142841372955403`}], 
        PointBox[{17.6, 0.17060794279672584`}], 
        PointBox[{17.7, 0.17254870400433447`}], 
        PointBox[{17.8, 0.1732344534083777}], 
        PointBox[{17.9, 0.16962592982924696`}], 
        PointBox[{18., 0.17345195632223986`}], 
        PointBox[{18.1, 0.17347803734007153`}], 
        PointBox[{18.2, 0.17161753551363046`}], 
        PointBox[{18.3, 0.1718644205975335}], 
        PointBox[{18.4, 0.17586462843457956`}], 
        PointBox[{18.5, 0.1713122431701296}], 
        PointBox[{18.6, 0.17194869133040877`}], 
        PointBox[{18.7, 0.1738100557648073}], 
        PointBox[{18.8, 0.1728900361000073}], 
        PointBox[{18.9, 0.1704224895637527}], 
        PointBox[{19., 0.17395422459145052`}], 
        PointBox[{19.1, 0.1727364030075183}], 
        PointBox[{19.2, 0.17098787364044887`}], 
        PointBox[{19.3, 0.1730919147166009}], 
        PointBox[{19.4, 0.1743991783749972}], 
        PointBox[{19.5, 0.17090962991560954`}], 
        PointBox[{19.6, 0.1724039638028615}], 
        PointBox[{19.7, 0.173741678996041}], 
        PointBox[{19.8, 0.17096765745900872`}], 
        PointBox[{19.9, 0.17084508318193675`}], 
        PointBox[{20., 0.17282606235401232`}], 
        PointBox[{20.1, 0.17091655924808688`}], 
        PointBox[{20.2, 0.16975099785276077`}], 
        PointBox[{20.3, 0.17360022073882372`}], 
        PointBox[{20.4, 0.17150671991820546`}], 
        PointBox[{20.5, 0.1700357045357364}], 
        PointBox[{20.6, 0.17179809176483524`}], 
        PointBox[{20.7, 0.17215658697160535`}], 
        PointBox[{20.8, 0.16796722417261079`}], 
        PointBox[{20.9, 0.17016704826312556`}], 
        PointBox[{21., 0.17028045658426036`}], 
        PointBox[{21.1, 0.16816149560074586`}], 
        PointBox[{21.2, 0.1680325145858632}], 
        PointBox[{21.3, 0.17240743588264956`}], 
        PointBox[{21.4, 0.16814719807486658`}], 
        PointBox[{21.5, 0.16841454584615606`}], 
        PointBox[{21.6, 0.1699637245284176}], 
        PointBox[{21.7, 0.16894085792853744`}], 
        PointBox[{21.8, 0.1643724640979489}], 
        PointBox[{21.9, 0.1678031916302149}], 
        PointBox[{22., 0.16652746370054458`}], 
        PointBox[{22.1, 0.16457599970444184`}], 
        PointBox[{22.2, 0.16580283637172383`}], 
        PointBox[{22.3, 0.16891780011472915`}], 
        PointBox[{22.4, 0.16452489385707184`}], 
        PointBox[{22.5, 0.1658045581045537}], 
        PointBox[{22.6, 0.1667700139945311}], 
        PointBox[{22.7, 0.16414070036405634`}], 
        PointBox[{22.8, 0.1607336215640572}], 
        PointBox[{22.9, 0.16377980022956784`}], 
        PointBox[{23., 0.161726480363736}], 
        PointBox[{23.1, 0.1602198427620612}], 
        PointBox[{23.2, 0.162814383175895}], 
        PointBox[{23.3, 0.1635468622134158}], 
        PointBox[{23.4, 0.16040089246242872`}], 
        PointBox[{23.5, 0.16204890199659638`}], 
        PointBox[{23.6, 0.16216081230118473`}], 
        PointBox[{23.7, 0.1579477348717323}], 
        PointBox[{23.8, 0.15663369392521959`}], 
        PointBox[{23.9, 0.1583730989358697}], 
        PointBox[{24., 0.1559975780055743}], 
        PointBox[{24.1, 0.15511193155327013`}], 
        PointBox[{24.2, 0.15870119603671345`}], 
        PointBox[{24.3, 0.1571096965461839}], 
        PointBox[{24.4, 0.1555022681586681}], 
        PointBox[{24.5, 0.15709810120903123`}], 
        PointBox[{24.6, 0.1561988082352811}], 
        PointBox[{24.7, 0.15070258629863106`}], 
        PointBox[{24.8, 0.1514479329089064}], 
        PointBox[{24.9, 0.15187718401928352`}], 
        PointBox[{25., 0.14945036072789836`}], 
        PointBox[{25.1, 0.14925079638895364`}], 
        PointBox[{25.2, 0.153240704360231}], 
        PointBox[{25.3, 0.15009211782128723`}], 
        PointBox[{25.4, 0.14969242245729614`}], 
        PointBox[{25.5, 0.15102208332087144`}], 
        PointBox[{25.6, 0.1490890116256018}], 
        PointBox[{25.7, 0.14293336289738365`}], 
        PointBox[{25.8, 0.14507402725344146`}], 
        PointBox[{25.9, 0.14455883712700915`}], 
        PointBox[{26., 0.14220868551446017`}], 
        PointBox[{26.1, 0.1426492467694952}], 
        PointBox[{26.2, 0.14653037388503068`}], 
        PointBox[{26.3, 0.14263419095142882`}], 
        PointBox[{26.4, 0.14299144000589697`}], 
        PointBox[{26.5, 0.14400261271511722`}], 
        PointBox[{26.6, 0.14116368630517395`}], 
        PointBox[{26.7, 0.13494408799194843`}], 
        PointBox[{26.8, 0.1377516145543327}], 
        PointBox[{26.9, 0.13666906561228373`}], 
        PointBox[{27., 0.13442395390504328`}], 
        PointBox[{27.1, 0.13537196416700403`}], 
        PointBox[{27.2, 0.13891133615829837`}], 
        PointBox[{27.3, 0.13478608636585046`}], 
        PointBox[{27.4, 0.1355409260512676}], 
        PointBox[{27.5, 0.13630384097114026`}], 
        PointBox[{27.6, 0.132811964169237}], 
        PointBox[{27.7, 0.12679187098897937`}], 
        PointBox[{27.8, 0.12980816996301137`}], 
        PointBox[{27.9, 0.12845097537804062`}], 
        PointBox[{28., 0.1262756634199512}], 
        PointBox[{28.1, 0.12755287620052883`}], 
        PointBox[{28.2, 0.13077701352903665`}], 
        PointBox[{28.3, 0.12664718481708317`}], 
        PointBox[{28.4, 0.12754934162500797`}], 
        PointBox[{28.5, 0.12821271422149874`}], 
        PointBox[{28.6, 0.12438983747050615`}], 
        PointBox[{28.7, 0.11853638192835027`}], 
        PointBox[{28.8, 0.1215449228839782}], 
        PointBox[{28.9, 0.12013577267262347`}], 
        PointBox[{29., 0.11796220349458271`}], 
        PointBox[{29.1, 0.1193811935747386}], 
        PointBox[{29.2, 0.12245431293880449`}], 
        PointBox[{29.3, 0.1183852174403432}], 
        PointBox[{29.4, 0.11924608206656365`}], 
        PointBox[{29.5, 0.11998766579002342`}], 
        PointBox[{29.6, 0.11617124025511323`}], 
        PointBox[{29.7, 0.11032846717934178`}], 
        PointBox[{29.8, 0.1132130051541203}], 
        PointBox[{29.9, 0.11194153236285763`}], 
        PointBox[{30., 0.10969655891306673`}], 
        PointBox[{30.1, 0.11107942865547414`}], 
        PointBox[{30.2, 0.11418881654390949`}], 
        PointBox[{30.3, 0.11021629562355358`}], 
        PointBox[{30.4, 0.11086070093255267`}], 
        PointBox[{30.5, 0.11183820425474521`}], 
        PointBox[{30.6, 0.10834600536439634`}], 
        PointBox[{30.7, 0.10240037944943532`}], 
        PointBox[{30.8, 0.10502894544777792`}], 
        PointBox[{30.9, 0.10407527956002513`}], 
        PointBox[{31., 0.10170717644126326`}], 
        PointBox[{31.1, 0.10289071918786488`}], 
        PointBox[{31.2, 0.10617404195256527`}], 
        PointBox[{31.3, 0.10238366159252316`}], 
        PointBox[{31.4, 0.10262633746689681`}], 
        PointBox[{31.5, 0.1039352519528248}], 
        PointBox[{31.6, 0.1010388736561047}], 
        PointBox[{31.7, 0.09503381416262291}], 
        PointBox[{31.8, 0.09720490350042915}], 
        PointBox[{31.9, 0.09674188278212605}], 
        PointBox[{32., 0.09424305073383424}], 
        PointBox[{32.1, 0.09508148379396672}], 
        PointBox[{32.2, 0.09859250253184733}], 
        PointBox[{32.3, 0.0951436045712517}], 
        PointBox[{32.4, 0.09479995627120907}], 
        PointBox[{32.5, 0.09644833197896716}], 
        PointBox[{32.6, 0.09434409319773719}], 
        PointBox[{32.7, 0.08853141344114089}], 
        PointBox[{32.8, 0.08998283768703143}], 
        PointBox[{32.9, 0.09015384785712635}], 
        PointBox[{33., 0.08757583784601616}], 
        PointBox[{33.1, 0.08794861727006167}], 
        PointBox[{33.2, 0.0916511810394598}], 
        PointBox[{33.3, 0.08875356383506144}], 
        PointBox[{33.4, 0.08767817148596416}], 
        PointBox[{33.5, 0.08958257212214113}], 
        PointBox[{33.6, 0.0883745313998313}], 
        PointBox[{33.7, 0.08313802774441446}], 
        PointBox[{33.8, 0.0836515176197607}], 
        PointBox[{33.9, 0.08453714834967364}], 
        PointBox[{34., 0.08199411095125733}], 
        PointBox[{34.1, 0.08181937076602988}], 
        PointBox[{34.2, 0.08560149190666697}], 
        PointBox[{34.3, 0.08346443304857518}], 
        PointBox[{34.4, 0.08159640346180333}], 
        PointBox[{34.5, 0.08359714746783442}], 
        PointBox[{34.6, 0.08330191813417266}], 
        PointBox[{34.7, 0.07892025919758401}], 
        PointBox[{34.8, 0.07853895734152402}], 
        PointBox[{34.9, 0.08013220941613786}], 
        PointBox[{35., 0.07778651247056396}], 
        PointBox[{35.1, 0.07703582312100558}], 
        PointBox[{35.2, 0.08073478361007644}], 
        PointBox[{35.3, 0.0795167529336264}], 
        PointBox[{35.4, 0.07690319260790253}], 
        PointBox[{35.5, 0.078797812124211}], 
        PointBox[{35.6, 0.07935828979665302}], 
        PointBox[{35.7, 0.07580978851291455}], 
        PointBox[{35.8, 0.07496418869657893}], 
        PointBox[{35.9, 0.0771715878227435}], 
        PointBox[{36., 0.07520899089885003}], 
        PointBox[{36.1, 0.07391666814795973}], 
        PointBox[{36.2, 0.07734536631616805}], 
        PointBox[{36.3, 0.07712964728692451}], 
        PointBox[{36.4, 0.07391398446101265}], 
        PointBox[{36.5, 0.07549741423807757}], 
        PointBox[{36.6, 0.07679896131832821}], 
        PointBox[{36.7, 0.0739439940975796}], 
        PointBox[{36.8, 0.07315041008687631}], 
        PointBox[{36.9, 0.07583521809666281}], 
        PointBox[{37., 0.07443814542147269}], 
        PointBox[{37.1, 0.07270191985895752}], 
        PointBox[{37.2, 0.07567079879684406}], 
        PointBox[{37.3, 0.07646812476619869}], 
        PointBox[{37.4, 0.07285271232599369}], 
        PointBox[{37.5, 0.07395481100498537}], 
        PointBox[{37.6, 0.07583904474262114}], 
        PointBox[{37.7, 0.07365343206229669}], 
        PointBox[{37.8, 0.07310372813743651}], 
        PointBox[{37.9, 0.07619456102436066}], 
        PointBox[{38., 0.0755232304306493}], 
        PointBox[{38.1, 0.07349636874995086}], 
        PointBox[{38.2, 0.07583321153938641}], 
        PointBox[{38.3, 0.0775912893283876}], 
        PointBox[{38.4, 0.0738002506923684}], 
        PointBox[{38.5, 0.07430556304770053}], 
        PointBox[{38.6, 0.07658744183216129}], 
        PointBox[{38.7, 0.07513209072308802}], 
        PointBox[{38.8, 0.07454797627834349}], 
        PointBox[{38.9, 0.07818087202156368}], 
        PointBox[{39., 0.0783620845981582}], 
        PointBox[{39.1, 0.07623801923537524}], 
        PointBox[{39.2, 0.0778138013450683}], 
        PointBox[{39.3, 0.08041998004394127}], 
        PointBox[{39.4, 0.07667384517413636}], 
        PointBox[{39.5, 0.07652950795850727}], 
        PointBox[{39.6, 0.07901439726848228}], 
        PointBox[{39.7, 0.07834365998910495}], 
        PointBox[{39.8, 0.07721856128804515}], 
        PointBox[{39.9, 0.08160604436450966}], 
        PointBox[{40., 0.08272485271845385}], 
        PointBox[{40.1, 0.08071229188725586}], 
        PointBox[{40.2, 0.08147318106749937}], 
        PointBox[{40.3, 0.08474962043256891}], 
        PointBox[{40.4, 0.08124904740881289}], 
        PointBox[{40.5, 0.08046395157293086}], 
        PointBox[{40.6, 0.0829693680687322}], 
        PointBox[{40.7, 0.08308125229427124}], 
        PointBox[{40.8, 0.08120061940721422}], 
        PointBox[{40.9, 0.08622412081535225}], 
        PointBox[{41., 0.08831585690064069}], 
        PointBox[{41.1, 0.08660513970750751}], 
        PointBox[{41.2, 0.0865941065745349}], 
        PointBox[{41.3, 0.09031107987618432}], 
        PointBox[{41.4, 0.08721433683645781}], 
        PointBox[{41.5, 0.08585148723306499}], 
        PointBox[{41.6, 0.08823354944653104}], 
        PointBox[{41.7, 0.08905347560611009}], 
        PointBox[{41.8, 0.0865745547253626}], 
        PointBox[{41.9, 0.09180052072569155}], 
        PointBox[{42., 0.09483947603779404}], 
        PointBox[{42.1, 0.0935668570375797}], 
        PointBox[{42.2, 0.09291586722574081}], 
        PointBox[{42.3, 0.09683092041063882}], 
        PointBox[{42.4, 0.09422820853523366}], 
        PointBox[{42.5, 0.0923914837898903}], 
        PointBox[{42.6, 0.09456381856861358}], 
        PointBox[{42.7, 0.09595839431827499}], 
        PointBox[{42.8, 0.09315431730456859}], 
        PointBox[{42.9, 0.09816275065827296}], 
        PointBox[{43., 0.10204380008354239`}], 
        PointBox[{43.1, 0.10126447658562834`}], 
        PointBox[{43.2, 0.10015541312186159`}], 
        PointBox[{43.3, 0.10407169804969704`}], 
        PointBox[{43.4, 0.10196191391577708`}], 
        PointBox[{43.5, 0.09977866375050563}], 
        PointBox[{43.6, 0.10172289125044405`}], 
        PointBox[{43.7, 0.10352925357102458`}], 
        PointBox[{43.8, 0.10061803484265336`}], 
        PointBox[{43.9, 0.10520765032797896`}], 
        PointBox[{44., 0.109733842529706}], 
        PointBox[{44.1, 0.10940821358092002`}], 
        PointBox[{44.2, 0.10802192463157538`}], 
        PointBox[{44.3, 0.11184122677815554`}], 
        PointBox[{44.4, 0.11011715826426462`}], 
        PointBox[{44.5, 0.10772574661319088`}], 
        PointBox[{44.6, 0.10948235711562107`}], 
        PointBox[{44.7, 0.11154251824941287`}], 
        PointBox[{44.8, 0.10862490666372392`}], 
        PointBox[{44.9, 0.11285242761463396`}], 
        PointBox[{45., 0.11775457465318516`}], 
        PointBox[{45.1, 0.11775236603897415`}], 
        PointBox[{45.2, 0.11623278378168113`}], 
        PointBox[{45.3, 0.1199716516300071}], 
        PointBox[{45.4, 0.11842634532887412`}], 
        PointBox[{45.5, 0.1159716534030746}], 
        PointBox[{45.6, 0.11762511500262246`}], 
        PointBox[{45.7, 0.11980170612522226`}], 
        PointBox[{45.8, 0.11686445528477742`}], 
        PointBox[{45.9, 0.12098031623913807`}], 
        PointBox[{46., 0.1259533096849559}], 
        PointBox[{46.1, 0.12607636689578752`}], 
        PointBox[{46.2, 0.12452400652791304`}], 
        PointBox[{46.3, 0.12829494646771522`}], 
        PointBox[{46.4, 0.1266399494494437}], 
        PointBox[{46.5, 0.12428040350743666`}], 
        PointBox[{46.6, 0.12593759138538235`}], 
        PointBox[{46.7, 0.12810989242598642`}], 
        PointBox[{46.8, 0.1250685071352855}], 
        PointBox[{46.9, 0.12941943640750406`}], 
        PointBox[{47., 0.13413789615740793`}], 
        PointBox[{47.1, 0.13415921516247276`}], 
        PointBox[{47.2, 0.13265746643600862`}], 
        PointBox[{47.3, 0.13661130993755868`}], 
        PointBox[{47.4, 0.1345172178464965}], 
        PointBox[{47.5, 0.13243714941370327`}], 
        PointBox[{47.6, 0.13420281219148966`}], 
        PointBox[{47.7, 0.1362402239579213}], 
        PointBox[{47.8, 0.13302458508540288`}], 
        PointBox[{47.9, 0.13793010632321004`}], 
        PointBox[{48., 0.14205378300842791`}], 
        PointBox[{48.1, 0.14176712339658212`}], 
        PointBox[{48.2, 0.14043395819901328`}], 
        PointBox[{48.3, 0.14465245488043413`}], 
        PointBox[{48.4, 0.14183798722680968`}], 
        PointBox[{48.5, 0.14024586300978234`}], 
        PointBox[{48.6, 0.1421985233282371}], 
        PointBox[{48.7, 0.14391863964388582`}], 
        PointBox[{48.8, 0.14062549728573123`}], 
        PointBox[{48.9, 0.14618702506700543`}], 
        PointBox[{49., 0.14939887832218685`}], 
        PointBox[{49.1, 0.14866810467854372`}], 
        PointBox[{49.2, 0.14772317511803087`}], 
        PointBox[{49.3, 0.1520467888900283}], 
        PointBox[{49.4, 0.14843725904402644`}], 
        PointBox[{49.5, 0.14753354266035051`}], 
        PointBox[{49.6, 0.14969944004649924`}], 
        PointBox[{49.7, 0.15081656444176558`}], 
        PointBox[{49.8, 0.14790766846866565`}], 
        PointBox[{49.9, 0.153795729959302}], 
        PointBox[{50., 0.15587433535374084`}], 
        PointBox[{50.1, 0.15467162341847596`}], 
        PointBox[{50.2, 0.1544955651615823}], 
        PointBox[{50.3, 0.15833032238788033`}], 
        PointBox[{50.4, 0.15424042760112575`}], 
        PointBox[{50.5, 0.15415851836830236`}], 
        PointBox[{50.6, 0.1564852152304024}], 
        PointBox[{50.7, 0.15658483675143942`}], 
        PointBox[{50.8, 0.15495699601112087`}], 
        PointBox[{50.9, 0.16036990642961235`}], 
        PointBox[{51., 0.1612482412749145}], 
        PointBox[{51.1, 0.15968051942161754`}], 
        PointBox[{51.2, 0.1607993113888366}], 
        PointBox[{51.3, 0.16310788307512708`}], 
        PointBox[{51.4, 0.159258651459012}], 
        PointBox[{51.5, 0.16000973249082306`}], 
        PointBox[{51.6, 0.16233455586837336`}], 
        PointBox[{51.7, 0.1609698860798469}], 
        PointBox[{51.8, 0.16149808910886837`}], 
        PointBox[{51.9, 0.16562289001069194`}], 
        PointBox[{52., 0.16539763212930075`}], 
        PointBox[{52.1, 0.1637336423887858}], 
        PointBox[{52.2, 0.1665821032102024}], 
        PointBox[{52.3, 0.16633475029439782`}], 
        PointBox[{52.4, 0.16353974374263425`}], 
        PointBox[{52.5, 0.1649972868586212}], 
        PointBox[{52.6, 0.16701332499040145`}], 
        PointBox[{52.7, 0.16410764160355987`}], 
        PointBox[{52.8, 0.16693912015577345`}], 
        PointBox[{52.9, 0.16941809626861412`}], 
        PointBox[{53., 0.16831906762982252`}], 
        PointBox[{53.1, 0.16702424799315763`}], 
        PointBox[{53.2, 0.17135520568719595`}], 
        PointBox[{53.3, 0.1683892553987475}], 
        PointBox[{53.4, 0.16711010860140207`}], 
        PointBox[{53.5, 0.16903149215269117`}], 
        PointBox[{53.6, 0.170251718702501}], 
        PointBox[{53.7, 0.16674063393970373`}], 
        PointBox[{53.8, 0.1709528986246096}], 
        PointBox[{53.9, 0.1717618058731533}], 
        PointBox[{54., 0.1701141070521789}], 
        PointBox[{54.1, 0.16985906170087384`}], 
        PointBox[{54.2, 0.1741882066932904}], 
        PointBox[{54.3, 0.1697631616633682}], 
        PointBox[{54.4, 0.16994178068715876`}], 
        PointBox[{54.5, 0.171997412160027}], 
        PointBox[{54.6, 0.17179729927455692`}], 
        PointBox[{54.7, 0.16934393330761754`}], 
        PointBox[{54.8, 0.17334364573552338`}], 
        PointBox[{54.9, 0.17275988510689383`}], 
        PointBox[{55., 0.17096806078987384`}], 
        PointBox[{55.1, 0.17247123238988113`}], 
        PointBox[{55.2, 0.17460662567735552`}], 
        PointBox[{55.3, 0.17072224492802493`}], 
        PointBox[{55.4, 0.17194990050816453`}], 
        PointBox[{55.5, 0.17373041628118083`}], 
        PointBox[{55.6, 0.17165280424141138`}], 
        PointBox[{55.7, 0.17145264607691352`}], 
        PointBox[{55.8, 0.17408412025989034`}], 
        PointBox[{55.9, 0.17256917846216435`}], 
        PointBox[{56., 0.17112102154907477`}], 
        PointBox[{56.1, 0.17461738321847867`}], 
        PointBox[{56.2, 0.1732987561674573}], 
        PointBox[{56.3, 0.17124758299293788`}], 
        PointBox[{56.4, 0.1730033641504145}], 
        PointBox[{56.5, 0.17402563337475332`}], 
        PointBox[{56.6, 0.17038285904486405`}], 
        PointBox[{56.7, 0.1725715042569167}], 
        PointBox[{56.8, 0.17332080605194164`}], 
        PointBox[{56.9, 0.17135951641106506`}], 
        PointBox[{57., 0.17081233052898714`}], 
        PointBox[{57.1, 0.1753249014533715}], 
        PointBox[{57.2, 0.17132043236832586`}], 
        PointBox[{57.3, 0.17115501161565644`}], 
        PointBox[{57.4, 0.17294188096814478`}], 
        PointBox[{57.5, 0.1726907667439835}], 
        PointBox[{57.6, 0.16860915142933225`}], 
        PointBox[{57.7, 0.17209608114740643`}], 
        PointBox[{57.8, 0.17125683004174508`}], 
        PointBox[{57.9, 0.16928863952289766`}], 
        PointBox[{58., 0.17016439267113728`}], 
        PointBox[{58.1, 0.1736321195970934}], 
        PointBox[{58.2, 0.16912733247470815`}], 
        PointBox[{58.3, 0.17021551698792212`}], 
        PointBox[{58.4, 0.17159531107655138`}], 
        PointBox[{58.5, 0.16968288350135663`}], 
        PointBox[{58.6, 0.16672787361701027`}], 
        PointBox[{58.7, 0.1698824737636245}], 
        PointBox[{58.8, 0.16807143142087533`}], 
        PointBox[{58.9, 0.16647935766224362`}], 
        PointBox[{59., 0.1690051771802653}], 
        PointBox[{59.1, 0.1697436103799821}], 
        PointBox[{59.2, 0.16658919176484266`}], 
        PointBox[{59.3, 0.16822111377099586`}], 
        PointBox[{59.4, 0.16881483140345543`}], 
        PointBox[{59.5, 0.16518773016516625`}], 
        PointBox[{59.6, 0.16452975221961308`}], 
        PointBox[{59.7, 0.16613281748780587`}], 
        PointBox[{59.8, 0.16389647099991517`}], 
        PointBox[{59.9, 0.16299684580416446`}], 
        PointBox[{60., 0.16680910367776927`}], 
        PointBox[{60.1, 0.1646696980120287}], 
        PointBox[{60.2, 0.16338897091838053`}], 
        PointBox[{60.3, 0.16502074738684355`}], 
        PointBox[{60.4, 0.1645241807381628}], 
        PointBox[{60.5, 0.15948933708006363`}], 
        PointBox[{60.6, 0.16113923580107267`}], 
        PointBox[{60.7, 0.16110770051012402`}], 
        PointBox[{60.8, 0.15882438289764467`}], 
        PointBox[{60.9, 0.1588320412455711}], 
        PointBox[{61., 0.16300228977518275`}], 
        PointBox[{61.1, 0.15907146933421928`}], 
        PointBox[{61.2, 0.15926775264101478`}], 
        PointBox[{61.3, 0.16054639986437302`}], 
        PointBox[{61.4, 0.158771177643141}], 
        PointBox[{61.5, 0.15317014206629578`}], 
        PointBox[{61.6, 0.15623064585245494`}], 
        PointBox[{61.7, 0.155030909822184}], 
        PointBox[{61.8, 0.1529285327793251}], 
        PointBox[{61.9, 0.15390494719701422`}], 
        PointBox[{62., 0.15744602502984106`}], 
        PointBox[{62.1, 0.15303168266920886`}], 
        PointBox[{62.2, 0.15410397313769886`}], 
        PointBox[{62.3, 0.15483841342401178`}], 
        PointBox[{62.4, 0.15176062754014552`}], 
        PointBox[{62.5, 0.14663982174274867`}], 
        PointBox[{62.6, 0.14998913740021314`}], 
        PointBox[{62.7, 0.14809829219798298`}], 
        PointBox[{62.8, 0.1462827551883528}], 
        PointBox[{62.9, 0.14812669487468766`}], 
        PointBox[{63., 0.1505104812694101}], 
        PointBox[{63.1, 0.1464299185601154}], 
        PointBox[{63.2, 0.14792032202966868`}], 
        PointBox[{63.3, 0.14805799834211553`}], 
        PointBox[{63.4, 0.14383270554449626`}], 
        PointBox[{63.5, 0.1397372590879385}], 
        PointBox[{63.6, 0.142759629740673}], 
        PointBox[{63.7, 0.14050480611126162`}], 
        PointBox[{63.8, 0.13898838572017744`}], 
        PointBox[{63.9, 0.14148256472858473`}], 
        PointBox[{64., 0.14272473725437254`}], 
        PointBox[{64.1, 0.13920913285116365`}], 
        PointBox[{64.2, 0.14085903632841718`}], 
        PointBox[{64.3, 0.14047438127771952`}], 
        PointBox[{64.4, 0.13539804883867326`}], 
        PointBox[{64.5, 0.13229603261078685`}], 
        PointBox[{64.6, 0.13488631550722566`}], 
        PointBox[{64.7, 0.13245689685354795`}], 
        PointBox[{64.8, 0.13118050143489615`}], 
        PointBox[{64.9, 0.13407987143015646`}], 
        PointBox[{65., 0.13451159815840966`}], 
        PointBox[{65.1, 0.1314382275261348}], 
        PointBox[{65.2, 0.13313869890110666`}], 
        PointBox[{65.3, 0.13241115631972222`}], 
        PointBox[{65.4, 0.1268343111174645}], 
        PointBox[{65.5, 0.12436400197919636`}], 
        PointBox[{65.6, 0.126670351646847}], 
        PointBox[{65.7, 0.12417129165818053`}], 
        PointBox[{65.8, 0.12302742269607883`}], 
        PointBox[{65.9, 0.12612718622887684`}], 
        PointBox[{66., 0.12616155880428853`}], 
        PointBox[{66.1, 0.12328136630439543`}], 
        PointBox[{66.2, 0.12500308530367502`}], 
        PointBox[{66.3, 0.1241778202181988}], 
        PointBox[{66.4, 0.1184240402152623}], 
        PointBox[{66.5, 0.11613037888731916`}], 
        PointBox[{66.6, 0.11836487671247826`}], 
        PointBox[{66.7, 0.1158655461433109}], 
        PointBox[{66.8, 0.11472575928671758`}], 
        PointBox[{66.9, 0.11787254059402046`}], 
        PointBox[{67., 0.1178896558167548}], 
        PointBox[{67.1, 0.11495491510485376`}], 
        PointBox[{67.2, 0.11668463082080252`}], 
        PointBox[{67.3, 0.11602129140044684`}], 
        PointBox[{67.4, 0.11037821848463135`}], 
        PointBox[{67.5, 0.10784201532448873`}], 
        PointBox[{67.6, 0.1101830476255952}], 
        PointBox[{67.7, 0.1077566501652862}], 
        PointBox[{67.8, 0.10649222242263127`}], 
        PointBox[{67.9, 0.10956567788024732`}], 
        PointBox[{68., 0.10987815708862284`}], 
        PointBox[{68.1, 0.10670551150893931`}], 
        PointBox[{68.2, 0.10839579917944174`}], 
        PointBox[{68.3, 0.10811960299581701`}], 
        PointBox[{68.4, 0.10286767334969119`}], 
        PointBox[{68.5, 0.09977526054672532}], 
        PointBox[{68.6, 0.10231572839627608`}], 
        PointBox[{68.7, 0.10006498246472594`}], 
        PointBox[{68.8, 0.09856966271580639}], 
        PointBox[{68.9, 0.10145437419312603`}], 
        PointBox[{69., 0.10229568959719727`}], 
        PointBox[{69.1, 0.09880432638724873}], 
        PointBox[{69.2, 0.10034752335287772`}], 
        PointBox[{69.3, 0.10061116942725319`}], 
        PointBox[{69.4, 0.09601888119276063}], 
        PointBox[{69.5, 0.09224153212222488}], 
        PointBox[{69.6, 0.09495440907246305}], 
        PointBox[{69.7, 0.09301894225957463}], 
        PointBox[{69.8, 0.09122808503611766}], 
        PointBox[{69.9, 0.09380074531964949}], 
        PointBox[{70., 0.09531227401794994}], 
        PointBox[{70.1, 0.0915457608698719}], 
        PointBox[{70.2, 0.09277548426625953}], 
        PointBox[{70.3, 0.09363968289256834}], 
        PointBox[{70.4, 0.08990774242712496}], 
        PointBox[{70.5, 0.08558584454364916}], 
        PointBox[{70.6, 0.08831448092994004}], 
        PointBox[{70.7, 0.08685861064971935}], 
        PointBox[{70.8, 0.08476590006732902}], 
        PointBox[{70.9, 0.08689766168589405}], 
        PointBox[{71., 0.0891193866114679}], 
        PointBox[{71.1, 0.08523955267403709}], 
        PointBox[{71.2, 0.08596212041188002}], 
        PointBox[{71.3, 0.0873924723633179}], 
        PointBox[{71.4, 0.08462032706118383}], 
        PointBox[{71.5, 0.08016231628580678}], 
        PointBox[{71.6, 0.08265031849705058}], 
        PointBox[{71.7, 0.08183284874824692}], 
        PointBox[{71.8, 0.07949975201794188}], 
        PointBox[{71.9, 0.08107136387170114}], 
        PointBox[{72., 0.08394488413974033}], 
        PointBox[{72.1, 0.08019176781570661}], 
        PointBox[{72.2, 0.0802359562663305}], 
        PointBox[{72.3, 0.0821154025115879}], 
        PointBox[{72.4, 0.08032629222817399}], 
        PointBox[{72.5, 0.07623882373108079}], 
        PointBox[{72.6, 0.07824470665904001}], 
        PointBox[{72.7, 0.07818679051944252}], 
        PointBox[{72.8, 0.07573891770107286}], 
        PointBox[{72.9, 0.07665848163281852}], 
        PointBox[{73., 0.08004683705968908}], 
        PointBox[{73.1, 0.07668016014406488}], 
        PointBox[{73.2, 0.07594337154148094}], 
        PointBox[{73.3, 0.07809515800958963}], 
        PointBox[{73.4, 0.0772680134637618}], 
        PointBox[{73.5, 0.07382467103269034}], 
        PointBox[{73.6, 0.07536468689581234}], 
        PointBox[{73.7, 0.07613077712449003}], 
        PointBox[{73.8, 0.07374072656435329}], 
        PointBox[{73.9, 0.07396095164334876}], 
        PointBox[{74., 0.0776741790324627}], 
        PointBox[{74.1, 0.07492470793763463}], 
        PointBox[{74.2, 0.07339314399126358}], 
        PointBox[{74.3, 0.07561244808797113}], 
        PointBox[{74.4, 0.07569063363069636}], 
        PointBox[{74.5, 0.07271353996992325}], 
        PointBox[{74.6, 0.07419361655631267}], 
        PointBox[{74.7, 0.07579401931326694}], 
        PointBox[{74.8, 0.07365799047889315}], 
        PointBox[{74.9, 0.07318940746205586}], 
        PointBox[{75., 0.0770031653634719}], 
        PointBox[{75.1, 0.0750508617411067}], 
        PointBox[{75.2, 0.07279004373043214}], 
        PointBox[{75.3, 0.07487477204337918}], 
        PointBox[{75.4, 0.07576349697485078}], 
        PointBox[{75.5, 0.07298268368358285}], 
        PointBox[{75.6, 0.07476170127241744}], 
        PointBox[{75.7, 0.07717705240130165}], 
        PointBox[{75.8, 0.07549223815100735}], 
        PointBox[{75.9, 0.07440951730302713}], 
        PointBox[{76., 0.07808036120086265}], 
        PointBox[{76.1, 0.0770510515356179}], 
        PointBox[{76.2, 0.07418222076772985}], 
        PointBox[{76.3, 0.07595813378751093}], 
        PointBox[{76.4, 0.07752618007674793}], 
        PointBox[{76.5, 0.07494808883560382}], 
        PointBox[{76.6, 0.0769130749024176}], 
        PointBox[{76.7, 0.08014351066825294}], 
        PointBox[{76.8, 0.07908633033407886}], 
        PointBox[{76.9, 0.07753034423966514}], 
        PointBox[{77., 0.08081538352371219}], 
        PointBox[{77.1, 0.0807767503063926}], 
        PointBox[{77.2, 0.07745279720662558}], 
        PointBox[{77.3, 0.0787938287959658}], 
        PointBox[{77.4, 0.08087803006016775}], 
        PointBox[{77.5, 0.07867860846292461}], 
        PointBox[{77.6, 0.08034818937201663}], 
        PointBox[{77.7, 0.08446037129918625}], 
        PointBox[{77.8, 0.08416555036334121}], 
        PointBox[{77.9, 0.08232775385978508}], 
        PointBox[{78., 0.08502231931430647}], 
        PointBox[{78.1, 0.08596896431333957}], 
        PointBox[{78.2, 0.08235454642228832}], 
        PointBox[{78.3, 0.0831963974661692}], 
        PointBox[{78.4, 0.08561614027560949}], 
        PointBox[{78.5, 0.08396544048541303}], 
        PointBox[{78.6, 0.0848242282714633}], 
        PointBox[{78.7, 0.08986291604956279}], 
        PointBox[{78.8, 0.09040528240027568}], 
        PointBox[{78.9, 0.08849161978776754}], 
        PointBox[{79., 0.0904754799463838}], 
        PointBox[{79.1, 0.09231802770399788}], 
        PointBox[{79.2, 0.08856809980949851}], 
        PointBox[{79.3, 0.08891255464296213}], 
        PointBox[{79.4, 0.09149623965107456}], 
        PointBox[{79.5, 0.090477930011422}], 
        PointBox[{79.6, 0.09031237902308831}], 
        PointBox[{79.7, 0.09611629245791337}], 
        PointBox[{79.8, 0.0974915134273831}], 
        PointBox[{79.9, 0.0956791880456254}], 
        PointBox[{80., 0.09694537653724661}], 
        PointBox[{80.1, 0.09952036947018739}], 
        PointBox[{80.2, 0.09575553323421467}], 
        PointBox[{80.3, 0.09566462829691597}], 
        PointBox[{80.4, 0.09827859502036876}], 
        PointBox[{80.5, 0.09787040135775733}], 
        PointBox[{80.6, 0.09679625229816348}], 
        PointBox[{80.7, 0.10304581422902687`}], 
        PointBox[{80.8, 0.10515860978692917`}], 
        PointBox[{80.9, 0.10355602128123027`}], 
        PointBox[{81., 0.1042050884847261}], 
        PointBox[{81.1, 0.1073103505517885}], 
        PointBox[{81.2, 0.10359424993499407`}], 
        PointBox[{81.3, 0.10317777649023425`}], 
        PointBox[{81.4, 0.10574330451589209`}], 
        PointBox[{81.5, 0.10583308818401628`}], 
        PointBox[{81.6, 0.1041108532500331}], 
        PointBox[{81.7, 0.11053111392525838`}], 
        PointBox[{81.8, 0.11319279796554418`}], 
        PointBox[{81.9, 0.11182148584248944`}], 
        PointBox[{82., 0.11202602379742509`}], 
        PointBox[{82.1, 0.11546383462294321`}], 
        PointBox[{82.2, 0.11179175286909745`}], 
        PointBox[{82.3, 0.1111918841200404}], 
        PointBox[{82.4, 0.11368823069841083`}], 
        PointBox[{82.5, 0.114103743603509}], 
        PointBox[{82.6, 0.11200618410591544`}], 
        PointBox[{82.7, 0.1184685347316652}], 
        PointBox[{82.8, 0.12141241691243512`}], 
        PointBox[{82.9, 0.12021081926843694`}], 
        PointBox[{83., 0.12017960730793231`}], 
        PointBox[{83.1, 0.12377684424147008`}], 
        PointBox[{83.2, 0.1200870007642298}], 
        PointBox[{83.3, 0.11946699854178208`}], 
        PointBox[{83.4, 0.12191628240426153`}], 
        PointBox[{83.5, 0.12244991410027656`}], 
        PointBox[{83.6, 0.12023601034097618`}], 
        PointBox[{83.7, 0.12672145414344327`}], 
        PointBox[{83.8, 0.1296335587842562}], 
        PointBox[{83.9, 0.1284822876125757}], 
        PointBox[{84., 0.12844574451725546`}], 
        PointBox[{84.1, 0.13202862251617667`}], 
        PointBox[{84.2, 0.12824444369067284`}], 
        PointBox[{84.3, 0.12777888639822985`}], 
        PointBox[{84.4, 0.13022338389295557`}], 
        PointBox[{84.5, 0.13063534161237686`}], 
        PointBox[{84.6, 0.12860062323463958`}], 
        PointBox[{84.7, 0.13508354697883593`}], 
        PointBox[{84.8, 0.13763856160677446`}], 
        PointBox[{84.9, 0.13640386106798988`}], 
        PointBox[{85., 0.13662865428112764`}], 
        PointBox[{85.1, 0.1399468965753081}], 
        PointBox[{85.2, 0.13605367746467234`}], 
        PointBox[{85.3, 0.13591471281103013`}], 
        PointBox[{85.4, 0.13838817114851565`}], 
        PointBox[{85.5, 0.13839299765675}], 
        PointBox[{85.6, 0.13696099699177813`}], 
        PointBox[{85.7, 0.14326076626047196`}], 
        PointBox[{85.8, 0.1451689966818059}], 
        PointBox[{85.9, 0.1437534965206625}], 
        PointBox[{86., 0.14457244957580948`}], 
        PointBox[{86.1, 0.14720051601741319`}], 
        PointBox[{86.2, 0.14333843688050232`}], 
        PointBox[{86.3, 0.14367158020633775`}], 
        PointBox[{86.4, 0.1461675318971457}], 
        PointBox[{86.5, 0.1454254534501609}], 
        PointBox[{86.6, 0.14519486493256994`}], 
        PointBox[{86.7, 0.15089186928754258`}], 
        PointBox[{86.8, 0.151952929682367}], 
        PointBox[{86.9, 0.15034940874694766`}], 
        PointBox[{87., 0.15215568911306226`}], 
        PointBox[{87.1, 0.15346288779667241`}], 
        PointBox[{87.2, 0.1499730381853973}], 
        PointBox[{87.3, 0.15086486736422267`}], 
        PointBox[{87.4, 0.15329881731606018`}], 
        PointBox[{87.5, 0.15147929812512123`}], 
        PointBox[{87.6, 0.15304171957768184`}], 
        PointBox[{87.7, 0.15761245494544202`}], 
        PointBox[{87.8, 0.157755922125599}], 
        PointBox[{87.9, 0.15609875108597188`}], 
        PointBox[{88., 0.15920761280363882`}], 
        PointBox[{88.1, 0.15854507271002619`}], 
        PointBox[{88.2, 0.15588474244888262`}], 
        PointBox[{88.3, 0.15733405304880144`}], 
        PointBox[{88.4, 0.1594978502623028}], 
        PointBox[{88.5, 0.15653533372628914`}], 
        PointBox[{88.6, 0.16003466184040951`}], 
        PointBox[{88.7, 0.1631383828737998}], 
        PointBox[{88.8, 0.16243263809249123`}], 
        PointBox[{88.9, 0.1610496829048688}], 
        PointBox[{89., 0.16532474065449643`}], 
        PointBox[{89.1, 0.16250521285541478`}], 
        PointBox[{89.2, 0.16103906927722644`}], 
        PointBox[{89.3, 0.1629425522872908}], 
        PointBox[{89.4, 0.1644551654091454}], 
        PointBox[{89.5, 0.16101704182505766`}], 
        PointBox[{89.6, 0.16577051940787157`}], 
        PointBox[{89.7, 0.16731734771851703`}], 
        PointBox[{89.8, 0.1659552791763926}], 
        PointBox[{89.9, 0.1654053271592904}], 
        PointBox[{90., 0.1698065715883771}], 
        PointBox[{90.1, 0.16559195986357486`}], 
        PointBox[{90.2, 0.1654117631474187}], 
        PointBox[{90.3, 0.1675608620329478}], 
        PointBox[{90.4, 0.1678606750965934}], 
        PointBox[{90.5, 0.16541712673868325`}], 
        PointBox[{90.6, 0.1700084539283393}], 
        PointBox[{90.7, 0.17012999481374944`}], 
        PointBox[{90.8, 0.16841918132451322`}], 
        PointBox[{90.9, 0.16941837415597305`}], 
        PointBox[{91., 0.1721249558611416}], 
        PointBox[{91.1, 0.1680513812593057}], 
        PointBox[{91.2, 0.1689610139162655}], 
        PointBox[{91.3, 0.17103812244382108`}], 
        PointBox[{91.4, 0.16957000252827095`}], 
        PointBox[{91.5, 0.16933212762611297`}], 
        PointBox[{91.6, 0.17264081269721604`}], 
        PointBox[{91.7, 0.17165805544250945`}], 
        PointBox[{91.8, 0.17003168286236953`}], 
        PointBox[{91.9, 0.17305186895017674`}], 
        PointBox[{92., 0.17258163221978548`}], 
        PointBox[{92.1, 0.1699824047890678}], 
        PointBox[{92.2, 0.1716089793098926}], 
        PointBox[{92.3, 0.1731723908309186}], 
        PointBox[{92.4, 0.16998675243521372`}], 
        PointBox[{92.5, 0.172195356766798}], 
        PointBox[{92.6, 0.1737190878832813}], 
        PointBox[{92.7, 0.17204761684927272`}], 
        PointBox[{92.8, 0.1710773436681719}], 
        PointBox[{92.9, 0.17555334241518758`}], 
        PointBox[{93., 0.1720668396497557}], 
        PointBox[{93.1, 0.1713292844398227}], 
        PointBox[{93.2, 0.17323705810882753`}], 
        PointBox[{93.3, 0.17373242605404243`}], 
        PointBox[{93.4, 0.1699786802575528}], 
        PointBox[{93.5, 0.1735884031169476}], 
        PointBox[{93.6, 0.17339976900382315`}], 
        PointBox[{93.7, 0.1714775602675704}], 
        PointBox[{93.8, 0.17182000583276166`}], 
        PointBox[{93.9, 0.17579209047485478`}], 
        PointBox[{94., 0.17121359514943016`}], 
        PointBox[{94.1, 0.1719402340478481}], 
        PointBox[{94.2, 0.1736869576620365}], 
        PointBox[{94.3, 0.17257099882662486`}], 
        PointBox[{94.4, 0.16980683334145039`}], 
        PointBox[{94.5, 0.17325873881703163`}], 
        PointBox[{94.6, 0.17186674391783904`}], 
        PointBox[{94.7, 0.17013229205426034`}], 
        PointBox[{94.8, 0.17227638932023323`}], 
        PointBox[{94.9, 0.17359209470119427`}], 
        PointBox[{95., 0.170099511807187}], 
        PointBox[{95.1, 0.1716288134024532}], 
        PointBox[{95.2, 0.17277835283090603`}], 
        PointBox[{95.3, 0.16984623258452608`}], 
        PointBox[{95.4, 0.16937089444883066`}], 
        PointBox[{95.5, 0.17130416268868656`}], 
        PointBox[{95.6, 0.16928417090744222`}], 
        PointBox[{95.7, 0.16816782504171346`}], 
        PointBox[{95.8, 0.17195254274103325`}], 
        PointBox[{95.9, 0.1699727937904354}], 
        PointBox[{96., 0.16848376554421624`}], 
        PointBox[{96.1, 0.17021076730578874`}], 
        PointBox[{96.2, 0.17034772885960578`}], 
        PointBox[{96.3, 0.16595213773837658`}], 
        PointBox[{96.4, 0.16785623725162907`}], 
        PointBox[{96.5, 0.167956458461854}], 
        PointBox[{96.6, 0.16577672987500774`}], 
        PointBox[{96.7, 0.16565849448219444`}], 
        PointBox[{96.8, 0.1699797323434466}], 
        PointBox[{96.9, 0.16585288540414794`}], 
        PointBox[{97., 0.16607009414550084`}], 
        PointBox[{97.1, 0.16753351435099334`}], 
        PointBox[{97.2, 0.16631860845099783`}], 
        PointBox[{97.3, 0.16137764149688086`}], 
        PointBox[{97.4, 0.16468783868582346`}], 
        PointBox[{97.5, 0.16342888401184358`}], 
        PointBox[{97.6, 0.16142688670463334`}], 
        PointBox[{97.7, 0.16254005483828468`}], 
        PointBox[{97.8, 0.16586849195975828`}], 
        PointBox[{97.9, 0.16141319059095138`}], 
        PointBox[{98., 0.1626325644247671}], 
        PointBox[{98.1, 0.1635063321172322}], 
        PointBox[{98.2, 0.1607671489570321}], 
        PointBox[{98.3, 0.15670221783625513`}], 
        PointBox[{98.4, 0.15992111766919892`}], 
        PointBox[{98.5, 0.15788571154504094`}], 
        PointBox[{98.6, 0.1562839009091726}], 
        PointBox[{98.7, 0.15860624187671934`}], 
        PointBox[{98.8, 0.15997009699979564`}], 
        PointBox[{98.9, 0.15643851157849256`}], 
        PointBox[{99., 0.1580582994797655}], 
        PointBox[{99.1, 0.15813626767304567`}], 
        PointBox[{99.2, 0.15391362108563067`}], 
        PointBox[{99.3, 0.15161933539422648`}], 
        PointBox[{99.4, 0.15385554963103676`}], 
        PointBox[{99.5, 0.1514642139369354}], 
        PointBox[{99.6, 0.15037915133614774`}], 
        PointBox[{99.7, 0.15361898541991245`}], 
        PointBox[{99.8, 0.1529844624914405}], 
        PointBox[{99.9, 0.15071054744889092`}], 
        PointBox[{100., 0.1523585578517085}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 0.2}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
        PointBox[{0.1, 356.4984926089873}], 
        PointBox[{0.2, 357.99288605058774`}], 
        PointBox[{0.3, 357.93575559614777`}], 
        PointBox[{0.4, 355.5903604434318}], 
        PointBox[{0.5, 356.86367695479544`}], 
        PointBox[{0.6, 358.7728388486302}], 
        PointBox[{0.7, 356.47623810491655`}], 
        PointBox[{0.8, 355.9191323611122}], 
        PointBox[{0.9, 357.5931765460047}], PointBox[{1., 355.3429609282341}],
         PointBox[{1.1, 350.99335322615593`}], 
        PointBox[{1.2, 352.05428458333785`}], 
        PointBox[{1.3, 352.4622482043273}], 
        PointBox[{1.4, 350.2924475704269}], 
        PointBox[{1.5, 350.8396401689289}], 
        PointBox[{1.6, 353.21405344729254`}], 
        PointBox[{1.7, 351.16961515984235`}], 
        PointBox[{1.8, 350.159057996016}], PointBox[{1.9, 351.7683843150032}],
         PointBox[{2., 350.76090683488223`}], 
        PointBox[{2.1, 346.2565051119769}], 
        PointBox[{2.2, 346.6923580826514}], 
        PointBox[{2.3, 347.4597549630073}], 
        PointBox[{2.4, 345.6530113836296}], 
        PointBox[{2.5, 345.48944773209115`}], 
        PointBox[{2.6, 348.11905951891805`}], 
        PointBox[{2.7, 346.46303677423947`}], 
        PointBox[{2.8, 345.1101265762109}], 
        PointBox[{2.9, 346.47084423477537`}], 
        PointBox[{3., 346.47670872898277`}], 
        PointBox[{3.1, 342.4025539296761}], 
        PointBox[{3.2, 342.1755734712045}], 
        PointBox[{3.3, 343.1600807177047}], 
        PointBox[{3.4, 341.82053438837875`}], 
        PointBox[{3.5, 341.06416976332616`}], 
        PointBox[{3.6, 343.7414193761788}], 
        PointBox[{3.7, 342.52618314463655`}], 
        PointBox[{3.8, 340.96990335508184`}], 
        PointBox[{3.9, 341.9856556986509}], PointBox[{4., 342.7141266238099}],
         PointBox[{4.1, 339.30186509554034`}], 
        PointBox[{4.2, 338.5851954349394}], 
        PointBox[{4.3, 339.6475648479149}], 
        PointBox[{4.4, 338.78467151194934`}], 
        PointBox[{4.5, 337.6179948218341}], 
        PointBox[{4.6, 340.17563448611736`}], 
        PointBox[{4.7, 339.37831404992204`}], 
        PointBox[{4.8, 337.74796338267663`}], 
        PointBox[{4.9, 338.4093538482188}], 
        PointBox[{5., 339.58314344708253`}], 
        PointBox[{5.1, 336.77382157224866`}], 
        PointBox[{5.2, 335.85182922671805`}], 
        PointBox[{5.3, 336.88748837043426`}], 
        PointBox[{5.4, 336.43561781253123`}], 
        PointBox[{5.5, 335.05095789573005`}], 
        PointBox[{5.6, 337.3878308310806}], 
        PointBox[{5.7, 336.93173887765033`}], 
        PointBox[{5.8, 335.3231253776275}], 
        PointBox[{5.9, 335.68493090347147`}], 
        PointBox[{6., 337.07918149922904`}], 
        PointBox[{6.1, 334.73032851982646`}], 
        PointBox[{6.2, 333.8146375007707}], 
        PointBox[{6.3, 334.76817699352114`}], 
        PointBox[{6.4, 334.6213368017363}], 
        PointBox[{6.5, 333.17285181648106`}], 
        PointBox[{6.6, 335.26327621317495`}], 
        PointBox[{6.7, 335.04038407327204`}], 
        PointBox[{6.8, 333.51044627304105`}], 
        PointBox[{6.9, 333.660235034576}], 
        PointBox[{7., 335.12084712438224`}], 
        PointBox[{7.1, 333.10243457678934`}], 
        PointBox[{7.2, 332.27776972353763`}], 
        PointBox[{7.3, 333.1386648170843}], 
        PointBox[{7.4, 333.1819611938781}], 
        PointBox[{7.5, 331.7625384119901}], 
        PointBox[{7.6, 333.6470271791086}], 
        PointBox[{7.7, 333.5364312144741}], 
        PointBox[{7.8, 332.1106164310315}], 
        PointBox[{7.9, 332.1436388023475}], 
        PointBox[{8., 333.58311741294824`}], 
        PointBox[{8.1, 331.77308512103536`}], 
        PointBox[{8.2, 331.05228583590554`}], 
        PointBox[{8.3, 331.83744040827736`}], 
        PointBox[{8.4, 331.9638471996275}], 
        PointBox[{8.5, 330.6130307066727}], 
        PointBox[{8.6, 332.3746257648844}], 
        PointBox[{8.7, 332.25423276521565`}], 
        PointBox[{8.8, 330.9406624027317}], 
        PointBox[{8.9, 330.94584719471413`}], 
        PointBox[{9., 332.3213156942056}], 
        PointBox[{9.1, 330.59923631660575`}], 
        PointBox[{9.2, 329.97970555330534`}], 
        PointBox[{9.3, 330.71339510267615`}], 
        PointBox[{9.4, 330.8296482435648}], 
        PointBox[{9.5, 329.55734195384133`}], 
        PointBox[{9.6, 331.2884372020393}], 
        PointBox[{9.7, 331.0453860508039}], 
        PointBox[{9.8, 329.8494991949824}], 
        PointBox[{9.9, 329.90551563147346`}], 
        PointBox[{10., 331.1868198883075}], 
        PointBox[{10.1, 329.4473714527174}], 
        PointBox[{10.2, 328.9418863981098}], 
        PointBox[{10.3, 329.63993117744974`}], 
        PointBox[{10.4, 329.6635932820543}], 
        PointBox[{10.5, 328.489850245364}], 
        PointBox[{10.6, 330.2486346029891}], 
        PointBox[{10.7, 329.7941355057087}], 
        PointBox[{10.8, 328.7299133947539}], 
        PointBox[{10.9, 328.9047530197746}], 
        PointBox[{11., 330.03593315432977`}], 
        PointBox[{11.1, 328.2122803335143}], 
        PointBox[{11.2, 327.86656707769674`}], 
        PointBox[{11.3, 328.52344529897374`}], 
        PointBox[{11.4, 328.37907701395727`}], 
        PointBox[{11.5, 327.37708992172}], 
        PointBox[{11.6, 329.13498562151165`}], 
        PointBox[{11.7, 328.42830000876415`}], 
        PointBox[{11.8, 327.5234794023363}], 
        PointBox[{11.9, 327.8766063628388}], 
        PointBox[{12., 328.73028285796863`}], 
        PointBox[{12.1, 326.82209822038044`}], 
        PointBox[{12.2, 326.7226995926927}], 
        PointBox[{12.3, 327.30329271514864`}], 
        PointBox[{12.4, 326.92255000794023`}], 
        PointBox[{12.5, 326.2565379006729}], 
        PointBox[{12.6, 327.85100669421433`}], 
        PointBox[{12.7, 326.92402043489034`}], 
        PointBox[{12.8, 326.2184453208742}], 
        PointBox[{12.9, 326.7948623709928}], 
        PointBox[{13., 327.1447263692993}], 
        PointBox[{13.1, 325.28164613584283`}], 
        PointBox[{13.2, 325.50112269308624`}], 
        PointBox[{13.3, 325.9445508413536}], 
        PointBox[{13.4, 325.2786730739625}], 
        PointBox[{13.5, 325.1951435521205}], 
        PointBox[{13.6, 326.3408963365443}], 
        PointBox[{13.7, 325.3007336319395}], 
        PointBox[{13.8, 324.83972250461545`}], 
        PointBox[{13.9, 325.6494725905415}], 
        PointBox[{14., 325.2198089751726}], 
        PointBox[{14.1, 323.7162716078427}], 
        PointBox[{14.2, 324.19563331916055`}], 
        PointBox[{14.3, 324.4274506743144}], 
        PointBox[{14.4, 323.4864045349165}], 
        PointBox[{14.5, 324.1869067091919}], 
        PointBox[{14.6, 324.61013026864015`}], 
        PointBox[{14.7, 323.60577244662744`}], 
        PointBox[{14.8, 323.4323462685147}], 
        PointBox[{14.9, 324.3981260601281}], 
        PointBox[{15., 323.0406042798468}], 
        PointBox[{15.1, 322.2331837911884}], 
        PointBox[{15.2, 322.7946625432034}], 
        PointBox[{15.3, 322.7414307261735}], 
        PointBox[{15.4, 321.66950938043846`}], 
        PointBox[{15.5, 323.07558566313736`}], 
        PointBox[{15.6, 322.7248253873889}], 
        PointBox[{15.7, 321.8967128842764}], 
        PointBox[{15.8, 322.0412032347339}], 
        PointBox[{15.9, 322.9083371592851}], 
        PointBox[{16., 320.81825080813735`}], 
        PointBox[{16.1, 320.8199241950927}], 
        PointBox[{16.2, 321.28250557659965`}], 
        PointBox[{16.3, 320.8876270058654}], 
        PointBox[{16.4, 320.04273737064005`}], 
        PointBox[{16.5, 321.65690260205656`}], 
        PointBox[{16.6, 320.7795644180392}], 
        PointBox[{16.7, 320.2258521811876}], 
        PointBox[{16.8, 320.68752332302023`}], 
        PointBox[{16.9, 320.96491143022115`}], 
        PointBox[{17., 318.8565833859575}], 
        PointBox[{17.1, 319.4088930908896}], 
        PointBox[{17.2, 319.64388777421124`}], 
        PointBox[{17.3, 318.8984443391849}], 
        PointBox[{17.4, 318.78085111416567`}], 
        PointBox[{17.5, 319.8826706287161}], 
        PointBox[{17.6, 318.8616152899092}], 
        PointBox[{17.7, 318.6304259609161}], 
        PointBox[{17.8, 319.33636050299896`}], 
        PointBox[{17.9, 318.50694283308025`}], 
        PointBox[{18., 317.2535118533449}], 
        PointBox[{18.1, 317.9393912183229}], 
        PointBox[{18.2, 317.870859637025}], 
        PointBox[{18.3, 316.8741299274849}], 
        PointBox[{18.4, 317.7561617513612}], 
        PointBox[{18.5, 317.88901245197144`}], 
        PointBox[{18.6, 317.03011960583416`}], 
        PointBox[{18.7, 317.1254997800455}], 
        PointBox[{18.8, 317.85470985305585`}], 
        PointBox[{18.9, 315.9305241681499}], 
        PointBox[{19., 315.84383306068696`}], 
        PointBox[{19.1, 316.3763480549192}], 
        PointBox[{19.2, 315.97236554602557`}], 
        PointBox[{19.3, 315.0032005218868}], 
        PointBox[{19.4, 316.56142379873876`}], 
        PointBox[{19.5, 315.85791347456757`}], 
        PointBox[{19.6, 315.31443972696144`}], 
        PointBox[{19.7, 315.6963832197337}], 
        PointBox[{19.8, 316.0161250629689}], 
        PointBox[{19.9, 313.78179518936827`}], 
        PointBox[{20., 314.46372033728966`}], 
        PointBox[{20.1, 314.71027928837304`}], 
        PointBox[{20.2, 313.98820401680763`}], 
        PointBox[{20.3, 313.4892898662141}], 
        PointBox[{20.4, 314.95733485872137`}], 
        PointBox[{20.5, 313.9142607601966}], 
        PointBox[{20.6, 313.72011082691034`}], 
        PointBox[{20.7, 314.2885297645221}], 
        PointBox[{20.8, 313.7209749738418}], 
        PointBox[{20.9, 312.1498041585354}], 
        PointBox[{21., 313.03378511835035`}], 
        PointBox[{21.1, 312.95522527181}], 
        PointBox[{21.2, 311.9994432259688}], 
        PointBox[{21.3, 312.3467753230145}], 
        PointBox[{21.4, 313.06313163012925`}], 
        PointBox[{21.5, 312.1136432432729}], 
        PointBox[{21.6, 312.23542902770913`}], 
        PointBox[{21.7, 312.80302080979567`}], 
        PointBox[{21.8, 311.28139126896303`}], 
        PointBox[{21.9, 310.80232761638456`}], 
        PointBox[{22., 311.5412063281964}], 
        PointBox[{22.1, 311.1467657944795}], 
        PointBox[{22.2, 310.12658573480417`}], 
        PointBox[{22.3, 311.3148357670217}], 
        PointBox[{22.4, 311.1175884903988}], 
        PointBox[{22.5, 310.4689407542772}], 
        PointBox[{22.6, 310.83724787974296`}], 
        PointBox[{22.7, 311.1382499080229}], 
        PointBox[{22.8, 309.10072999206335`}], 
        PointBox[{22.9, 309.5499730651725}], 
        PointBox[{23., 310.01287401723505`}], 
        PointBox[{23.1, 309.339668233337}], 
        PointBox[{23.2, 308.48717279498226`}], 
        PointBox[{23.3, 310.1204054015275}], 
        PointBox[{23.4, 309.2825958424093}], 
        PointBox[{23.5, 308.9747623349904}], 
        PointBox[{23.6, 309.49761239875824`}], 
        PointBox[{23.7, 309.3254246584147}], 
        PointBox[{23.8, 307.3574243755449}], 
        PointBox[{23.9, 308.32551414677}], PointBox[{24., 308.4958370504981}],
         PointBox[{24.1, 307.59981067975303`}], 
        PointBox[{24.2, 307.1327565483058}], 
        PointBox[{24.3, 308.7316576885316}], 
        PointBox[{24.4, 307.62487557859964`}], 
        PointBox[{24.5, 307.6205078122128}], 
        PointBox[{24.6, 308.195217716312}], 
        PointBox[{24.7, 307.56252189042874`}], 
        PointBox[{24.8, 305.98408587842425`}], 
        PointBox[{24.9, 307.13434510155133`}], 
        PointBox[{25., 307.04132732516575`}], 
        PointBox[{25.1, 305.98779042644196`}], 
        PointBox[{25.2, 306.0183213802817}], 
        PointBox[{25.3, 307.28606482921316`}], 
        PointBox[{25.4, 306.1551010455509}], 
        PointBox[{25.5, 306.3935055553108}], 
        PointBox[{25.6, 306.9301496227119}], 
        PointBox[{25.7, 305.95861505282386`}], 
        PointBox[{25.8, 304.8375035322624}], 
        PointBox[{25.9, 306.001776715982}], PointBox[{26., 305.688994964517}],
         PointBox[{26.1, 304.53782477388285`}], 
        PointBox[{26.2, 305.0462306222438}], 
        PointBox[{26.3, 305.91743434378446`}], 
        PointBox[{26.4, 304.85350467621504`}], 
        PointBox[{26.5, 305.27380961980674`}], 
        PointBox[{26.6, 305.72653713696087`}], 
        PointBox[{26.7, 304.5281041314897}], 
        PointBox[{26.8, 303.8000610490196}], 
        PointBox[{26.9, 304.93588539157156`}], 
        PointBox[{27., 304.44981309805496`}], 
        PointBox[{27.1, 303.2389585100879}], 
        PointBox[{27.2, 304.12294599060783`}], 
        PointBox[{27.3, 304.68240207103764`}], 
        PointBox[{27.4, 303.6750128022734}], 
        PointBox[{27.5, 304.2237533965846}], 
        PointBox[{27.6, 304.60067189932795`}], 
        PointBox[{27.7, 303.2480137613769}], 
        PointBox[{27.8, 302.77298066056727`}], 
        PointBox[{27.9, 303.90558888315445`}], 
        PointBox[{28., 303.29320031037537`}], 
        PointBox[{28.1, 302.0291850339168}], 
        PointBox[{28.2, 303.16638836933646`}], 
        PointBox[{28.3, 303.5601429528639}], 
        PointBox[{28.4, 302.54653317374976`}], 
        PointBox[{28.5, 303.17593381988996`}], 
        PointBox[{28.6, 303.5163595558203}], 
        PointBox[{28.7, 302.03723273252956`}], 
        PointBox[{28.8, 301.6448015027459}], 
        PointBox[{28.9, 302.8294951938373}], 
        PointBox[{29., 302.1409349240812}], 
        PointBox[{29.1, 300.8008285388246}], 
        PointBox[{29.2, 302.07909584070796`}], 
        PointBox[{29.3, 302.46865202294856`}], 
        PointBox[{29.4, 301.3650884042063}], 
        PointBox[{29.5, 302.02575502678286`}], 
        PointBox[{29.6, 302.381347951047}], 
        PointBox[{29.7, 300.76801383802496`}], 
        PointBox[{29.8, 300.2778948342696}], 
        PointBox[{29.9, 301.57544816363446`}], 
        PointBox[{30., 300.8701247174975}], 
        PointBox[{30.1, 299.41309183553693`}], 
        PointBox[{30.2, 300.72831248492355`}], 
        PointBox[{30.3, 301.27740345551905`}], 
        PointBox[{30.4, 300.0021744997496}], 
        PointBox[{30.5, 300.6330616564734}], 
        PointBox[{30.6, 301.0690336129504}], 
        PointBox[{30.7, 299.2880567998638}], 
        PointBox[{30.8, 298.513961114858}], 
        PointBox[{30.9, 299.9689753471911}], 
        PointBox[{31., 299.3220157810504}], 
        PointBox[{31.1, 297.7058954849001}], 
        PointBox[{31.2, 298.9483716398081}], 
        PointBox[{31.3, 299.81548272106335`}], 
        PointBox[{31.4, 298.31323346070457`}], 
        PointBox[{31.5, 298.831846426339}], 
        PointBox[{31.6, 299.42899548933565`}], 
        PointBox[{31.7, 297.441309383698}], 
        PointBox[{31.8, 296.1938544207426}], 
        PointBox[{31.9, 297.8092888259032}], 
        PointBox[{32., 297.31467869427297`}], 
        PointBox[{32.1, 295.51480745599963`}], 
        PointBox[{32.2, 296.56032788978104`}], 
        PointBox[{32.3, 297.8800532899833}], 
        PointBox[{32.4, 296.1496071645614}], 
        PointBox[{32.5, 296.4485022113174}], 
        PointBox[{32.6, 297.2771154096001}], 
        PointBox[{32.7, 295.0917232663443}], 
        PointBox[{32.8, 293.1867781062021}], 
        PointBox[{32.9, 294.8973444171548}], 
        PointBox[{33., 294.6619583547982}], 
        PointBox[{33.1, 292.69057609540926`}], 
        PointBox[{33.2, 293.4033350193944}], 
        PointBox[{33.3, 295.2557848987671}], 
        PointBox[{33.4, 293.37400375660167`}], 
        PointBox[{33.5, 293.32939957586746`}], 
        PointBox[{33.6, 294.4032612450975}], 
        PointBox[{33.7, 292.1685502237018}], 
        PointBox[{33.8, 289.42871889042647`}], 
        PointBox[{33.9, 291.08142901904813`}], 
        PointBox[{34., 291.2049060929289}], 
        PointBox[{34.1, 289.12628567296065`}], 
        PointBox[{34.2, 289.375592154992}], 
        PointBox[{34.3, 291.75609783880407`}], 
        PointBox[{34.4, 289.88224321197623`}], 
        PointBox[{34.5, 289.378464473926}], 
        PointBox[{34.6, 290.6309713728051}], 
        PointBox[{34.7, 288.70041361212725`}], 
        PointBox[{34.8, 284.96495889583923`}], 
        PointBox[{34.9, 286.31866576555336`}], 
        PointBox[{35., 286.8629932585454}], 
        PointBox[{35.1, 284.7989807659501}], 
        PointBox[{35.2, 284.48464714409783`}], 
        PointBox[{35.3, 287.2897532314179}], 
        PointBox[{35.4, 285.63853097432536`}], 
        PointBox[{35.5, 284.604730614385}], 
        PointBox[{35.6, 285.8989941290331}], 
        PointBox[{35.7, 284.71819441782844`}], 
        PointBox[{35.8, 279.9886682546141}], 
        PointBox[{35.9, 280.73876195014503`}], 
        PointBox[{36., 281.6968635363581}], 
        PointBox[{36.1, 279.81262487054516`}], 
        PointBox[{36.2, 278.8952890706387}], 
        PointBox[{36.3, 281.93313126987584`}], 
        PointBox[{36.4, 280.7211637842513}], 
        PointBox[{36.5, 279.1666846707135}], 
        PointBox[{36.6, 280.3297613702414}], 
        PointBox[{36.7, 280.13404985303686`}], 
        PointBox[{36.8, 274.83591950994173`}], 
        PointBox[{36.9, 274.67028769251124`}], 
        PointBox[{37., 275.95148705025747`}], 
        PointBox[{37.1, 274.41938774280146`}], 
        PointBox[{37.2, 272.94499110055483`}], 
        PointBox[{37.3, 275.96832905522217`}], 
        PointBox[{37.4, 275.3561282313424}], 
        PointBox[{37.5, 273.3834826995886}], 
        PointBox[{37.6, 274.2494361602185}], 
        PointBox[{37.7, 274.95756337628825`}], 
        PointBox[{37.8, 269.8802018116322}], 
        PointBox[{37.9, 268.5866260550169}], 
        PointBox[{38., 270.028089518984}], 
        PointBox[{38.1, 268.97933164194296`}], 
        PointBox[{38.2, 267.08681857747877`}], 
        PointBox[{38.3, 269.83778842144505`}], 
        PointBox[{38.4, 269.8940203879262}], 
        PointBox[{38.5, 267.67705944545685`}], 
        PointBox[{38.6, 268.1288292027854}], 
        PointBox[{38.7, 269.47900325797485`}], 
        PointBox[{38.8, 265.3286417125041}], 
        PointBox[{38.9, 262.97344173298234`}], 
        PointBox[{39., 264.37586563630066`}], 
        PointBox[{39.1, 263.8622894497559}], 
        PointBox[{39.2, 261.76051711449753`}], 
        PointBox[{39.3, 264.0202056204564}], 
        PointBox[{39.4, 264.7169075355263}], 
        PointBox[{39.5, 262.45212251922914`}], 
        PointBox[{39.6, 262.4488104787326}], 
        PointBox[{39.7, 264.1347564101102}], 
        PointBox[{39.8, 261.171398147811}], 
        PointBox[{39.9, 258.18280779748795`}], 
        PointBox[{40., 259.3579693622645}], 
        PointBox[{40.1, 259.3430542281621}], 
        PointBox[{40.2, 257.2614482356655}], 
        PointBox[{40.3, 258.89269189163207`}], 
        PointBox[{40.4, 260.1265673649151}], 
        PointBox[{40.5, 257.98169015571915`}], 
        PointBox[{40.6, 257.5609605754101}], 
        PointBox[{40.7, 259.31082702589583`}], 
        PointBox[{40.8, 257.444956922665}], 
        PointBox[{40.9, 254.3534587514352}], 
        PointBox[{41., 255.17517055263733`}], 
        PointBox[{41.1, 255.55676000307886`}], 
        PointBox[{41.2, 253.68617936264687`}], 
        PointBox[{41.3, 254.65706827189211`}], 
        PointBox[{41.4, 256.2818351959053}], 
        PointBox[{41.5, 254.36350749925384`}], 
        PointBox[{41.6, 253.6194124583618}], 
        PointBox[{41.7, 255.2396415738724}], 
        PointBox[{41.8, 254.27321294880159`}], 
        PointBox[{41.9, 251.41643044027342`}], 
        PointBox[{42., 251.86325392480586`}], 
        PointBox[{42.1, 252.511852757763}], 
        PointBox[{42.2, 250.96237507702176`}], 
        PointBox[{42.3, 251.34097427469675`}], 
        PointBox[{42.4, 253.20133815392637`}], 
        PointBox[{42.5, 251.54801312452852`}], 
        PointBox[{42.6, 250.59603420551383`}], 
        PointBox[{42.7, 251.98735276900456`}], 
        PointBox[{42.8, 251.70017820297238`}], 
        PointBox[{42.9, 249.17670837042078`}], 
        PointBox[{43., 249.3360145754088}], 
        PointBox[{43.1, 250.12983735801475`}], 
        PointBox[{43.2, 248.9226866761506}], 
        PointBox[{43.3, 248.8458059808795}], 
        PointBox[{43.4, 250.80540199992984`}], 
        PointBox[{43.5, 249.3987571353764}], 
        PointBox[{43.6, 248.34728365443098`}], 
        PointBox[{43.7, 249.49356749859015`}], 
        PointBox[{43.8, 249.66646142726734`}], 
        PointBox[{43.9, 247.4311651997266}], 
        PointBox[{44., 247.43902113324455`}], 
        PointBox[{44.1, 248.28438314681173`}], 
        PointBox[{44.2, 247.37025831424748`}], 
        PointBox[{44.3, 247.0006490683063}], 
        PointBox[{44.4, 248.95729786374807`}], 
        PointBox[{44.5, 247.74080563636488`}], 
        PointBox[{44.6, 246.67522590710962`}], 
        PointBox[{44.7, 247.61849991372233`}], 
        PointBox[{44.8, 248.0515631877683}], 
        PointBox[{44.9, 246.02515465298177`}], 
        PointBox[{45., 245.99091323181491`}], 
        PointBox[{45.1, 246.82630939193675`}], 
        PointBox[{45.2, 246.1159940133543}], 
        PointBox[{45.3, 245.6099427570829}], 
        PointBox[{45.4, 247.49633438500229`}], 
        PointBox[{45.5, 246.39545625405043`}], 
        PointBox[{45.6, 245.37713838969265`}], 
        PointBox[{45.7, 246.19024411185538`}], 
        PointBox[{45.8, 246.7109309966591}], 
        PointBox[{45.9, 244.83174001204839`}], 
        PointBox[{46., 244.81701214703912`}], 
        PointBox[{46.1, 245.60543760702532`}], 
        PointBox[{46.2, 244.9950236783022}], 
        PointBox[{46.3, 244.4922245882991}], 
        PointBox[{46.4, 246.25914376723017`}], 
        PointBox[{46.5, 245.2002310166192}], 
        PointBox[{46.6, 244.27343243308556`}], 
        PointBox[{46.7, 245.03801657203317`}], 
        PointBox[{46.8, 245.49290110397232`}], 
        PointBox[{46.9, 243.7240355802488}], 
        PointBox[{47., 243.7694056615788}], 
        PointBox[{47.1, 244.48517349416068`}], 
        PointBox[{47.2, 243.87252119637483`}], 
        PointBox[{47.3, 243.50801224949936`}], 
        PointBox[{47.4, 245.09451560947196`}], 
        PointBox[{47.5, 244.02287425132312`}], 
        PointBox[{47.6, 243.2242124950202}], 
        PointBox[{47.7, 244.01779501159828`}], 
        PointBox[{47.8, 244.25091587309763`}], 
        PointBox[{47.9, 242.5850738973882}], 
        PointBox[{48., 242.73836304968881`}], 
        PointBox[{48.1, 243.35401723235847`}], 
        PointBox[{48.2, 242.64922802495207`}], 
        PointBox[{48.3, 242.57246520956608`}], 
        PointBox[{48.4, 243.87576457735483`}], 
        PointBox[{48.5, 242.77245511032004`}], 
        PointBox[{48.6, 242.1383184812147}], 
        PointBox[{48.7, 243.02280399187853`}], 
        PointBox[{48.8, 242.86056423928295`}], 
        PointBox[{48.9, 241.3425283532514}], 
        PointBox[{49., 241.65379885100936`}], 
        PointBox[{49.1, 242.13075659383836`}], 
        PointBox[{49.2, 241.26897578463576`}], 
        PointBox[{49.3, 241.64360643665225`}], 
        PointBox[{49.4, 242.5134664369674}], 
        PointBox[{49.5, 241.40500630214052`}], 
        PointBox[{49.6, 240.9751603367442}], 
        PointBox[{49.7, 241.97969651597526`}], 
        PointBox[{49.8, 241.25129656376166`}], 
        PointBox[{49.9, 240.00612671153323`}], 
        PointBox[{50., 240.47810476522295`}], 
        PointBox[{50.1, 240.76355516977955`}], 
        PointBox[{50.2, 239.73277965446826`}], 
        PointBox[{50.3, 240.678573833261}], 
        PointBox[{50.4, 240.96773298413788`}], 
        PointBox[{50.5, 239.92123260008518`}], 
        PointBox[{50.6, 239.7384354526608}], 
        PointBox[{50.7, 240.8208524199964}], 
        PointBox[{50.8, 239.43576741285955`}], 
        PointBox[{50.9, 238.63779924118384`}], 
        PointBox[{51., 239.19246712971074`}], 
        PointBox[{51.1, 239.22318958697483`}], 
        PointBox[{51.2, 238.11933876309956`}], 
        PointBox[{51.3, 239.58413458465168`}], 
        PointBox[{51.4, 239.2524726474316}], 
        PointBox[{51.5, 238.35522262385132`}], 
        PointBox[{51.6, 238.45906531710747`}], 
        PointBox[{51.7, 239.43953251866805`}], 
        PointBox[{51.8, 237.4828567214982}], 
        PointBox[{51.9, 237.27343301832812`}], 
        PointBox[{52., 237.7851274882289}], 
        PointBox[{52.1, 237.49908455604577`}], 
        PointBox[{52.2, 236.5928482966326}], 
        PointBox[{52.3, 238.23460940400514`}], 
        PointBox[{52.4, 237.42357698233383`}], 
        PointBox[{52.5, 236.75787340514535`}], 
        PointBox[{52.6, 237.17232356808034`}], 
        PointBox[{52.7, 237.67148882616652`}], 
        PointBox[{52.8, 235.55681139513223`}], 
        PointBox[{52.9, 235.8983728548132}], 
        PointBox[{53., 236.24466218803838`}], 
        PointBox[{53.1, 235.6065207384317}], 
        PointBox[{53.2, 235.32403297685966`}], 
        PointBox[{53.3, 236.5704382987836}], 
        PointBox[{53.4, 235.55495737533008`}], 
        PointBox[{53.5, 235.18106356580824`}], 
        PointBox[{53.6, 235.8799582095453}], 
        PointBox[{53.7, 235.42009042282774`}], 
        PointBox[{53.8, 233.86566499036823`}], 
        PointBox[{53.9, 234.47466284595947`}], 
        PointBox[{54., 234.56027799179512`}], 
        PointBox[{54.1, 233.6166575339275}], 
        PointBox[{54.2, 234.28309548282976`}], 
        PointBox[{54.3, 234.65934980681226`}], 
        PointBox[{54.4, 233.71525148464045`}], 
        PointBox[{54.5, 233.6647100922296}], 
        PointBox[{54.6, 234.50224581379302`}], 
        PointBox[{54.7, 232.89483335238276`}], 
        PointBox[{54.8, 232.38917207536178`}], 
        PointBox[{54.9, 232.96638297207193`}], 
        PointBox[{55., 232.728648549464}], 
        PointBox[{55.1, 231.69581215331857`}], 
        PointBox[{55.2, 233.15275951953555`}], 
        PointBox[{55.3, 232.64393171630047`}], 
        PointBox[{55.4, 231.9535863981866}], 
        PointBox[{55.5, 232.22331378267137`}], 
        PointBox[{55.6, 232.83604797945344`}], 
        PointBox[{55.7, 230.58232282641114`}], 
        PointBox[{55.8, 230.9894948784906}], 
        PointBox[{55.9, 231.34986234806823`}], 
        PointBox[{56., 230.7677415763604}], 
        PointBox[{56.1, 230.08016433474663`}], 
        PointBox[{56.2, 231.63880846952577`}], 
        PointBox[{56.3, 230.6548733533147}], 
        PointBox[{56.4, 230.29639389829458`}], 
        PointBox[{56.5, 230.831274152032}], 
        PointBox[{56.6, 230.6570671638905}], 
        PointBox[{56.7, 228.77606997283613`}], 
        PointBox[{56.8, 229.5612632378382}], 
        PointBox[{56.9, 229.61869869502124`}], 
        PointBox[{57., 228.73935661074069`}], 
        PointBox[{57.1, 228.87779526313}], 
        PointBox[{57.2, 229.76553240461234`}], 
        PointBox[{57.3, 228.77137811666546`}], 
        PointBox[{57.4, 228.7480874779942}], 
        PointBox[{57.5, 229.40020162900362`}], 
        PointBox[{57.6, 228.09971945311838`}], 
        PointBox[{57.7, 227.32622049347685`}], 
        PointBox[{57.8, 228.05679779986193`}], 
        PointBox[{57.9, 227.78646508009797`}], 
        PointBox[{58., 226.76620268497055`}], 
        PointBox[{58.1, 227.85213113189008`}], 
        PointBox[{58.2, 227.7538021126088}], 
        PointBox[{58.3, 227.02533813472758`}], 
        PointBox[{58.4, 227.2922491801129}], 
        PointBox[{58.5, 227.77753152605933`}], 
        PointBox[{58.6, 225.69512925224043`}], 
        PointBox[{58.7, 226.00105288358088`}], 
        PointBox[{58.8, 226.47278923882797`}], 
        PointBox[{58.9, 225.89073940855457`}], 
        PointBox[{59., 225.01127507214474`}], 
        PointBox[{59.1, 226.6214507629925}], 
        PointBox[{59.2, 225.7954489752311}], 
        PointBox[{59.3, 225.4201506978534}], 
        PointBox[{59.4, 225.8927994364149}], 
        PointBox[{59.5, 225.84993248992495`}], 
        PointBox[{59.6, 223.78366629142045`}], 
        PointBox[{59.7, 224.6805879523389}], 
        PointBox[{59.8, 224.83593212669692`}], 
        PointBox[{59.9, 223.99450233262516`}], 
        PointBox[{60., 223.58676984301425`}], 
        PointBox[{60.1, 225.06955564050764`}], 
        PointBox[{60.2, 223.9855135129314}], 
        PointBox[{60.3, 223.94627512592385`}], 
        PointBox[{60.4, 224.50024296765275`}], 
        PointBox[{60.5, 223.7604871518577}], 
        PointBox[{60.6, 222.31215891883923`}], 
        PointBox[{60.7, 223.3433989119326}], 
        PointBox[{60.8, 223.1916434281982}], 
        PointBox[{60.9, 222.17909660116922`}], 
        PointBox[{61., 222.45549320906278`}], 
        PointBox[{61.1, 223.35652687459643`}], 
        PointBox[{61.2, 222.35263641817025`}], 
        PointBox[{61.3, 222.5906538543277}], 
        PointBox[{61.4, 223.07258212513935`}], 
        PointBox[{61.5, 221.751963999998}], 
        PointBox[{61.6, 221.09182251821227`}], 
        PointBox[{61.7, 222.01839072830134`}], 
        PointBox[{61.8, 221.59443076930435`}], 
        PointBox[{61.9, 220.52104453184648`}], 
        PointBox[{62., 221.46523187068814`}], 
        PointBox[{62.1, 221.67956595723982`}], 
        PointBox[{62.2, 220.8947398051838}], 
        PointBox[{62.3, 221.34171922874424`}], 
        PointBox[{62.4, 221.62402834306727`}], 
        PointBox[{62.5, 219.9584792136257}], 
        PointBox[{62.6, 219.9980910489557}], 
        PointBox[{62.7, 220.7482071752529}], 
        PointBox[{62.8, 220.09414166327426`}], 
        PointBox[{62.9, 219.0636491581815}], 
        PointBox[{63., 220.49189637732337`}], 
        PointBox[{63.1, 220.15159294445448`}], 
        PointBox[{63.2, 219.59498733156488`}], 
        PointBox[{63.3, 220.1888907817188}], 
        PointBox[{63.4, 220.2411012856932}], 
        PointBox[{63.5, 218.43842730926764`}], 
        PointBox[{63.6, 218.97552721974995`}], 
        PointBox[{63.7, 219.5632123769395}], 
        PointBox[{63.8, 218.7198964509164}], 
        PointBox[{63.9, 217.7962876210339}], 
        PointBox[{64., 219.5051583546697}], 
        PointBox[{64.1, 218.80178824819023`}], 
        PointBox[{64.2, 218.42120347314113`}], 
        PointBox[{64.3, 219.11605977175915`}], 
        PointBox[{64.4, 218.99578644725813`}], 
        PointBox[{64.5, 217.14239245763164`}], 
        PointBox[{64.6, 217.98371069905326`}], 
        PointBox[{64.7, 218.4612784220517}], 
        PointBox[{64.8, 217.46344743704466`}], 
        PointBox[{64.9, 216.65312672586344`}], 
        PointBox[{65., 218.51380007256085`}], 
        PointBox[{65.1, 217.600579422487}], 
        PointBox[{65.2, 217.31756775514117`}], 
        PointBox[{65.3, 218.08741482543095`}], 
        PointBox[{65.4, 217.85841782487833`}], 
        PointBox[{65.5, 215.95211735727443`}], 
        PointBox[{65.6, 216.95679878828085`}], 
        PointBox[{65.7, 217.394549506935}], 
        PointBox[{65.8, 216.26974482367703`}], 
        PointBox[{65.9, 215.52633271730997`}], 
        PointBox[{66., 217.4943149753221}], 
        PointBox[{66.1, 216.47552018775437`}], 
        PointBox[{66.2, 216.19806014077295`}], 
        PointBox[{66.3, 217.03284145420662`}], 
        PointBox[{66.4, 216.72857647579548`}], 
        PointBox[{66.5, 214.72483894563337`}], 
        PointBox[{66.6, 215.78605296571988`}], 
        PointBox[{66.7, 216.26564832387808`}], 
        PointBox[{66.8, 215.03860680083946`}], 
        PointBox[{66.9, 214.27988362140383`}], 
        PointBox[{67., 216.3587353301601}], 
        PointBox[{67.1, 215.3193067876895}], 
        PointBox[{67.2, 214.94478139333333`}], 
        PointBox[{67.3, 215.8395019090105}], 
        PointBox[{67.4, 215.47872545933868`}], 
        PointBox[{67.5, 213.310535653314}], 
        PointBox[{67.6, 214.32005766165918`}], 
        PointBox[{67.7, 214.9298660652628}], 
        PointBox[{67.8, 213.63046721243376`}], 
        PointBox[{67.9, 212.75840179994228`}], 
        PointBox[{68., 214.95641085671795`}], 
        PointBox[{68.1, 213.9963999357853}], 
        PointBox[{68.2, 213.41508201534273`}], 
        PointBox[{68.3, 214.35451526774548`}], 
        PointBox[{68.4, 213.97973980569256`}], 
        PointBox[{68.5, 211.56219902760546`}], 
        PointBox[{68.6, 212.37969261001322`}], 
        PointBox[{68.7, 213.20580550398725`}], 
        PointBox[{68.8, 211.88145264826727`}], 
        PointBox[{68.9, 210.7980264616986}], 
        PointBox[{69., 213.0928161691272}], 
        PointBox[{69.1, 212.34788158201633`}], 
        PointBox[{69.2, 211.45417466653572`}], 
        PointBox[{69.3, 212.39698709543066`}], 
        PointBox[{69.4, 212.11989239796694`}], 
        PointBox[{69.5, 209.34620759513848`}], 
        PointBox[{69.6, 209.7831791618397}], 
        PointBox[{69.7, 210.891497056504}], 
        PointBox[{69.8, 209.61693230903063`}], 
        PointBox[{69.9, 208.2413862754686}], 
        PointBox[{70., 210.55932422839604`}], 
        PointBox[{70.1, 210.19781143201487`}], 
        PointBox[{70.2, 208.9124672706175}], 
        PointBox[{70.3, 209.7798022330973}], 
        PointBox[{70.4, 209.78584512079968`}], 
        PointBox[{70.5, 206.559936659294}], 
        PointBox[{70.6, 206.38412413270535`}], 
        PointBox[{70.7, 207.79304878123452`}], 
        PointBox[{70.8, 206.67315575527456`}], 
        PointBox[{70.9, 204.96138596416975`}], 
        PointBox[{71., 207.17506591603774`}], 
        PointBox[{71.1, 207.36750332392856`}], 
        PointBox[{71.2, 205.669398211393}], 
        PointBox[{71.3, 206.3453728484807}], 
        PointBox[{71.4, 206.8044214897108}], 
        PointBox[{71.5, 203.16397199444228`}], 
        PointBox[{71.6, 202.1214558192936}], 
        PointBox[{71.7, 203.7733924662466}], 
        PointBox[{71.8, 202.93183416453613`}], 
        PointBox[{71.9, 200.89738616532938`}], 
        PointBox[{72., 202.84003520466092`}], 
        PointBox[{72.1, 203.71104140026142`}], 
        PointBox[{72.2, 201.66528136748488`}], 
        PointBox[{72.3, 202.01453952650667`}], 
        PointBox[{72.4, 202.96939106872807`}], 
        PointBox[{72.5, 199.2229493104452}], 
        PointBox[{72.6, 197.07355277783125`}], 
        PointBox[{72.7, 198.81839041540746`}], 
        PointBox[{72.8, 198.37084084559126`}], 
        PointBox[{72.9, 196.10043553744856`}], 
        PointBox[{73., 197.59389000799652`}], 
        PointBox[{73.1, 199.1779509915874}], 
        PointBox[{73.2, 196.9409672245477}], 
        PointBox[{73.3, 196.84164636562738`}], 
        PointBox[{73.4, 198.1896706074254}], 
        PointBox[{73.5, 194.90259652268367`}], 
        PointBox[{73.6, 191.49509227120205`}], 
        PointBox[{73.7, 193.09760981406234`}], 
        PointBox[{73.8, 193.1152511778455}], 
        PointBox[{73.9, 190.76837691950868`}], 
        PointBox[{74., 191.65843600636163`}], 
        PointBox[{74.1, 193.880458593418}], 
        PointBox[{74.2, 191.67130235933155`}], 
        PointBox[{74.3, 191.05471557789903`}], 
        PointBox[{74.4, 192.60089275265005`}], 
        PointBox[{74.5, 190.33291972603655`}], 
        PointBox[{74.6, 185.80021212997943`}], 
        PointBox[{74.7, 186.9762887700621}], 
        PointBox[{74.8, 187.4572096637201}], 
        PointBox[{74.9, 185.24024131365485`}], 
        PointBox[{75., 185.43535819380864`}], 
        PointBox[{75.1, 188.1238012473527}], 
        PointBox[{75.2, 186.16894269363732`}], 
        PointBox[{75.3, 185.04738035061976`}], 
        PointBox[{75.4, 186.56677552811206`}], 
        PointBox[{75.5, 185.5326663668928}], 
        PointBox[{75.6, 180.45565947834456`}], 
        PointBox[{75.7, 180.93584615169289`}], 
        PointBox[{75.8, 181.79917037391598`}], 
        PointBox[{75.9, 179.9133341293987}], 
        PointBox[{76., 179.41401166477854`}], 
        PointBox[{76.1, 182.33761056790442`}], 
        PointBox[{76.2, 180.81409261528003`}], 
        PointBox[{76.3, 179.28197433303657`}], 
        PointBox[{76.4, 180.57603236281977`}], 
        PointBox[{76.5, 180.64028616997496`}], 
        PointBox[{76.6, 175.8000651640402}], 
        PointBox[{76.7, 175.43089462782316`}], 
        PointBox[{76.8, 176.5371052582732}], 
        PointBox[{76.9, 175.12499413797835`}], 
        PointBox[{77., 174.03443994569227`}], 
        PointBox[{77.1, 176.94941784767948`}], 
        PointBox[{77.2, 175.95091498141286`}], 
        PointBox[{77.3, 174.15553991773996`}], 
        PointBox[{77.4, 175.0929555317088}], 
        PointBox[{77.5, 175.96558608823463`}], 
        PointBox[{77.6, 171.8946286756911}], 
        PointBox[{77.7, 170.76595062627828`}], 
        PointBox[{77.8, 171.9551229369429}], 
        PointBox[{77.9, 171.06671184497952`}], 
        PointBox[{78., 169.56858683718252`}], 
        PointBox[{78.1, 172.26344042251776`}], 
        PointBox[{78.2, 171.79568841966025`}], 
        PointBox[{78.3, 169.8936600598572}], 
        PointBox[{78.4, 170.42912312986041`}], 
        PointBox[{78.5, 171.79821076768872`}], 
        PointBox[{78.6, 168.6004691109152}], 
        PointBox[{78.7, 167.04858454692268`}], 
        PointBox[{78.8, 168.18101095863807`}], 
        PointBox[{78.9, 167.77700975529282`}], 
        PointBox[{79., 166.0849864288339}], 
        PointBox[{79.1, 168.41681225547464`}], 
        PointBox[{79.2, 168.4153402699086}], 
        PointBox[{79.3, 166.53489449486676`}], 
        PointBox[{79.4, 166.70077628210768`}], 
        PointBox[{79.5, 168.29860465161963`}], 
        PointBox[{79.6, 165.84292703231912`}], 
        PointBox[{79.7, 164.21819297813306`}], 
        PointBox[{79.8, 165.20602142781686`}], 
        PointBox[{79.9, 165.18887357003535`}], 
        PointBox[{80., 163.487194085626}], 
        PointBox[{80.1, 165.40119908282145`}], 
        PointBox[{80.2, 165.7579817056888}], 
        PointBox[{80.3, 163.98009741217746`}], 
        PointBox[{80.4, 163.8592761873227}], 
        PointBox[{80.5, 165.49435344942762`}], 
        PointBox[{80.6, 163.6210656477857}], 
        PointBox[{80.7, 162.1078584758165}], 
        PointBox[{80.8, 162.92790889409957`}], 
        PointBox[{80.9, 163.17748846567238`}], 
        PointBox[{81., 161.5837086968473}], 
        PointBox[{81.1, 163.11151442505056`}], 
        PointBox[{81.2, 163.6994724890833}], 
        PointBox[{81.3, 162.05794042919237`}], 
        PointBox[{81.4, 161.75124235432412`}], 
        PointBox[{81.5, 163.31728369624065`}], 
        PointBox[{81.6, 161.87121672621063`}], 
        PointBox[{81.7, 160.51303025637517`}], 
        PointBox[{81.8, 161.19452915915997`}], 
        PointBox[{81.9, 161.59707708031013`}], 
        PointBox[{82., 160.15211087814882`}], 
        PointBox[{82.1, 161.39221882724445`}], 
        PointBox[{82.2, 162.0816613981359}], 
        PointBox[{82.3, 160.57556835272308`}], 
        PointBox[{82.4, 160.18035446149534`}], 
        PointBox[{82.5, 161.6425131352029}], 
        PointBox[{82.6, 160.45963244630695`}], 
        PointBox[{82.7, 159.24261346952335`}], 
        PointBox[{82.8, 159.8380841404448}], 
        PointBox[{82.9, 160.29788848085082`}], 
        PointBox[{83., 158.98347663887108`}], 
        PointBox[{83.1, 160.07332739944874`}], 
        PointBox[{83.2, 160.7388976951412}], 
        PointBox[{83.3, 159.3497973776915}], 
        PointBox[{83.4, 158.94903934194028`}], 
        PointBox[{83.5, 160.31996514764649`}], 
        PointBox[{83.6, 159.2302669637581}], 
        PointBox[{83.7, 158.13718174656623`}], 
        PointBox[{83.8, 158.69882082208767`}], 
        PointBox[{83.9, 159.1387197045861}], 
        PointBox[{84., 157.90502097185623`}], 
        PointBox[{84.1, 158.99530701323457`}], 
        PointBox[{84.2, 159.51549978791138`}], 
        PointBox[{84.3, 158.2248413594793}], 
        PointBox[{84.4, 157.8875760539209}], 
        PointBox[{84.5, 159.19756536494333`}], 
        PointBox[{84.6, 158.03784494263985`}], 
        PointBox[{84.7, 157.07336309086682`}], 
        PointBox[{84.8, 157.6421371512803}], 
        PointBox[{84.9, 157.9968718430452}], 
        PointBox[{85., 156.79323096110747`}], 
        PointBox[{85.1, 158.02291293001633`}], 
        PointBox[{85.2, 158.2807852152382}], 
        PointBox[{85.3, 157.08427015034616`}], 
        PointBox[{85.4, 156.86981824355985`}], 
        PointBox[{85.5, 158.13802294785037`}], 
        PointBox[{85.6, 156.77190643341126`}], 
        PointBox[{85.7, 155.97189397071958`}], 
        PointBox[{85.8, 156.5676483747792}], 
        PointBox[{85.9, 156.77562278130685`}], 
        PointBox[{86., 155.58534502522795`}], 
        PointBox[{86.1, 157.04318245938853`}], 
        PointBox[{86.2, 156.94236694684614`}], 
        PointBox[{86.3, 155.85802678802912`}], 
        PointBox[{86.4, 155.8204605241631}], 
        PointBox[{86.5, 157.01775960035846`}], 
        PointBox[{86.6, 155.36759286657409`}], 
        PointBox[{86.7, 154.80394538420123`}], 
        PointBox[{86.8, 155.4102196262619}], 
        PointBox[{86.9, 155.40835755730555`}], 
        PointBox[{87., 154.2931963761931}], 
        PointBox[{87.1, 155.9544456708464}], 
        PointBox[{87.2, 155.4566190060061}], 
        PointBox[{87.3, 154.52413088503968`}], 
        PointBox[{87.4, 154.71333078215426`}], 
        PointBox[{87.5, 155.71272532913025`}], 
        PointBox[{87.6, 153.79408666275063`}], 
        PointBox[{87.7, 153.57359238380306`}], 
        PointBox[{87.8, 154.13282105683342`}], 
        PointBox[{87.9, 153.85818584964613`}], 
        PointBox[{88., 153.00456939264689`}], 
        PointBox[{88.1, 154.66305889581935`}], 
        PointBox[{88.2, 153.82805935167391`}], 
        PointBox[{88.3, 153.09959129831864`}], 
        PointBox[{88.4, 153.55409970204232`}], 
        PointBox[{88.5, 154.08931802337253`}], 
        PointBox[{88.6, 152.09231462846878`}], 
        PointBox[{88.7, 152.28618894508756`}], 
        PointBox[{88.8, 152.71517317595507`}], 
        PointBox[{88.9, 152.12096590318154`}], 
        PointBox[{89., 151.83634106246535`}], 
        PointBox[{89.1, 153.1133087617246}], 
        PointBox[{89.2, 152.09846752146447`}], 
        PointBox[{89.3, 151.62691060873257`}], 
        PointBox[{89.4, 152.3511748770928}], 
        PointBox[{89.5, 152.0670581067927}], 
        PointBox[{89.6, 150.43271419596434`}], 
        PointBox[{89.7, 150.93304715242627`}], 
        PointBox[{89.8, 151.14445216446734`}], 
        PointBox[{89.9, 150.24182838405616`}], 
        PointBox[{90., 150.8019773663852}], 
        PointBox[{90.1, 151.32407392960957`}], 
        PointBox[{90.2, 150.32767563126902`}], 
        PointBox[{90.3, 150.15622112414172`}], 
        PointBox[{90.4, 151.06491189912552`}], 
        PointBox[{90.5, 149.7477072390423}], 
        PointBox[{90.6, 148.9185379011189}], 
        PointBox[{90.7, 149.4946514401725}], 
        PointBox[{90.8, 149.4120917825528}], 
        PointBox[{90.9, 148.35233165767698`}], 
        PointBox[{91., 149.70647644359138`}], 
        PointBox[{91.1, 149.3840124059502}], 
        PointBox[{91.2, 148.5751355103035}], 
        PointBox[{91.3, 148.72794930964258`}], 
        PointBox[{91.4, 149.5491798358802}], 
        PointBox[{91.5, 147.42668994373764`}], 
        PointBox[{91.6, 147.49897372036466`}], 
        PointBox[{91.7, 147.94976855678843`}], 
        PointBox[{91.8, 147.5223384195797}], 
        PointBox[{91.9, 146.67759883091412`}], 
        PointBox[{92., 148.29160791413423`}], 
        PointBox[{92.1, 147.40528195564124`}], 
        PointBox[{92.2, 146.8876225220209}], 
        PointBox[{92.3, 147.35136023349546`}], 
        PointBox[{92.4, 147.5687583791337}], 
        PointBox[{92.5, 145.45958204861475`}], 
        PointBox[{92.6, 146.08239501809243`}], 
        PointBox[{92.7, 146.28225366659254`}], 
        PointBox[{92.8, 145.51260087569653`}], 
        PointBox[{92.9, 145.39691925079399`}], 
        PointBox[{93., 146.5013194302425}], 
        PointBox[{93.1, 145.47869703342332`}], 
        PointBox[{93.2, 145.29229622460502`}], 
        PointBox[{93.3, 145.9767382041223}], 
        PointBox[{93.4, 145.0731862368105}], 
        PointBox[{93.5, 143.88570504883404`}], 
        PointBox[{93.6, 144.6029147796072}], 
        PointBox[{93.7, 144.48809422053816`}], 
        PointBox[{93.8, 143.4873011523182}], 
        PointBox[{93.9, 144.3713038962237}], 
        PointBox[{94., 144.4958913924067}], 
        PointBox[{94.1, 143.65817714576832`}], 
        PointBox[{94.2, 143.79325125984016`}], 
        PointBox[{94.3, 144.46271231220106`}], 
        PointBox[{94.4, 142.5065000896772}], 
        PointBox[{94.5, 142.49939262608714`}], 
        PointBox[{94.6, 143.03057519576686`}], 
        PointBox[{94.7, 142.5835868742159}], 
        PointBox[{94.8, 141.62774872787514`}], 
        PointBox[{94.9, 143.1849297562972}], 
        PointBox[{95., 142.4721649243464}], 
        PointBox[{95.1, 141.96477059162837`}], 
        PointBox[{95.2, 142.36676309637366`}], 
        PointBox[{95.3, 142.6013361279499}], 
        PointBox[{95.4, 140.3954300471377}], 
        PointBox[{95.5, 141.13525725566524`}], 
        PointBox[{95.6, 141.36540578330468`}], 
        PointBox[{95.7, 140.61540273317829`}], 
        PointBox[{95.8, 140.11511188040248`}], 
        PointBox[{95.9, 141.60622234293277`}], 
        PointBox[{96., 140.553839318071}], 
        PointBox[{96.1, 140.3973459718501}], 
        PointBox[{96.2, 140.95612156109638`}], 
        PointBox[{96.3, 140.35420232758264`}], 
        PointBox[{96.4, 138.79315971806435`}], 
        PointBox[{96.5, 139.7265662655157}], 
        PointBox[{96.6, 139.63169909845485`}], 
        PointBox[{96.7, 138.66597962413502`}], 
        PointBox[{96.8, 138.9564378998321}], 
        PointBox[{96.9, 139.75930895652616`}], 
        PointBox[{97., 138.79060426246866`}], 
        PointBox[{97.1, 138.94178351564125`}], 
        PointBox[{97.2, 139.47607087574508`}], 
        PointBox[{97.3, 138.0299438546229}], 
        PointBox[{97.4, 137.47550534448615`}], 
        PointBox[{97.5, 138.27427123630594`}], 
        PointBox[{97.6, 137.8734662168565}], 
        PointBox[{97.7, 136.84149749876318`}], 
        PointBox[{97.8, 137.9345677743055}], 
        PointBox[{97.9, 137.87803196456534`}], 
        PointBox[{98., 137.1914350102682}], 
        PointBox[{98.1, 137.57841318065277`}], 
        PointBox[{98.2, 137.86512606463646`}], 
        PointBox[{98.3, 135.93860033015505`}], 
        PointBox[{98.4, 136.27000248028156`}], 
        PointBox[{98.5, 136.8151103112666}], 
        PointBox[{98.6, 136.1483150167112}], 
        PointBox[{98.7, 135.23640977672977`}], 
        PointBox[{98.8, 136.8254412288604}], 
        PointBox[{98.9, 136.11750122805066`}], 
        PointBox[{99., 135.7492987263577}], 
        PointBox[{99.1, 136.28853752092994`}], 
        PointBox[{99.2, 136.18806679784947`}], 
        PointBox[{99.3, 134.2280317252239}], 
        PointBox[{99.4, 135.11666008660066`}], 
        PointBox[{99.5, 135.39860050887393`}], 
        PointBox[{99.6, 134.515736159439}], 
        PointBox[{99.7, 133.8857430808062}], 
        PointBox[{99.8, 135.5930665203692}], 
        PointBox[{99.9, 134.53963497637093`}], 
        PointBox[{100., 134.45165442437795`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 360}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
        40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {0, -180}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
        PointBox[{0.1, 4.708959391589076}], 
        PointBox[{0.2, 4.1056018828487595`}], 
        PointBox[{0.3, 5.081084121166441}], 
        PointBox[{0.4, 8.439721564535489}], 
        PointBox[{0.5, 8.238564563747104}], 
        PointBox[{0.6, 7.409301150528677}], 
        PointBox[{0.7, 10.743050888478535`}], 
        PointBox[{0.8, 12.241720777719138`}], 
        PointBox[{0.9, 11.44569249760275}], 
        PointBox[{1., 14.766034903911645`}], 
        PointBox[{1.1, 20.419955503903793`}], 
        PointBox[{1.2, 20.257091203512914`}], 
        PointBox[{1.3, 20.719642760988904`}], 
        PointBox[{1.4, 23.846419589219863`}], 
        PointBox[{1.5, 24.32766594892223}], 
        PointBox[{1.6, 23.004107756771532`}], 
        PointBox[{1.7, 26.075032743037127`}], 
        PointBox[{1.8, 28.022067450012855`}], 
        PointBox[{1.9, 27.26337640012548}], PointBox[{2., 29.2097531302976}], 
        PointBox[{2.1, 35.02549706170612}], 
        PointBox[{2.2, 35.49787197949672}], 
        PointBox[{2.3, 35.53256427539918}], 
        PointBox[{2.4, 38.210708731248815`}], 
        PointBox[{2.5, 39.32499799915513}], 
        PointBox[{2.6, 37.680943081965324`}], 
        PointBox[{2.7, 40.317193976501585`}], 
        PointBox[{2.8, 42.57043874275519}], 
        PointBox[{2.9, 42.01222886658911}], 
        PointBox[{3., 42.826034829427044`}], 
        PointBox[{3.1, 48.11944883788988}], 
        PointBox[{3.2, 49.271871146446756`}], 
        PointBox[{3.3, 49.00404584363605}], 
        PointBox[{3.4, 51.10316271245392}], 
        PointBox[{3.5, 52.70127587529714}], 
        PointBox[{3.6, 50.90979505126188}], 
        PointBox[{3.7, 53.02344932492724}], 
        PointBox[{3.8, 55.411057313320725`}], 
        PointBox[{3.9, 55.12421661758435}], PointBox[{4., 55.09568038562975}],
         PointBox[{4.1, 59.558293475331084`}], 
        PointBox[{4.2, 61.21180977543372}], 
        PointBox[{4.3, 60.76616993014795}], 
        PointBox[{4.4, 62.253704129970174`}], 
        PointBox[{4.5, 64.1250358736761}], PointBox[{4.6, 62.32179295111837}],
         PointBox[{4.7, 63.9016990793225}], 
        PointBox[{4.8, 66.26122016105319}], 
        PointBox[{4.9, 66.22681559310786}], PointBox[{5., 65.62146918538292}],
         PointBox[{5.1, 69.27351303234218}], 
        PointBox[{5.2, 71.10785889553563}], 
        PointBox[{5.3, 70.57424165047223}], 
        PointBox[{5.4, 71.49509738897268}], 
        PointBox[{5.5, 73.42247692953288}], 
        PointBox[{5.6, 71.68058436025603}], PointBox[{5.7, 72.7721276618945}],
         PointBox[{5.8, 74.97557776649228}], 
        PointBox[{5.9, 75.1092084560205}], PointBox[{6., 74.13321994178523}], 
        PointBox[{6.1, 77.10815374376443}], 
        PointBox[{6.2, 78.85311022492488}], 
        PointBox[{6.3, 78.26839962173881}], 
        PointBox[{6.4, 78.70948668236178}], 
        PointBox[{6.5, 80.51741756281854}], 
        PointBox[{6.6, 78.83861358943523}], 
        PointBox[{6.7, 79.52245074584243}], 
        PointBox[{6.8, 81.48312494747734}], 
        PointBox[{6.9, 81.66802155611185}], PointBox[{7., 80.45363213682776}],
         PointBox[{7.1, 82.88238627626197}], 
        PointBox[{7.2, 84.39397947882208}], 
        PointBox[{7.3, 83.74306448638345}], 
        PointBox[{7.4, 83.80125102538022}], 
        PointBox[{7.5, 85.37922913288367}], 
        PointBox[{7.6, 83.70349962768432}], 
        PointBox[{7.7, 84.07796447569763}], PointBox[{7.8, 85.7441846238662}],
         PointBox[{7.9, 85.85784190953746}], PointBox[{8., 84.4702748802465}],
         PointBox[{8.1, 86.47619478004071}], 
        PointBox[{8.2, 87.6931760406078}], PointBox[{8.3, 86.92619736457073}],
         PointBox[{8.4, 86.69184466962543}], 
        PointBox[{8.5, 87.98696771684172}], PointBox[{8.6, 86.2166230638868}],
         PointBox[{8.7, 86.38688268449187}], 
        PointBox[{8.8, 87.72885366066112}], 
        PointBox[{8.9, 87.65860605098169}], PointBox[{9., 86.12074913534616}],
         PointBox[{9.1, 87.82716994547627}], 
        PointBox[{9.2, 88.71284473562628}], 
        PointBox[{9.3, 87.77051445817142}], PointBox[{9.4, 87.3238280478945}],
         PointBox[{9.5, 88.31858428058513}], 
        PointBox[{9.6, 86.35252815412059}], 
        PointBox[{9.7, 86.42101323976749}], 
        PointBox[{9.8, 87.41725825433059}], 
        PointBox[{9.9, 87.06585384508799}], 
        PointBox[{10., 85.39305986788622}], 
        PointBox[{10.1, 86.91487989448524}], 
        PointBox[{10.2, 87.41813923015343}], 
        PointBox[{10.3, 86.25706629023534}], 
        PointBox[{10.4, 85.67457303548508}], 
        PointBox[{10.5, 86.34822953452931}], 
        PointBox[{10.6, 84.12689588901776}], 
        PointBox[{10.7, 84.17888271191077}], 
        PointBox[{10.8, 84.80594206170463}], 
        PointBox[{10.9, 84.09353308183927}], 
        PointBox[{11., 82.33580921641533}], 
        PointBox[{11.1, 83.76000196389214}], 
        PointBox[{11.2, 83.79225516257884}], 
        PointBox[{11.3, 82.40775368248069}], 
        PointBox[{11.4, 81.7700177434208}], 
        PointBox[{11.5, 82.05665376034995}], 
        PointBox[{11.6, 79.61605590186173}], 
        PointBox[{11.7, 79.69562837760805}], 
        PointBox[{11.8, 79.9236966906019}], 
        PointBox[{11.9, 78.78740191070574}], 
        PointBox[{12., 77.0796176486192}], 
        PointBox[{12.1, 78.42976613198152}], 
        PointBox[{12.2, 77.86714964512976}], 
        PointBox[{12.3, 76.30649750644443}], 
        PointBox[{12.4, 75.6999670254645}], 
        PointBox[{12.5, 75.45000897833779}], 
        PointBox[{12.6, 72.96974553918335}], 
        PointBox[{12.7, 73.05421875481625}], 
        PointBox[{12.8, 72.8492137072135}], 
        PointBox[{12.9, 71.2504715206087}], 
        PointBox[{13., 69.84581861246988}], 
        PointBox[{13.1, 70.99003332390384}], 
        PointBox[{13.2, 69.7611080024617}], 
        PointBox[{13.3, 68.11745546709062}], 
        PointBox[{13.4, 67.62055314738427}], 
        PointBox[{13.5, 66.6073937074907}], 
        PointBox[{13.6, 64.39793234742865}], 
        PointBox[{13.7, 64.39374774476892}], 
        PointBox[{13.8, 63.723676414465444`}], 
        PointBox[{13.9, 61.670191902145234`}], 
        PointBox[{14., 60.898029949396005`}], 
        PointBox[{14.1, 61.47554776488505}], 
        PointBox[{14.2, 59.69652155840413}], 
        PointBox[{14.3, 58.09001194695338}], 
        PointBox[{14.4, 57.72951039023246}], 
        PointBox[{14.5, 55.775651019041106`}], 
        PointBox[{14.6, 54.13943835999453}], 
        PointBox[{14.7, 53.914756785738064`}], 
        PointBox[{14.8, 52.75713880432522}], 
        PointBox[{14.9, 50.35802414885802}], 
        PointBox[{15., 50.44758564741824}], 
        PointBox[{15.1, 50.05676562429289}], 
        PointBox[{15.2, 47.98902527967766}], 
        PointBox[{15.3, 46.54464284221285}], 
        PointBox[{15.4, 46.21321869397798}], 
        PointBox[{15.5, 43.426590288449006`}], 
        PointBox[{15.6, 42.44034041917985}], 
        PointBox[{15.7, 41.87563185976251}], 
        PointBox[{15.8, 40.227856487228564`}], 
        PointBox[{15.9, 37.78943159629125}], 
        PointBox[{16., 38.59648807057965}], 
        PointBox[{16.1, 37.11206136912551}], 
        PointBox[{16.2, 35.017077231579606`}], 
        PointBox[{16.3, 33.842794058900836`}], 
        PointBox[{16.4, 33.212919212419365`}], 
        PointBox[{16.5, 30.127320110666915`}], 
        PointBox[{16.6, 29.562452405551085`}], 
        PointBox[{16.7, 28.585161129893095`}], 
        PointBox[{16.8, 26.484114741682788`}], 
        PointBox[{16.9, 24.579417354598263`}], 
        PointBox[{17., 25.339346991344428`}], 
        PointBox[{17.1, 23.11469577592652}], 
        PointBox[{17.2, 21.189962233902406`}], 
        PointBox[{17.3, 20.3411010392374}], 
        PointBox[{17.4, 18.93414919483621}], 
        PointBox[{17.5, 16.30878607831619}], 
        PointBox[{17.6, 15.799158510551933`}], 
        PointBox[{17.7, 14.392638660456214`}], 
        PointBox[{17.8, 11.95945898260834}], 
        PointBox[{17.9, 11.21981874989433}], 
        PointBox[{18., 10.97560504097055}], 
        PointBox[{18.1, 8.542278519633328}], 
        PointBox[{18.2, 6.921095547642835}], 
        PointBox[{18.3, 6.336283303793607}], 
        PointBox[{18.4, 3.9003004885671544`}], 
        PointBox[{18.5, 2.223838769918075}], 
        PointBox[{18.6, 1.4852396372534713`}], 
        PointBox[{18.7, -0.3156273861586669}], 
        PointBox[{18.8, -2.7921407824687776`}], 
        PointBox[{18.9, -2.3171835822431603`}], 
        PointBox[{19., -3.883840723465255}], 
        PointBox[{19.1, -6.15388097471623}], 
        PointBox[{19.2, -7.3923851385170565`}], 
        PointBox[{19.3, -7.9649609902280645`}], 
        PointBox[{19.4, -11.077076595456674`}], 
        PointBox[{19.5, -11.916934111588489`}], 
        PointBox[{19.6, -13.00715349190068}], 
        PointBox[{19.7, -15.113928113134534`}], 
        PointBox[{19.8, -17.102080622760695`}], 
        PointBox[{19.9, -16.259967121293812`}], 
        PointBox[{20., -18.640441085346538`}], 
        PointBox[{20.1, -20.55340533441631}], 
        PointBox[{20.2, -21.38829455064115}], 
        PointBox[{20.3, -22.373727884618347`}], 
        PointBox[{20.4, -25.35745482585844}], 
        PointBox[{20.5, -25.840797317603574`}], 
        PointBox[{20.6, -27.276412455918035`}], 
        PointBox[{20.7, -29.528034265898896`}], 
        PointBox[{20.8, -30.428214777733956`}], 
        PointBox[{20.9, -30.274791972164167`}], 
        PointBox[{21., -32.79600719828704}], 
        PointBox[{21.1, -34.266813298530906`}], 
        PointBox[{21.2, -34.75205903362439}], 
        PointBox[{21.3, -36.51054999875487}], 
        PointBox[{21.4, -38.66700835233496}], 
        PointBox[{21.5, -39.2022061581647}], 
        PointBox[{21.6, -40.901194532481895`}], 
        PointBox[{21.7, -43.032566622081504`}], 
        PointBox[{21.8, -42.73387892462597}], 
        PointBox[{21.9, -43.69009880133672}], 
        PointBox[{22., -45.93426394052585}], 
        PointBox[{22.1, -46.93614505971345}], 
        PointBox[{22.2, -47.217004209804145`}], 
        PointBox[{22.3, -49.71945871947901}], 
        PointBox[{22.4, -50.85663415501767}], 
        PointBox[{22.5, -51.615051445805875`}], 
        PointBox[{22.6, -53.452620019008464`}], 
        PointBox[{22.7, -55.10074078341495}], 
        PointBox[{22.8, -54.10273258151028}], 
        PointBox[{22.9, -55.909085330151356`}], 
        PointBox[{23., -57.69871913024508}], 
        PointBox[{23.1, -58.24003134337727}], 
        PointBox[{23.2, -58.52891336488756}], 
        PointBox[{23.3, -61.34648033933445}], 
        PointBox[{23.4, -61.712455354219856`}], 
        PointBox[{23.5, -62.691262566568184`}], 
        PointBox[{23.6, -64.51617286890541}], 
        PointBox[{23.7, -65.37817013897802}], 
        PointBox[{23.8, -64.33394269405835}], 
        PointBox[{23.9, -66.49963921830931}], 
        PointBox[{24., -67.78663774744564}], 
        PointBox[{24.1, -67.90061037740088}], 
        PointBox[{24.2, -68.39725545401961}], 
        PointBox[{24.3, -71.01609494216609}], 
        PointBox[{24.4, -70.95710381293247}], 
        PointBox[{24.5, -72.0757050206048}], 
        PointBox[{24.6, -73.72716556259547}], 
        PointBox[{24.7, -73.78154699525112}], 
        PointBox[{24.8, -73.02093687851448}], 
        PointBox[{24.9, -75.15988268256478}], 
        PointBox[{25., -75.95281669878386}], 
        PointBox[{25.1, -75.68788049689829}], 
        PointBox[{25.2, -76.48676840537883}], 
        PointBox[{25.3, -78.58108562370762}], 
        PointBox[{25.4, -78.31584439724975}], 
        PointBox[{25.5, -79.47646318912302}], 
        PointBox[{25.6, -80.81650998077384}], 
        PointBox[{25.7, -80.22047224375274}], 
        PointBox[{25.8, -79.76718488186452}], 
        PointBox[{25.9, -81.68566172410283}], 
        PointBox[{26., -82.01697931310264}], 
        PointBox[{26.1, -81.42249609447026}], 
        PointBox[{26.2, -82.48795214097117}], 
        PointBox[{26.3, -83.97223711917468}], 
        PointBox[{26.4, -83.56959042137532}], 
        PointBox[{26.5, -84.6861462629895}], 
        PointBox[{26.6, -85.64331521353597}], 
        PointBox[{26.7, -84.55556997090025}], 
        PointBox[{26.8, -84.30345019892775}], 
        PointBox[{26.9, -85.95074499534894}], 
        PointBox[{27., -85.86488879004901}], 
        PointBox[{27.1, -84.97515755120912}], 
        PointBox[{27.2, -86.19379044232846}], 
        PointBox[{27.3, -87.14185011472364}], 
        PointBox[{27.4, -86.57697851409102}], 
        PointBox[{27.5, -87.58590693524093}], 
        PointBox[{27.6, -88.17363067052429}], 
        PointBox[{27.7, -86.69634798711559}], 
        PointBox[{27.8, -86.48461808755019}], 
        PointBox[{27.9, -87.89034935467498}], 
        PointBox[{28., -87.44081401761287}], 
        PointBox[{28.1, -86.26581273860938}], 
        PointBox[{28.2, -87.51142121564044}], 
        PointBox[{28.3, -88.06677937953282}], 
        PointBox[{28.4, -87.27233162237462}], 
        PointBox[{28.5, -88.13041014626651}], 
        PointBox[{28.6, -88.420901000296}], 
        PointBox[{28.7, -86.59424454161854}], 
        PointBox[{28.8, -86.2485754496629}], 
        PointBox[{28.9, -87.48164387792349}], 
        PointBox[{29., -86.73257745345109}], 
        PointBox[{29.1, -85.25965879292562}], 
        PointBox[{29.2, -86.42414134636783}], 
        PointBox[{29.3, -86.75313179105433}], 
        PointBox[{29.4, -85.64947398118238}], 
        PointBox[{29.5, -86.3223559460057}], 
        PointBox[{29.6, -86.4154800285105}], 
        PointBox[{29.7, -84.23762562838965}], 
        PointBox[{29.8, -83.58396747012375}], 
        PointBox[{29.9, -84.72512670419019}], 
        PointBox[{30., -83.7561274564141}], 
        PointBox[{30.1, -81.96100877624849}], 
        PointBox[{30.2, -82.95161407779233}], 
        PointBox[{30.3, -83.22895686454285}], 
        PointBox[{30.4, -81.74497017716203}], 
        PointBox[{30.5, -82.19155190756283}], 
        PointBox[{30.6, -82.2034174914661}], 
        PointBox[{30.7, -79.6519791719511}], 
        PointBox[{30.8, -78.5146829543628}], 
        PointBox[{30.9, -79.63251861147}], 
        PointBox[{31., -78.54368561944284}], 
        PointBox[{31.1, -76.40622565629383}], 
        PointBox[{31.2, -77.13091546380747}], 
        PointBox[{31.3, -77.53112848179808}], 
        PointBox[{31.4, -75.6265496678534}], 
        PointBox[{31.5, -75.7848109767765}], 
        PointBox[{31.6, -75.83944636682281}], 
        PointBox[{31.7, -72.90213398713604}], 
        PointBox[{31.8, -71.10184779010524}], 
        PointBox[{31.9, -72.2251407259646}], 
        PointBox[{32., -71.13893460044346}], 
        PointBox[{32.1, -68.66118197119431}], 
        PointBox[{32.2, -69.0188905904688}], 
        PointBox[{32.3, -69.6969361980191}], 
        PointBox[{32.4, -67.38910362016395}], 
        PointBox[{32.5, -67.17091247296412}], 
        PointBox[{32.6, -67.36771454415066}], 
        PointBox[{32.7, -64.10322697281663}], 
        PointBox[{32.8, -61.46032084773833}], 
        PointBox[{32.9, -62.549619572255324`}], 
        PointBox[{33., -61.60352125175996}], 
        PointBox[{33.1, -58.82810969740967}], 
        PointBox[{33.2, -58.71089865891554}], 
        PointBox[{33.3, -59.77117542756969}], 
        PointBox[{33.4, -57.158507286556414`}], 
        PointBox[{33.5, -56.45866111771102}], 
        PointBox[{33.6, -56.82708204373557}], 
        PointBox[{33.7, -53.455221544008964`}], 
        PointBox[{33.8, -49.78886957485156}], 
        PointBox[{33.9, -50.714751177703874`}], 
        PointBox[{34., -50.03967971891689}], 
        PointBox[{34.1, -47.06381440138284}], 
        PointBox[{34.2, -46.37268269309425}], 
        PointBox[{34.3, -47.83846798737068}], 
        PointBox[{34.4, -45.1048525998267}], 
        PointBox[{34.5, -43.82693572898279}], 
        PointBox[{34.6, -44.30899834701631}], 
        PointBox[{34.7, -41.259687952915556`}], 
        PointBox[{34.8, -36.40744791699399}], 
        PointBox[{34.9, -36.94772741794077}], 
        PointBox[{35., -36.63607174819481}], 
        PointBox[{35.1, -33.615733768241626`}], 
        PointBox[{35.2, -32.284986298025615`}], 
        PointBox[{35.3, -34.08416466318522}], 
        PointBox[{35.4, -31.472152655969694`}], 
        PointBox[{35.5, -29.566748514855135`}], 
        PointBox[{35.6, -30.033952068770304`}], 
        PointBox[{35.7, -27.80018774538621}], 
        PointBox[{35.8, -21.793973243529763`}], 
        PointBox[{35.9, -21.65519486505218}], 
        PointBox[{36., -21.727987758404197`}], 
        PointBox[{36.1, -18.86237956289915}], 
        PointBox[{36.2, -16.88877734394191}], 
        PointBox[{36.3, -18.863660748669645`}], 
        PointBox[{36.4, -16.620852889984235`}], 
        PointBox[{36.5, -14.121797666943166`}], 
        PointBox[{36.6, -14.413113154721941`}], 
        PointBox[{36.7, -13.233578914925602`}], 
        PointBox[{36.8, -6.5785330471953785`}], 
        PointBox[{36.9, -5.448212420353229}], 
        PointBox[{37., -5.839253766891488}], 
        PointBox[{37.1, -3.3334017012020922`}], 
        PointBox[{37.2, -0.7993195038434351}], 
        PointBox[{37.3, -2.7387918921704113`}], 
        PointBox[{37.4, -1.059385603723058}], 
        PointBox[{37.5, 1.9029719317913987`}], 
        PointBox[{37.6, 1.9367092492211668`}], 
        PointBox[{37.7, 2.1567770705078146`}], 
        PointBox[{37.8, 8.566072772271582}], 
        PointBox[{37.9, 10.913004443955288`}], 
        PointBox[{38., 10.34699864524373}], 
        PointBox[{38.1, 12.331840673879924`}], 
        PointBox[{38.2, 15.252068759582471`}], 
        PointBox[{38.3, 13.569132898122916`}], 
        PointBox[{38.4, 14.580762211477122`}], 
        PointBox[{38.5, 17.80160562381934}], 
        PointBox[{38.6, 18.25576591614299}], 
        PointBox[{38.7, 17.784160732335295`}], 
        PointBox[{38.8, 23.146156079117645`}], 
        PointBox[{38.9, 26.652487064977322`}], 
        PointBox[{39., 26.097033042860858`}], 
        PointBox[{39.1, 27.48220395511089}], 
        PointBox[{39.2, 30.546404389984673`}], 
        PointBox[{39.3, 29.302958250806114`}], 
        PointBox[{39.4, 29.638187784690672`}], 
        PointBox[{39.5, 32.887723662584904`}], 
        PointBox[{39.6, 33.77725586709494}], 
        PointBox[{39.7, 32.91425023263946}], 
        PointBox[{39.8, 36.920190713335614`}], 
        PointBox[{39.9, 41.126227437322086`}], 
        PointBox[{40., 40.76181570577319}], 
        PointBox[{40.1, 41.56050608872101}], 
        PointBox[{40.2, 44.508703605599294`}], 
        PointBox[{40.3, 43.80776626326406}], 
        PointBox[{40.4, 43.53354266176757}], 
        PointBox[{40.5, 46.60933311527697}], 
        PointBox[{40.6, 47.867224498339056`}], 
        PointBox[{40.7, 46.86922710681756}], 
        PointBox[{40.8, 49.606731919811864`}], 
        PointBox[{40.9, 53.90448265860323}], 
        PointBox[{41., 53.85414450599637}], 
        PointBox[{41.1, 54.14835719943221}], 
        PointBox[{41.2, 56.7622408063944}], 
        PointBox[{41.3, 56.60438405377499}], 
        PointBox[{41.4, 55.832341884684865`}], 
        PointBox[{41.5, 58.59304356098073}], 
        PointBox[{41.6, 60.09385680848209}], 
        PointBox[{41.7, 59.13267812961931}], 
        PointBox[{41.8, 60.808092730621865`}], 
        PointBox[{41.9, 64.773712250877}], PointBox[{42., 65.05466783096199}],
         PointBox[{42.1, 64.95586343168179}], 
        PointBox[{42.2, 67.10110095044365}], 
        PointBox[{42.3, 67.39030069537694}], 
        PointBox[{42.4, 66.24400585806507}], 
        PointBox[{42.5, 68.61785779154525}], 
        PointBox[{42.6, 70.2141162527987}], PointBox[{42.7, 69.363504149871}],
         PointBox[{42.8, 70.19592362814001}], 
        PointBox[{42.9, 73.66383269320795}], 
        PointBox[{43., 74.17327697343353}], 
        PointBox[{43.1, 73.7855213476978}], 
        PointBox[{43.2, 75.4194463261374}], 
        PointBox[{43.3, 75.99432293211794}], 
        PointBox[{43.4, 74.58206683376193}], 
        PointBox[{43.5, 76.55663837999964}], 
        PointBox[{43.6, 78.10870237720883}], 
        PointBox[{43.7, 77.35735928756912}], 
        PointBox[{43.8, 77.55536060764643}], 
        PointBox[{43.9, 80.53193984694008}], 
        PointBox[{44., 81.0992848788228}], 
        PointBox[{44.1, 80.49667513369059}], 
        PointBox[{44.2, 81.64968041177053}], 
        PointBox[{44.3, 82.32668760652086}], 
        PointBox[{44.4, 80.72712818218861}], 
        PointBox[{44.5, 82.33197036339334}], 
        PointBox[{44.6, 83.72539959296046}], 
        PointBox[{44.7, 83.00395910324005}], 
        PointBox[{44.8, 82.7520233914911}], 
        PointBox[{44.9, 85.30217743190951}], 
        PointBox[{45., 85.76789393429135}], 
        PointBox[{45.1, 84.9894619394654}], 
        PointBox[{45.2, 85.7345699882062}], 
        PointBox[{45.3, 86.34078312444399}], 
        PointBox[{45.4, 84.60286885871028}], 
        PointBox[{45.5, 85.89033738798389}], 
        PointBox[{45.6, 87.03825119775138}], 
        PointBox[{45.7, 86.24850604558378}], 
        PointBox[{45.8, 85.70308858283533}], 
        PointBox[{45.9, 87.88853118771658}], 
        PointBox[{46., 88.13467298868636}], 
        PointBox[{46.1, 87.1931545415573}], PointBox[{46.2, 87.621563830784}],
         PointBox[{46.3, 88.0054728688483}], 
        PointBox[{46.4, 86.16592915978981}], 
        PointBox[{46.5, 87.19299540638895}], 
        PointBox[{46.6, 88.03028789920063}], 
        PointBox[{46.7, 87.06883796270995}], 
        PointBox[{46.8, 86.37071419984568}], 
        PointBox[{46.9, 88.23503576411167}], 
        PointBox[{47., 88.16613997840614}], 
        PointBox[{47.1, 87.06590378731926}], 
        PointBox[{47.2, 87.27269181630982}], 
        PointBox[{47.3, 87.29330554382614}], 
        PointBox[{47.4, 85.40755500528758}], 
        PointBox[{47.5, 86.21841854814556}], 
        PointBox[{47.6, 86.69347369629395}], 
        PointBox[{47.7, 85.4667387179652}], 
        PointBox[{47.8, 84.76695338569698}], 
        PointBox[{47.9, 86.32375945066451}], 
        PointBox[{48., 85.84571507307555}], 
        PointBox[{48.1, 84.60267905056389}], 
        PointBox[{48.2, 84.67916889396292}], 
        PointBox[{48.3, 84.18798587327183}], 
        PointBox[{48.4, 82.3615332536283}], 
        PointBox[{48.5, 82.9713986019633}], 
        PointBox[{48.6, 83.03999493285664}], 
        PointBox[{48.7, 81.4779105732232}], 
        PointBox[{48.8, 80.95867612092843}], 
        PointBox[{48.9, 82.15723542084015}], 
        PointBox[{49., 81.19595081483567}], 
        PointBox[{49.1, 79.85276738197717}], 
        PointBox[{49.2, 79.87589158407354}], 
        PointBox[{49.3, 78.71781249122432}], 
        PointBox[{49.4, 77.11216041820444}], 
        PointBox[{49.5, 77.49751744839159}], 
        PointBox[{49.6, 77.12014570874453}], 
        PointBox[{49.7, 75.1958976876922}], 
        PointBox[{49.8, 75.05686723106191}], 
        PointBox[{49.9, 75.74133892944519}], 
        PointBox[{50., 74.30669624809525}], 
        PointBox[{50.1, 72.93750538244785}], 
        PointBox[{50.2, 72.94166019432305}], 
        PointBox[{50.3, 71.01335317850317}], 
        PointBox[{50.4, 69.79392188493512}], 
        PointBox[{50.5, 69.89709091882105}], 
        PointBox[{50.6, 69.03981750179082}], 
        PointBox[{50.7, 66.81121081641322}], 
        PointBox[{50.8, 67.19708784046816}], 
        PointBox[{50.9, 67.1405077071613}], 
        PointBox[{51., 65.35742545192625}], 
        PointBox[{51.1, 64.06113180870307}], 
        PointBox[{51.2, 63.97962312322488}], 
        PointBox[{51.3, 61.35765130716027}], 
        PointBox[{51.4, 60.585418238537386`}], 
        PointBox[{51.5, 60.33420289341302}], 
        PointBox[{51.6, 58.97471906667488}], 
        PointBox[{51.7, 56.65496051017544}], 
        PointBox[{51.8, 57.5365079459516}], 
        PointBox[{51.9, 56.559841701280675`}], 
        PointBox[{52., 54.6178390278219}], 
        PointBox[{52.1, 53.50088000026153}], 
        PointBox[{52.2, 53.092876299364434`}], 
        PointBox[{52.3, 50.15162898696144}], 
        PointBox[{52.4, 49.704846962522424`}], 
        PointBox[{52.5, 49.03735564449744}], 
        PointBox[{52.6, 47.177745915389096`}], 
        PointBox[{52.7, 45.20451984160172}], 
        PointBox[{52.8, 46.1558469636293}], 
        PointBox[{52.9, 44.343113065871876`}], 
        PointBox[{53., 42.43086725815374}], 
        PointBox[{53.1, 41.57538922286767}], 
        PointBox[{53.2, 40.44046729360707}], 
        PointBox[{53.3, 37.78933113334642}], 
        PointBox[{53.4, 37.411091020207095`}], 
        PointBox[{53.5, 36.292721155739855`}], 
        PointBox[{53.6, 33.99567865672725}], 
        PointBox[{53.7, 32.93870110135322}], 
        PointBox[{53.8, 33.16663319307554}], 
        PointBox[{53.9, 30.909137129900046`}], 
        PointBox[{54., 29.18350405631645}], 
        PointBox[{54.1, 28.58596776377817}], 
        PointBox[{54.2, 26.422181634625304`}], 
        PointBox[{54.3, 24.569956420375092`}], 
        PointBox[{54.4, 24.00415399223857}], 
        PointBox[{54.5, 22.43510855564091}], 
        PointBox[{54.6, 19.898605244809005`}], 
        PointBox[{54.7, 20.044178801843373`}], 
        PointBox[{54.8, 19.003687489377626`}], 
        PointBox[{54.9, 16.698854722133547`}], 
        PointBox[{55., 15.276891444147623`}], 
        PointBox[{55.1, 14.75518949180696}], 
        PointBox[{55.2, 11.74976426500507}], 
        PointBox[{55.3, 10.734746637892385`}], 
        PointBox[{55.4, 9.824196750851115}], 
        PointBox[{55.5, 7.847002058340877}], 
        PointBox[{55.6, 5.512198791613628}], 
        PointBox[{55.7, 6.350818648650602}], 
        PointBox[{55.8, 4.2405703645563335`}], 
        PointBox[{55.9, 2.148051242431393}], 
        PointBox[{56., 1.0967981760331895`}], 
        PointBox[{56.1, 0.23901942974771373`}], 
        PointBox[{56.2, -2.882226340312627}], 
        PointBox[{56.3, -3.4546867872340954`}], 
        PointBox[{56.4, -4.7552781884223805`}], 
        PointBox[{56.5, -7.035353144987312}], 
        PointBox[{56.6, -8.492478055864922}], 
        PointBox[{56.7, -8.06716599133506}], 
        PointBox[{56.8, -10.5899559636091}], 
        PointBox[{56.9, -12.327228864618519`}], 
        PointBox[{57., -13.017817582840507`}], 
        PointBox[{57.1, -14.67697153131303}], 
        PointBox[{57.2, -17.103251893568086`}], 
        PointBox[{57.3, -17.679348032121197`}], 
        PointBox[{57.4, -19.331870288624486`}], 
        PointBox[{57.5, -21.70081531481992}], 
        PointBox[{57.6, -21.839756797948212`}], 
        PointBox[{57.7, -22.612603617832065`}], 
        PointBox[{57.8, -25.02330706869543}], 
        PointBox[{57.9, -26.335837006525253`}], 
        PointBox[{58., -26.79367972289765}], 
        PointBox[{58.1, -29.355378852844296`}], 
        PointBox[{58.2, -30.74128648709302}], 
        PointBox[{58.3, -31.56743436421675}], 
        PointBox[{58.4, -33.47648599333479}], 
        PointBox[{58.5, -35.56043651559594}], 
        PointBox[{58.6, -34.74917897461273}], 
        PointBox[{58.7, -36.617004686522705`}], 
        PointBox[{58.8, -38.649535838987504`}], 
        PointBox[{58.9, -39.517582497603144`}], 
        PointBox[{59., -40.00338433821162}], 
        PointBox[{59.1, -43.012381589498546`}], 
        PointBox[{59.2, -43.59399365790159}], 
        PointBox[{59.3, -44.71750165299454}], 
        PointBox[{59.4, -46.73915249011043}], 
        PointBox[{59.5, -48.063403019819816`}], 
        PointBox[{59.6, -47.18210597871075}], 
        PointBox[{59.7, -49.54976678971434}], 
        PointBox[{59.8, -51.10312144704221}], 
        PointBox[{59.9, -51.55001405627263}], 
        PointBox[{60., -52.37718648790178}], 
        PointBox[{60.1, -55.143672005608096`}], 
        PointBox[{60.2, -55.36706118557777}], 
        PointBox[{60.3, -56.72374003351433}], 
        PointBox[{60.4, -58.665506706020096`}], 
        PointBox[{60.5, -58.980821720040694`}], 
        PointBox[{60.6, -58.67112351234391}], 
        PointBox[{60.7, -61.00888331852184}], 
        PointBox[{60.8, -62.0603888948026}], 
        PointBox[{60.9, -62.150773936649784`}], 
        PointBox[{61., -63.51235991388239}], 
        PointBox[{61.1, -65.54655076721247}], 
        PointBox[{61.2, -65.71967266332649}], 
        PointBox[{61.3, -67.2017597284721}], 
        PointBox[{61.4, -68.83671719770791}], 
        PointBox[{61.5, -68.27857772193238}], 
        PointBox[{61.6, -68.661048819813}], 
        PointBox[{61.7, -70.68538060432911}], 
        PointBox[{61.8, -71.24660949384997}], 
        PointBox[{61.9, -71.07192708072398}], 
        PointBox[{62., -72.92839409922453}], 
        PointBox[{62.1, -74.09692125388392}], 
        PointBox[{62.2, -74.32502849379671}], 
        PointBox[{62.3, -75.819273479603}], 
        PointBox[{62.4, -76.95230496906879}], 
        PointBox[{62.5, -75.81592522317806}], 
        PointBox[{62.6, -76.73334190425521}], 
        PointBox[{62.7, -78.34740885146311}], 
        PointBox[{62.8, -78.44500724624231}], 
        PointBox[{62.9, -78.0948688611461}], 
        PointBox[{63., -80.23877870236174}], 
        PointBox[{63.1, -80.6522929182538}], 
        PointBox[{63.2, -80.91425067311502}], 
        PointBox[{63.3, -82.32416698278394}], 
        PointBox[{63.4, -82.88695445162739}], 
        PointBox[{63.5, -81.42114675058838}], 
        PointBox[{63.6, -82.62836155157856}], 
        PointBox[{63.7, -83.83539896724687}], 
        PointBox[{63.8, -83.50281246842496}], 
        PointBox[{63.9, -83.03221486246184}], 
        PointBox[{64., -85.24137813023845}], 
        PointBox[{64.1, -85.07656643769587}], 
        PointBox[{64.2, -85.29894287737989}], 
        PointBox[{64.3, -86.56057523363415}], 
        PointBox[{64.4, -86.61809246201301}], 
        PointBox[{64.5, -84.91733434099297}], 
        PointBox[{64.6, -86.20256944821449}], 
        PointBox[{64.7, -87.05553273868281}], 
        PointBox[{64.8, -86.32829048785061}], 
        PointBox[{64.9, -85.7405692650209}], 
        PointBox[{65., -87.87595004290051}], 
        PointBox[{65.1, -87.27818426081649}], 
        PointBox[{65.2, -87.3729866013382}], 
        PointBox[{65.3, -88.46157125740865}], 
        PointBox[{65.4, -88.11615268806054}], 
        PointBox[{65.5, -86.1666117673376}], 
        PointBox[{65.6, -87.38762251198932}], 
        PointBox[{65.7, -87.96674054120376}], 
        PointBox[{65.8, -86.8809380907478}], 
        PointBox[{65.9, -86.13339244770759}], 
        PointBox[{66., -88.14931314172281}], 
        PointBox[{66.1, -87.22253652317886}], 
        PointBox[{66.2, -87.09919118199468}], 
        PointBox[{66.3, -88.02231427924562}], 
        PointBox[{66.4, -87.3562917260424}], 
        PointBox[{66.5, -85.1002026587521}], 
        PointBox[{66.6, -86.16003646296303}], 
        PointBox[{66.7, -86.56431767453614}], 
        PointBox[{66.8, -85.16019755640446}], 
        PointBox[{66.9, -84.18102971206827}], 
        PointBox[{67., -86.0878579268392}], 
        PointBox[{67.1, -84.92359413334634}], 
        PointBox[{67.2, -84.48898944556277}], 
        PointBox[{67.3, -85.26840893252665}], 
        PointBox[{67.4, -84.35264992943121}], 
        PointBox[{67.5, -81.71427059629787}], 
        PointBox[{67.6, -82.5210180070062}], 
        PointBox[{67.7, -82.86148355232581}], 
        PointBox[{67.8, -81.19010425706074}], 
        PointBox[{67.9, -79.89792692573246}], 
        PointBox[{68., -81.7173581438692}], 
        PointBox[{68.1, -80.4279861615214}], 
        PointBox[{68.2, -79.58674077781325}], 
        PointBox[{68.3, -80.23506753165566}], 
        PointBox[{68.4, -79.16778998295922}], 
        PointBox[{68.5, -76.05870376784878}], 
        PointBox[{68.6, -76.49120747015695}], 
        PointBox[{68.7, -76.88024559374753}], 
        PointBox[{68.8, -75.01486606043909}], 
        PointBox[{68.9, -73.3339759862356}], 
        PointBox[{69., -75.0625259431763}], 
        PointBox[{69.1, -73.80075950654282}], 
        PointBox[{69.2, -72.46431975453015}], 
        PointBox[{69.3, -72.96421977793943}], 
        PointBox[{69.4, -71.91288203480508}], 
        PointBox[{69.5, -68.23183946485369}], 
        PointBox[{69.6, -68.12028367057792}], 
        PointBox[{69.7, -68.65196691562596}], 
        PointBox[{69.8, -66.69664471256692}], 
        PointBox[{69.9, -64.57335370849614}], 
        PointBox[{70., -66.16100026083586}], 
        PointBox[{70.1, -65.11616699409205}], 
        PointBox[{70.2, -63.224259936469025`}], 
        PointBox[{70.3, -63.51623536564148}], 
        PointBox[{70.4, -62.70949948429188}], 
        PointBox[{70.5, -58.386924687816645`}], 
        PointBox[{70.6, -57.513660056793015`}], 
        PointBox[{70.7, -58.23478958016494}], 
        PointBox[{70.8, -56.326018380095775`}], 
        PointBox[{70.9, -53.747106421913486`}], 
        PointBox[{71., -55.09445036406396}], 
        PointBox[{71.1, -54.46169008901052}], 
        PointBox[{71.2, -52.01433242287021}], 
        PointBox[{71.3, -51.99923661144567}], 
        PointBox[{71.4, -51.62703400901228}], 
        PointBox[{71.5, -46.758755757640756`}], 
        PointBox[{71.6, -44.87600640147866}], 
        PointBox[{71.7, -45.75591101851023}], 
        PointBox[{71.8, -44.04992375570873}], 
        PointBox[{71.9, -41.06260094777099}], 
        PointBox[{72., -42.034604064065206`}], 
        PointBox[{72.1, -41.96664008317748}], 
        PointBox[{72.2, -39.05280166781449}], 
        PointBox[{72.3, -38.61208603285195}], 
        PointBox[{72.4, -38.719408762452076`}], 
        PointBox[{72.5, -33.699828610122495`}], 
        PointBox[{72.6, -30.561556359294627`}], 
        PointBox[{72.7, -31.473716163178324`}], 
        PointBox[{72.8, -30.118262735079043`}], 
        PointBox[{72.9, -26.844345400451857`}], 
        PointBox[{73., -27.29748283544177}], 
        PointBox[{73.1, -27.86013616253331}], 
        PointBox[{73.2, -24.663236567583226`}], 
        PointBox[{73.3, -23.694022881769342`}], 
        PointBox[{73.4, -24.176640174431668`}], 
        PointBox[{73.5, -19.66370039871981}], 
        PointBox[{73.6, -15.108544062946748`}], 
        PointBox[{73.7, -15.835831851203693`}], 
        PointBox[{73.8, -14.932255150517449`}], 
        PointBox[{73.9, -11.56630322347337}], 
        PointBox[{74., -11.382616415670782`}], 
        PointBox[{74.1, -12.534690979271545`}], 
        PointBox[{74.2, -9.303733877568447}], 
        PointBox[{74.3, -7.759402742951352}], 
        PointBox[{74.4, -8.425736909674015}], 
        PointBox[{74.5, -5.03931724310678}], 
        PointBox[{74.6, 0.7796146801338182}], 
        PointBox[{74.7, 0.5111743062807363}], 
        PointBox[{74.8, 0.937780172956991}], 
        PointBox[{74.9, 4.155513135905494}], 
        PointBox[{75., 5.030805919348495}], 
        PointBox[{75.1, 3.424795470382378}], 
        PointBox[{75.2, 6.430339239333989}], 
        PointBox[{75.3, 8.511515975631482}], 
        PointBox[{75.4, 7.875534531784069}], 
        PointBox[{75.5, 9.914155923572253}], 
        PointBox[{75.6, 16.33990316346899}], 
        PointBox[{75.7, 16.799913316383027`}], 
        PointBox[{75.8, 16.80728201039892}], 
        PointBox[{75.9, 19.643949029341456`}], 
        PointBox[{76., 21.174552393444174`}], 
        PointBox[{76.1, 19.30920500974753}], 
        PointBox[{76.2, 21.87730918147281}], 
        PointBox[{76.3, 24.371668404761294`}], 
        PointBox[{76.4, 23.94714476099034}], 
        PointBox[{76.5, 24.78829520959698}], 
        PointBox[{76.6, 30.935909435211215`}], 
        PointBox[{76.7, 32.2878736427956}], 
        PointBox[{76.8, 31.996846479065425`}], 
        PointBox[{76.9, 34.28129126793647}], 
        PointBox[{77., 36.33006152973394}], 
        PointBox[{77.1, 34.4129544929674}], 
        PointBox[{77.2, 36.41384623470367}], 
        PointBox[{77.3, 39.142126974256826`}], 
        PointBox[{77.4, 39.03740900943376}], 
        PointBox[{77.5, 38.97723051444336}], 
        PointBox[{77.6, 44.22055926048051}], 
        PointBox[{77.7, 46.38130164986069}], 
        PointBox[{77.8, 45.93733375177544}], 
        PointBox[{77.9, 47.59426394703769}], 
        PointBox[{78., 49.946403481917514`}], 
        PointBox[{78.1, 48.154753647671896`}], 
        PointBox[{78.2, 49.54681522025203}], 
        PointBox[{78.3, 52.318912994727725`}], 
        PointBox[{78.4, 52.55231782262854}], 
        PointBox[{78.5, 51.895881869320874`}], 
        PointBox[{78.6, 56.07583986209647}], 
        PointBox[{78.7, 58.68550041766866}], 
        PointBox[{78.8, 58.21677506648848}], 
        PointBox[{78.9, 59.26320435219532}], 
        PointBox[{79., 61.676985291429446`}], 
        PointBox[{79.1, 60.122202345883125`}], 
        PointBox[{79.2, 60.93552407245443}], 
        PointBox[{79.3, 63.58943204804382}], 
        PointBox[{79.4, 64.0989848280733}], 
        PointBox[{79.5, 63.097807476791786`}], 
        PointBox[{79.6, 66.33195174665889}], 
        PointBox[{79.7, 68.98007425346441}], 
        PointBox[{79.8, 68.56273809693812}], 
        PointBox[{79.9, 69.07623389107903}], 
        PointBox[{80., 71.34258682732616}], 
        PointBox[{80.1, 70.05150323878479}], 
        PointBox[{80.2, 70.36257719259447}], 
        PointBox[{80.3, 72.78475176409847}], 
        PointBox[{80.4, 73.45704217811726}], 
        PointBox[{80.5, 72.28095767627383}], 
        PointBox[{80.6, 74.73125267326395}], 
        PointBox[{80.7, 77.16385105221707}], 
        PointBox[{80.8, 76.80418057343195}], 
        PointBox[{80.9, 76.88595256872213}], 
        PointBox[{81., 78.86576794715802}], 
        PointBox[{81.1, 77.78260722998675}], 
        PointBox[{81.2, 77.69079318122385}], 
        PointBox[{81.3, 79.81727156120178}], 
        PointBox[{81.4, 80.52139174248441}], 
        PointBox[{81.5, 79.25243234017398}], 
        PointBox[{81.6, 81.07376965701405}], 
        PointBox[{81.7, 83.1913755430287}], 
        PointBox[{81.8, 82.83298932117759}], 
        PointBox[{81.9, 82.5779515192844}], PointBox[{82., 84.2121208025128}],
         PointBox[{82.1, 83.21830329227669}], 
        PointBox[{82.2, 82.83038829971338}], 
        PointBox[{82.3, 84.63554987313546}], 
        PointBox[{82.4, 85.24615672670916}], 
        PointBox[{82.5, 83.8946557631134}], 
        PointBox[{82.6, 85.24617453373503}], 
        PointBox[{82.7, 87.02591150418448}], 
        PointBox[{82.8, 86.5779614079438}], 
        PointBox[{82.9, 86.06303337056306}], 
        PointBox[{83., 87.35555883373308}], 
        PointBox[{83.1, 86.29812654935085}], 
        PointBox[{83.2, 85.72218919832085}], 
        PointBox[{83.3, 87.2025539872484}], 
        PointBox[{83.4, 87.61216200036142}], 
        PointBox[{83.5, 86.1429175206431}], 
        PointBox[{83.6, 87.1893803762141}], 
        PointBox[{83.7, 88.62541610465269}], 
        PointBox[{83.8, 87.99157821646804}], 
        PointBox[{83.9, 87.27700687110337}], 
        PointBox[{84., 88.26843460027885}], 
        PointBox[{84.1, 86.9864240844181}], 
        PointBox[{84.2, 86.33306035579153}], 
        PointBox[{84.3, 87.49067074922641}], 
        PointBox[{84.4, 87.61055981381651}], 
        PointBox[{84.5, 85.9751130236109}], 
        PointBox[{84.6, 86.87979113996698}], 
        PointBox[{84.7, 87.94750459663192}], 
        PointBox[{84.8, 87.04755038744042}], 
        PointBox[{84.9, 86.18772166500275}], 
        PointBox[{85., 86.92635220049851}], 
        PointBox[{85.1, 85.27712597817299}], 
        PointBox[{85.2, 84.65967925774748}], 
        PointBox[{85.3, 85.48875341186795}], 
        PointBox[{85.4, 85.24638781088288}], 
        PointBox[{85.5, 83.41458339508972}], 
        PointBox[{85.6, 84.32594422891998}], 
        PointBox[{85.7, 84.96137995222671}], 
        PointBox[{85.8, 83.75343539095775}], 
        PointBox[{85.9, 82.80983878677216}], 
        PointBox[{86., 83.31854267528979}], 
        PointBox[{86.1, 81.21772756113205}], 
        PointBox[{86.2, 80.73638336671866}], 
        PointBox[{86.3, 81.21588976879138}], 
        PointBox[{86.4, 80.55182755450369}], 
        PointBox[{86.5, 78.55243399434403}], 
        PointBox[{86.6, 79.57708502919559}], 
        PointBox[{86.7, 79.66686654028308}], 
        PointBox[{86.8, 78.1712503690942}], 
        PointBox[{86.9, 77.22075352064712}], 
        PointBox[{87., 77.45254577241576}], 
        PointBox[{87.1, 74.93837351338152}], 
        PointBox[{87.2, 74.64156346012896}], 
        PointBox[{87.3, 74.73612697925273}], 
        PointBox[{87.4, 73.60400570681668}], 
        PointBox[{87.5, 71.57875872904697}], 
        PointBox[{87.6, 72.73811860134447}], 
        PointBox[{87.7, 72.13546633419901}], 
        PointBox[{87.8, 70.43904979635408}], 
        PointBox[{87.9, 69.5720157816395}], PointBox[{88., 69.3616179590681}],
         PointBox[{88.1, 66.66333820581349}], 
        PointBox[{88.2, 66.5055989560351}], 
        PointBox[{88.3, 66.17462735049776}], 
        PointBox[{88.4, 64.5492331997084}], 
        PointBox[{88.5, 62.80030650997651}], 
        PointBox[{88.6, 63.90824498410075}], 
        PointBox[{88.7, 62.54987058287952}], 
        PointBox[{88.8, 60.78255209416966}], 
        PointBox[{88.9, 60.083173639803135`}], 
        PointBox[{89., 59.14688074027072}], 
        PointBox[{89.1, 56.67377250406571}], 
        PointBox[{89.2, 56.51436606593779}], 
        PointBox[{89.3, 55.723212415745365`}], 
        PointBox[{89.4, 53.624250026572554`}], 
        PointBox[{89.5, 52.571432246637414`}], 
        PointBox[{89.6, 53.134365831210744`}], 
        PointBox[{89.7, 51.202974704770895`}], 
        PointBox[{89.8, 49.5067127753282}], 
        PointBox[{89.9, 49.00513116169168}], 
        PointBox[{90., 47.092126970346726`}], 
        PointBox[{90.1, 45.24976145830442}], 
        PointBox[{90.2, 44.909078589269484`}], 
        PointBox[{90.3, 43.63916968758713}], 
        PointBox[{90.4, 41.18989501368924}], 
        PointBox[{90.5, 41.13853291957639}], 
        PointBox[{90.6, 40.64471890737332}], 
        PointBox[{90.7, 38.46605016911781}], 
        PointBox[{90.8, 36.97265413424611}], 
        PointBox[{90.9, 36.55588787038141}], 
        PointBox[{91., 33.746163691168476`}], 
        PointBox[{91.1, 32.650416798693186`}], 
        PointBox[{91.2, 31.98150201592216}], 
        PointBox[{91.3, 30.240096635825466`}], 
        PointBox[{91.4, 27.7708053868555}], 
        PointBox[{91.5, 28.53935409313999}], 
        PointBox[{91.6, 26.89208789888653}], 
        PointBox[{91.7, 24.750155662099132`}], 
        PointBox[{91.8, 23.562001433907426`}], 
        PointBox[{91.9, 22.887057706000633`}], 
        PointBox[{92., 19.75087521300884}], 
        PointBox[{92.1, 19.13883380747575}], 
        PointBox[{92.2, 18.06526782309811}], 
        PointBox[{92.3, 15.905771999285207`}], 
        PointBox[{92.4, 14.023455862610717`}], 
        PointBox[{92.5, 14.731486716264044`}], 
        PointBox[{92.6, 12.38937793642981}], 
        PointBox[{92.7, 10.476934772959794`}], 
        PointBox[{92.8, 9.635834950619028}], 
        PointBox[{92.9, 8.208124206692446}], 
        PointBox[{93., 5.553949941138853}], 
        PointBox[{93.1, 5.014270462750574}], 
        PointBox[{93.2, 3.530091582928435}], 
        PointBox[{93.3, 1.0957175437361002`}], 
        PointBox[{93.4, 0.4361454416648485}], 
        PointBox[{93.5, 0.09298899385612458}], 
        PointBox[{93.6, -2.376160098152468}], 
        PointBox[{93.7, -3.9413225070165936`}], 
        PointBox[{93.8, -4.511350700064213}], 
        PointBox[{93.9, -6.943588894500863}], 
        PointBox[{94., -8.613558356519206}], 
        PointBox[{94.1, -9.379179945171927}], 
        PointBox[{94.2, -11.221971190432669`}], 
        PointBox[{94.3, -13.621843407890992`}], 
        PointBox[{94.4, -13.083284266598639`}], 
        PointBox[{94.5, -14.723097323483671`}], 
        PointBox[{94.6, -16.95972929627169}], 
        PointBox[{94.7, -18.116413280848064`}], 
        PointBox[{94.8, -18.66655892280687}], 
        PointBox[{94.9, -21.747680964763276`}], 
        PointBox[{95., -22.554945643612882`}], 
        PointBox[{95.1, -23.658694215249852`}], 
        PointBox[{95.2, -25.753419895510888`}], 
        PointBox[{95.3, -27.59400733676739}], 
        PointBox[{95.4, -26.732374201747007`}], 
        PointBox[{95.5, -29.120802446836024`}], 
        PointBox[{95.6, -30.95385167223867}], 
        PointBox[{95.7, -31.695939255325356`}], 
        PointBox[{95.8, -32.61960036121309}], 
        PointBox[{95.9, -35.57221460832807}], 
        PointBox[{96., -35.99590884640929}], 
        PointBox[{96.1, -37.41547052831447}], 
        PointBox[{96.2, -39.587759082511184`}], 
        PointBox[{96.3, -40.35083482024493}], 
        PointBox[{96.4, -40.13562787391129}], 
        PointBox[{96.5, -42.62133022068883}], 
        PointBox[{96.6, -43.9849992939271}], 
        PointBox[{96.7, -44.37138838370447}], 
        PointBox[{96.8, -45.986917936155805`}], 
        PointBox[{96.9, -48.151284758292604`}], 
        PointBox[{97., -48.58781223098049}], 
        PointBox[{97.1, -50.2297033881332}], 
        PointBox[{97.2, -52.2194336989196}], 
        PointBox[{97.3, -51.87063945343834}], 
        PointBox[{97.4, -52.64273147865606}], 
        PointBox[{97.5, -54.83396982126578}], 
        PointBox[{97.6, -55.71485039898835}], 
        PointBox[{97.7, -55.87204841393395}], 
        PointBox[{97.8, -58.16743901094014}], 
        PointBox[{97.9, -59.34137183110579}], 
        PointBox[{98., -59.95279225950071}], 
        PointBox[{98.1, -61.6908431250049}], 
        PointBox[{98.2, -63.18307205416204}], 
        PointBox[{98.3, -62.148574523685966`}], 
        PointBox[{98.4, -63.697823404407245`}], 
        PointBox[{98.5, -65.43483996475697}], 
        PointBox[{98.6, -65.8475646727602}], 
        PointBox[{98.7, -65.94279496376112}], 
        PointBox[{98.8, -68.58063818384835}], 
        PointBox[{98.9, -68.94650656619342}], 
        PointBox[{99., -69.72851319692563}], 
        PointBox[{99.1, -71.42527238656476}], 
        PointBox[{99.2, -72.19922458662768}], 
        PointBox[{99.3, -70.986122123737}], 
        PointBox[{99.4, -72.91377991062473}], 
        PointBox[{99.5, -74.16123153734952}], 
        PointBox[{99.6, -74.13682160257304}], 
        PointBox[{99.7, -74.31529490067624}], 
        PointBox[{99.8, -76.88728089860524}], 
        PointBox[{99.9, -76.72755864882492}], 
        PointBox[{100., -77.6044705388922}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {-180, 180}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \
\\\"input\\\" -> \\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-328., 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.8804630968744793`*^9, 3.88046406879908*^9, 
  3.8804642111208887`*^9, 3.880612967586327*^9, 3.880613098859754*^9, 
  3.880655519573432*^9, 3.880702739748116*^9, 3.880703455333356*^9, 
  3.890982080223662*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"bd2a33aa-ce4f-407e-bc95-5abefa9914b8"]
}, Open  ]],

Cell["\<\
Produce the four labelled plots for the case of 2:1 resonance medium \
libration amplitude.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
  3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
  3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
  3.880462756268464*^9}, {3.880613554439003*^9, 3.880613598974339*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6a45a7ee-519a-471a-95d5-df350e34df1f"],

Cell[BoxData[
 RowBox[{"FourPlot", "[", 
  RowBox[{"0.001", ",", " ", "init2", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.880458214389099*^9, 3.88045821483778*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"33d2f3f2-3f1c-4d45-a155-ad290268a99e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcB", "=", "gc"}]], "Input",
 CellChangeTimes->{{3.880458220439043*^9, 3.880458225158008*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"67d5eb9b-0a6a-44da-a81a-061f47d14b89"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJw9W3k8VO//lUS0SgstIhEh2Xdz7NtgFmZGVFS0L5+kfVG0ay+l/dO+l7Qv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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0.6000000000000013},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0.6, 
           FormBox["0.6`", TraditionalForm]}, {0.62, 
           FormBox["0.62`", TraditionalForm]}, {0.64, 
           FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0.6, 0.65}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Prolog->{
        Dashing[{Small, Small}], 
        LineBox[{{0, 0.629961}, {100, 0.629961}}]},
      Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
     ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJw9m3lcjVvYvwkpMkZkapA0a55rf5vn2u2hXaYyhWTMcIpIZOwoMo85EpEj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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {0.1, 
           FormBox["0.1`", TraditionalForm]}, {0.2, 
           FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 0.2}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -159.99}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.0055000000000000005`], Thickness[0.0075], PointBox[CompressedData["
1:eJxd13c8FQzY/3EtLUrpJiqJkqSyZX/tzdnn6FZJRsNWUipaWtpTJC0tDWlp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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}, {360, 
           FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 360.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJxdm3lcTev3xw+hVJdouEXlNJ2SSlQapHbzoHlSCVESN1MZynAddElCKPMQ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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[CurlyPhi]\
\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{-180, 
           FormBox[
            RowBox[{"-", "180"}], TraditionalForm]}, {0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {-180., 180.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -383.19}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-438.99, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.880458226254426*^9, 3.880463109608329*^9, 
  3.880464070198588*^9, 3.8804642123277884`*^9, 3.88061296896286*^9, 
  3.880613100218089*^9, 3.8806555206235647`*^9, 3.880702740828918*^9, 
  3.880703456432767*^9, 3.890982081390382*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"4ba50bef-450e-40f0-b451-882415bc9e7a"]
}, Open  ]],

Cell["\<\
Produce the x-y plot for the case of 2:1 resonance medium libration \
amplitude.  This is Fig.8.17b.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
  3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
  3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
  3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
  3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
  3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
  3.880462756268464*^9}, {3.8804631336031713`*^9, 3.880463137112747*^9}, {
  3.88061360644468*^9, 3.880613619284938*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"98406d5b-40b4-49ec-967b-6670a5222fc7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xyB", "=", "xyplot"}]], "Input",
 CellChangeTimes->{{3.8804582310890713`*^9, 3.880458236033197*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"4ed60d73-d0e2-4642-bbc5-c56cbef15436"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwtV3k4Vd/3vvdwZSxjKiQSmUpJ0UetjQzJlOaBQoOSpFlIRCiFCoUIkczz
rHPMU2TMPM+ze83j/d7f8/zOP+dZz1p773XO2utd7ytmbmN8EyORSKNMJNL/
vQmOszlMd2lA+v/HX9PjqcIiDQ51dI9Pb2TB36Cn2fvkZkFExPdkH3MGPMlb
9u/ypUHkw40cVqscyCOnxMn70EBOr2GmnbUUWvfnXHJ5PgvHrgwqhr0vBf+n
LXhODg1C9j6V2ONQBBaRFPdDQAOsCWOTSqmCa05hdw/n0qDgmYtsrFotCPmU
3FGupcHz04O51Oc1UM7k2GaxSIXpy/Yz8tR6KEgmIhf4GX6hErszk21w0rfM
7KYTDbj3Ox7wM2gHe7e841ULVJD7vG4is68d1Kxye4ucqTA/dj5SbK4LFOqS
msaNGfkcsRlx9e0Bp9hf129QqXA4t3Ah9nkX3O7mS93EQ4UiC/saLK0Hnt+X
eEw7QYUbczfYksz64PHBxO+vA6jwU+tKi59YH/D9ORbxIGUG7M1exGXG9gFd
c4Lt4vkZ0H/qze47NAQfsyr1zpTNQLeZkb/s9DAc9ik8Yf1oBu7UP7ik4DQM
L/i/VmvfngYjSS6Z7KwR6DQvOHrk0Azwzz0Y+eI1Bn9HZCdE1GbgUsSZwFyh
UdgfbaDQfm4K7i1250/ljwJxuae2hTIF3zyTVvd9HodvNmbcjT1T8LovxPhL
7Tj0zRHUD06TIPOdqnzwwjgsfdix9JU2Dr+6trmbyU7DkYLin+A4Ac+PyVw2
fzcDoXIyLzTPTQDLj55Rb70ZWKcY6HvGjoHwwk9WJfcZuHorjxXqxyC62/tj
QyAV/NVktVUSxiHh1ZCGMRsV/nLMGHI4jELmE0qE58QM5N7TSBd7NQJuu7iE
O4sYdRHZ6ZmpNQq8exaE58VosM3Tu7DbfwTmWMyPUEKpYKHjZDL+bAgS8hcE
K0VmgUPTYrr08RBoWXtv5rSZA0m1oBGRLIZfgiNNUm8Oqk/9uDiKBkFR1kfQ
S3EOZPT0yw9/HQDWvwPj4//Nw5fSDI23i4PQ3/xo2W9mDgYEzQ9YbB4Apjdz
3EnP58BlNUr1mX8f5Cg7OAqKz0MgXk7fuaMfeHhPfs5JmIfS/WY9nOL9EKaW
r39UeB5qBqUpurk9kHpDNqRcaAEUemuk9BR6AN1l4V6IWgTZw4sHpjJ64Hbq
6cvhKYsw7W1f32PUDetvmqS0byxCz47Tr2e6OiDq9QN2+vElGKiMV+/f3AO1
gr8aN6EliKe4M7850AntkdtSzD0XodzlovKVglbgrD799fD6IsQ++Siho9gG
N8/IPGYNXwKxLeEDQg/a4ZTE1iw58SUouKdSZPzlH7yf1zTkSliCIPsb71KJ
Rvhgd2La++wKrM4Wvkjh/gfOL+XIx31WwEN/F1wZaATOLTlvQHoFdjhNhC0O
18H3s5XK639W4OCOSXPuy03wKYbNbphrFVKWP+ukmzXAhcSHjncUV4Awl/l0
LvMvXIpX+2Nox9gvcfD88Zq/4OYbUma3ZxXYzC9Kksj1ULF16wmXohVAgfd5
b89WQmKahfDPlRV48rdbZfBVKXzN3pg+G70Gf1hfj3s8qwDWr+HTnazrsHyO
y/teRzlU322djg9egy1OvpMW1YVwZ6771QX+dTDedOl0OFslWI5evqXntA5d
LDdfHM0sg/xNQ+2qn9cgd9OOwJ9CBdDg/tyiLm8NfpcZqiWyFcB6wcSTW5br
cCL/1/tdDJyiclMy10XWwVLh7FhcVh549dx+5SO5DvK5j3uOd6bCzT20yYq6
DRislvkX15kDa6f5ROtO0MGPJnvuuGce/PnhwzXdtgEVfHIdGz7J0O+yOdRK
lQ6s3hcqAssI0L0b4lSdSYcbjtsN47bhYBVZuN2qbAOmC+c23INSYcWmNkV/
aANkRfVDUyPToL+G29DPmw5k2YuG6csEmCAax6AuHUJ+p21rpKeAuWkgh7Ae
HaYnDrjfTfgJ4Q4e2c3PSCh3iDijV5EGD7rkX19NJKEVaW2p+cgsQFKaT4Ne
kNBGw9MPz84mgvq+RlnpeBJ6JbZkQKgUQL+IxRm3fhLadmqk19eGALEPxZ62
90hIczZ4+UBdJqhkZvawviKhoD9OHyYCcqF+LxTW15PQbq67x82flUDT8MVC
kygSmvx7xRGa8oASeSI/NpOEvsiTPhMoG0g78ioVX5FRPqu/o5BDIZRYfVQY
jyajtiDXya9CJbDs2xy2zZaMmsb6BNt5CsEzXrqHI4WMco/btkTrVoOL/tfV
HX/ISOrRLgUFoz+gaU1sdr9CRqORaoJH71bAys+tcpftyMiCt+ToL6tq4M/g
P7irlIyYJJM4pZrrgemr49R+xvlsEgW9OvQaMJ86JdKWSUZrn35cbKDUAjP5
AvnvHQwF2n4b8khsgNCe9Ezepxji+09CNE+gCWavh3SPKWMIf1pbOZPdCJV7
RNyNfDG08s1wYIGrHcoJvRsejzH0t810/cCpNvCpWJYa48MQufEQl9gko3+F
HwgWqWLIJjDi9nPdTrAx2War9xxD8dabvov59ECU9d/ySk4MfXfpz2TW7oIz
Owa/2ztg6HRcZfqTCz0wYesyMEpiQgnbJR4I3u2DwdefyL0DGLLcrfgqEOuH
1ddVIdsjMcRhxckxWdUPU843y1/wMCFtBc4bXu1DoPHu60LnTwzZPTnuqmk5
BNKHbaO9zDFU+qHUdefoEJxtcjA+6o0hZYHyAHejUTjxLyWk7weGLguHBKZ9
HIMs+it67nYM2csObxNvGgXjO/mOJb8xVBdg/SJ6bRzuu0Tc5V7B0FEWTR5H
likYWPJxuZnE+J6uLunse1OA1fbYbLLDUOhTbbbbBjNw7OrRrbQWDGW5mCUe
u0UFRaP3GZNSGNr8VFb4uQYVhAoqm8owDHm4X7UUHqHC6fmly4/EMSR9XaW9
ymQWdmyVL+FfIKMiH+n2PQ9m4Xqrl3zDEzKikgtOzGfMgsor7DuVER/leIXL
knMedI9Hs02TMeTGNNqt0TMPQ+4lLm0+ZCT4xMswlW0BzlDPvVR9REYvLA5J
tNctwolvEic0XMhIuFtN1nD/Ehj6i8Qn5JDQh7FVzeVTS3C/9bmkTCwJBduz
fOMzWIYgbf7jP3+Q0M6CO+TUjBXIiWr+JSpKQsv6dE6S8Qq8NSlSC+uiw1NH
/Tdbz6yCj0fsoyAjEkqsStj639s1oFfdOXAikQ5zNXy2C2zr8HGkZDs9cgNM
apUcFm+vwz+mZ5GZ8RuAJwZvLzSmw1QseydTFAOveoqKBwTo0KWUe/DfvTXI
PxHvuexOh6zME3+vnViDxFfvYzmvk9Bi4ZD5jrRV+O3N0rD2h4Se227Dm7hW
4HbbYFhEGAnljJ95V+21AvXvdx3SNmb0hV0yTfbwCpz59mSbTDoZhTQ4rJ+v
XYIZDqdr0hVk1Ji9PZHctggsIyKpzscwFH5by+5kH2O+aSsdrqjC0PUjvfVZ
tfPw7F9j1dA3DJHOJm182DkPfwUEs1mXMcRYUcYcPwcUb2uByx5MaD9ZKjjt
6Sx08UjEnbNnQqHtyges66nwL8LhQMJPJjSgMLhu/o0Gz344/axRZEYEy/Lv
LUCFk8+nBHL0mFFufayx24tp6HVOlNfWZUbDe/enhG+dgpnMzeFbMApKjeV7
8K1hAkynbwj2DjAj8cE3jzkfj0DE5dssEy3M6MJCXPbDL8PwsOZj2ksVCuqI
cnl6tWIQiP2FWKAbBfmyMMcJq/aB0dN9K+JiFDSdlrcxWdQDWcdJm0pCKWic
11jqZmkPVKssZxysoKCGzqUdNfJtEK1jphgaTkFCB/eZuGNNkPyf62G5ZAqq
yfs6IaDZAFWfT7YJ6bCgG+YfWy8blIMY+y+3vfkUdG7GWvYdUy74fE6/LdNI
QY6Pwf6VcArQh3w8nvOyoLIVm+XPu7zxMMce0+VJCgq82OFYIFyALx0w8Rxk
5PNt12LdMVIeHn5r+oUaOwu6755Pa5gpw89lrLbq/qWgE46j16h/63H1HnpS
oAcFcSZeZc6/9A/n8cv6OFFMQaLBTE5rJi248mMjR/48xv87u1dQk9KLu13x
Hn6tSkGzXq9iz0z24qdUJTjYzlHQTdfg5+vp/fgpxVN75vQoaGjftT+L2DAe
ZodKzAhmdG3qkQ/X21F8ebfhZXIjMzrlGBT/SW8EH0o84NZUxYx0Qsu7LbdM
4LUG5+cqjZnRS33rh9vsp/AX9hn3PHiZ0WVXsZf/PZzGb+1V/NdjzowiWqi9
HuUzeB3V7/2LBCZUdrzdOfsnDd9/k/epiA0T+vg72L67noavHt3XLHyDCb07
eZRNhj6Lb/rssL2DwoRKjp2vKvSax/2V7jg73MAQv4/nzO6gedy20lMp4hcD
V/fWvGeqnMftlYOm78kzcPIR+fDMvUX8pttgHD2SjFQuWSxqci7hewKDvxh7
kJF9qf6VP2eW8IZyxUNLX8gosSTp3keuFfxFiu/evXEk1C0j/fxvwgoedSUp
sPojCW0/XHZelW0VpyTkY7cZOGApf0ApV2MNP8prxmloQgeBVy3c69rr+IGL
NrbbYzbgnp3o6adn13Cns395NRk8pNCppuTtg3W8/Z/O/J276zAiw5G39cYG
3rKW+tqfgSeiahMJXZ4beFuWXM2VwDV4gd/l3D2ygcet5q23561CAavuZksT
EjF1a1az6/oKbDlZpa5ziEREBDlmiEquwJqj1VtlZxLxIeHAxFaVZbCg28oE
MJEJjkaNU9yMvp/pDye93UYmTJRli9KmF6E2prtxyYNEfDIQYaszWgTjoxEW
T1TIxPRsoojk7DwQtq+vbL1KJiy4snlNrObhxPY0jQo9MpG8kJCR5j8PjVk9
ni/DycTphBlL1vFZcPvs8rdYBSNupZ1+YGEwC1uVrvkNTpMJ5SOuHdReGjD3
+UxwnMSIe3J/pB2yqBD+iWCe9McIo96njT8zZsCxs+Ui/T+M2DDV8eH/jwpf
DTNncibJxHqxX95u9hn4Gu87+dMWI8a0FZaOzE8CRT+3kf8CRtAUHW1df0yC
nkGeoxLCiBpn+5v8CQz7+PH+xTyMyBS/tXf7wihUXhkQa+jECPpjmcryklEY
l84nMmIwQk7/1q//vEfAq9I922QVI1RzRsnx/w3BA7eD/Z/ZmYjd9J/YO7NB
YH6s03PlOkbI+ArYSDP0zgEXntNzNzDCSWjrWdvCfshvKTvT8AMjngnandtr
3cfQda/3nLuDEX07E7505ffBzfbG6bcmGGG68tr7vkIf3CdHyk+NM2yHSwdN
FLogfCKXPpSAEVbiNn5X/3TBD+zik5/fMKJ/6cGeWEoHzE8Z+e1ux4iM0d9e
JnItcFDm90EiCSOapDmzTsa0wE+HFwn/9ZMJ/Vt7C2r3tcEmzKXrrBhGaLw4
df2HahMYq1fUHZLBCGUmqaPvuBvhpMV/R272kYlPN8k1Zt+awH10TjdqlEwY
1RMpx542ALdMosPfhxgR7xaDr9yvgaWDY5E3mDBCSDG2i1OzFpRrf5JucWBE
6x6+8LVtVWBRYUW/qYQRg+KDw9SKEvD0US5Z6CYT28PKHvcwVYIWXzmX6hYy
YRmXsnGsvArKC4Oy91mSiUTnAtvJoCKoGxZ6wmREJnQ/DQ8vJRcBj7OrVT4L
mXCcjqi0FywHjb98OGUXmZAxsL7xKq8Q9rPmHWQPJBMOwrsruw1zYWkP9+EH
jPutr6a82cuWgKIiZT3ffWTiXmTx2cqzmXDGJcBW7xSZeFdZEfpCMRkS+cJv
uraTiNbEyrdGyflgvqBUsIePRFxUcHbaI0fAtlNxQyKPScTrjVPGCkdS4fWt
P+U79EmE+Mop04zRDMCymLlFKSQi+OhLToFeAqJjfHZNS5OIO9c4pwz5MqF0
7t3TdwEkYoKXtCv6ajIktf82nOUlETHdX1qiYrLAX6O1ZEKeROis1s150ZPg
46y15ZImiVh+97iMpSMWaojQu78/0/HKBjOm4m958HMqPzOYawP3frl7r8de
AtYFdvYOV2/gIZMzb90fpUPhcKdQnP0G7iW1tPHSOBf0DzxE90bX8R32b67m
cBQDzm10IfDIBj7GXiNiyYaD6wnC6hk7HRdMTS99BrnwRmyaj53CWD/L4nLc
rBCEnMt0Nilu4OQtoW4xWjgE/CBfdLuzgdvybpdZfJ0PX7FTNjEP13G2bZkS
C86lYKKXJabXu4oLXsHPR6ZVQNC9yPsbH9fws/+u8fGNFgNH/UJGoOEafmNm
qqj5WDlUit+9JJmyiif+0nM64sPQn+fbXt+aXsU3u1ormD3/Awa117kelK/h
m5xQ4dnblaDr8WqH5p9VvFpp3rlEthaCb7p6POtcxfe/v3buY3cNPOVf7dWR
WMNDN/arHemsBlXXE5/eaKziopd1nToT6yEl0SSl2G8ZP8uTeIsLmqB8S5Xw
UYkVvKG/rEdqUwOYSKmfcSCt4FvS4h1G3BpB3Omth+rpZbz19KVzb3xbYOf3
eE3PW8t4wdkKmipLC9zd2ZhL0V3Bj6CDl5We/IP7Tc7z8xbLuGawzvWa3lbo
omXW9cEynnfl7KN5hp54Hb6SNu2/jLOb/Lc3UbgVXpEcX4z1LuHmBrWd2eYd
8PKR9zs6zyI+FuHnqLDWDV5Fjlk+Vxbxy9a7ry6QuoCrZnd+z81F3PbCJfeE
2S4oPUN5HBW1gPdtyW2X/9QLpi1Wp01fLuABXJSy2KleqL8Y6PjIbBG/1qbA
xVPSA3MHS3V7fy3gflsuk2Jf94EoqfWg8NEFnKSvJ7SboUfsfLKtGj4t4KZL
rqE7bPvATLyfs0tkARfWiliT+NEPPKs/NmkencOLGlCG279B6KYRyvl8c7id
Qn/HBeFB2NU2fKzu9Bx+pU5zbU5qEPp63r1h853F/W3DjpWLDoO45oGuUuFZ
fHvHyMFW+RFor+kXfTAwi5uJKzaFpDD0Tdj5XVwvZvFrY45FBlIjYH+Phiem
03CZxxdbEiVGgafXrqBkgYZbhOguSvuMwLnAxLWQChq+EHCwx3fPKBzxN5pr
WpjBE0M3+Y/fH4eegkTrbyoz+I3sR6eTFMZB29T5onnIDB7auFeHmxgD6cWe
Q8kT07gi+5vzEYYTICU0IexqPYXbrgQG3iFNgUBZloiH3TR+2cCuFD2ZgC8n
n9GuWk/jQRUbyofVJuFtTIJW3NVJfOue7wmJ4VOweiFDn3Z7EufgfBz6VXsK
5u5zlbZ8mMRZo6WC6sSnIFu9o4TyYAyfbpJx7uaagY6Alpbi+GFc1CnLc0hj
BtpPrpm+ezaCj6yZli6nTcMTtRAbsc/DuBK7co/KqRkIPV5VxBQziP/xug0N
56hwpmd7Y8rwIL7e7d3MlDMDIXSTY03hQ/i7Kr2LcdEz4JBjN7/15gDeIn66
Tt2SCoeh1UOe6MdpNXHSnI+ocE4ksElafgCnLRs/UmZl6LVPl5Kr53vxGwrp
VuXxVDjLn7r2RqsDRxNJ6l5HaLDZ2oX/9VQHzhKrfz/qNxUaJLtuHD/ZgZ/M
CH07X0SFrbpG0SLaLfgzqbr9gn9oEPXuru5qwz886Iv8l2BPGoyL/qedcq4V
Xyy7biKwTgW/k2wsP1404TurHO85fKFBsam6SnpGPa4is/mk3gCDLwRqOWdZ
NeB3XH+l7tWhAZ9QqOHTg3X4GWnZb2OPaRC+oK62b1MBvjvJd9lNbhYwfeP5
9+r5uKuzGbm1hgY5Lydfupb+xs0d+ud5bWhgF2evXiyfjJtYf9oedmQWrp5b
Si/e64sLHCFf1bw1CzJJj3kvpcTjk9KSvDyvaDDJ+keFfdAPt/PtXe8toUFq
yJnOmPkI2HV+J8d/aBakSyPDMxp/ANdZ9vF3yTSo2CI8reYeBR6GTSFyV2nw
Zcrl/LBoKRDSsbs+kmbh4tHQh4aG1ZBOkwmK7qLBdec+vwrvKiD3bo99pkqD
7wdJF7oG/sIeHvY6+mcaOPzO/WxyohGsqp7ySO+dhTI5m0efX9aDzEf7GOpu
Gshzj6UsdtdD9ydjEcoSFUS9pWUV+JvhUlu1Fo8dDVqUFRoLr7XAgv7Jmz9k
aeCdZUM6btQMkf35dtOM+2DD7s+/t6QTHo+0/JbHqUDxLTN6U9sLnyjnp6K6
qWByQYArwKUXMvalsnyTp8KzxoFw1u5eiGjwo+lQqCD3xo+/YusA8Oxn+tj4
lwr/nT7ldm6jH445v6vnnZyBG0837UhV74fm9Ae3XxjPwLPHzNfqhAbhVsem
aeOEGVjOvfrtg9EQGIxcISBtBjw+rr7qCR0EDt+G9sEr07AfeKgz3sPwSDzD
PlJlGryTS7/jGuPwQOIh8DVOQxw5/EKhzTicscpy9oqfgmYbV2BVHIcP6X7I
//Uk/AzlsxZmmgR+GrX+Cs805Dl2MPNUT4LFpLJ/0fgkfLwee+Ca9QSEbz+8
Jsw/AYHdR51TUichX3nuF4vWBCjVO6ZoqU1DduqfH6ptE3Br0Kgy+M8UtNza
8bYgZwyeXrMR3HV3GhQV9NhTqkfhgRaHDn8KFcptb9/b9nQMHChxj0kiNHia
ZG8pWDwK5vpW++UbqQAlzuESwiMQN3NUWfUmDVzyR5+LoFE4z8Iu5ig5C4IV
HksvekegheNE1eAZGrw/MyFVnD0EN7S/LR8OpkEdV39P1MUhWCzwfsFiPQtp
+w3oN5SGoUNkU9SOu7OwS4/eR3o0COGHNt3bdXAWmozVdSq7++Gj3te/IYLz
ULEnocX29AC02yuZKDTPQ0tp25WYnQNwhtexPsd9HvRjwq69MOmD845cw1r5
DB3Qa3V1caQP1MdeXOBOW4CvTpN3Dur0w8Dit1L/YUY8ah+/JNwLhtIFrNWt
8xBnbmAQpt4D2RmfWLy+LoD6itbBTvleyOIRNOqqWQDt/nPKh1h7oF+ni/uX
+gJ8VFr5OMHZAbU/HU+2TyzCv3P+qtu0OqA7t13gyvQSfDx/3VsspwOOVOnm
G6QsQfP+Y5a231rBd6aS6VrIEuxROHw80b8VVKXkvvhGLsOHtZpHfG/boW/W
KmBpYQlS5GnvuXybQVepTKQ5cgk6zxz0v3uqCUxebZvi01mG5kF3AaA0g97H
HncUvQzPugWN1Tb9g2GrieGnc0sQYnbDgNOvDsbiBFJuX1kBVODGYH914B54
WmDRYxXePHhxi/VyPdzN+6EtYLkKA6+qtpB6/gJZ9nCgyJ5VsPf/dqXhQg1c
l7uyq1JyDbYrdvo2sNSDaqrX5eOBq6CTX2nadaga+NU02BNFVuE/kRFfAaNy
OB4/4tEfsQplZoGoM7AKJDEfS4edayA0ulT+rqUKBA6JmF40XQWnW2dZYssK
gSlD/i/Jl7G/3JkeyegCMLLliHndsA7DLr89XAaLIVdJ0n29ch24D71NqvYp
gJekvUyvH6zDedVLAm9FcMB4vax/WG6AtWZwMVd4KZRePVIyRV0HFcWUpN39
BNzK7M3mM1uH5hsnhX+kZMFWJrFNhU3r8FjC7IN3Gw5N8o591Vc3IDP3v4de
lQXQmhh3bu/XdTDtCJrmF0mBspciMRVpGyDR0ndd9FcSfCd2jYkt0yE1ekm1
eGs2qE+mukSs0sHp3hsXLlI6iPHZmPp8pcND/q/sh/ekwJ+rlZPndEiIbvYy
Pv9QAQRxuu5s4SChBS+uubDcLLhr8VyY7E4HkVwr+p6AZFjxSgwLXqTDLfGX
X2VDc0Ao6FDpTSChSBmmgM1bCRj5o3YsPJUOB4qNjpYeTILxPu4H96xJKKCU
hSneNhnWZ3dr+LGQ0UzrZq+dI7lwv2N7YSUTGZ0YUVyPi8qGo0JBXtUNJDST
JnTQ+EgOROt1ZmqeJaOVCrTzcl8JTKSM/BLaREbNUYHbLfECKKhNj5EsJ6Hi
4qGOr48ZfNo/Z/oXY7/bZmb6Er0lIDfs9dUAyIjlX1DGUlQ58G3Uk77Wk9B5
XkEb5aUC0DN6XdH9goxsiOiHtSPFIHTBbfemDTJKTVXtQgz9tZQ17205QUZv
8q4VTz2phM9pc5KNBWT0QUSj/nZRNQRIfrr3XAtDlkXzGtelGoBjU23S0TYy
8js9d+GETR0cEsn+LBpPRjF3RNWeOtfBYrbG9mrGflU6KQn1MU2wgF+f3sWH
oRuRe52ePPoH2YpP5yfCyehkrp/mZsacuk/KOcl/A0M8OWVbeP9rhv9ifdSz
cQythtjJbwpugwqTvdMBfhhqThbwfmbWBkWCzewpzzBECaDXOSp3weBRlz2v
pzG0/53K3kt1PRBVdVtd9DrDX6Xvo6bSAzsVqCYfdTEUv2PziuFsD0zTUkY1
PTD0T+zIfsVP/XBbfsVTxxVDrFflLv281g+rPWnMHXswNOy5mNp/rB8Kgi35
Oicx9I2Zfrzg7iCobXOO893MhOYD77f7cQ1D1/UiJ44yDO3KvhFoRxmGX7s6
BBMKMOQk/vVkjMwYYM+dq08wMaHP1jnuZVvG4ba13z3cDEMX3jrnHh4bg8py
euwVcww9ePNfxzmbCTj8N782+QOGZN6p9fadngbb1eAgQ20MedD6bYOcp0D/
/Gur8d0YGtRyXrKInAbTBDNjiWIMSbgqvnnNRwURD74ZPBhDNkcWt9zIpwLS
5hNBqhhqTyL7fh6jAklv+VLqJQxJpQ1KebTPgg2nWVK+PIbc2cqtv3TOgqHB
Q8rmEDIy97jIe0JkDjRq9l7njyajF2F6w4fQPHifkYlzjCGjsWpWFQG7BTAK
qnMJ5SOj8ns3f5xmXoDdqil4qz4Zkc6+GDLYtwh4+MUOnvdk5OxCS5gxXoLD
/gn1i6JkdLxhovF03hKcNZ6Yn8sgIa/vw52nLZdhblOx4aUxEnp2ZnN7M88q
1Hr/CfpyhIQy+fqOtnasQMkr31rdBDoD5zQ61p+vQpS0/OUDkXR4wu5Yq9W0
Bh8aRz+0CNPhVLLNOqvpOtjmntYZ+rQOx0Dw6l+GLfi8fveTzxvwu4U0PFey
AZbpjk5X+DZgINrm2+/3dBDYcdFtpXkN0ivV54Xy6PDyTh1LIgN/WySJvApv
EnJanQ1l/m8NZGbslhWGSKjd89DpwUMrYHSFdUipnYSAUqu/o2IZ3vzUipFi
/AcW0y2NF+4sw2gtutTG6IuWdD0WG/kl+Fbl3H61hIwOaSy4zbIsgr3fhQv/
yWGo/HmQ8jSxCNo+J0RmMzA0EU2+nG25AG5YRYt5B4aO/toyep5nHhbkpFUX
ZzB000rtyO0fc7A53MbG4C8TaoZDV3MTZ4G/hd1cM4gJvWF9qxExSYWk9zuw
jQwmZDn9WRzzpkLPSpfAHQVmNHvEQpYaOwNfGnk+xL5mRtFv5DpyGXwmQ1RG
f1CRGS2un57MtZ+ErUmXT6NaZnR/aaJQIW4CfJaUc7yZKMipj/zY6MgoyMlu
1yqkMqPk+x9aaL1DMPTuWvKufRSk9+f9KyUGX5P+6Bvtkk5B5qU9bwq39IH2
gPZJDn0KKqduypWS6gGutgM8wq4UhBwOdTvWdAJriWsGfzsFzdROJLdvawGp
1u/uISkUdMlrXOcCUQuC1id2Z0RQ0N19vXdcTjRAg70G1zIHC0om8+8vkaqE
kr5jmNYQBTkcM965rpMDmypCp0VyKIgjfC1WPjQGKg9/bifkWFDBhmiha4I7
GEXEx9esUBBmZnk6Nq0AP93N/Z84I9/GIdZvPxaL8Qqb2LilAQpadrqxR0Si
GleYu1OyOEVBd+J8bP1/NuHiNAn127coyOPVIXYJn1b8YMUWWgkj31fenhUu
gS14wunk0fhwCrIN3/5SdF8PPh6k+vehOgU9PoN3Wfn14T60kCFzcQqy6HmI
2bzrxztPGhrWeVKQNbuddogPQ5+t5181rGJGNu8ufV0JGMXDD9oHP0xnRt9H
/ytTuj2G6z9fXT2TzYyMgx/JtfFP4upzHeta15mR9Z2LeyuPzOA1vf+tbO5h
QoMbO/pSOqbxP10v7+fJMSNb6yaeOzUzeNw1N/H5NCb0e2dwFOkWDVd3fuV4
8QQTct/EvVOEbxbHBwoCBXWZkGmY9N9H9rP4zFBY6vwRJjS8vWvlbsg8/qMk
3TTrCYauzJGWeObncclRpZ6WuwzcNWzdWh22gH/YyXZIgoEzE0GmbIfYl/Au
98cGAe5kZCen1HKUexmP5P2yP+wmGeVKeuykiy/hRe7d6r1GZJRUsCX9et4y
Xp82qqUVS0LfRVyNxX6t4NsOcF3da0hCKd2u7KXDK7iZXqZi+gMSOrhRXz0Y
sIofqvunIfKGDoEf8dQiy3X8Rny3e+6PDVh955bYJbeOm2/NX5Rj8A7uO/VF
I1s28CMbq8365uvg56V6/44KHW8zGj04x7YGAtIxvElKdDwjbPbt2K010PP9
qToftYE7HJcwlb6+CtlhAZ+XuUjEO1dL5ie7V6D6lpdj10ES0aNwTfrA72UY
pzrwTSuRiNkOZEPqXIbLGZGMipGIwTLKEenhRWD51sg+s5dMpPz2LfTwWwRV
mGX9xEsmrqBPXdvoC8DKoX9Bzo1MzOgkaK/kzIPuXNgurxYykYQJs4x2z4EM
uSrK5QqZsL629jlSex4ezvuy1r8gE7JmhZ5bmmZh+m4Sr8EgI94wRuHVEA1y
t/Xrvq0jE29LLg6ea6FBYm7RgY9NZMLjCQ/L9FOGrijjt6G+wYje6/sPP8ye
ga/Z2/ndLDBiS9f5DZXwGYj8ZulZboMRJlb+F/K+TgPRqb/pSxVGlHEFf1kS
YeBGDHukazVjfSXb5W9VE8BiXb9rhQcjli4HeBE9E9Chpsbe9oJhh/NbbeUc
g/6hykvXP2NEadZDVtflEej0Xm4rYJxXHuJWK3B1FEoMQj/3O2BEQv159w8v
hkGSxi3GKsJEmPxU7u/WG4T9CXtpEUkYocfb7mEoOQj1M3vHApoxYvXbtHPe
iX7g2Nqw7RY3E9Fs9Dru5u1eYKPJhVwuxYjzlaXJYagPKj/ExIxxYcT+lNrm
JftesG/u5sbeYsQv0/usIRZd0C74zu6BFUZItq/VFBV3QvixblENRYwYl06/
eJ6jG7b5m5dilhgh98VDK3miFZRVDsiifxjhtu+gcZZ0C7AYGLAfuYQRkSBq
vSW3GV4Gjle+88KI5OYLTbqCjdB/ixJ0NBwj3sWevSa2rR5uze/DybswwmKw
J0xTvgnO8S7uZPEiE995C1drgurhLFXuN77CqK+Vl+HR6BrI/JW6+0Y+mbiB
u+SFzv0FXuqCsoMnmbh+jP1rO4OfBZ8spIQy6ltiTq4p21wOxfdtsdUtGME/
Tm4N1SqHlBMjjavBZGJe7/3m0cdlAKrSJ8YayESPm5xQlGgB8E8uT/rXkImr
subHfx0l4JPRW4OdMmRC47Wf1JvaMtA/WRPNkkciYtVpR6skC2F1Uzi3myCZ
8Gn7sXI9Kpeh78DO/g+JqCgTOpXNUwCGcwKk8VASEfbJqnHtv2Kw5JChDKyQ
CJfhRw731dPAtLeNZYGHTPA+psceNckG8XMObUfjSERTxA4w/JMFJGPLpPJ+
EhHwdTXn0UAcpFMeUXf9JREqXX8e+lGTIOme6lbJ7SQiOH37578DBMzVtxty
uNLxQ8JST9SfZsI+4y+2xTwkou55PVl+OBkS9tZkuDH8yeh984xiLjTffRRq
pkjHWT+3rvPpFMBIaZyu8AIdn2T/0f7zQxLM/gsaMmEiEV6Hg1CSVhb8HUz1
OKNFx9OfVL4XTM+GZPsEea10Ok6ZPyFw4G4y+J7dYafsRsf9JZgr3h3MADPn
hufZHBt4tzkt0lmqGEpOP9Y6YLGOFy+F8BwTYuiluc+fqzbW8fbs681eR/Lg
SXTqX5brDD/THqw5pghGq3xtOljXcRFW4p2STjnQPB/3+Zav40l7fHsLLhDw
GH+726h7HS/0bTo/GFMML2+cBXaBdbz/V1H0ZHEptHwdul7gtI6HBknLiTws
ggvX8W1rJut4RAjfpS6eUggxFE6jDa7ii1drfv379BesLr91SNyxig+fc4lb
3F0NN+L7WyTwVXz39vqpM0pVwMS2K4157yruSdP0GPCtBS1r7ZP3clZwqxSN
kaNvGsDs7acPzjdX8QuuMgXp/LXw3vp8Ev5tFSfMC4orGHrWhayyyyJ7BX9i
4HDPfbgBYneIJlXzreJJxMo/7bB68D782YqPm3E+z2jyVEQDiA1bbdX8tYx/
0vmnO2fVAjEpr4K0vyzhp/RKssk6LfD8kK6Dy4llPNo/ss2Arxk2/bzqbkEs
4VURfLpRA63Az+ROYd+/hH8vSjxu6t0JiuvTRo8Sl3Ae1f/C/lUw9EYqHvZy
xzL+YIL4OUzqgDpJERWF7Ut4dIL13nuZXcCkp5Zurr+EO+uuHBSkdULpm4nS
pPtLuEA6WuU42QX88RNiEfsWcdGj7f9uXO8FFTe0tbNgHleVbKl6u9wLWa0s
CkpmCzjpa0rqDcVe0BbQ5N5BXsDTy6/KC53rA8PrY3UF2vN4bcjrPMUnA6B4
22Nlj+s8vvOT++27vv0g22Dc9EJiAX8tsuFxmGGn2bInpwrO431DB1g2/zcI
geL9Nx+zzeNLxaJqhw8Pwi68p+bNSYb/xJ39ITMDDP4f3Slyag7nbKk7NFQx
BPNxUVHYaxp+7jCtHm0bgV2iHQeix2m4AS8mLX90GNJ+koKDCmj4lipAbd3D
4NKl/jd+jIpzVRR2XtoxBiVHBQ0M/lBxfjOdlg/DoyD40jiKz4eG97eYVLbJ
jEIqj2nowDcqrtSk9GSxewxyFM+lgBIVv5B9YKz67DhMLbfHfnek4nq7L4tw
Jo6B+qG3951aZ3D0UHSvxeA4tD5b62r+NYn/s/SUPkVMwuEn4+a3Qifx3gnP
fSWkSdBO3CtnVDaJNyxYJpmyTAJTyl5XGt8EXu/GlLzIOQ3zDYOlB7jGcXv9
yZ39sdPA/sxm5fj7CXx7hPTXmJNT8HqxYa/GsXF8aM+/V35R03Cf0qmdGT+K
pyuEDc+cmoE0LbGjmZvGcIW0L6sdTdPAHT2lUuM2iovqZy6wCc+Ah71OMO4w
iC+NfhzNEabCkCj0flYawMUPW94un54B6ZqGhud5A/i+g/vrEyJmoFW4tkPM
oB/3VPhFPXiNCiuZEwLufr34c80VITYeGmzoE1+qI/vwCs+Dmi1HqFCULqxU
p9iHc/9JpZm5M+zWsby5bT34ltc6XunSNLBknZYk93XjryMqOE8NU2HcFK8W
5+vB/fze10hGM3j/VrXkbtVW/MKjxcz6FzQYHViznZhrwAMen3OTDKSBpPy8
Lb9QE05X+dySto0G2+zeMLfoN+A6WqyN2rdpUKfgpvJVrAa/0p5jxHphFo6+
EKgZ3/MX51pSN7b/RIMjLe+Z9rjV4lFsmx2P3aTBWR7O/A6hcjyiiOmz3qZZ
mGqO+yf5uxgv/BT9XJt5Ft5JWrTPeZTiLZfOvHzPiFfUPP3o+1w2nvbktPO3
ZhrYFrWntVj6wKxLqN0EzML9th3HMlbdIOhD8pYvaTTwb2+f8PryCezcVubU
3tIgZYTb5+77dNAI4H3A4KVgv9YjVfQgF6prmbIEGOc391MO71NOgTsVpcUs
12jg6D+xeNuHgMrpKNncGob91nH/Q9dSmDXLEYrbMgvX3hkIDAqWwMvd51qf
qtOAlYmitNOjAuwUhg78UqaBa5milLZpE7y7uKWou4gG16WvLD/79Q9ym55x
11+mwa7rx6NU5f8Bx8Cqh9sfKpRZGV0tvdMKQW9/LDG9pMHj7ztnd//sgG2R
ps/YntPgg+yBkUt9rQADWTUL9lToVJpN4RHogM6f5yUTP1KB5c8jXc6Wbsia
Eyr8t0GFPbnnW1iWusGS4pQqqkOFne+21Lyd6AbFgiad5wUzUHnIvD9ZYAAC
LJ7z7FeiQvoScy8vPgh9ePvLJVYqGKhWs1qeHIQtCjdV9TVn4FYgt1XxviFA
E3ttD3nOgIwsJZXNeATevZz5NjwxA8+pE+b2CsMQQLsudfvXNNj7/oxpvjwM
mhu2kT3s09DTG5M/rzEK1o3E5kOj09D/jWS2q4eBAwPNGX95puHmGuVwxO5R
SOaUmqHDJKQN7C9YfzoB90Ofzzd+mYRzjZcc1LdMg7jORML73Ekw12DCirKm
gHr2akSV4gTQ+ZKtt/VOwaDyb6uiynEQ+6R35IX7DDw9tXOVJD4JYjsWyOwn
ZiBpi2i7m8Q4KHNGsUsy+hQ43r9QaBqFWs9MfSkGj424L1/w2XYMhlifxL3U
YOjfA9oeM6fHoNN44eFS2QwMrQCHAOcIPLAu0nvQQ4W95qVCr7KHQf3IMJbr
NAtMko7knQoj8Imz9lWKK+NeWZ3SvbE8BPfy6x49Oc245xl2SuSaQWAWjVN5
fnQOolT0NYyvDoNs8F8s8+wc5AXE2fK0D4LDxEac669ZuPvGIKd96wBw/au/
lKEyB3ca8jad0R+AxY5w0svhOai8m/P1e9UACIQM6aq8nINRmuse77t90BLc
yLQPmwdPCw9T7de9cP/ye7agigXopHZ+fLW9DySuOX25zLkIrxw2X7lxpRfK
j17aV5uyAOfyJZdZXLrhl5a/6q6zixByEgu4Ar3gzvx+/n3hIiw8Nu/MuNgD
mT50iaHhBaBgVNOYog54oJS021aJoVPOV4/2WHfASMHsnw+Ti5BPaRWgqXcB
LdhL4Ef8Igz1d4wnDraC6SIf55vMRchh24SY1JtBcAf5dIDrMrySsztnYtEC
0rcf3eskrYC4Z1ZSRVczcGpdvBX4bRm0pPDQd7aNECzyqq97cRmeb6+LOMDb
DI6Rl5t0IlZANk+6p83mHzTwbKw0py2Dnwj/CtmjHtSyKzFqJSNeZvjefFId
ZFtYjns5rkBULvPTKc5GEGJXsPCyXAE5j8N6V+7Uwle1vJunRFcg+DPXb4Hv
lTBC4eFm71mFko7RUyXJf+AEb12L9ps1uFQh/Mf/UjWMZ6qFpkmvQd5aWM69
uVK48OpjXYXBGrDtcU08llYFh6/9cR7fuQ5hS1/jnl36AxFxsWttsmtgY/Dr
l7poCfTzeBtTdq6Bl03uv0GJIljTFYv2LV2DnYoNb19Fl8P8XWeh6do1OCFN
jzTtKISKrZcPfL60Blh3FuawkgWNj75vfcC5Af8m+D5feJQPb8qftewp34BS
qXP7pUsIiHbbXRT1ZAM6OL/om3tkgIlHZMlvxw3QKvZ5NKnK4OvtT8NkrtFh
aW/d5uuKhSBmWD6ne3cDPJhvxaYkZ8InXdkeO4MNOLnvS6jGjzSQLdTdvmNm
AyIrvY+75xFQFRM1ELmJDmbqF1uezWcC53iB+dlXjHj+ZtvBtGh4jR1sc9vK
0OWjpzeuPk2BE8e70iofkdDgs+41anUW7GuMCVbVIyGVg2TvB+8SoVFXKqVd
n4RO3Ws9PnMoD3IDry4a/CYhsavMu81iCFDIZjVJRCRkwIvLruZmwPlA7z07
DpNQ3pk9lkLcGeDiM0zqcSMhjZsT8CKsEMYt/C3tvEho5LZWqsDDPBhevycd
aEBCV5ZtVbb/SoXdY9Lr+RJk1GSdcPPQ3zz4OJ69mvCYjFaovGpW1oXwoz01
OlaHjBY8akPOl+RDwKfBtFtnyEjQd8A66k4Z8Oz4w6GcQUYhAsYfvuVUwGPb
F1eGFMnotoQWd0JWCbTv7FYfOERGF7S+s5vpl4H8Ny8H19dk9PzYWkubaC1w
jmi0PX1CRvQitt0Br6vg6vydr2UGZLSaUWf226cCfr7XULotiqGIndkBvJy1
UGU3UnX3DIYMLfqlXLTrgcp/WyxWGEPrXyw0SrfWgY54zxlRVQwxix27t6/p
H2j9m2e9bochgfUbCWK2zSCbllsjuUhGLdLnNVR1/8GHotPlS5swVMrWIX7r
egu0cvuRHxhi6Kp4RGywcSdoRPlqZG/H0J7cXQHRiW1wxed5kYU4hoRMD6uo
OLXDr8K0F5OtGPq+0yaDO7KboY/Jnvz9GHIWI9fFD/SAwh2FbWUhGCowiAHP
yh6gySX/uN+BoUkbvZUqtQFw1hU4l1CHIRWltugr8gPgIyV3yskEQ/0vR/e1
yA1A/Kv+rAB7DCXxH9m5a3UQGoTOyfPEY2jnxPnaJKMRMFSWsTiOMHTptuY9
X55h8BlVT9X2xtBUzun7dt4jkKNP5R/nZEJsA7b0p41jcNfgy8sfPRg6cWdC
czluHFrYE71CPmEoo+wiXdN5AmwtH9yPGcdQ8tnoFonhaci8pfM33AFDdebr
tka+0xBS2zUfL4UhR/KfxEsSjLnietGNVRtDViybRv0sqfC0i8bErYuh2Q8f
+NXkaCCRrBN2OIGMHEhZJ+8y5oaoWkH+a0a+Y8Q2saTtsyCePVXoZI6hcT4b
4RO75yBRraK4iYQhNqUX+7xuzcG+hEv6W3LI6OzxV0vpHvNglry0aTsLhixP
OcVsjl8AFk+mBs3jZJS667g9yXcBTLF+E+vNZPROW9coz2ARDPZ959bYTkaL
FKk3qSVLkBCj9SqqloT2/p7dOde2BCPv/ZqHVEmovZ/L0kJ9Gea9Sexfmklo
Kv2k0pXvKxA6J+tr6k1CZg/MpZtNVwEm2bxmWUjozLr3zdkPq6DDLZ6qnk6H
a31vY+quroPTBtdKoz8dGtiFkulB67Bw/m3Ata510FS+cYK1YB2Sjr80HYxe
BzxnUdTnzwbwI3fxn6brUNuYczaWnYSEJPV44vkYeOjE6in6gw4n5S2uVUSs
QhCkfYs2I6EUJVKV9K41EE/kzPg8xsijUHMXS+8KWCaTjl/YSkbsp5jvbslZ
hk49dTdNRt8KC2amUr8vw4mCY4ETchg63ydiwXNyCaI3j3xiWiKjmy/8XvNt
WoTYq4nzBxQZdY4TEP2SswB7pH1uVBZh6NZ1QwmiZx5UFHjZCS4mlDIsxCPB
Mwe9Pfd9uAcwFHb5+UcJrzmg1h75FvieCZnvYf6j2jQL7k3L25armJD6Hf/f
xYgGQsuHb3VWMqGHsoeYTzP4BU2jO5p+nBl9jD77DNtGhQtnHR6//86MUNza
Uabvk7Cz8PGnuBvMqNMsB9ttOAFvbZ02rWQyI+U9y4sHWMeh3cFsXFuSgu6J
W715LzQCrodLjbypzCjtC8dTu4kBYLUW1uNg+Dv0gnlFjg9B7HQLJ78XBYl9
tPzZOdUHV01VvDEHCjovgQ8El3eDWJhVPlhRkCXn86yvgp3w7OqbzcXcLGh3
um2459NWEGpn/RuKU1CuWqyzxHgtPKgK3hcQR2Hg2O1D+tY1kCpcvPn4PAVJ
eiKna3ElUFWWxETawoK+Pm78bEKKhYu78KR/fhQUt6dPArH6AdFh1HmBgwVJ
l4luNz/9EESOhJGukVhQMumACf1wPv7r19bFt9kUpLm77GULrQzP26RZ+Z6g
IF+TgK6mJ1X445chEXzSLOjYEt1NPqAJ557keWjiREHHbksb7uBqw3+/kIhm
f0dBqtRzJoHPOnAiTOvDl3AKYucrmX4t24t/CTDe/EyPglbR72jpyAF8qFqP
TYRMQQov6jS83/Tjr4x370jSpqBmOy75raZDuE2rmq15DzNyDOmsv/BsFMfh
rF+1BzMS+/7ew6p7DG9ae1wikMOM/gbmcx/DJvAn+27rVtkxo3v/jkuynZ/B
/c0vX5ujMSHs+bC68scZPJ4QmE5cYEJtQrseCLyk4hk1R1UEi5jQ2rWHTPI8
s/gD+SivYBFGvCef3rnVWTzpdUxXphITUjj4KSzuEsOvHDstRmZCv1meBt2T
m8eNM/ZJhNtgyIN1i8EFkQUcf3X8WooshgI2nbq3+mABf3JkJM7qBoZsmh0e
d7xdxLuSf618+UBGTlLKhuwiy3iTRgjN05CMtkQSITaSy3hdZxFQZBlz8M+B
62onVnCFS9VebbEk1JTunKP9cRWnqG0//nELCfWzfW7R0V3Fj8WFrq6dIiHe
jCe7pOxX8a8H7+ypsaDDw7+jexr61vCDEUu8H09tADkn1vTdsXU8SuKwtBUf
g6cYtsXq3VvHvUXVvqvQ12H77RKuB5x03HJbj8W7HWvAt+Pt8+HrdHzveDDH
i6FVyBaX8+ILp+NfaJ7/mSuvgr761dATl0nEfxv8soK9y5A/dW7eKZlEeBLH
/CIMliHdMfjZ0E4SwWXSrmFttgwtAw/ZMkNJxBkYd902wuC5EQ+nryySiImH
HRNO2xYh4EOcvMgMicAHzgboSi+Ckpe/kcxWMtG5ba3jlPICVHvVPDozSCa6
7d++i2HwcLd93NVs4WRijeOiZVbCHKy0xl+M6iETr+l/jgYlz8Ko1096izZG
vAs8uFhjRQNjlsrw+8oY8aatyns9gAZ7w96rqH8hEzJU8Y77dCrwto6plBzC
iMtXpBR/x84Ax7OuZS1VjKgYqr9fdGwGzmZe+4sJY0Q/8734IasZiJfZm3Dr
BkawN4xy9MdNQr7LWUHrUYwY/RxgI+g1AbFT7nkGbzGCdLm6UKtuHJrtJJoP
NmJEwciotIP/KIypLrUqsjERdyf52jKHGHpmNUdcLhgj1uyz3b8IjgIP5/Yc
RUY+ug2szKYLQ+BnV0XljceIhuNcfwroA3BuMLtJwhkj9mzVTVDvHQDlzBbf
CFOM2B3H0uK5bRAGPuhu7CvHiMgwZrvTYb2wTcmf+984RpSbnF+796kX/J8R
v7O+Y4TVtWf1S8E9UKPWVpk2iBH/A/9pK7E=
     "]]}, {{}, {}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-4., 4.}, {-4., 4.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Prolog->{
    Thickness[0.002], 
    LineBox[{{0, -4}, {0, 4}}], 
    LineBox[{{-4, 0}, {4, 0}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.880458236912816*^9, 3.880459498439193*^9, 
  3.880463149906624*^9, 3.880464070289773*^9, 3.8804642123995943`*^9, 
  3.880612969035183*^9, 3.8806131002799587`*^9, 3.880655520676552*^9, 
  3.880702740884008*^9, 3.880703456499322*^9, 3.890982081450185*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"0a303672-cb5f-4d4a-b1fd-78d04361694e"]
}, Open  ]],

Cell["\<\
Produce the four unlabelled plots for the case of 2:1 resonance large \
libration amplitude.  This is Fig.8.16c.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8806136263053503`*^9, 
   3.880613637944726*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"076378cb-11b7-43cc-a850-929a76f96ec2"],

Cell[BoxData[
 RowBox[{"FourPlotNoLabel", "[", 
  RowBox[{"0.001", ",", " ", "init3", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.88046267960392*^9, 3.880462680234071*^9}, {
  3.880463182008906*^9, 3.880463182578125*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"00a9dc06-b573-4db1-a30c-fd0c79e6bcc5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcNLC", "=", "gcNL"}]], "Input",
 CellChangeTimes->{{3.880463026210558*^9, 3.88046302986303*^9}, {
  3.880463083413727*^9, 3.880463090373127*^9}, {3.880463186522532*^9, 
  3.880463187214306*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"c3e26c24-4678-4986-9030-62dcea1c6e41"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
       {Dashing[{Small, Small}], LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], 
        PointBox[{0, 0.6378370000000001}], 
        PointBox[{0.1, 0.6368821941042105}], 
        PointBox[{0.2, 0.6377376120620503}], 
        PointBox[{0.3, 0.6396055726512849}], 
        PointBox[{0.4, 0.6415525161395735}], 
        PointBox[{0.5, 0.6426191389595117}], 
        PointBox[{0.6, 0.6421590516526469}], 
        PointBox[{0.7, 0.6405839236206406}], 
        PointBox[{0.8, 0.638625423643196}], 
        PointBox[{0.9, 0.6370250314374283}], 
        PointBox[{1., 0.6372895105942552}], 
        PointBox[{1.1, 0.6371783567680237}], 
        PointBox[{1.2, 0.63698513254673}], 
        PointBox[{1.3, 0.6384229416194981}], 
        PointBox[{1.4, 0.6405201594590314}], 
        PointBox[{1.5, 0.6421756607824674}], 
        PointBox[{1.6, 0.6423266992496549}], 
        PointBox[{1.7, 0.6412091475334563}], 
        PointBox[{1.8, 0.6394453866905508}], 
        PointBox[{1.9, 0.6374799772506322}], 
        PointBox[{2., 0.6365833894925275}], 
        PointBox[{2.1, 0.6375619397472995}], 
        PointBox[{2.2, 0.636533499314694}], 
        PointBox[{2.3, 0.6372393393555231}], 
        PointBox[{2.4, 0.6391552119769092}], 
        PointBox[{2.5, 0.6412892917115302}], 
        PointBox[{2.6, 0.6420822917462217}], 
        PointBox[{2.7, 0.6414284911208689}], 
        PointBox[{2.8, 0.6400101071223698}], 
        PointBox[{2.9, 0.6380484245494241}], 
        PointBox[{3., 0.6363010865542043}], 
        PointBox[{3.1, 0.6369622029248629}], 
        PointBox[{3.2, 0.6364825903520982}], 
        PointBox[{3.3, 0.6362317377132519}], 
        PointBox[{3.4, 0.6376386975028734}], 
        PointBox[{3.5, 0.6399876350053509}], 
        PointBox[{3.6, 0.641455840289929}], 
        PointBox[{3.7, 0.6412654671930236}], 
        PointBox[{3.8, 0.6402156970466175}], 
        PointBox[{3.9, 0.6385188526645547}], 
        PointBox[{4., 0.6363543410812561}], 
        PointBox[{4.1, 0.6358262831735159}], 
        PointBox[{4.2, 0.6366646408431473}], 
        PointBox[{4.3, 0.6355093233282294}], 
        PointBox[{4.4, 0.636176038723186}], 
        PointBox[{4.5, 0.638366738255963}], 
        PointBox[{4.6, 0.6404708872978255}], 
        PointBox[{4.7, 0.6407769817733724}], 
        PointBox[{4.8, 0.6400553374157109}], 
        PointBox[{4.9, 0.6387234362017401}], 
        PointBox[{5., 0.6365561151353738}], 
        PointBox[{5.1, 0.6349672124954112}], 
        PointBox[{5.2, 0.6362649388308609}], 
        PointBox[{5.3, 0.6351132855392743}], 
        PointBox[{5.4, 0.6349119354127855}], 
        PointBox[{5.5, 0.6365997451500864}], 
        PointBox[{5.6, 0.6391528793870231}], 
        PointBox[{5.7, 0.6400221368720591}], 
        PointBox[{5.8, 0.639583377928648}], 
        PointBox[{5.9, 0.6385919033921716}], 
        PointBox[{6., 0.6367099279964682}], 
        PointBox[{6.1, 0.634436731686783}], 
        PointBox[{6.2, 0.6349969605687896}], 
        PointBox[{6.3, 0.6349731226359135}], 
        PointBox[{6.4, 0.6338984882086304}], 
        PointBox[{6.5, 0.6348792523611835}], 
        PointBox[{6.6, 0.6375554785636276}], 
        PointBox[{6.7, 0.6390493255937324}], 
        PointBox[{6.8, 0.6388723050344823}], 
        PointBox[{6.9, 0.6381426048880458}], 
        PointBox[{7., 0.6366554936403538}], 
        PointBox[{7.1, 0.6341122510641799}], 
        PointBox[{7.2, 0.6335967860454036}], 
        PointBox[{7.3, 0.6347658855736237}], 
        PointBox[{7.4, 0.6331133181506099}], 
        PointBox[{7.5, 0.6333308304827215}], 
        PointBox[{7.6, 0.6357753256265269}], 
        PointBox[{7.7, 0.6378929388234724}], 
        PointBox[{7.8, 0.6379842757382002}], 
        PointBox[{7.9, 0.6374359023020705}], 
        PointBox[{8., 0.6363146267550683}], 
        PointBox[{8.1, 0.6338499936668787}], 
        PointBox[{8.2, 0.6323752251955996}], 
        PointBox[{8.3, 0.634041618306399}], 
        PointBox[{8.4, 0.6324769331842103}], 
        PointBox[{8.5, 0.6319744101042133}], 
        PointBox[{8.6, 0.6339364150834332}], 
        PointBox[{8.7, 0.6365780686253828}], 
        PointBox[{8.8, 0.6369603705727558}], 
        PointBox[{8.9, 0.6365286443269608}], 
        PointBox[{9., 0.6356833877928625}], 
        PointBox[{9.1, 0.6335022768864375}], 
        PointBox[{9.2, 0.6312986934798596}], 
        PointBox[{9.3, 0.6327886256504655}], 
        PointBox[{9.4, 0.6318573219133189}], 
        PointBox[{9.5, 0.6307484940175435}], 
        PointBox[{9.6, 0.6321376864356851}], 
        PointBox[{9.7, 0.6351288757122315}], 
        PointBox[{9.8, 0.6358184607230162}], 
        PointBox[{9.9, 0.6354535010340084}], 
        PointBox[{10., 0.634788493633718}], 
        PointBox[{10.1, 0.6329462229030746}], 
        PointBox[{10.2, 0.6302628040228243}], 
        PointBox[{10.3, 0.6313126964088105}], 
        PointBox[{10.4, 0.6310882014802937}], 
        PointBox[{10.5, 0.6295462064243879}], 
        PointBox[{10.6, 0.630409947768004}], 
        PointBox[{10.7, 0.6335737581736183}], 
        PointBox[{10.8, 0.6345546782089312}], 
        PointBox[{10.9, 0.634212796812633}], 
        PointBox[{11., 0.6336485137926294}], 
        PointBox[{11.1, 0.6320990388973408}], 
        PointBox[{11.2, 0.6291446918868412}], 
        PointBox[{11.3, 0.6297812251336906}], 
        PointBox[{11.4, 0.6300228756209993}], 
        PointBox[{11.5, 0.6282456933260367}], 
        PointBox[{11.6, 0.6287183736489472}], 
        PointBox[{11.7, 0.6319460475190027}], 
        PointBox[{11.8, 0.6331479169407643}], 
        PointBox[{11.9, 0.6327822078500893}], 
        PointBox[{12., 0.6322580006825529}], 
        PointBox[{12.1, 0.6309085710392573}], 
        PointBox[{12.2, 0.6278114437555318}], 
        PointBox[{12.3, 0.628208923901719}], 
        PointBox[{12.4, 0.6285649578332296}], 
        PointBox[{12.5, 0.6267329536846631}], 
        PointBox[{12.6, 0.6270019296056918}], 
        PointBox[{12.7, 0.6302866513434161}], 
        PointBox[{12.8, 0.6315664624640235}], 
        PointBox[{12.9, 0.631123408653517}], 
        PointBox[{13., 0.6305941498753396}], 
        PointBox[{13.1, 0.6293356037036151}], 
        PointBox[{13.2, 0.6261391497335607}], 
        PointBox[{13.3, 0.6265683036275512}], 
        PointBox[{13.4, 0.6266565075400478}], 
        PointBox[{13.5, 0.6249501986245575}], 
        PointBox[{13.6, 0.6252316845291926}], 
        PointBox[{13.7, 0.6286542933712179}], 
        PointBox[{13.8, 0.6297794226180365}], 
        PointBox[{13.9, 0.6292067749787863}], 
        PointBox[{14., 0.6286397752789761}], 
        PointBox[{14.1, 0.6273505292955187}], 
        PointBox[{14.2, 0.6240587135005852}], 
        PointBox[{14.3, 0.624832035367987}], 
        PointBox[{14.4, 0.6243146626465939}], 
        PointBox[{14.5, 0.6229470353703107}], 
        PointBox[{14.6, 0.6234811665856057}], 
        PointBox[{14.7, 0.6271310365991609}], 
        PointBox[{14.8, 0.6277804082534083}], 
        PointBox[{14.9, 0.6270515539592055}], 
        PointBox[{15., 0.6264216020933094}], 
        PointBox[{15.1, 0.6249483383599362}], 
        PointBox[{15.2, 0.6216545012039392}], 
        PointBox[{15.3, 0.6228666005952181}], 
        PointBox[{15.4, 0.6217608100673785}], 
        PointBox[{15.5, 0.6209199716835341}], 
        PointBox[{15.6, 0.6219770715864787}], 
        PointBox[{15.7, 0.6257512437785998}], 
        PointBox[{15.8, 0.6256157027561816}], 
        PointBox[{15.9, 0.6247535504235039}], 
        PointBox[{16., 0.6240306691939398}], 
        PointBox[{16.1, 0.6221563277592578}], 
        PointBox[{16.2, 0.6193083629716057}], 
        PointBox[{16.3, 0.620414031126556}], 
        PointBox[{16.4, 0.6194046916112294}], 
        PointBox[{16.5, 0.6191665096766554}], 
        PointBox[{16.6, 0.6210703785379106}], 
        PointBox[{16.7, 0.6243725709402126}], 
        PointBox[{16.8, 0.6233969636139172}], 
        PointBox[{16.9, 0.6224622937983968}], 
        PointBox[{17., 0.6215869027088534}], 
        PointBox[{17.1, 0.6190475941380634}], 
        PointBox[{17.2, 0.6175839804650461}], 
        PointBox[{17.3, 0.6179561725570162}], 
        PointBox[{17.4, 0.617599854439743}], 
        PointBox[{17.5, 0.6179865729085741}], 
        PointBox[{17.6, 0.6210191393796223}], 
        PointBox[{17.7, 0.6227455567432026}], 
        PointBox[{17.8, 0.6212663983615246}], 
        PointBox[{17.9, 0.6203079524056976}], 
        PointBox[{18., 0.6191524552067988}], 
        PointBox[{18.1, 0.6159550231363021}], 
        PointBox[{18.2, 0.6161706092158742}], 
        PointBox[{18.3, 0.6162735015077652}], 
        PointBox[{18.4, 0.6165022994091028}], 
        PointBox[{18.5, 0.6176232877742577}], 
        PointBox[{18.6, 0.6214554158155183}], 
        PointBox[{18.7, 0.6208721996777812}], 
        PointBox[{18.8, 0.6193363031137407}], 
        PointBox[{18.9, 0.6183487173158067}], 
        PointBox[{19., 0.616689533131884}], 
        PointBox[{19.1, 0.6139250076602342}], 
        PointBox[{19.2, 0.6149157028127455}], 
        PointBox[{19.3, 0.6154661276242641}], 
        PointBox[{19.4, 0.6161380093724372}], 
        PointBox[{19.5, 0.6182437235981768}], 
        PointBox[{19.6, 0.6211830307672834}], 
        PointBox[{19.7, 0.6190228707254108}], 
        PointBox[{19.8, 0.6176635946826896}], 
        PointBox[{19.9, 0.6165760410590962}], 
        PointBox[{20., 0.6142287124140207}], 
        PointBox[{20.1, 0.6133250812340196}], 
        PointBox[{20.2, 0.6145512469010037}], 
        PointBox[{20.3, 0.6153759400471794}], 
        PointBox[{20.4, 0.6164983779093506}], 
        PointBox[{20.5, 0.6196543050474951}], 
        PointBox[{20.6, 0.6197377427464078}], 
        PointBox[{20.7, 0.6174363603929506}], 
        PointBox[{20.8, 0.6162715766437855}], 
        PointBox[{20.9, 0.6149653143180662}], 
        PointBox[{21., 0.6124887028201554}], 
        PointBox[{21.1, 0.6134596225958567}], 
        PointBox[{21.2, 0.6148955602634975}], 
        PointBox[{21.3, 0.6158666722635813}], 
        PointBox[{21.4, 0.6175777139853992}], 
        PointBox[{21.5, 0.6206047688118673}], 
        PointBox[{21.6, 0.6179972356845798}], 
        PointBox[{21.7, 0.6162240141388672}], 
        PointBox[{21.8, 0.6151859594853734}], 
        PointBox[{21.9, 0.6135929837249562}], 
        PointBox[{22., 0.612289866515077}], 
        PointBox[{22.1, 0.6144303962139882}], 
        PointBox[{22.2, 0.6157129322097263}], 
        PointBox[{22.3, 0.6168556707921634}], 
        PointBox[{22.4, 0.6192349638801022}], 
        PointBox[{22.5, 0.6198023521738403}], 
        PointBox[{22.6, 0.6166853113302654}], 
        PointBox[{22.7, 0.6154441083570595}], 
        PointBox[{22.8, 0.614478367981673}], 
        PointBox[{22.9, 0.6129150952507539}], 
        PointBox[{23., 0.6135056138835905}], 
        PointBox[{23.1, 0.6157812007282744}], 
        PointBox[{23.2, 0.6168923406061074}], 
        PointBox[{23.3, 0.6182847898854879}], 
        PointBox[{23.4, 0.6207678591110273}], 
        PointBox[{23.5, 0.6182344078778645}], 
        PointBox[{23.6, 0.6160064283898941}], 
        PointBox[{23.7, 0.6151686025736026}], 
        PointBox[{23.8, 0.6143370434002834}], 
        PointBox[{23.9, 0.6131826942877895}], 
        PointBox[{24., 0.6156586221464937}], 
        PointBox[{24.1, 0.6173472358055971}], 
        PointBox[{24.2, 0.6183853022341417}], 
        PointBox[{24.3, 0.6200479945907551}], 
        PointBox[{24.4, 0.6210393629987}], 
        PointBox[{24.5, 0.6172764133145954}], 
        PointBox[{24.6, 0.6159965648249256}], 
        PointBox[{24.7, 0.615523070656417}], 
        PointBox[{24.8, 0.6150621954280004}], 
        PointBox[{24.9, 0.6148187035840136}], 
        PointBox[{25., 0.6179218317912846}], 
        PointBox[{25.1, 0.6191205048027516}], 
        PointBox[{25.2, 0.6201623642498845}], 
        PointBox[{25.3, 0.6218717039915572}], 
        PointBox[{25.4, 0.6202890688393069}], 
        PointBox[{25.5, 0.6172601106630388}], 
        PointBox[{25.6, 0.6166915148754303}], 
        PointBox[{25.7, 0.6166991602696309}], 
        PointBox[{25.8, 0.616230592791863}], 
        PointBox[{25.9, 0.6177534744953066}], 
        PointBox[{26., 0.6201933986858891}], 
        PointBox[{26.1, 0.6211137471922494}], 
        PointBox[{26.2, 0.6221730541647531}], 
        PointBox[{26.3, 0.6233466649247787}], 
        PointBox[{26.4, 0.6199217538024048}], 
        PointBox[{26.5, 0.6180972833631686}], 
        PointBox[{26.6, 0.6181332103983136}], 
        PointBox[{26.7, 0.6187796887048004}], 
        PointBox[{26.8, 0.6177770754410141}], 
        PointBox[{26.9, 0.6208205476152391}], 
        PointBox[{27., 0.6225320461201436}], 
        PointBox[{27.1, 0.6233037473783215}], 
        PointBox[{27.2, 0.6243183078261875}], 
        PointBox[{27.3, 0.6243805943933868}], 
        PointBox[{27.4, 0.6205125304057065}], 
        PointBox[{27.5, 0.6196259373105256}], 
        PointBox[{27.6, 0.6202899864291422}], 
        PointBox[{27.7, 0.6211100997706543}], 
        PointBox[{27.8, 0.6202575107921079}], 
        PointBox[{27.9, 0.6236596111533891}], 
        PointBox[{28., 0.6249193673572453}], 
        PointBox[{28.1, 0.6255993337272274}], 
        PointBox[{28.2, 0.6264618792809796}], 
        PointBox[{28.3, 0.6253789820197578}], 
        PointBox[{28.4, 0.6218650562660589}], 
        PointBox[{28.5, 0.6216152938170858}], 
        PointBox[{28.6, 0.622911449204978}], 
        PointBox[{28.7, 0.623011911928395}], 
        PointBox[{28.8, 0.622993589496773}], 
        PointBox[{28.9, 0.6262183533775482}], 
        PointBox[{29., 0.6272456108910276}], 
        PointBox[{29.1, 0.6278527364983864}], 
        PointBox[{29.2, 0.6284902884103422}], 
        PointBox[{29.3, 0.6266669901533393}], 
        PointBox[{29.4, 0.6236062280017496}], 
        PointBox[{29.5, 0.6237595415219227}], 
        PointBox[{29.6, 0.6255159599168516}], 
        PointBox[{29.7, 0.6247854034432705}], 
        PointBox[{29.8, 0.6254267972415296}], 
        PointBox[{29.9, 0.628446807519961}], 
        PointBox[{30., 0.6293810583672595}], 
        PointBox[{30.1, 0.6299251966647923}], 
        PointBox[{30.2, 0.6303498785031469}], 
        PointBox[{30.3, 0.6282274812502258}], 
        PointBox[{30.4, 0.6254273523376522}], 
        PointBox[{30.5, 0.625768886536013}], 
        PointBox[{30.6, 0.6277278381507403}], 
        PointBox[{30.7, 0.6265170193981321}], 
        PointBox[{30.8, 0.6273795762977129}], 
        PointBox[{30.9, 0.6303082625072424}], 
        PointBox[{31., 0.6312494814668236}], 
        PointBox[{31.1, 0.631748788526517}], 
        PointBox[{31.2, 0.6320323666937845}], 
        PointBox[{31.3, 0.6299230514069473}], 
        PointBox[{31.4, 0.6271658569056597}], 
        PointBox[{31.5, 0.6274799065760456}], 
        PointBox[{31.6, 0.6294895551793358}], 
        PointBox[{31.7, 0.6281469428829469}], 
        PointBox[{31.8, 0.6288756071867547}], 
        PointBox[{31.9, 0.6318032700555837}], 
        PointBox[{32., 0.6328421722265926}], 
        PointBox[{32.1, 0.6333270766239799}], 
        PointBox[{32.2, 0.6335519570365602}], 
        PointBox[{32.3, 0.6316557000368958}], 
        PointBox[{32.4, 0.6287993075705528}], 
        PointBox[{32.5, 0.628879405058549}], 
        PointBox[{32.6, 0.6308634051068065}], 
        PointBox[{32.7, 0.6296828132684388}], 
        PointBox[{32.8, 0.6300182868787623}], 
        PointBox[{32.9, 0.632953236247122}], 
        PointBox[{33., 0.6341847103004981}], 
        PointBox[{33.1, 0.6346976056967016}], 
        PointBox[{33.2, 0.6349288097113828}], 
        PointBox[{33.3, 0.6333739021426958}], 
        PointBox[{33.4, 0.6303900616849893}], 
        PointBox[{33.5, 0.6300520893973324}], 
        PointBox[{33.6, 0.6318746959350477}], 
        PointBox[{33.7, 0.631182946280805}], 
        PointBox[{33.8, 0.6309369164035161}], 
        PointBox[{33.9, 0.6337804257021297}], 
        PointBox[{34., 0.6353013492991334}], 
        PointBox[{34.1, 0.6358981727685175}], 
        PointBox[{34.2, 0.6361820548569637}], 
        PointBox[{34.3, 0.6350366502320451}], 
        PointBox[{34.4, 0.6320249356520862}], 
        PointBox[{34.5, 0.6311236963085813}], 
        PointBox[{34.6, 0.6325581716992518}], 
        PointBox[{34.7, 0.6326926224973746}], 
        PointBox[{34.8, 0.6317682763000914}], 
        PointBox[{34.9, 0.6343109969350901}], 
        PointBox[{35., 0.6361942847576672}], 
        PointBox[{35.1, 0.6369482655330473}], 
        PointBox[{35.2, 0.6373216105020106}], 
        PointBox[{35.3, 0.6365995744523057}], 
        PointBox[{35.4, 0.6337632654703677}], 
        PointBox[{35.5, 0.6322227790827037}], 
        PointBox[{35.6, 0.6330450700092046}], 
        PointBox[{35.7, 0.6341286495692459}], 
        PointBox[{35.8, 0.6326416587716004}], 
        PointBox[{35.9, 0.6345979778354794}], 
        PointBox[{36., 0.6368386966615867}], 
        PointBox[{36.1, 0.6378411259085458}], 
        PointBox[{36.2, 0.6383435557782804}], 
        PointBox[{36.3, 0.6380146092533807}], 
        PointBox[{36.4, 0.6355941631526417}], 
        PointBox[{36.5, 0.6334582154934756}], 
        PointBox[{36.6, 0.6335332320897111}], 
        PointBox[{36.7, 0.6351368348816813}], 
        PointBox[{36.8, 0.6336694095274271}], 
        PointBox[{36.9, 0.6347451200848907}], 
        PointBox[{37., 0.6371955677912002}], 
        PointBox[{37.1, 0.638540089445982}], 
        PointBox[{37.2, 0.63922654820628}], 
        PointBox[{37.3, 0.6392457176465545}], 
        PointBox[{37.4, 0.6374220447369005}], 
        PointBox[{37.5, 0.6348973341548657}], 
        PointBox[{37.6, 0.6341816919760118}], 
        PointBox[{37.7, 0.6354463983903414}], 
        PointBox[{37.8, 0.6349295324394134}], 
        PointBox[{37.9, 0.6349013408729771}], 
        PointBox[{38., 0.6372484699667414}], 
        PointBox[{38.1, 0.6389847312344596}], 
        PointBox[{38.2, 0.6399270872590209}], 
        PointBox[{38.3, 0.6402639201519699}], 
        PointBox[{38.4, 0.6390994853701027}], 
        PointBox[{38.5, 0.6365336148966472}], 
        PointBox[{38.6, 0.6350740376758458}], 
        PointBox[{38.7, 0.6354788925978204}], 
        PointBox[{38.8, 0.636273266270047}], 
        PointBox[{38.9, 0.6352275381949717}], 
        PointBox[{39., 0.637051892886152}], 
        PointBox[{39.1, 0.639110345165442}], 
        PointBox[{39.2, 0.640383190838676}], 
        PointBox[{39.3, 0.6410379761774212}], 
        PointBox[{39.4, 0.6404987151211072}], 
        PointBox[{39.5, 0.638257205708057}], 
        PointBox[{39.6, 0.6362298828113223}], 
        PointBox[{39.7, 0.6357286351840571}], 
        PointBox[{39.8, 0.6369393492742829}], 
        PointBox[{39.9, 0.6358695747552646}], 
        PointBox[{40., 0.6367523396436002}], 
        PointBox[{40.1, 0.6388886752829568}], 
        PointBox[{40.2, 0.6405234818307917}], 
        PointBox[{40.3, 0.6415264917966994}], 
        PointBox[{40.4, 0.6415441737412626}], 
        PointBox[{40.5, 0.6398775541760579}], 
        PointBox[{40.6, 0.6376002830727461}], 
        PointBox[{40.7, 0.6363255815234335}], 
        PointBox[{40.8, 0.636751575505583}], 
        PointBox[{40.9, 0.6368754729402816}], 
        PointBox[{41., 0.636549763830339}], 
        PointBox[{41.1, 0.6383767329200146}], 
        PointBox[{41.2, 0.6402920988940312}], 
        PointBox[{41.3, 0.6416769294427644}], 
        PointBox[{41.4, 0.6422057570799408}], 
        PointBox[{41.5, 0.6412032089222057}], 
        PointBox[{41.6, 0.6390482965209855}], 
        PointBox[{41.7, 0.6372278248143594}], 
        PointBox[{41.8, 0.6366509059699997}], 
        PointBox[{41.9, 0.6376574838968551}], 
        PointBox[{42., 0.6366430826236974}], 
        PointBox[{42.1, 0.6377314534840016}], 
        PointBox[{42.2, 0.6396903931940052}], 
        PointBox[{42.3, 0.6414365037291045}], 
        PointBox[{42.4, 0.6424661734385851}], 
        PointBox[{42.5, 0.6421181038782303}], 
        PointBox[{42.6, 0.6403719529465174}], 
        PointBox[{42.7, 0.6383238774353593}], 
        PointBox[{42.8, 0.6369645318901149}], 
        PointBox[{42.9, 0.6373561142529185}], 
        PointBox[{43., 0.637171422201385}], 
        PointBox[{43.1, 0.637162151529185}], 
        PointBox[{43.2, 0.6388149740613346}], 
        PointBox[{43.3, 0.6407810840327663}], 
        PointBox[{43.4, 0.6423038063383877}], 
        PointBox[{43.5, 0.6425851040992602}], 
        PointBox[{43.6, 0.6413844889372831}], 
        PointBox[{43.7, 0.6394387372829989}], 
        PointBox[{43.8, 0.6376076497669084}], 
        PointBox[{43.9, 0.636900112168161}], 
        PointBox[{44., 0.6377947625038568}], 
        PointBox[{44.1, 0.6368684957344224}], 
        PointBox[{44.2, 0.6378484446118399}], 
        PointBox[{44.3, 0.6397584639291961}], 
        PointBox[{44.4, 0.6416977263044971}], 
        PointBox[{44.5, 0.6426070065050732}], 
        PointBox[{44.6, 0.6419826334050757}], 
        PointBox[{44.7, 0.6403697064885825}], 
        PointBox[{44.8, 0.6384128666180499}], 
        PointBox[{44.9, 0.6368789027354883}], 
        PointBox[{45., 0.637404955319589}], 
        PointBox[{45.1, 0.6369977999284565}], 
        PointBox[{45.2, 0.6369934759136593}], 
        PointBox[{45.3, 0.6385120782279383}], 
        PointBox[{45.4, 0.6406570577711739}], 
        PointBox[{45.5, 0.6421910196785392}], 
        PointBox[{45.6, 0.6421494184454538}], 
        PointBox[{45.7, 0.6409619921638724}], 
        PointBox[{45.8, 0.639175633469927}], 
        PointBox[{45.9, 0.6372054751849825}], 
        PointBox[{46., 0.636550184307351}], 
        PointBox[{46.1, 0.6373816850281375}], 
        PointBox[{46.2, 0.6364123038694907}], 
        PointBox[{46.3, 0.6372428628541283}], 
        PointBox[{46.4, 0.6392622419666455}], 
        PointBox[{46.5, 0.6413415758429246}], 
        PointBox[{46.6, 0.6419144808023586}], 
        PointBox[{46.7, 0.6411571149398431}], 
        PointBox[{46.8, 0.6397040126708143}], 
        PointBox[{46.9, 0.6376874487532309}], 
        PointBox[{47., 0.6360648864859145}], 
        PointBox[{47.1, 0.6370181559825492}], 
        PointBox[{47.2, 0.6362087810296904}], 
        PointBox[{47.3, 0.636132200858116}], 
        PointBox[{47.4, 0.6376848808830179}], 
        PointBox[{47.5, 0.6400800055174716}], 
        PointBox[{47.6, 0.6413173505191707}], 
        PointBox[{47.7, 0.6409773509930071}], 
        PointBox[{47.8, 0.6398851137999391}], 
        PointBox[{47.9, 0.6381106132910229}], 
        PointBox[{48., 0.6359461392471233}], 
        PointBox[{48.1, 0.6358328792728429}], 
        PointBox[{48.2, 0.6363158225249067}], 
        PointBox[{48.3, 0.6352876888882187}], 
        PointBox[{48.4, 0.6361328152070016}], 
        PointBox[{48.5, 0.6384808316214261}], 
        PointBox[{48.6, 0.6403889702575069}], 
        PointBox[{48.7, 0.6404824735302876}], 
        PointBox[{48.8, 0.6397058708152129}], 
        PointBox[{48.9, 0.6382987071122211}], 
        PointBox[{49., 0.6360260649130874}], 
        PointBox[{49.1, 0.6347655956487276}], 
        PointBox[{49.2, 0.6361369800069203}], 
        PointBox[{49.3, 0.6347475400729612}], 
        PointBox[{49.4, 0.6347610526270657}], 
        PointBox[{49.5, 0.6366939826104583}], 
        PointBox[{49.6, 0.6391560927174302}], 
        PointBox[{49.7, 0.6397371973347242}], 
        PointBox[{49.8, 0.6392184377940677}], 
        PointBox[{49.9, 0.638165109488192}], 
        PointBox[{50., 0.6361168584065714}], 
        PointBox[{50.1, 0.6340170361166845}], 
        PointBox[{50.2, 0.6350728855190758}], 
        PointBox[{50.3, 0.6344685938330574}], 
        PointBox[{50.4, 0.6336276396226329}], 
        PointBox[{50.5, 0.6349052617335533}], 
        PointBox[{50.6, 0.6376574420042707}], 
        PointBox[{50.7, 0.6387951003105564}], 
        PointBox[{50.8, 0.6384947293900597}], 
        PointBox[{50.9, 0.6377158815898365}], 
        PointBox[{51., 0.6360499787943298}], 
        PointBox[{51.1, 0.6334959860025249}], 
        PointBox[{51.2, 0.6336143020216917}], 
        PointBox[{51.3, 0.6342480660681247}], 
        PointBox[{51.4, 0.6327078108459221}], 
        PointBox[{51.5, 0.633253006944641}], 
        PointBox[{51.6, 0.635960138101597}], 
        PointBox[{51.7, 0.6376930224301931}], 
        PointBox[{51.8, 0.6375953266689331}], 
        PointBox[{51.9, 0.6370037432403755}], 
        PointBox[{52., 0.635722574047019}], 
        PointBox[{52.1, 0.6330757401101257}], 
        PointBox[{52.2, 0.6322307845962115}], 
        PointBox[{52.3, 0.6337288277788116}], 
        PointBox[{52.4, 0.6319229690313225}], 
        PointBox[{52.5, 0.6317746781494995}], 
        PointBox[{52.6, 0.6341592804753045}], 
        PointBox[{52.7, 0.6364550431207606}], 
        PointBox[{52.8, 0.6365587020395159}], 
        PointBox[{52.9, 0.6360814272636147}], 
        PointBox[{53., 0.635106174902607}], 
        PointBox[{53.1, 0.632618509937603}], 
        PointBox[{53.2, 0.6309687687533064}], 
        PointBox[{53.3, 0.6327268043782986}], 
        PointBox[{53.4, 0.6311517182280066}], 
        PointBox[{53.5, 0.6304202347016228}], 
        PointBox[{53.6, 0.632343530699691}], 
        PointBox[{53.7, 0.6350967601112513}], 
        PointBox[{53.8, 0.6353970441573401}], 
        PointBox[{53.9, 0.634976971662526}], 
        PointBox[{54., 0.6342100157760138}], 
        PointBox[{54.1, 0.6319900445630712}], 
        PointBox[{54.2, 0.6297407253257211}], 
        PointBox[{54.3, 0.6313869105912506}], 
        PointBox[{54.4, 0.6302447106066554}], 
        PointBox[{54.5, 0.6290880992762131}], 
        PointBox[{54.6, 0.6305577690136076}], 
        PointBox[{54.7, 0.6336322625727064}], 
        PointBox[{54.8, 0.6340986322464919}], 
        PointBox[{54.9, 0.6336884953984327}], 
        PointBox[{55., 0.6330436363938228}], 
        PointBox[{55.1, 0.6310820232902464}], 
        PointBox[{55.2, 0.6284319690054089}], 
        PointBox[{55.3, 0.6298910423136845}], 
        PointBox[{55.4, 0.6290559952015061}], 
        PointBox[{55.5, 0.6276628237622026}], 
        PointBox[{55.6, 0.6287947567489443}], 
        PointBox[{55.7, 0.6320807037377227}], 
        PointBox[{55.8, 0.632633596156152}], 
        PointBox[{55.9, 0.6321893029331156}], 
        PointBox[{56., 0.6315989143038508}], 
        PointBox[{56.1, 0.6298129751308962}], 
        PointBox[{56.2, 0.6269244775015973}], 
        PointBox[{56.3, 0.6282996556481185}], 
        PointBox[{56.4, 0.6274758562496601}], 
        PointBox[{56.5, 0.6260479038366829}], 
        PointBox[{56.6, 0.6270314106592997}], 
        PointBox[{56.7, 0.6304689247447928}], 
        PointBox[{56.8, 0.6309625520213042}], 
        PointBox[{56.9, 0.6304429444873648}], 
        PointBox[{57., 0.6298551600582332}], 
        PointBox[{57.1, 0.6281201225636622}], 
        PointBox[{57.2, 0.6251277283363732}], 
        PointBox[{57.3, 0.6265749917659558}], 
        PointBox[{57.4, 0.6254646171385632}], 
        PointBox[{57.5, 0.624213306058185}], 
        PointBox[{57.6, 0.6252864631049925}], 
        PointBox[{57.7, 0.62883455343814}], 
        PointBox[{57.8, 0.6290576132730119}], 
        PointBox[{57.9, 0.6284335419640698}], 
        PointBox[{58., 0.6278060572574864}], 
        PointBox[{58.1, 0.6259595231862323}], 
        PointBox[{58.2, 0.6230514036718161}], 
        PointBox[{58.3, 0.6245654985620246}], 
        PointBox[{58.4, 0.6231229411244326}], 
        PointBox[{58.5, 0.6222501006725392}], 
        PointBox[{58.6, 0.6236986988953941}], 
        PointBox[{58.7, 0.6272049359585601}], 
        PointBox[{58.8, 0.626936952853292}], 
        PointBox[{58.9, 0.6262054843810264}], 
        PointBox[{59., 0.6254943808019762}], 
        PointBox[{59.1, 0.6233237827360981}], 
        PointBox[{59.2, 0.6209161862800888}], 
        PointBox[{59.3, 0.6220631343132715}], 
        PointBox[{59.4, 0.6207414743169101}], 
        PointBox[{59.5, 0.6203884410726306}], 
        PointBox[{59.6, 0.6225447707377053}], 
        PointBox[{59.7, 0.6255384937885694}], 
        PointBox[{59.8, 0.6246910766366028}], 
        PointBox[{59.9, 0.6238778147565397}], 
        PointBox[{60., 0.6230152774916031}], 
        PointBox[{60.1, 0.620283451522961}], 
        PointBox[{60.2, 0.6191173511747001}], 
        PointBox[{60.3, 0.6193822056484993}], 
        PointBox[{60.4, 0.6186880911934678}], 
        PointBox[{60.5, 0.6189443363670019}], 
        PointBox[{60.6, 0.6220848305541293}], 
        PointBox[{60.7, 0.623728598866389}], 
        PointBox[{60.8, 0.622464797805608}], 
        PointBox[{60.9, 0.6215986947689455}], 
        PointBox[{61., 0.6204551441733911}], 
        PointBox[{61.1, 0.6171619799257618}], 
        PointBox[{61.2, 0.6174937923555097}], 
        PointBox[{61.3, 0.6172692988147196}], 
        PointBox[{61.4, 0.6172312611587739}], 
        PointBox[{61.5, 0.6182328741051644}], 
        PointBox[{61.6, 0.6221073058867588}], 
        PointBox[{61.7, 0.6217715712886479}], 
        PointBox[{61.8, 0.6203922844294569}], 
        PointBox[{61.9, 0.6194676139749653}], 
        PointBox[{62., 0.6178145633650792}], 
        PointBox[{62.1, 0.6148793053474398}], 
        PointBox[{62.2, 0.6157902007200693}], 
        PointBox[{62.3, 0.616008365130824}], 
        PointBox[{62.4, 0.616490842916268}], 
        PointBox[{62.5, 0.6185016746241215}], 
        PointBox[{62.6, 0.6216809944300736}], 
        PointBox[{62.7, 0.6198381727578102}], 
        PointBox[{62.8, 0.6185505395720023}], 
        PointBox[{62.9, 0.6175015633882782}], 
        PointBox[{63., 0.6151020350474663}], 
        PointBox[{63.1, 0.6139834859166987}], 
        PointBox[{63.2, 0.6148931844711453}], 
        PointBox[{63.3, 0.615525531299884}], 
        PointBox[{63.4, 0.6165114687054888}], 
        PointBox[{63.5, 0.619677589289325}], 
        PointBox[{63.6, 0.6202748485693714}], 
        PointBox[{63.7, 0.6181182777919598}], 
        PointBox[{63.8, 0.6169662859700096}], 
        PointBox[{63.9, 0.6156623807715591}], 
        PointBox[{64., 0.6129179092703946}], 
        PointBox[{64.1, 0.6136273200757559}], 
        PointBox[{64.2, 0.6148284227690455}], 
        PointBox[{64.3, 0.6156969195680461}], 
        PointBox[{64.4, 0.6173244119202066}], 
        PointBox[{64.5, 0.6206624125017585}], 
        PointBox[{64.6, 0.6184950850589948}], 
        PointBox[{64.7, 0.6167182927741274}], 
        PointBox[{64.8, 0.6156490083549953}], 
        PointBox[{64.9, 0.6139583698427461}], 
        PointBox[{65., 0.6123373899901547}], 
        PointBox[{65.1, 0.6141366513812059}], 
        PointBox[{65.2, 0.6153429218615797}], 
        PointBox[{65.3, 0.616435763474868}], 
        PointBox[{65.4, 0.6188501673875167}], 
        PointBox[{65.5, 0.6200078266326134}], 
        PointBox[{65.6, 0.6170106036386289}], 
        PointBox[{65.7, 0.6156929788549638}], 
        PointBox[{65.8, 0.6146349330944099}], 
        PointBox[{65.9, 0.6127664813413247}], 
        PointBox[{66., 0.6130525103698241}], 
        PointBox[{66.1, 0.6151838603510478}], 
        PointBox[{66.2, 0.6162889277201636}], 
        PointBox[{66.3, 0.6176863228454036}], 
        PointBox[{66.4, 0.6204440913864504}], 
        PointBox[{66.5, 0.6183673577560147}], 
        PointBox[{66.6, 0.6160655202348227}], 
        PointBox[{66.7, 0.6151010853204174}], 
        PointBox[{66.8, 0.614056259801669}], 
        PointBox[{66.9, 0.6126734147018649}], 
        PointBox[{67., 0.6148351024368095}], 
        PointBox[{67.1, 0.6165249281734627}], 
        PointBox[{67.2, 0.6175937123598205}], 
        PointBox[{67.3, 0.619354943394009}], 
        PointBox[{67.4, 0.6207782922284671}], 
        PointBox[{67.5, 0.6171386430583732}], 
        PointBox[{67.6, 0.6157204867182408}], 
        PointBox[{67.7, 0.6150484323951448}], 
        PointBox[{67.8, 0.6142325362799271}], 
        PointBox[{67.9, 0.6138932867692933}], 
        PointBox[{68., 0.61686731870824}], 
        PointBox[{68.1, 0.6181052000776688}], 
        PointBox[{68.2, 0.6192162796947116}], 
        PointBox[{68.3, 0.6211512282168951}], 
        PointBox[{68.4, 0.6198107486898364}], 
        PointBox[{68.5, 0.6167711031070957}], 
        PointBox[{68.6, 0.6160265262718172}], 
        PointBox[{68.7, 0.6157247645908349}], 
        PointBox[{68.8, 0.6150949836751248}], 
        PointBox[{68.9, 0.6165796296220635}], 
        PointBox[{69., 0.6189513378974673}], 
        PointBox[{69.1, 0.6199239477594214}], 
        PointBox[{69.2, 0.6211042341331646}], 
        PointBox[{69.3, 0.6225162952516479}], 
        PointBox[{69.4, 0.6190683877084351}], 
        PointBox[{69.5, 0.6172457882123781}], 
        PointBox[{69.6, 0.6170614346471318}], 
        PointBox[{69.7, 0.6173292688520919}], 
        PointBox[{69.8, 0.6164062888599082}], 
        PointBox[{69.9, 0.6195156241485255}], 
        PointBox[{70., 0.6211371400030412}], 
        PointBox[{70.1, 0.6219737594662353}], 
        PointBox[{70.2, 0.6231554175813165}], 
        PointBox[{70.3, 0.6231921056122933}], 
        PointBox[{70.4, 0.619317107810477}], 
        PointBox[{70.5, 0.6184710806838607}], 
        PointBox[{70.6, 0.6188894165460097}], 
        PointBox[{70.7, 0.61943640246527}], 
        PointBox[{70.8, 0.6189302570809639}], 
        PointBox[{70.9, 0.6222963040927648}], 
        PointBox[{71., 0.6234431918592606}], 
        PointBox[{71.1, 0.6241998369011008}], 
        PointBox[{71.2, 0.6252203760084544}], 
        PointBox[{71.3, 0.6237288105584731}], 
        PointBox[{71.4, 0.6204506943022685}], 
        PointBox[{71.5, 0.6203062984222119}], 
        PointBox[{71.6, 0.6214055016510817}], 
        PointBox[{71.7, 0.6212266790154354}], 
        PointBox[{71.8, 0.6219264696099595}], 
        PointBox[{71.9, 0.6249042431501155}], 
        PointBox[{72., 0.6257962974090693}], 
        PointBox[{72.1, 0.6264814970907013}], 
        PointBox[{72.2, 0.6271855792886538}], 
        PointBox[{72.3, 0.624692141366193}], 
        PointBox[{72.4, 0.6221287211852486}], 
        PointBox[{72.5, 0.6225035820604817}], 
        PointBox[{72.6, 0.6241406416426288}], 
        PointBox[{72.7, 0.6230466026959545}], 
        PointBox[{72.8, 0.624686050718392}], 
        PointBox[{72.9, 0.6272934699935783}], 
        PointBox[{73., 0.6280587690967132}], 
        PointBox[{73.1, 0.6286655764168}], 
        PointBox[{73.2, 0.6290235848188666}], 
        PointBox[{73.3, 0.6261142383744236}], 
        PointBox[{73.4, 0.6240069580341409}], 
        PointBox[{73.5, 0.6247334881581631}], 
        PointBox[{73.6, 0.6265350693233747}], 
        PointBox[{73.7, 0.6249405807240812}], 
        PointBox[{73.8, 0.6269608027442988}], 
        PointBox[{73.9, 0.6293892686577852}], 
        PointBox[{74., 0.6301077393121599}], 
        PointBox[{74.1, 0.6306389944045616}], 
        PointBox[{74.2, 0.6307461576319581}], 
        PointBox[{74.3, 0.6277847309893247}], 
        PointBox[{74.4, 0.625834296896295}], 
        PointBox[{74.5, 0.6267160603639366}], 
        PointBox[{74.6, 0.6284748748426968}], 
        PointBox[{74.7, 0.6267114282210512}], 
        PointBox[{74.8, 0.628727312430454}], 
        PointBox[{74.9, 0.6311519729508497}], 
        PointBox[{75., 0.631888823445289}], 
        PointBox[{75.1, 0.6323646539927936}], 
        PointBox[{75.2, 0.6323559572084426}], 
        PointBox[{75.3, 0.629542191221899}], 
        PointBox[{75.4, 0.6275031104535976}], 
        PointBox[{75.5, 0.6283291230150431}], 
        PointBox[{75.6, 0.6300981961272766}], 
        PointBox[{75.7, 0.6282955184998829}], 
        PointBox[{75.8, 0.6300462514684476}], 
        PointBox[{75.9, 0.6325850271638648}], 
        PointBox[{76., 0.6334100903150192}], 
        PointBox[{76.1, 0.6338639654186147}], 
        PointBox[{76.2, 0.633851061005872}], 
        PointBox[{76.3, 0.6313230161287506}], 
        PointBox[{76.4, 0.6290306267577407}], 
        PointBox[{76.5, 0.629597434759128}], 
        PointBox[{76.6, 0.6314725226348583}], 
        PointBox[{76.7, 0.6297424830878923}], 
        PointBox[{76.8, 0.6310131516198819}], 
        PointBox[{76.9, 0.6337079315479549}], 
        PointBox[{77., 0.6347040440996662}], 
        PointBox[{77.1, 0.6351784110606484}], 
        PointBox[{77.2, 0.6352323485594594}], 
        PointBox[{77.3, 0.633107660830462}], 
        PointBox[{77.4, 0.630503164013555}], 
        PointBox[{77.5, 0.6306288661399558}], 
        PointBox[{77.6, 0.6325459091348933}], 
        PointBox[{77.7, 0.6311449447469752}], 
        PointBox[{77.8, 0.6317457601453894}], 
        PointBox[{77.9, 0.6345316520192243}], 
        PointBox[{78., 0.6357944787429495}], 
        PointBox[{78.1, 0.636342228409115}], 
        PointBox[{78.2, 0.636501922409696}], 
        PointBox[{78.3, 0.6348670171140156}], 
        PointBox[{78.4, 0.6320237405268796}], 
        PointBox[{78.5, 0.6315612102079725}], 
        PointBox[{78.6, 0.6332428579434137}], 
        PointBox[{78.7, 0.6325899668468484}], 
        PointBox[{78.8, 0.6323766119155679}], 
        PointBox[{78.9, 0.6350616188630661}], 
        PointBox[{79., 0.6366804389991508}], 
        PointBox[{79.1, 0.6373691104497761}], 
        PointBox[{79.2, 0.6376583858427721}], 
        PointBox[{79.3, 0.6365455561997014}], 
        PointBox[{79.4, 0.6336708285476512}], 
        PointBox[{79.5, 0.6325291442431697}], 
        PointBox[{79.6, 0.633641393237391}], 
        PointBox[{79.7, 0.6340836782821397}], 
        PointBox[{79.8, 0.6330383052780334}], 
        PointBox[{79.9, 0.6353219727878717}], 
        PointBox[{80., 0.6373314036909631}], 
        PointBox[{80.1, 0.6382459949514765}], 
        PointBox[{80.2, 0.6386911705917839}], 
        PointBox[{80.3, 0.6380744910795785}], 
        PointBox[{80.4, 0.635455250533694}], 
        PointBox[{80.5, 0.633641985815052}], 
        PointBox[{80.6, 0.6339846838514116}], 
        PointBox[{80.7, 0.6353506487652262}], 
        PointBox[{80.8, 0.6338533956476387}], 
        PointBox[{80.9, 0.6353900761888647}], 
        PointBox[{81., 0.6376992485822347}], 
        PointBox[{81.1, 0.6389328878021302}], 
        PointBox[{81.2, 0.6395749878035527}], 
        PointBox[{81.3, 0.6393967255656862}], 
        PointBox[{81.4, 0.6372917458851127}], 
        PointBox[{81.5, 0.634968185614164}], 
        PointBox[{81.6, 0.6344896983026574}], 
        PointBox[{81.7, 0.635875634605228}], 
        PointBox[{81.8, 0.6349238087917948}], 
        PointBox[{81.9, 0.6354074365421196}], 
        PointBox[{82., 0.6377515353675379}], 
        PointBox[{82.1, 0.6393661819752386}], 
        PointBox[{82.2, 0.6402666703515023}], 
        PointBox[{82.3, 0.6404735947407916}], 
        PointBox[{82.4, 0.6390230925715373}], 
        PointBox[{82.5, 0.6365101219769395}], 
        PointBox[{82.6, 0.635257254211871}], 
        PointBox[{82.7, 0.6358544457961407}], 
        PointBox[{82.8, 0.6362227032744976}], 
        PointBox[{82.9, 0.6355459159440576}], 
        PointBox[{83., 0.6375220438547957}], 
        PointBox[{83.1, 0.6394780344480798}], 
        PointBox[{83.2, 0.6407050646634413}], 
        PointBox[{83.3, 0.6412758004924488}], 
        PointBox[{83.4, 0.6404904837757429}], 
        PointBox[{83.5, 0.6381719625758848}], 
        PointBox[{83.6, 0.6363036446356259}], 
        PointBox[{83.7, 0.6359573144644407}], 
        PointBox[{83.8, 0.6371294771084706}], 
        PointBox[{83.9, 0.635973329200516}], 
        PointBox[{84., 0.6371412286001181}], 
        PointBox[{84.1, 0.6392333684413586}], 
        PointBox[{84.2, 0.6408208425696208}], 
        PointBox[{84.3, 0.6417688622251329}], 
        PointBox[{84.4, 0.6415938984983496}], 
        PointBox[{84.5, 0.6397685341078182}], 
        PointBox[{84.6, 0.637578596442137}], 
        PointBox[{84.7, 0.6364220866922911}], 
        PointBox[{84.8, 0.6370173783997172}], 
        PointBox[{84.9, 0.6367992104795945}], 
        PointBox[{85., 0.636807542208487}], 
        PointBox[{85.1, 0.6386787245832115}], 
        PointBox[{85.2, 0.6405583540360076}], 
        PointBox[{85.3, 0.6419083136122301}], 
        PointBox[{85.4, 0.6422907588129906}], 
        PointBox[{85.5, 0.6410986624022186}], 
        PointBox[{85.6, 0.638950504747522}], 
        PointBox[{85.7, 0.6372151905872367}], 
        PointBox[{85.8, 0.636772698092298}], 
        PointBox[{85.9, 0.6376716394513826}], 
        PointBox[{86., 0.6367279321691953}], 
        PointBox[{86.1, 0.637961653197283}], 
        PointBox[{86.2, 0.63991587467198}], 
        PointBox[{86.3, 0.6416477972916304}], 
        PointBox[{86.4, 0.6425699571594625}], 
        PointBox[{86.5, 0.6420285362842804}], 
        PointBox[{86.6, 0.6402220980993919}], 
        PointBox[{86.7, 0.6382207540629439}], 
        PointBox[{86.8, 0.6369384487676862}], 
        PointBox[{86.9, 0.6375240120582208}], 
        PointBox[{87., 0.6370692522823754}], 
        PointBox[{87.1, 0.6372879109984717}], 
        PointBox[{87.2, 0.6389833266816624}], 
        PointBox[{87.3, 0.6409636653653153}], 
        PointBox[{87.4, 0.642417364555821}], 
        PointBox[{87.5, 0.6425109175967048}], 
        PointBox[{87.6, 0.6412029278045778}], 
        PointBox[{87.7, 0.639264575964907}], 
        PointBox[{87.8, 0.6374642384371728}], 
        PointBox[{87.9, 0.6369310559184949}], 
        PointBox[{88., 0.6376818169015335}], 
        PointBox[{88.1, 0.6368565477029873}], 
        PointBox[{88.2, 0.6379393080288986}], 
        PointBox[{88.3, 0.639898005950035}], 
        PointBox[{88.4, 0.641817109608077}], 
        PointBox[{88.5, 0.6425485950557415}], 
        PointBox[{88.6, 0.6417811146626986}], 
        PointBox[{88.7, 0.6401427137862067}], 
        PointBox[{88.8, 0.6381801711762369}], 
        PointBox[{88.9, 0.6367305872731673}], 
        PointBox[{89., 0.637496452235681}], 
        PointBox[{89.1, 0.6368216623629112}], 
        PointBox[{89.2, 0.636985755903062}], 
        PointBox[{89.3, 0.6385882622941441}], 
        PointBox[{89.4, 0.6407756259016336}], 
        PointBox[{89.5, 0.6421580346091865}], 
        PointBox[{89.6, 0.6419370731148307}], 
        PointBox[{89.7, 0.6406972259341992}], 
        PointBox[{89.8, 0.6388822116854546}], 
        PointBox[{89.9, 0.6369131991804526}], 
        PointBox[{90., 0.6365473848617792}], 
        PointBox[{90.1, 0.6371371845357082}], 
        PointBox[{90.2, 0.6362832018628269}], 
        PointBox[{90.3, 0.6372349194383509}], 
        PointBox[{90.4, 0.6393625059615659}], 
        PointBox[{90.5, 0.6413490365410882}], 
        PointBox[{90.6, 0.6417023789156684}], 
        PointBox[{90.7, 0.6408630098157261}], 
        PointBox[{90.8, 0.6393721455673191}], 
        PointBox[{90.9, 0.6372938792476569}], 
        PointBox[{91., 0.6358507818206423}], 
        PointBox[{91.1, 0.6370022426785987}], 
        PointBox[{91.2, 0.6359317119530221}], 
        PointBox[{91.3, 0.6360224444995443}], 
        PointBox[{91.4, 0.6377340771421001}], 
        PointBox[{91.5, 0.6401389590232847}], 
        PointBox[{91.6, 0.6411241521053623}], 
        PointBox[{91.7, 0.6406607950028493}], 
        PointBox[{91.8, 0.639528277512298}], 
        PointBox[{91.9, 0.6376606525648074}], 
        PointBox[{92., 0.63553836537125}], 
        PointBox[{92.1, 0.635875885801886}], 
        PointBox[{92.2, 0.6359194046305953}], 
        PointBox[{92.3, 0.6350602930868295}], 
        PointBox[{92.4, 0.6360983750762229}], 
        PointBox[{92.5, 0.6385838942652025}], 
        PointBox[{92.6, 0.6402430407487006}], 
        PointBox[{92.7, 0.6401525365659358}], 
        PointBox[{92.8, 0.6393304136838025}], 
        PointBox[{92.9, 0.6378288246526309}], 
        PointBox[{93., 0.635468232883581}], 
        PointBox[{93.1, 0.6346303430184912}], 
        PointBox[{93.2, 0.6358625147383079}], 
        PointBox[{93.3, 0.6343812499779738}], 
        PointBox[{93.4, 0.6346205338446568}], 
        PointBox[{93.5, 0.6368059986498851}], 
        PointBox[{93.6, 0.6390905037746943}], 
        PointBox[{93.7, 0.6394070349129594}], 
        PointBox[{93.8, 0.6388273058272749}], 
        PointBox[{93.9, 0.6376949458298106}], 
        PointBox[{94., 0.6354677452987193}], 
        PointBox[{94.1, 0.6336605354302007}], 
        PointBox[{94.2, 0.6350833255725009}], 
        PointBox[{94.3, 0.6339506549087213}], 
        PointBox[{94.4, 0.6333674747152469}], 
        PointBox[{94.5, 0.6349734375244991}], 
        PointBox[{94.6, 0.6376978039010395}], 
        PointBox[{94.7, 0.6384806651991586}], 
        PointBox[{94.8, 0.6380883576556198}], 
        PointBox[{94.9, 0.6372491519033414}], 
        PointBox[{95., 0.6353673268327998}], 
        PointBox[{95.1, 0.6329236783836871}], 
        PointBox[{95.2, 0.6336901909747908}], 
        PointBox[{95.3, 0.6336338826816738}], 
        PointBox[{95.4, 0.6323167020920935}], 
        PointBox[{95.5, 0.6332303259703195}], 
        PointBox[{95.6, 0.6361097911726068}], 
        PointBox[{95.7, 0.6374116568297561}], 
        PointBox[{95.8, 0.637172298426611}], 
        PointBox[{95.9, 0.6365337160913089}], 
        PointBox[{96., 0.6350430977437914}], 
        PointBox[{96.1, 0.6323084528560451}], 
        PointBox[{96.2, 0.6322053989237528}], 
        PointBox[{96.3, 0.6331794968158238}], 
        PointBox[{96.4, 0.6313873278436702}], 
        PointBox[{96.5, 0.63163460628562}], 
        PointBox[{96.6, 0.634391532073983}], 
        PointBox[{96.7, 0.6362217977357572}], 
        PointBox[{96.8, 0.6361137575319804}], 
        PointBox[{96.9, 0.6355953767928738}], 
        PointBox[{97., 0.6344375170284379}], 
        PointBox[{97.1, 0.631688132979722}], 
        PointBox[{97.2, 0.6307924994446342}], 
        PointBox[{97.3, 0.6323696765151704}], 
        PointBox[{97.4, 0.6304612745711687}], 
        PointBox[{97.5, 0.6301511912217765}], 
        PointBox[{97.6, 0.6326122894923325}], 
        PointBox[{97.7, 0.6349190123276333}], 
        PointBox[{97.8, 0.6349180092132016}], 
        PointBox[{97.9, 0.6344574963132739}], 
        PointBox[{98., 0.6335376338109047}], 
        PointBox[{98.1, 0.6309273847854739}], 
        PointBox[{98.2, 0.6294042903722729}], 
        PointBox[{98.3, 0.6311935621453851}], 
        PointBox[{98.4, 0.629399928489}], 
        PointBox[{98.5, 0.6286898706528021}], 
        PointBox[{98.6, 0.630823351290312}], 
        PointBox[{98.7, 0.6335054665512064}], 
        PointBox[{98.8, 0.6335668781853484}], 
        PointBox[{98.9, 0.6331148482500881}], 
        PointBox[{99., 0.6323404042084055}], 
        PointBox[{99.1, 0.6298990160700971}], 
        PointBox[{99.2, 0.6279448992740599}], 
        PointBox[{99.3, 0.6297516521457492}], 
        PointBox[{99.4, 0.6280682590042924}], 
        PointBox[{99.5, 0.6271464894671375}], 
        PointBox[{99.6, 0.6290434914467866}], 
        PointBox[{99.7, 0.6319816072927127}], 
        PointBox[{99.8, 0.6320236940705573}], 
        PointBox[{99.9, 0.6315394393358367}], 
        PointBox[{100., 0.6308326084552227}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0.6, 0.65}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], 
        PointBox[{0, 0.012286199999996425`}], 
        PointBox[{0.1, 0.014787000935964018`}], 
        PointBox[{0.2, 0.015758757134471127`}], 
        PointBox[{0.3, 0.013220342337240785`}], 
        PointBox[{0.4, 0.014916472581743535`}], 
        PointBox[{0.5, 0.017402449620990183`}], 
        PointBox[{0.6, 0.014615852932436809`}], 
        PointBox[{0.7, 0.013169144880059986`}], 
        PointBox[{0.8, 0.01601778900751362}], 
        PointBox[{0.9, 0.015558588608091043`}], 
        PointBox[{1., 0.014585015707782966`}], 
        PointBox[{1.1, 0.020183758480863588`}], 
        PointBox[{1.2, 0.022762541552241045`}], 
        PointBox[{1.3, 0.020595731817565032`}], 
        PointBox[{1.4, 0.02153004036211773}], 
        PointBox[{1.5, 0.024415737907588383`}], 
        PointBox[{1.6, 0.02187934917001051}], 
        PointBox[{1.7, 0.019991307691023336`}], 
        PointBox[{1.8, 0.022839293833118737`}], 
        PointBox[{1.9, 0.02322146399511602}], 
        PointBox[{2., 0.021344857243563123`}], 
        PointBox[{2.1, 0.027021430944021565`}], 
        PointBox[{2.2, 0.032041889636579814`}], 
        PointBox[{2.3, 0.030895873933331437`}], 
        PointBox[{2.4, 0.03031385807736529}], 
        PointBox[{2.5, 0.033705207284158295`}], 
        PointBox[{2.6, 0.03229658678526866}], 
        PointBox[{2.7, 0.029452155122776286`}], 
        PointBox[{2.8, 0.0316090894135311}], 
        PointBox[{2.9, 0.033354079425395894`}], 
        PointBox[{3., 0.0309219808368337}], 
        PointBox[{3.1, 0.034184402810716774`}], 
        PointBox[{3.2, 0.041054629993700534`}], 
        PointBox[{3.3, 0.041943878876912845`}], 
        PointBox[{3.4, 0.040182888960564836`}], 
        PointBox[{3.5, 0.04308713175694771}], 
        PointBox[{3.6, 0.04348479534377358}], 
        PointBox[{3.7, 0.04003060860941067}], 
        PointBox[{3.8, 0.04084750677536632}], 
        PointBox[{3.9, 0.04364362834032953}], 
        PointBox[{4., 0.04190255804861852}], 
        PointBox[{4.1, 0.042275818483904305`}], 
        PointBox[{4.2, 0.04910631780975129}], 
        PointBox[{4.3, 0.05264362236029244}], 
        PointBox[{4.4, 0.050834714268826506`}], 
        PointBox[{4.5, 0.05214991498829536}], 
        PointBox[{4.6, 0.05443368992256077}], 
        PointBox[{4.7, 0.05111066845832089}], 
        PointBox[{4.8, 0.05038755208919629}], 
        PointBox[{4.9, 0.05337777005384061}], 
        PointBox[{5., 0.05325362268800581}], 
        PointBox[{5.1, 0.05136889347458902}], 
        PointBox[{5.2, 0.05674575781270671}], 
        PointBox[{5.3, 0.062378764736355015`}], 
        PointBox[{5.4, 0.06174882160169131}], 
        PointBox[{5.5, 0.061206501208447964`}], 
        PointBox[{5.6, 0.06461520491716205}], 
        PointBox[{5.7, 0.06225088756480133}], 
        PointBox[{5.8, 0.06019459844389849}], 
        PointBox[{5.9, 0.06257845359768315}], 
        PointBox[{6., 0.0641496962772639}], 
        PointBox[{6.1, 0.06127390172322786}], 
        PointBox[{6.2, 0.06472459299483406}], 
        PointBox[{6.3, 0.07097261111939449}], 
        PointBox[{6.4, 0.07233569340950408}], 
        PointBox[{6.5, 0.07061398593762593}], 
        PointBox[{6.6, 0.07386712756251491}], 
        PointBox[{6.7, 0.07311438458846593}], 
        PointBox[{6.8, 0.07014609471879471}], 
        PointBox[{6.9, 0.07150221797411149}], 
        PointBox[{7., 0.07417401291213978}], 
        PointBox[{7.1, 0.07168114012983628}], 
        PointBox[{7.2, 0.07297117093429119}], 
        PointBox[{7.3, 0.0787942710394368}], 
        PointBox[{7.4, 0.08223414813994678}], 
        PointBox[{7.5, 0.0803793055241188}], 
        PointBox[{7.6, 0.08240684399252379}], 
        PointBox[{7.7, 0.08349061473170137}], 
        PointBox[{7.8, 0.08009953970728463}], 
        PointBox[{7.9, 0.08036062478028336}], 
        PointBox[{8., 0.0833816317393297}], 
        PointBox[{8.1, 0.08216224845811988}], 
        PointBox[{8.2, 0.08138920263572337}], 
        PointBox[{8.3, 0.08657567630405742}], 
        PointBox[{8.4, 0.09140311455712237}], 
        PointBox[{8.5, 0.09026436340167283}], 
        PointBox[{8.6, 0.09070656106606909}], 
        PointBox[{8.7, 0.09332465116800581}], 
        PointBox[{8.8, 0.0899745873490283}], 
        PointBox[{8.9, 0.08927749381360185}], 
        PointBox[{9., 0.09210724416757729}], 
        PointBox[{9.1, 0.09235774735742214}], 
        PointBox[{9.2, 0.09005038689865234}], 
        PointBox[{9.3, 0.09468909135072835}], 
        PointBox[{9.4, 0.10008642558120516`}], 
        PointBox[{9.5, 0.10009143487832936`}], 
        PointBox[{9.6, 0.09923065706358823}], 
        PointBox[{9.7, 0.10274211653270099`}], 
        PointBox[{9.8, 0.09979072822351942}], 
        PointBox[{9.9, 0.09835141199444876}], 
        PointBox[{10., 0.10074484110080817`}], 
        PointBox[{10.1, 0.10217666475345359`}], 
        PointBox[{10.2, 0.09904857220098423}], 
        PointBox[{10.3, 0.10313280207431341`}], 
        PointBox[{10.4, 0.10871568031922113`}], 
        PointBox[{10.5, 0.10988883343025932`}], 
        PointBox[{10.6, 0.10826286034062958`}], 
        PointBox[{10.7, 0.11203811184563327`}], 
        PointBox[{10.8, 0.10966098748025264`}], 
        PointBox[{10.9, 0.10770753684330583`}], 
        PointBox[{11., 0.10964540464797891`}], 
        PointBox[{11.1, 0.11181782176645445`}], 
        PointBox[{11.2, 0.10845249587972879`}], 
        PointBox[{11.3, 0.1120005153439257}], 
        PointBox[{11.4, 0.11776495994842938`}], 
        PointBox[{11.5, 0.11985006629392421`}], 
        PointBox[{11.6, 0.1179236039301713}], 
        PointBox[{11.7, 0.1216052083966143}], 
        PointBox[{11.8, 0.1197499022558104}], 
        PointBox[{11.9, 0.11749784061861578`}], 
        PointBox[{12., 0.11909552012320175`}], 
        PointBox[{12.1, 0.12163242295417677`}], 
        PointBox[{12.2, 0.11831181102699785`}], 
        PointBox[{12.3, 0.12153184546278498`}], 
        PointBox[{12.4, 0.1276218723963391}], 
        PointBox[{12.5, 0.13020296345571725`}], 
        PointBox[{12.6, 0.12823301873357626`}], 
        PointBox[{12.7, 0.13179987454718264`}], 
        PointBox[{12.8, 0.13018746706867063`}], 
        PointBox[{12.9, 0.1278459308626852}], 
        PointBox[{13., 0.12928866541352949`}], 
        PointBox[{13.1, 0.13193488518492194`}], 
        PointBox[{13.2, 0.12864410934897383`}], 
        PointBox[{13.3, 0.13198429491214994`}], 
        PointBox[{13.4, 0.13847643922213218`}], 
        PointBox[{13.5, 0.14101227856184703`}], 
        PointBox[{13.6, 0.13908554235991963`}], 
        PointBox[{13.7, 0.14276346599227924`}], 
        PointBox[{13.8, 0.14093270460982413`}], 
        PointBox[{13.9, 0.13873792382022387`}], 
        PointBox[{14., 0.14023730856235758`}], 
        PointBox[{14.1, 0.1428058786305943}], 
        PointBox[{14.2, 0.13937345318704322`}], 
        PointBox[{14.3, 0.14348823711914652`}], 
        PointBox[{14.4, 0.15011128531857396`}], 
        PointBox[{14.5, 0.1519830214170256}], 
        PointBox[{14.6, 0.15015781931417452`}], 
        PointBox[{14.7, 0.15421169164825466`}], 
        PointBox[{14.8, 0.15164452422058536`}], 
        PointBox[{14.9, 0.14989757150230854`}], 
        PointBox[{15., 0.15164946154053627`}], 
        PointBox[{15.1, 0.15389661857287784`}], 
        PointBox[{15.2, 0.1503052095842225}], 
        PointBox[{15.3, 0.155832958327706}], 
        PointBox[{15.4, 0.161679783100971}], 
        PointBox[{15.5, 0.1624038420823059}], 
        PointBox[{15.6, 0.16095178555057946`}], 
        PointBox[{15.7, 0.16524964746258555`}], 
        PointBox[{15.8, 0.1617227023576954}], 
        PointBox[{15.9, 0.1607646730541953}], 
        PointBox[{16., 0.16288882598357635`}], 
        PointBox[{16.1, 0.16432108562894054`}], 
        PointBox[{16.2, 0.1612998206679979}], 
        PointBox[{16.3, 0.1680547462128602}], 
        PointBox[{16.4, 0.17196010478587062`}], 
        PointBox[{16.5, 0.17143434973934862`}], 
        PointBox[{16.6, 0.17111670761139244`}], 
        PointBox[{16.7, 0.17451246257609232`}], 
        PointBox[{16.8, 0.17061288338210268`}], 
        PointBox[{16.9, 0.17069071673447955`}], 
        PointBox[{17., 0.17314118771650153`}], 
        PointBox[{17.1, 0.17286051261971458`}], 
        PointBox[{17.2, 0.17230710674101363`}], 
        PointBox[{17.3, 0.17842725883637015`}], 
        PointBox[{17.4, 0.18003723246234735`}], 
        PointBox[{17.5, 0.1786012088396726}], 
        PointBox[{17.6, 0.1806007572715888}], 
        PointBox[{17.7, 0.18106531399296016`}], 
        PointBox[{17.8, 0.17809147943403064`}], 
        PointBox[{17.9, 0.17921163948116375`}], 
        PointBox[{18., 0.18163591907986074`}], 
        PointBox[{18.1, 0.1789023338989095}], 
        PointBox[{18.2, 0.18225990428161315`}], 
        PointBox[{18.3, 0.18588394414572626`}], 
        PointBox[{18.4, 0.18565390143751453`}], 
        PointBox[{18.5, 0.184150376311276}], 
        PointBox[{18.6, 0.18858671505048935`}], 
        PointBox[{18.7, 0.1853420408773845}], 
        PointBox[{18.8, 0.18421126368968632`}], 
        PointBox[{18.9, 0.18610693680765064`}], 
        PointBox[{19., 0.1876169349654971}], 
        PointBox[{19.1, 0.1840754944493684}], 
        PointBox[{19.2, 0.18938634533464963`}], 
        PointBox[{19.3, 0.19045722905460824`}], 
        PointBox[{19.4, 0.18909230780345793`}], 
        PointBox[{19.5, 0.18904941423600038`}], 
        PointBox[{19.6, 0.19279539296246662`}], 
        PointBox[{19.7, 0.18844780333776298`}], 
        PointBox[{19.8, 0.18906157790535552`}], 
        PointBox[{19.9, 0.19121089074707515`}], 
        PointBox[{20., 0.19035020001770184`}], 
        PointBox[{20.1, 0.18976725973844372`}], 
        PointBox[{20.2, 0.19337307728994932`}], 
        PointBox[{20.3, 0.19261964789605546`}], 
        PointBox[{20.4, 0.1910046267376383}], 
        PointBox[{20.5, 0.1940272661701583}], 
        PointBox[{20.6, 0.1931796294140818}], 
        PointBox[{20.7, 0.190949854972125}], 
        PointBox[{20.8, 0.19260175180867978`}], 
        PointBox[{20.9, 0.194157839752513}], 
        PointBox[{21., 0.19057140637754139`}], 
        PointBox[{21.1, 0.19378557636183608`}], 
        PointBox[{21.2, 0.19462906330093896`}], 
        PointBox[{21.3, 0.19294268349569962`}], 
        PointBox[{21.4, 0.1923143172252475}], 
        PointBox[{21.5, 0.1970580132971545}], 
        PointBox[{21.6, 0.19247614027478402`}], 
        PointBox[{21.7, 0.1927497647840589}], 
        PointBox[{21.8, 0.1945979133037493}], 
        PointBox[{21.9, 0.19432735006343216`}], 
        PointBox[{22., 0.1910845077689603}], 
        PointBox[{22.1, 0.19493690654306417`}], 
        PointBox[{22.2, 0.19374680751932868`}], 
        PointBox[{22.3, 0.19200918291681304`}], 
        PointBox[{22.4, 0.19381971686204089`}], 
        PointBox[{22.5, 0.19533318569219452`}], 
        PointBox[{22.6, 0.19190133608059615`}], 
        PointBox[{22.7, 0.19343665553938452`}], 
        PointBox[{22.8, 0.19460785990889376`}], 
        PointBox[{22.9, 0.19155368644281828`}], 
        PointBox[{23., 0.1919394514028749}], 
        PointBox[{23.1, 0.19326478938208488`}], 
        PointBox[{23.2, 0.19123854359511985`}], 
        PointBox[{23.3, 0.19036760992739438`}], 
        PointBox[{23.4, 0.1946733812420728}], 
        PointBox[{23.5, 0.19124368039712522`}], 
        PointBox[{23.6, 0.19092879899248905`}], 
        PointBox[{23.7, 0.19249209256923666`}], 
        PointBox[{23.8, 0.19204092819195748`}], 
        PointBox[{23.9, 0.18711975822488514`}], 
        PointBox[{24., 0.1906025259552461}], 
        PointBox[{24.1, 0.189383673037627}], 
        PointBox[{24.2, 0.18744573873471643`}], 
        PointBox[{24.3, 0.18833673732058687`}], 
        PointBox[{24.4, 0.19185464051945686`}], 
        PointBox[{24.5, 0.18729195095432158`}], 
        PointBox[{24.6, 0.18869011131771882`}], 
        PointBox[{24.7, 0.18935088131835778`}], 
        PointBox[{24.8, 0.18643200683621014`}], 
        PointBox[{24.9, 0.1832224699490941}], 
        PointBox[{25., 0.1860219795825033}], 
        PointBox[{25.1, 0.18372480879142}], 
        PointBox[{25.2, 0.18251729850415857`}], 
        PointBox[{25.3, 0.18549923885895392`}], 
        PointBox[{25.4, 0.18498063677020815`}], 
        PointBox[{25.5, 0.1829772678461347}], 
        PointBox[{25.6, 0.18446927822586615`}], 
        PointBox[{25.7, 0.18345592255850526`}], 
        PointBox[{25.8, 0.1778661912517493}], 
        PointBox[{25.9, 0.1787150064610272}], 
        PointBox[{26., 0.1788203819013063}], 
        PointBox[{26.1, 0.176460558045601}], 
        PointBox[{26.2, 0.17639779170173994`}], 
        PointBox[{26.3, 0.18045279026736397`}], 
        PointBox[{26.4, 0.1766778851615381}], 
        PointBox[{26.5, 0.17719397256932817`}], 
        PointBox[{26.6, 0.17778786832184815`}], 
        PointBox[{26.7, 0.1744731986339002}], 
        PointBox[{26.8, 0.16799410188452907`}], 
        PointBox[{26.9, 0.171373290526378}], 
        PointBox[{27., 0.16963166579504024`}], 
        PointBox[{27.1, 0.16767716108351913`}], 
        PointBox[{27.2, 0.16887539596208728`}], 
        PointBox[{27.3, 0.17217036673321295`}], 
        PointBox[{27.4, 0.1677781440930858}], 
        PointBox[{27.5, 0.16938904128271068`}], 
        PointBox[{27.6, 0.16854405341764442`}], 
        PointBox[{27.7, 0.16293598450060431`}], 
        PointBox[{27.8, 0.15809701367362652`}], 
        PointBox[{27.9, 0.16155543858785115`}], 
        PointBox[{28., 0.15902030086611238`}], 
        PointBox[{28.1, 0.15760269148033126`}], 
        PointBox[{28.2, 0.15983143728062751`}], 
        PointBox[{28.3, 0.16142561495217117`}], 
        PointBox[{28.4, 0.15793534864770412`}], 
        PointBox[{28.5, 0.15971037170473873`}], 
        PointBox[{28.6, 0.157285052778762}], 
        PointBox[{28.7, 0.1504986512815395}], 
        PointBox[{28.8, 0.14781245287532557`}], 
        PointBox[{28.9, 0.15048739241999817`}], 
        PointBox[{29., 0.147686435847533}], 
        PointBox[{29.1, 0.14673225196538986`}], 
        PointBox[{29.2, 0.14957054865166355`}], 
        PointBox[{29.3, 0.1497747414838962}], 
        PointBox[{29.4, 0.14724399064423688`}], 
        PointBox[{29.5, 0.1488913170906387}], 
        PointBox[{29.6, 0.14524785753842762`}], 
        PointBox[{29.7, 0.1384970183510035}], 
        PointBox[{29.8, 0.13715274231498062`}], 
        PointBox[{29.9, 0.13926539200688384`}], 
        PointBox[{30., 0.13637536385795787`}], 
        PointBox[{30.1, 0.13569377838505173`}], 
        PointBox[{30.2, 0.13877630512918296`}], 
        PointBox[{30.3, 0.1383393229535151}], 
        PointBox[{30.4, 0.13625563654432463`}], 
        PointBox[{30.5, 0.13784867595628697`}], 
        PointBox[{30.6, 0.1336821569125034}], 
        PointBox[{30.7, 0.127432390208176}], 
        PointBox[{30.8, 0.12652377629913267`}], 
        PointBox[{30.9, 0.12855222786806775`}], 
        PointBox[{31., 0.1256144383752204}], 
        PointBox[{31.1, 0.1249669958171441}], 
        PointBox[{31.2, 0.12807109399040686`}], 
        PointBox[{31.3, 0.12766552831342298`}], 
        PointBox[{31.4, 0.1254915441612767}], 
        PointBox[{31.5, 0.12720776466392467`}], 
        PointBox[{31.6, 0.12315477801601643`}], 
        PointBox[{31.7, 0.1173560609017546}], 
        PointBox[{31.8, 0.11618968674613532`}], 
        PointBox[{31.9, 0.11853432144855539`}], 
        PointBox[{32., 0.11559739672922222`}], 
        PointBox[{32.1, 0.11474511876142163`}], 
        PointBox[{32.2, 0.11772353201130865`}], 
        PointBox[{32.3, 0.11785755408326504`}], 
        PointBox[{32.4, 0.11520183508966937`}], 
        PointBox[{32.5, 0.11712417063848161`}], 
        PointBox[{32.6, 0.11365174890749317`}], 
        PointBox[{32.7, 0.10810263568656134`}], 
        PointBox[{32.8, 0.10619531795555719`}], 
        PointBox[{32.9, 0.10904523308725984`}], 
        PointBox[{33., 0.10626283303496087`}], 
        PointBox[{33.1, 0.10499287748127697`}], 
        PointBox[{33.2, 0.1076905096522726}], 
        PointBox[{33.3, 0.10870664987382937`}], 
        PointBox[{33.4, 0.10542955481982579`}], 
        PointBox[{33.5, 0.10741612009487456`}], 
        PointBox[{33.6, 0.10493198270285246`}], 
        PointBox[{33.7, 0.09941941191138512}], 
        PointBox[{33.8, 0.09650666854141454}], 
        PointBox[{33.9, 0.09972336347977905}], 
        PointBox[{34., 0.09741982075973597}], 
        PointBox[{34.1, 0.09557403445661047}], 
        PointBox[{34.2, 0.09779131212308924}], 
        PointBox[{34.3, 0.0998170300589659}], 
        PointBox[{34.4, 0.09615610713356873}], 
        PointBox[{34.5, 0.09777836446029109}], 
        PointBox[{34.6, 0.09663875845980625}], 
        PointBox[{34.7, 0.09105972300664}], 
        PointBox[{34.8, 0.08712037042319859}], 
        PointBox[{34.9, 0.09015781917402967}], 
        PointBox[{35., 0.08882067363770951}], 
        PointBox[{35.1, 0.08635058537920379}], 
        PointBox[{35.2, 0.08784479027418293}], 
        PointBox[{35.3, 0.09074513578129186}], 
        PointBox[{35.4, 0.08735125178479046}], 
        PointBox[{35.5, 0.08795976589771082}], 
        PointBox[{35.6, 0.08829171311312911}], 
        PointBox[{35.7, 0.08289761191961655}], 
        PointBox[{35.8, 0.07806221293297705}], 
        PointBox[{35.9, 0.08005467276843183}], 
        PointBox[{36., 0.08017122163353885}], 
        PointBox[{36.1, 0.07723123459114387}], 
        PointBox[{36.2, 0.07774725076786072}], 
        PointBox[{36.3, 0.08113879758485915}], 
        PointBox[{36.4, 0.07888331705605212}], 
        PointBox[{36.5, 0.07789618230863113}], 
        PointBox[{36.6, 0.07940237631227855}], 
        PointBox[{36.7, 0.07501777409735445}], 
        PointBox[{36.8, 0.06933341921693438}], 
        PointBox[{36.9, 0.06941650379619405}], 
        PointBox[{37., 0.07112134263329242}], 
        PointBox[{37.1, 0.06817083683308024}], 
        PointBox[{37.2, 0.06750361761912164}], 
        PointBox[{37.3, 0.07084491853247354}], 
        PointBox[{37.4, 0.07039577203390007}], 
        PointBox[{37.5, 0.06777166263527078}], 
        PointBox[{37.6, 0.06967333979450477}], 
        PointBox[{37.7, 0.06730880853882848}], 
        PointBox[{37.8, 0.06090213516134258}], 
        PointBox[{37.9, 0.058604534901392204`}], 
        PointBox[{38., 0.061322282671438244`}], 
        PointBox[{38.1, 0.05911462503137242}], 
        PointBox[{38.2, 0.057231094529781666`}], 
        PointBox[{38.3, 0.05992850603218033}], 
        PointBox[{38.4, 0.0613858972157638}], 
        PointBox[{38.5, 0.057927468901456544`}], 
        PointBox[{38.6, 0.05911325879161353}], 
        PointBox[{38.7, 0.05902087853321212}], 
        PointBox[{38.8, 0.05281011426207489}], 
        PointBox[{38.9, 0.0481759314378577}], 
        PointBox[{39., 0.05062823635390864}], 
        PointBox[{39.1, 0.0499209725067467}], 
        PointBox[{39.2, 0.04712473994614763}], 
        PointBox[{39.3, 0.04863831987911058}], 
        PointBox[{39.4, 0.051517198575136695`}], 
        PointBox[{39.5, 0.04855685259162459}], 
        PointBox[{39.6, 0.048068213390637604`}], 
        PointBox[{39.7, 0.04959363056595072}], 
        PointBox[{39.8, 0.045167101524996575`}], 
        PointBox[{39.9, 0.038624247284860774`}], 
        PointBox[{40., 0.03934956597262157}], 
        PointBox[{40.1, 0.040373770015264446`}], 
        PointBox[{40.2, 0.03738261328417949}], 
        PointBox[{40.3, 0.037369219553676586`}], 
        PointBox[{40.4, 0.040864530788833814`}], 
        PointBox[{40.5, 0.03946654389731416}], 
        PointBox[{40.6, 0.03716233986006866}], 
        PointBox[{40.7, 0.03914411766285407}], 
        PointBox[{40.8, 0.03740436651079744}], 
        PointBox[{40.9, 0.030294704781825096`}], 
        PointBox[{41., 0.02831394502288187}], 
        PointBox[{41.1, 0.03045860363611976}], 
        PointBox[{41.2, 0.02814848437907246}], 
        PointBox[{41.3, 0.02666414026018149}], 
        PointBox[{41.4, 0.029994045845538456`}], 
        PointBox[{41.5, 0.03037090077738822}], 
        PointBox[{41.6, 0.027071753315289174`}], 
        PointBox[{41.7, 0.028333747438490927`}], 
        PointBox[{41.8, 0.028874238355513695`}], 
        PointBox[{41.9, 0.02328022799604693}], 
        PointBox[{42., 0.01879288990342271}], 
        PointBox[{42.1, 0.02101851875623559}], 
        PointBox[{42.2, 0.019793600391209747`}], 
        PointBox[{42.3, 0.017412018588259148`}], 
        PointBox[{42.4, 0.02020854771020833}], 
        PointBox[{42.5, 0.021749718134469045`}], 
        PointBox[{42.6, 0.018424337076903895`}], 
        PointBox[{42.7, 0.018514636391975023`}], 
        PointBox[{42.8, 0.020384512174564603`}], 
        PointBox[{42.9, 0.017086343560312113`}], 
        PointBox[{43., 0.012938494154222985`}], 
        PointBox[{43.1, 0.015068073893918994`}], 
        PointBox[{43.2, 0.01446161079502193}], 
        PointBox[{43.3, 0.012037618103180138`}], 
        PointBox[{43.4, 0.01475538579888077}], 
        PointBox[{43.5, 0.016347803077341024`}], 
        PointBox[{43.6, 0.013064893228452685`}], 
        PointBox[{43.7, 0.012812944322348509`}], 
        PointBox[{43.8, 0.01524121207545076}], 
        PointBox[{43.9, 0.01337093571467299}], 
        PointBox[{44., 0.013070465547275248`}], 
        PointBox[{44.1, 0.01687647355378358}], 
        PointBox[{44.2, 0.016857155319880242`}], 
        PointBox[{44.3, 0.014707790634664864`}], 
        PointBox[{44.4, 0.017438732651398472`}], 
        PointBox[{44.5, 0.018774650212871388`}], 
        PointBox[{44.6, 0.01534620423768085}], 
        PointBox[{44.7, 0.015326536991162171`}], 
        PointBox[{44.8, 0.018058224122578972`}], 
        PointBox[{44.9, 0.016682450761590795`}], 
        PointBox[{45., 0.017277969456826563`}], 
        PointBox[{45.1, 0.023555530223125443`}], 
        PointBox[{45.2, 0.02527909170632638}], 
        PointBox[{45.3, 0.023081200231448426`}], 
        PointBox[{45.4, 0.024920036388806376`}], 
        PointBox[{45.5, 0.02708296182924948}], 
        PointBox[{45.6, 0.02388429258010669}], 
        PointBox[{45.7, 0.023014905200259162`}], 
        PointBox[{45.8, 0.026013450845685807`}], 
        PointBox[{45.9, 0.025559325732726193`}], 
        PointBox[{46., 0.024406011954622223`}], 
        PointBox[{46.1, 0.030903154892961315`}], 
        PointBox[{46.2, 0.035181581092819374`}], 
        PointBox[{46.3, 0.03358635323597091}], 
        PointBox[{46.4, 0.03377044600972511}], 
        PointBox[{46.5, 0.036963411513395626`}], 
        PointBox[{46.6, 0.03466503562399853}], 
        PointBox[{46.7, 0.03250572139618382}], 
        PointBox[{46.8, 0.03513855122767177}], 
        PointBox[{46.9, 0.036205589287670016`}], 
        PointBox[{47., 0.033785758021127946`}], 
        PointBox[{47.1, 0.038200847800350414`}], 
        PointBox[{47.2, 0.04463670647331273}], 
        PointBox[{47.3, 0.04474217308477766}], 
        PointBox[{47.4, 0.043377659594781216`}], 
        PointBox[{47.5, 0.04667940251626539}], 
        PointBox[{47.6, 0.04603041107621999}], 
        PointBox[{47.7, 0.04287915344678215}], 
        PointBox[{47.8, 0.044404199702115524`}], 
        PointBox[{47.9, 0.04683862680938987}], 
        PointBox[{48., 0.04452579330709855}], 
        PointBox[{48.1, 0.04612503387474444}], 
        PointBox[{48.2, 0.05302056921416156}], 
        PointBox[{48.3, 0.05561842715760164}], 
        PointBox[{48.4, 0.053700544753352716`}], 
        PointBox[{48.5, 0.05582592472649508}], 
        PointBox[{48.6, 0.05718646750301762}], 
        PointBox[{48.7, 0.05370471329214837}], 
        PointBox[{48.8, 0.05377520973661878}], 
        PointBox[{48.9, 0.05679366268055411}], 
        PointBox[{49., 0.055801115112363284`}], 
        PointBox[{49.1, 0.054827295292288664`}], 
        PointBox[{49.2, 0.06071208496470988}], 
        PointBox[{49.3, 0.06562178075320677}], 
        PointBox[{49.4, 0.0643962936555266}], 
        PointBox[{49.5, 0.0646693072783306}], 
        PointBox[{49.6, 0.0676515244248592}], 
        PointBox[{49.7, 0.06462219501133608}], 
        PointBox[{49.8, 0.06330781017588245}], 
        PointBox[{49.9, 0.06606199114087402}], 
        PointBox[{50., 0.06682205942973472}], 
        PointBox[{50.1, 0.06420354715100078}], 
        PointBox[{50.2, 0.06858774094041238}], 
        PointBox[{50.3, 0.07453870345980948}], 
        PointBox[{50.4, 0.07493749442438312}], 
        PointBox[{50.5, 0.07366650060176022}], 
        PointBox[{50.6, 0.07721171374419913}], 
        PointBox[{50.7, 0.07534741287847167}], 
        PointBox[{50.8, 0.07295508666544492}], 
        PointBox[{50.9, 0.07491733839129897}], 
        PointBox[{51., 0.07707920719502251}], 
        PointBox[{51.1, 0.07410292660292679}], 
        PointBox[{51.2, 0.07673684737388342}], 
        PointBox[{51.3, 0.08259198556732905}], 
        PointBox[{51.4, 0.08495323126984092}], 
        PointBox[{51.5, 0.08302574943329918}], 
        PointBox[{51.6, 0.0859699347237027}], 
        PointBox[{51.7, 0.08570928062857709}], 
        PointBox[{51.8, 0.0826291677559168}], 
        PointBox[{51.9, 0.08363269098401446}], 
        PointBox[{52., 0.08651260149015194}], 
        PointBox[{52.1, 0.08426196135846231}], 
        PointBox[{52.2, 0.08499483450028233}], 
        PointBox[{52.3, 0.09038752566283009}], 
        PointBox[{52.4, 0.09437361327064034}], 
        PointBox[{52.5, 0.09265847573862783}], 
        PointBox[{52.6, 0.09431380096290805}], 
        PointBox[{52.7, 0.0956773609172017}], 
        PointBox[{52.8, 0.09228938340740087}], 
        PointBox[{52.9, 0.09240313476949773}], 
        PointBox[{53., 0.09540871614822734}], 
        PointBox[{53.1, 0.09439814464709627}], 
        PointBox[{53.2, 0.0934228983576371}], 
        PointBox[{53.3, 0.09845905695580025}], 
        PointBox[{53.4, 0.10340278629896253`}], 
        PointBox[{53.5, 0.10242858460814148`}], 
        PointBox[{53.6, 0.10273517409066811`}], 
        PointBox[{53.7, 0.10537102619971922`}], 
        PointBox[{53.8, 0.10197999178717948`}], 
        PointBox[{53.9, 0.10138363017856837`}], 
        PointBox[{54., 0.10418091394154219`}], 
        PointBox[{54.1, 0.10438140366230685`}], 
        PointBox[{54.2, 0.10217328626603879`}], 
        PointBox[{54.3, 0.10698930944870823`}], 
        PointBox[{54.4, 0.11242437955445836`}], 
        PointBox[{54.5, 0.11233480840250878`}], 
        PointBox[{54.6, 0.11163440849993506`}], 
        PointBox[{54.7, 0.11504530026783799`}], 
        PointBox[{54.8, 0.11182300369558647`}], 
        PointBox[{54.9, 0.11073415733441354`}], 
        PointBox[{55., 0.11322561199599392`}], 
        PointBox[{55.1, 0.11431487118934036`}], 
        PointBox[{55.2, 0.11139633389217554`}], 
        PointBox[{55.3, 0.11609354969734294`}], 
        PointBox[{55.4, 0.12187584779777559`}], 
        PointBox[{55.5, 0.12250862665237025`}], 
        PointBox[{55.6, 0.12123912720340038`}], 
        PointBox[{55.7, 0.12502482887084884`}], 
        PointBox[{55.8, 0.12196943692270742`}], 
        PointBox[{55.9, 0.12061791090211056`}], 
        PointBox[{56., 0.12286167942830035`}], 
        PointBox[{56.1, 0.12445059553659259`}], 
        PointBox[{56.2, 0.12121065785671833`}], 
        PointBox[{56.3, 0.12598898274834125`}], 
        PointBox[{56.4, 0.13210024480443008`}], 
        PointBox[{56.5, 0.13308406959013008`}], 
        PointBox[{56.6, 0.1316095591009265}], 
        PointBox[{56.7, 0.13556378003220534`}], 
        PointBox[{56.8, 0.13250463333441584`}], 
        PointBox[{56.9, 0.13113525499627512`}], 
        PointBox[{57., 0.1332727996991876}], 
        PointBox[{57.1, 0.13499844534493707`}], 
        PointBox[{57.2, 0.13167743599977305`}], 
        PointBox[{57.3, 0.136903598467437}], 
        PointBox[{57.4, 0.1431611289477792}], 
        PointBox[{57.5, 0.14399853869767076`}], 
        PointBox[{57.6, 0.14261405614462827`}], 
        PointBox[{57.7, 0.14663469979738736`}], 
        PointBox[{57.8, 0.14331903359699955`}], 
        PointBox[{57.9, 0.14220574648391723`}], 
        PointBox[{58., 0.14440359999595725`}], 
        PointBox[{58.1, 0.14588982306530837`}], 
        PointBox[{58.2, 0.14276806541782078`}], 
        PointBox[{58.3, 0.14886705899164887`}], 
        PointBox[{58.4, 0.15462088479122613`}], 
        PointBox[{58.5, 0.1548228676969858}], 
        PointBox[{58.6, 0.15390649021935765`}], 
        PointBox[{58.7, 0.1576949913224292}], 
        PointBox[{58.8, 0.1540159127548864}], 
        PointBox[{58.9, 0.15345438794714292`}], 
        PointBox[{59., 0.15584256405057764`}], 
        PointBox[{59.1, 0.15656733895612174`}], 
        PointBox[{59.2, 0.15436153431726649`}], 
        PointBox[{59.3, 0.16129625244655083`}], 
        PointBox[{59.4, 0.16551023382539803`}], 
        PointBox[{59.5, 0.16481222583696037`}], 
        PointBox[{59.6, 0.1650410323242386}], 
        PointBox[{59.7, 0.16768453889924861`}], 
        PointBox[{59.8, 0.16400652730394608`}], 
        PointBox[{59.9, 0.16424466867067944`}], 
        PointBox[{60., 0.16682860854406012`}], 
        PointBox[{60.1, 0.1660240313822702}], 
        PointBox[{60.2, 0.166194501031108}], 
        PointBox[{60.3, 0.17267754516395664`}], 
        PointBox[{60.4, 0.17475890298632127`}], 
        PointBox[{60.5, 0.17329435218680608`}], 
        PointBox[{60.6, 0.17559416140466091`}], 
        PointBox[{60.7, 0.1756162704649354}], 
        PointBox[{60.8, 0.172796766868995}], 
        PointBox[{60.9, 0.17392488930119304`}], 
        PointBox[{61., 0.1764396988269094}], 
        PointBox[{61.1, 0.17355804072410574`}], 
        PointBox[{61.2, 0.1773013763035264}], 
        PointBox[{61.3, 0.18157422581496}], 
        PointBox[{61.4, 0.18174230978479808`}], 
        PointBox[{61.5, 0.18018365393643007`}], 
        PointBox[{61.6, 0.18458179734672037`}], 
        PointBox[{61.7, 0.18140971996876648`}], 
        PointBox[{61.8, 0.18018303586996068`}], 
        PointBox[{61.9, 0.1820631036566612}], 
        PointBox[{62., 0.1837349762548506}], 
        PointBox[{62.1, 0.18020345667613716`}], 
        PointBox[{62.2, 0.18591297620777536`}], 
        PointBox[{62.3, 0.1875980172335851}], 
        PointBox[{62.4, 0.1864573429136182}], 
        PointBox[{62.5, 0.18620053345269738`}], 
        PointBox[{62.6, 0.19004464926314485`}], 
        PointBox[{62.7, 0.18575468427016023`}], 
        PointBox[{62.8, 0.18617002406256014`}], 
        PointBox[{62.9, 0.18840250917669854`}], 
        PointBox[{63., 0.18784743439330095`}], 
        PointBox[{63.1, 0.1872080747044175}], 
        PointBox[{63.2, 0.19134321115232722`}], 
        PointBox[{63.3, 0.19104030903099484`}], 
        PointBox[{63.4, 0.18941359760895768`}], 
        PointBox[{63.5, 0.19211919430001217`}], 
        PointBox[{63.6, 0.1917322148604633}], 
        PointBox[{63.7, 0.18922383628347594`}], 
        PointBox[{63.8, 0.1907675301046144}], 
        PointBox[{63.9, 0.19259975126742593`}], 
        PointBox[{64., 0.18923281947468715`}], 
        PointBox[{64.1, 0.19250561278174197`}], 
        PointBox[{64.2, 0.19389304688501952`}], 
        PointBox[{64.3, 0.19242911198883042`}], 
        PointBox[{64.4, 0.19152810031187148`}], 
        PointBox[{64.5, 0.1963157863961414}], 
        PointBox[{64.6, 0.19195593694696056`}], 
        PointBox[{64.7, 0.1919008439885672}], 
        PointBox[{64.8, 0.19384047598357443`}], 
        PointBox[{64.9, 0.19404596737179572`}], 
        PointBox[{65., 0.1908146340332118}], 
        PointBox[{65.1, 0.1949262264543234}], 
        PointBox[{65.2, 0.19413657576624319`}], 
        PointBox[{65.3, 0.19237688092512145`}], 
        PointBox[{65.4, 0.1937940248090395}], 
        PointBox[{65.5, 0.19585987291299353`}], 
        PointBox[{65.6, 0.19212369417388847`}], 
        PointBox[{65.7, 0.19353173883879857`}], 
        PointBox[{65.8, 0.19503060215836743`}], 
        PointBox[{65.9, 0.19244472383528546`}], 
        PointBox[{66., 0.1927170237899694}], 
        PointBox[{66.1, 0.19448469353438028`}], 
        PointBox[{66.2, 0.19263061998383801`}], 
        PointBox[{66.3, 0.19153633582015867`}], 
        PointBox[{66.4, 0.19574014380843346`}], 
        PointBox[{66.5, 0.19267201555629115`}], 
        PointBox[{66.6, 0.19199631522561372`}], 
        PointBox[{66.7, 0.19369128490943743`}], 
        PointBox[{66.8, 0.19376795992262807`}], 
        PointBox[{66.9, 0.18921018942916118`}], 
        PointBox[{67., 0.1926541290675369}], 
        PointBox[{67.1, 0.19176533135045248`}], 
        PointBox[{67.2, 0.18980988865593953`}], 
        PointBox[{67.3, 0.19043581079033364`}], 
        PointBox[{67.4, 0.19423310791424736`}], 
        PointBox[{67.5, 0.18956255338147415`}], 
        PointBox[{67.6, 0.1908241272447556}], 
        PointBox[{67.7, 0.19185342100427946`}], 
        PointBox[{67.8, 0.18954582076352638`}], 
        PointBox[{67.9, 0.1864832596718383}], 
        PointBox[{68., 0.18940973907913972`}], 
        PointBox[{68.1, 0.1872647950276359}], 
        PointBox[{68.2, 0.18594862547770374`}], 
        PointBox[{68.3, 0.18888017041071428`}], 
        PointBox[{68.4, 0.18844228709922126`}], 
        PointBox[{68.5, 0.18633340330271558`}], 
        PointBox[{68.6, 0.18789427164776912`}], 
        PointBox[{68.7, 0.18743792770979606`}], 
        PointBox[{68.8, 0.1824043464598249}], 
        PointBox[{68.9, 0.183418155222453}], 
        PointBox[{69., 0.18350759977060005`}], 
        PointBox[{69.1, 0.18121696226378636`}], 
        PointBox[{69.2, 0.18110160020200688`}], 
        PointBox[{69.3, 0.18529352004723565`}], 
        PointBox[{69.4, 0.1812937659589564}], 
        PointBox[{69.5, 0.1818607177097455}], 
        PointBox[{69.6, 0.18263001385158126`}], 
        PointBox[{69.7, 0.17995783571120857`}], 
        PointBox[{69.8, 0.1738372621355673}], 
        PointBox[{69.9, 0.17738647758692536`}], 
        PointBox[{70., 0.1755313401345718}], 
        PointBox[{70.1, 0.1736774638723654}], 
        PointBox[{70.2, 0.1750303938426384}], 
        PointBox[{70.3, 0.17808117908683246`}], 
        PointBox[{70.4, 0.1737526683586989}], 
        PointBox[{70.5, 0.17538461109851947`}], 
        PointBox[{70.6, 0.17467552007273332`}], 
        PointBox[{70.7, 0.16948972508575208`}], 
        PointBox[{70.8, 0.16539341502100108`}], 
        PointBox[{70.9, 0.16848039803247597`}], 
        PointBox[{71., 0.16588135610885893`}], 
        PointBox[{71.1, 0.1646995304631994}], 
        PointBox[{71.2, 0.1673209083500322}], 
        PointBox[{71.3, 0.1679010367405408}], 
        PointBox[{71.4, 0.16515259767223472`}], 
        PointBox[{71.5, 0.1667304707033252}], 
        PointBox[{71.6, 0.1641664574490896}], 
        PointBox[{71.7, 0.1573670666254787}], 
        PointBox[{71.8, 0.15616221941540842`}], 
        PointBox[{71.9, 0.15779176391447813`}], 
        PointBox[{72., 0.15504620837570782`}], 
        PointBox[{72.1, 0.15453556107878313`}], 
        PointBox[{72.2, 0.15786879603627815`}], 
        PointBox[{72.3, 0.15644946335902105`}], 
        PointBox[{72.4, 0.15524056409883624`}], 
        PointBox[{72.5, 0.15635546909136774`}], 
        PointBox[{72.6, 0.1520864380712026}], 
        PointBox[{72.7, 0.14518269224073233`}], 
        PointBox[{72.8, 0.1458569204531001}], 
        PointBox[{72.9, 0.14642819130608306`}], 
        PointBox[{73., 0.14370930526546385`}], 
        PointBox[{73.1, 0.1437040290693433}], 
        PointBox[{73.2, 0.14724293287587972`}], 
        PointBox[{73.3, 0.14483393254400076`}], 
        PointBox[{73.4, 0.1444711644856482}], 
        PointBox[{73.5, 0.1451912539868982}], 
        PointBox[{73.6, 0.1399572378397447}], 
        PointBox[{73.7, 0.13366502633064228`}], 
        PointBox[{73.8, 0.13511740197151698`}], 
        PointBox[{73.9, 0.13526647408329218`}], 
        PointBox[{74., 0.13254913878381316`}], 
        PointBox[{74.1, 0.1327993658856325}], 
        PointBox[{74.2, 0.13632011139613232`}], 
        PointBox[{74.3, 0.13367413160333688`}], 
        PointBox[{74.4, 0.13352659828252714`}], 
        PointBox[{74.5, 0.1341666007456107}], 
        PointBox[{74.6, 0.12874971647661163`}], 
        PointBox[{74.7, 0.1230243853518742}], 
        PointBox[{74.8, 0.1245146101344971}], 
        PointBox[{74.9, 0.12478138283769794`}], 
        PointBox[{75., 0.12198262448672882`}], 
        PointBox[{75.1, 0.12222293900553347`}], 
        PointBox[{75.2, 0.12569092962727177`}], 
        PointBox[{75.3, 0.12330585874954754`}], 
        PointBox[{75.4, 0.12286823247767201`}], 
        PointBox[{75.5, 0.12377476147196667`}], 
        PointBox[{75.6, 0.11863145887374656`}], 
        PointBox[{75.7, 0.11323692131968299`}], 
        PointBox[{75.8, 0.11422279916696687`}], 
        PointBox[{75.9, 0.1150444672650219}], 
        PointBox[{76., 0.11211476620271435`}], 
        PointBox[{76.1, 0.112094834808797}], 
        PointBox[{76.2, 0.11549305359491836`}], 
        PointBox[{76.3, 0.1137900826803231}], 
        PointBox[{76.4, 0.11263330459002585`}], 
        PointBox[{76.5, 0.11402294287792093`}], 
        PointBox[{76.6, 0.10942802740036972`}], 
        PointBox[{76.7, 0.1041547705918655}], 
        PointBox[{76.8, 0.1041619704107719}], 
        PointBox[{76.9, 0.10584636623457028`}], 
        PointBox[{77., 0.10284801208106949`}], 
        PointBox[{77.1, 0.1023412443374602}], 
        PointBox[{77.2, 0.10557399308654972`}], 
        PointBox[{77.3, 0.10494558055648062`}], 
        PointBox[{77.4, 0.10277811207983878`}], 
        PointBox[{77.5, 0.10462419008493486`}], 
        PointBox[{77.6, 0.10092204505142248`}], 
        PointBox[{77.7, 0.09556913388007578}], 
        PointBox[{77.8, 0.09422595765262073}], 
        PointBox[{77.9, 0.09681946943483888}], 
        PointBox[{78., 0.09400053340734775}], 
        PointBox[{78.1, 0.09281806769421277}], 
        PointBox[{78.2, 0.09569159873677782}], 
        PointBox[{78.3, 0.09640164107630411}], 
        PointBox[{78.4, 0.09325276177896791}], 
        PointBox[{78.5, 0.09520411059286621}], 
        PointBox[{78.6, 0.09286286838850176}], 
        PointBox[{78.7, 0.08725977265959041}], 
        PointBox[{78.8, 0.0844198464846972}], 
        PointBox[{78.9, 0.08753417155873243}], 
        PointBox[{79., 0.08536673107326831}], 
        PointBox[{79.1, 0.08340286862634788}], 
        PointBox[{79.2, 0.08564600728388023}], 
        PointBox[{79.3, 0.08768765902585655}], 
        PointBox[{79.4, 0.08408262147600508}], 
        PointBox[{79.5, 0.08546351242265923}], 
        PointBox[{79.6, 0.08482003502900863}], 
        PointBox[{79.7, 0.07907544783280646}], 
        PointBox[{79.8, 0.07486036356807485}], 
        PointBox[{79.9, 0.07762663432793616}], 
        PointBox[{80., 0.07671439620185778}], 
        PointBox[{80.1, 0.0740380483305253}], 
        PointBox[{80.2, 0.07534327853324885}], 
        PointBox[{80.3, 0.0783835226077365}], 
        PointBox[{80.4, 0.07528624979633404}], 
        PointBox[{80.5, 0.0753007869072696}], 
        PointBox[{80.6, 0.07623508973184621}], 
        PointBox[{80.7, 0.07107589338606694}], 
        PointBox[{80.8, 0.06568121091015947}], 
        PointBox[{80.9, 0.0669908949207511}], 
        PointBox[{81., 0.06775335214925386}], 
        PointBox[{81.1, 0.06472886571580655}], 
        PointBox[{81.2, 0.0648170953457835}], 
        PointBox[{81.3, 0.06827385189107267}], 
        PointBox[{81.4, 0.06667520028516033}], 
        PointBox[{81.5, 0.06488857906833531}], 
        PointBox[{81.6, 0.06672658604423239}], 
        PointBox[{81.7, 0.0633698588200575}], 
        PointBox[{81.8, 0.05694717341383419}], 
        PointBox[{81.9, 0.055924649353027954`}], 
        PointBox[{82., 0.05815070594773051}], 
        PointBox[{82.1, 0.05548876394816972}], 
        PointBox[{82.2, 0.05422254848238405}], 
        PointBox[{82.3, 0.0574071383124481}], 
        PointBox[{82.4, 0.05780046404479981}], 
        PointBox[{82.5, 0.05463030351525565}], 
        PointBox[{82.6, 0.05626390505017136}], 
        PointBox[{82.7, 0.05535152717508528}], 
        PointBox[{82.8, 0.04870244547320932}], 
        PointBox[{82.9, 0.04504761562044801}], 
        PointBox[{83., 0.04770235179039449}], 
        PointBox[{83.1, 0.04625160387950994}], 
        PointBox[{83.2, 0.043807833816768435`}], 
        PointBox[{83.3, 0.046062909218229475`}], 
        PointBox[{83.4, 0.04823341671100865}], 
        PointBox[{83.5, 0.04489227801227676}], 
        PointBox[{83.6, 0.04517815299936308}], 
        PointBox[{83.7, 0.04626637761161176}], 
        PointBox[{83.8, 0.0410345069862577}], 
        PointBox[{83.9, 0.035028160037405096`}], 
        PointBox[{84., 0.03662345988277659}], 
        PointBox[{84.1, 0.03685966325086279}], 
        PointBox[{84.2, 0.03384874728563678}], 
        PointBox[{84.3, 0.03470257502874327}], 
        PointBox[{84.4, 0.03794636698146819}], 
        PointBox[{84.5, 0.03568207963508326}], 
        PointBox[{84.6, 0.03411792524617717}], 
        PointBox[{84.7, 0.036142104035400274`}], 
        PointBox[{84.8, 0.03352212381500957}], 
        PointBox[{84.9, 0.026420646658373445`}], 
        PointBox[{85., 0.02575035766051844}], 
        PointBox[{85.1, 0.0273537245383559}], 
        PointBox[{85.2, 0.024624891710767826`}], 
        PointBox[{85.3, 0.024012621332157952`}], 
        PointBox[{85.4, 0.027541986709401733`}], 
        PointBox[{85.5, 0.026827638008202804`}], 
        PointBox[{85.6, 0.023909435934968252`}], 
        PointBox[{85.7, 0.02572100366888235}], 
        PointBox[{85.8, 0.025517385007254013`}], 
        PointBox[{85.9, 0.019613375407652126`}], 
        PointBox[{86., 0.016699222141335467`}], 
        PointBox[{86.1, 0.018837264312591077`}], 
        PointBox[{86.2, 0.016832641379815008`}], 
        PointBox[{86.3, 0.015325748154323074`}], 
        PointBox[{86.4, 0.018728859372524477`}], 
        PointBox[{86.5, 0.018996918341655032`}], 
        PointBox[{86.6, 0.015620790574512954`}], 
        PointBox[{86.7, 0.016775835451762446`}], 
        PointBox[{86.8, 0.018050952657431885`}], 
        PointBox[{86.9, 0.01439879628103916}], 
        PointBox[{87., 0.012600967961240411`}], 
        PointBox[{87.1, 0.015157437306113082`}], 
        PointBox[{87.2, 0.013545871081095569`}], 
        PointBox[{87.3, 0.012195984547760438`}], 
        PointBox[{87.4, 0.015603440953809364`}], 
        PointBox[{87.5, 0.01563965361080594}], 
        PointBox[{87.6, 0.012198840118245307`}], 
        PointBox[{87.7, 0.01348085712752431}], 
        PointBox[{87.8, 0.015279231150114606`}], 
        PointBox[{87.9, 0.012927824109100287`}], 
        PointBox[{88., 0.015206417321790889`}], 
        PointBox[{88.1, 0.019402501424369813`}], 
        PointBox[{88.2, 0.01850504248631687}], 
        PointBox[{88.3, 0.017100347889771148`}], 
        PointBox[{88.4, 0.020385279595481025`}], 
        PointBox[{88.5, 0.02042997503952156}], 
        PointBox[{88.6, 0.016957833124003775`}], 
        PointBox[{88.7, 0.018188974708111517`}], 
        PointBox[{88.8, 0.020450128438581676`}], 
        PointBox[{88.9, 0.018437743254144257`}], 
        PointBox[{89., 0.02070774354113703}], 
        PointBox[{89.1, 0.027130131043712667`}], 
        PointBox[{89.2, 0.027988554024962753`}], 
        PointBox[{89.3, 0.025993096673035856`}], 
        PointBox[{89.4, 0.028570937787306544`}], 
        PointBox[{89.5, 0.029802734731360393`}], 
        PointBox[{89.6, 0.026296841977876663`}], 
        PointBox[{89.7, 0.026433955444985585`}], 
        PointBox[{89.8, 0.029336147005801085`}], 
        PointBox[{89.9, 0.028103311255667254`}], 
        PointBox[{90., 0.02797160999749307}], 
        PointBox[{90.1, 0.03495261000964974}], 
        PointBox[{90.2, 0.038388941795518834`}], 
        PointBox[{90.3, 0.03651162035425187}], 
        PointBox[{90.4, 0.03750523981101211}], 
        PointBox[{90.5, 0.04021406191320265}], 
        PointBox[{90.6, 0.03723576247372308}], 
        PointBox[{90.7, 0.03588529424877985}], 
        PointBox[{90.8, 0.038806356313909225`}], 
        PointBox[{90.9, 0.03911001391200793}], 
        PointBox[{91., 0.03703371298312899}], 
        PointBox[{91.1, 0.04239663396422245}], 
        PointBox[{91.2, 0.04824143606309025}], 
        PointBox[{91.3, 0.04766086570000169}], 
        PointBox[{91.4, 0.04685947617975366}], 
        PointBox[{91.5, 0.05029611384740081}], 
        PointBox[{91.6, 0.048647555463258337`}], 
        PointBox[{91.7, 0.046017776275095054`}], 
        PointBox[{91.8, 0.04813353162238952}], 
        PointBox[{91.9, 0.05004447548441918}], 
        PointBox[{92., 0.04738745230642094}], 
        PointBox[{92.1, 0.05021853095714831}], 
        PointBox[{92.2, 0.056976822195957094`}], 
        PointBox[{92.3, 0.05863075761685538}], 
        PointBox[{92.4, 0.05680017927166886}], 
        PointBox[{92.5, 0.059630213278609595`}], 
        PointBox[{92.6, 0.05990128817516686}], 
        PointBox[{92.7, 0.056545061330414655`}], 
        PointBox[{92.8, 0.05737207244490815}], 
        PointBox[{92.9, 0.06024221196510319}], 
        PointBox[{93., 0.05842184257716119}], 
        PointBox[{93.1, 0.05862751086339722}], 
        PointBox[{93.2, 0.06479951035727627}], 
        PointBox[{93.3, 0.06884378647421233}], 
        PointBox[{93.4, 0.06718664166603554}], 
        PointBox[{93.5, 0.06838911486988179}], 
        PointBox[{93.6, 0.0705725816197102}], 
        PointBox[{93.7, 0.06718137739888197}], 
        PointBox[{93.8, 0.06665716126591849}], 
        PointBox[{93.9, 0.06963145173354628}], 
        PointBox[{94., 0.06943938955664698}], 
        PointBox[{94.1, 0.06753194235732636}], 
        PointBox[{94.2, 0.07257232008027001}], 
        PointBox[{94.3, 0.07806288344891332}], 
        PointBox[{94.4, 0.0775913387652515}], 
        PointBox[{94.5, 0.07704875462799798}], 
        PointBox[{94.6, 0.08043544283319845}], 
        PointBox[{94.7, 0.077692452080176}], 
        PointBox[{94.8, 0.07601858146745312}], 
        PointBox[{94.9, 0.07847914051688006}], 
        PointBox[{95., 0.07988253880972747}], 
        PointBox[{95.1, 0.0768864989012318}], 
        PointBox[{95.2, 0.08065044895101206}], 
        PointBox[{95.3, 0.08642105546715874}], 
        PointBox[{95.4, 0.08765204437267575}], 
        PointBox[{95.5, 0.08598785992703775}], 
        PointBox[{95.6, 0.08951537876862825}], 
        PointBox[{95.7, 0.08794767803092961}], 
        PointBox[{95.8, 0.08542888090582504}], 
        PointBox[{95.9, 0.08711014353058096}], 
        PointBox[{96., 0.08957508716847247}], 
        PointBox[{96.1, 0.08658842408451181}], 
        PointBox[{96.2, 0.08886376386722893}], 
        PointBox[{96.3, 0.09438617456631704}], 
        PointBox[{96.4, 0.0972721577299354}], 
        PointBox[{96.5, 0.09530024836916583}], 
        PointBox[{96.6, 0.09810156265922408}], 
        PointBox[{96.7, 0.09794298849975493}], 
        PointBox[{96.8, 0.09488906404010278}], 
        PointBox[{96.9, 0.0957886514920565}], 
        PointBox[{97., 0.09872064216763066}], 
        PointBox[{97.1, 0.0964807434167081}], 
        PointBox[{97.2, 0.09722546074572355}], 
        PointBox[{97.3, 0.10251306931033527`}], 
        PointBox[{97.4, 0.10661906444698252`}], 
        PointBox[{97.5, 0.10493456575541572`}], 
        PointBox[{97.6, 0.10664979526856906`}], 
        PointBox[{97.7, 0.10780199165886102`}], 
        PointBox[{97.8, 0.10447190716764079`}], 
        PointBox[{97.9, 0.10472890791505099`}], 
        PointBox[{98., 0.10771966603099292`}], 
        PointBox[{98.1, 0.10645972197880237`}], 
        PointBox[{98.2, 0.10591455241169012`}], 
        PointBox[{98.3, 0.11115941842500174`}], 
        PointBox[{98.4, 0.11602955605908272`}], 
        PointBox[{98.5, 0.11488216546245553`}], 
        PointBox[{98.6, 0.11561597572220789`}], 
        PointBox[{98.7, 0.11774701366864226`}], 
        PointBox[{98.8, 0.1143094561039241}], 
        PointBox[{98.9, 0.11412737023966807`}], 
        PointBox[{99., 0.11699390369979751`}], 
        PointBox[{99.1, 0.1165603326761839}], 
        PointBox[{99.2, 0.11514686407572228`}], 
        PointBox[{99.3, 0.12053992496943}], 
        PointBox[{99.4, 0.12588136527191857`}], 
        PointBox[{99.5, 0.1252121181597005}], 
        PointBox[{99.6, 0.12531796285952634`}], 
        PointBox[{99.7, 0.1280236710018842}], 
        PointBox[{99.8, 0.12453987801020146`}], 
        PointBox[{99.9, 0.12415261689549269`}], 
        PointBox[{100., 0.12687957515267503`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 0.2}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
        PointBox[{0.1, 338.5526545001986}], 
        PointBox[{0.2, 345.62861482478456`}], 
        PointBox[{0.3, 343.7686697530962}], 
        PointBox[{0.4, 332.70849517431327`}], 
        PointBox[{0.5, 341.77583172292987`}], 
        PointBox[{0.6, 349.8647532870555}], 
        PointBox[{0.7, 337.53713387668205`}], 
        PointBox[{0.8, 335.9777714510052}], 
        PointBox[{0.9, 344.25812439299733`}], 
        PointBox[{1., 332.13742247816407`}], 
        PointBox[{1.1, 317.6257089673661}], PointBox[{1.2, 321.278310632163}],
         PointBox[{1.3, 322.08234949355005`}], 
        PointBox[{1.4, 314.3922577621723}], 
        PointBox[{1.5, 319.4323402665269}], 
        PointBox[{1.6, 325.7898515046204}], 
        PointBox[{1.7, 318.1156635770443}], 
        PointBox[{1.8, 315.2284590313473}], 
        PointBox[{1.9, 321.8133611072529}], 
        PointBox[{2., 318.25407453804246`}], 
        PointBox[{2.1, 312.00471503764965`}], 
        PointBox[{2.2, 313.14269974122044`}], 
        PointBox[{2.3, 316.0352908862424}], PointBox[{2.4, 311.247512726406}],
         PointBox[{2.5, 312.11398555665767`}], 
        PointBox[{2.6, 317.9405036007586}], 
        PointBox[{2.7, 314.3931707361264}], 
        PointBox[{2.8, 310.1429179435668}], 
        PointBox[{2.9, 314.2375480113187}], PointBox[{3., 315.1287220259906}],
         PointBox[{3.1, 310.8692808328134}], 
        PointBox[{3.2, 312.17330607491226`}], 
        PointBox[{3.3, 315.5778445825711}], 
        PointBox[{3.4, 313.7836742305379}], 
        PointBox[{3.5, 311.8589362352788}], 
        PointBox[{3.6, 316.68340456045604`}], 
        PointBox[{3.7, 316.07905013732744`}], 
        PointBox[{3.8, 311.7441020143225}], 
        PointBox[{3.9, 313.2441778503115}], PointBox[{4., 316.2167902681447}],
         PointBox[{4.1, 312.6544362052688}], 
        PointBox[{4.2, 314.44050384946996`}], 
        PointBox[{4.3, 317.4850671122611}], 
        PointBox[{4.4, 318.0868520157372}], PointBox[{4.5, 315.236632709521}],
         PointBox[{4.6, 318.31397615044614`}], 
        PointBox[{4.7, 319.68607046838474`}], 
        PointBox[{4.8, 316.16873183607754`}], 
        PointBox[{4.9, 315.6276456651999}], PointBox[{5., 318.8842850039732}],
         PointBox[{5.1, 317.02148978226313`}], 
        PointBox[{5.2, 317.7218974326525}], 
        PointBox[{5.3, 320.73077926558494`}], 
        PointBox[{5.4, 322.7637748062376}], 
        PointBox[{5.5, 320.5577170514002}], 
        PointBox[{5.6, 321.55255969638637`}], 
        PointBox[{5.7, 324.05682004004757`}], 
        PointBox[{5.8, 321.7111218358661}], 
        PointBox[{5.9, 319.98441268184126`}], 
        PointBox[{6., 322.407283309019}], PointBox[{6.1, 322.5163626016444}], 
        PointBox[{6.2, 321.5051132907465}], 
        PointBox[{6.3, 324.8310181561044}], 
        PointBox[{6.4, 327.47833535401446`}], 
        PointBox[{6.5, 326.62779019039385`}], 
        PointBox[{6.6, 325.89869389954043`}], 
        PointBox[{6.7, 328.75150433261285`}], 
        PointBox[{6.8, 327.58388916984103`}], 
        PointBox[{6.9, 325.4206068740295}], 
        PointBox[{7., 326.64043650635585`}], 
        PointBox[{7.1, 328.17344028458524`}], 
        PointBox[{7.2, 326.2904528385218}], 
        PointBox[{7.3, 329.3725030555123}], 
        PointBox[{7.4, 332.2115005327045}], 
        PointBox[{7.5, 332.6643247804405}], PointBox[{7.6, 331.048501681105}],
         PointBox[{7.7, 333.57254155224354`}], 
        PointBox[{7.8, 333.4259954571858}], 
        PointBox[{7.9, 331.29995787144577`}], PointBox[{8., 331.46519317901}],
         PointBox[{8.1, 333.59613902689716`}], 
        PointBox[{8.2, 331.82636670256466`}], 
        PointBox[{8.3, 334.0104077937923}], 
        PointBox[{8.4, 336.96149441157917`}], 
        PointBox[{8.5, 338.32727530138277`}], 
        PointBox[{8.6, 336.6523999316457}], 
        PointBox[{8.7, 338.4085800387088}], 
        PointBox[{8.8, 339.05750490942427`}], 
        PointBox[{8.9, 337.1955003489866}], PointBox[{9., 336.6494654752179}],
         PointBox[{9.1, 338.7196210319698}], 
        PointBox[{9.2, 337.6060915136173}], 
        PointBox[{9.3, 338.6803466666717}], PointBox[{9.4, 341.675938717158}],
         PointBox[{9.5, 343.5410140573505}], 
        PointBox[{9.6, 342.29378776499397`}], 
        PointBox[{9.7, 343.1686104096034}], 
        PointBox[{9.8, 344.36322877775154`}], 
        PointBox[{9.9, 342.829675309579}], 
        PointBox[{10., 341.89788320621625`}], 
        PointBox[{10.1, 343.58020646288685`}], 
        PointBox[{10.2, 343.2240148685888}], 
        PointBox[{10.3, 343.3910122254858}], 
        PointBox[{10.4, 346.25401201255556`}], 
        PointBox[{10.5, 348.2949913065549}], 
        PointBox[{10.6, 347.5917474643463}], 
        PointBox[{10.7, 347.7388709684623}], 
        PointBox[{10.8, 349.2401625181292}], 
        PointBox[{10.9, 348.0061090579571}], 
        PointBox[{11., 346.9208699820704}], 
        PointBox[{11.1, 348.1648783756001}], 
        PointBox[{11.2, 348.39869910332806`}], 
        PointBox[{11.3, 347.9945025169088}], 
        PointBox[{11.4, 350.5550681997518}], 
        PointBox[{11.5, 352.5422895368902}], 
        PointBox[{11.6, 352.267094731464}], 
        PointBox[{11.7, 351.9568527185836}], 
        PointBox[{11.8, 353.57068905288975`}], 
        PointBox[{11.9, 352.5558436519882}], 
        PointBox[{12., 351.4597179231591}], 
        PointBox[{12.1, 352.3660199020079}], 
        PointBox[{12.2, 352.93025448407155`}], 
        PointBox[{12.3, 352.2518144038428}], 
        PointBox[{12.4, 354.3963197563445}], 
        PointBox[{12.5, 356.17485454617446`}], 
        PointBox[{12.6, 356.11863932921284`}], 
        PointBox[{12.7, 355.61654299012554`}], 
        PointBox[{12.8, 357.20757859345224`}], 
        PointBox[{12.9, 356.3083650784446}], 
        PointBox[{13., 355.2836208943844}], 
        PointBox[{13.1, 356.0064214475878}], 
        PointBox[{13.2, 356.6469122303966}], 
        PointBox[{13.3, 355.9110986834416}], 
        PointBox[{13.4, 357.55274328714626`}], 
        PointBox[{13.5, 359.036164215011}], 
        PointBox[{13.6, 358.9836573604348}], 
        PointBox[{13.7, 358.51677638360303`}], 
        PointBox[{13.8, 359.98121393644084`}], 
        PointBox[{13.9, 359.0976378378395}], 
        PointBox[{14., 358.19762248618645`}], 
        PointBox[{14.1, 358.894361784728}], 
        PointBox[{14.2, 359.3721203461653}], 
        PointBox[{14.3, 358.73484723875686`}], 
        PointBox[{14.4, 359.8073056391245}], 
        PointBox[{14.5, 0.9786278912442506}], 
        PointBox[{14.6, 0.7426364778083259}], 
        PointBox[{14.7, 0.5420813965896559}], 
        PointBox[{14.8, 1.7399169622313164`}], 
        PointBox[{14.9, 0.8110974668922086}], 
        PointBox[{15., 0.08561334801710876}], 
        PointBox[{15.1, 0.8950219274640341}], 
        PointBox[{15.2, 0.9498986136521861}], 
        PointBox[{15.3, 0.48230919067542716`}], 
        PointBox[{15.4, 1.072463308084407}], 
        PointBox[{15.5, 1.9426285557956366`}], 
        PointBox[{15.6, 1.3849271905975704`}], 
        PointBox[{15.7, 1.7229949550293475`}], 
        PointBox[{15.8, 2.4293044624820492`}], 
        PointBox[{15.9, 1.4694399596614673`}], 
        PointBox[{16., 0.9812528854356397}], 
        PointBox[{16.1, 1.9894365132728635`}], 
        PointBox[{16.2, 1.3710375067475309`}], 
        PointBox[{16.3, 1.0001197472879388`}], 
        PointBox[{16.4, 1.457442309991157}], 
        PointBox[{16.5, 1.9982597094012355`}], 
        PointBox[{16.6, 1.0946062772009912`}], 
        PointBox[{16.7, 2.1545764128247726`}], 
        PointBox[{16.8, 2.1616615157496595`}], 
        PointBox[{16.9, 1.2650329506278435`}], 
        PointBox[{17., 1.0961506608745832`}], 
        PointBox[{17.1, 2.219185759619754}], 
        PointBox[{17.2, 0.9095962875590502}], 
        PointBox[{17.3, 0.6582381268424182}], 
        PointBox[{17.4, 1.170486266706702}], 
        PointBox[{17.5, 1.292399875820517}], 
        PointBox[{17.6, 0.3308923657896414}], 
        PointBox[{17.7, 1.830344346909269}], 
        PointBox[{17.8, 1.201901673217691}], 
        PointBox[{17.9, 0.5009715886618865}], 
        PointBox[{18., 0.7428559473661203}], 
        PointBox[{18.1, 1.4830396649574527`}], 
        PointBox[{18.2, 359.84349986984216`}], 
        PointBox[{18.3, 359.9680375913033}], 
        PointBox[{18.4, 0.38656058963126383`}], 
        PointBox[{18.5, 359.98299339282374`}], 
        PointBox[{18.6, 359.71850483243077`}], 
        PointBox[{18.7, 0.7584648465594854}], 
        PointBox[{18.8, 359.8658405683141}], 
        PointBox[{18.9, 359.4815235726439}], 
        PointBox[{19., 0.16844201231621392`}], 
        PointBox[{19.1, 359.69884280193844`}], 
        PointBox[{19.2, 358.6081818743664}], 
        PointBox[{19.3, 359.07293176624364`}], 
        PointBox[{19.4, 359.1994471165915}], 
        PointBox[{19.5, 358.31317165163495`}], 
        PointBox[{19.6, 359.2923114273921}], 
        PointBox[{19.7, 359.1833699236601}], 
        PointBox[{19.8, 358.41950174667426`}], 
        PointBox[{19.9, 358.4375482461248}], 
        PointBox[{20., 359.30115568818496`}], 
        PointBox[{20.1, 357.52786437753656`}], 
        PointBox[{20.2, 357.5613825931165}], 
        PointBox[{20.3, 357.9614788543681}], 
        PointBox[{20.4, 357.6533074286533}], 
        PointBox[{20.5, 356.84993949138624`}], 
        PointBox[{20.6, 358.3142971472267}], 
        PointBox[{20.7, 357.45659051034426`}], 
        PointBox[{20.8, 357.04021424096527`}], 
        PointBox[{20.9, 357.4795153158018}], 
        PointBox[{21., 357.5755019002714}], 
        PointBox[{21.1, 355.9017273882846}], 
        PointBox[{21.2, 356.5200277902887}], 
        PointBox[{21.3, 356.60769875794006`}], 
        PointBox[{21.4, 355.843749730826}], 
        PointBox[{21.5, 356.1543203561273}], 
        PointBox[{21.6, 356.6518420229571}], 
        PointBox[{21.7, 355.8259440741911}], 
        PointBox[{21.8, 355.8178012929925}], 
        PointBox[{21.9, 356.4967986218916}], 
        PointBox[{22., 355.0130432056336}], 
        PointBox[{22.1, 354.8436393704603}], 
        PointBox[{22.2, 355.3331158223607}], 
        PointBox[{22.3, 355.01390199841154`}], 
        PointBox[{22.4, 354.1057472511891}], 
        PointBox[{22.5, 355.5233083260591}], 
        PointBox[{22.6, 354.81845592410446`}], 
        PointBox[{22.7, 354.40210104073594`}], 
        PointBox[{22.8, 354.75250304529254`}], 
        PointBox[{22.9, 355.0014552140895}], 
        PointBox[{23., 353.0862699380063}], 
        PointBox[{23.1, 353.8632722282562}], 
        PointBox[{23.2, 353.9642498141608}], 
        PointBox[{23.3, 353.25809169276255`}], 
        PointBox[{23.4, 353.01380409053274`}], 
        PointBox[{23.5, 354.1007838399893}], 
        PointBox[{23.6, 353.181475141801}], 
        PointBox[{23.7, 353.20629336185004`}], 
        PointBox[{23.8, 353.71655611860274`}], 
        PointBox[{23.9, 352.7339458958873}], 
        PointBox[{24., 352.076456962336}], 
        PointBox[{24.1, 352.7724682700864}], 
        PointBox[{24.2, 352.4620625059002}], 
        PointBox[{24.3, 351.5635719664409}], 
        PointBox[{24.4, 352.5381289384066}], 
        PointBox[{24.5, 352.3420551658544}], 
        PointBox[{24.6, 351.8583979742351}], 
        PointBox[{24.7, 352.2084670457564}], 
        PointBox[{24.8, 352.4401203242034}], 
        PointBox[{24.9, 350.6841053797698}], 
        PointBox[{25., 351.3519089735577}], 
        PointBox[{25.1, 351.61361357760893`}], 
        PointBox[{25.2, 350.95888047109895`}], 
        PointBox[{25.3, 350.30428812279234`}], 
        PointBox[{25.4, 351.7934957223722}], 
        PointBox[{25.5, 350.8399284553725}], 
        PointBox[{25.6, 350.87675243891834`}], 
        PointBox[{25.7, 351.3513511734708}], 
        PointBox[{25.8, 351.0067637024716}], 
        PointBox[{25.9, 349.66841160893796`}], 
        PointBox[{26., 350.72243232695206`}], 
        PointBox[{26.1, 350.55474097469573`}], 
        PointBox[{26.2, 349.68261582821515`}], 
        PointBox[{26.3, 349.75883166792613`}], 
        PointBox[{26.4, 350.67875846425744`}], 
        PointBox[{26.5, 349.83602400789204`}], 
        PointBox[{26.6, 350.2823593004947}], 
        PointBox[{26.7, 350.64860308076146`}], 
        PointBox[{26.8, 349.92887274430836`}], 
        PointBox[{26.9, 349.51811652746693`}], 
        PointBox[{27., 350.36495475733005`}], 
        PointBox[{27.1, 349.8551860091271}], 
        PointBox[{27.2, 348.9384306386041}], 
        PointBox[{27.3, 349.84712266200944`}], 
        PointBox[{27.4, 349.85249510744313`}], 
        PointBox[{27.5, 349.46031716118017`}], 
        PointBox[{27.6, 350.19713786220893`}], 
        PointBox[{27.7, 350.52513058566984`}], 
        PointBox[{27.8, 349.60592661214224`}], 
        PointBox[{27.9, 350.05990281030057`}], 
        PointBox[{28., 350.5925916914892}], 
        PointBox[{28.1, 349.82778169786855`}], 
        PointBox[{28.2, 349.02576069320935`}], 
        PointBox[{28.3, 350.45583443270465`}], 
        PointBox[{28.4, 349.81634255782285`}], 
        PointBox[{28.5, 349.86599944348575`}], 
        PointBox[{28.6, 350.8402730495595}], 
        PointBox[{28.7, 351.5372186743534}], 
        PointBox[{28.8, 350.4305337815573}], 
        PointBox[{28.9, 351.4069022389698}], 
        PointBox[{29., 351.7022046605493}], 
        PointBox[{29.1, 350.7495017968687}], 
        PointBox[{29.2, 350.127730993537}], 
        PointBox[{29.3, 351.7635709947743}], 
        PointBox[{29.4, 350.811917752474}], 
        PointBox[{29.5, 351.19390768598396`}], 
        PointBox[{29.6, 352.4505058686964}], 
        PointBox[{29.7, 353.66204617547555`}], 
        PointBox[{29.8, 352.4381132836819}], 
        PointBox[{29.9, 353.6742097898797}], 
        PointBox[{30., 353.85348619642355`}], 
        PointBox[{30.1, 352.7551295325714}], 
        PointBox[{30.2, 352.2637439490241}], 
        PointBox[{30.3, 353.98843683470386`}], 
        PointBox[{30.4, 352.90480484298644`}], 
        PointBox[{30.5, 353.4781205386582}], 
        PointBox[{30.6, 355.08750774125116`}], 
        PointBox[{30.7, 356.76476252457815`}], 
        PointBox[{30.8, 355.4828592888042}], 
        PointBox[{30.9, 356.8287362556638}], 
        PointBox[{31., 357.0308472805204}], 
        PointBox[{31.1, 355.8097479302033}], 
        PointBox[{31.2, 355.3261916635366}], 
        PointBox[{31.3, 357.14988360547756`}], 
        PointBox[{31.4, 356.0307804495957}], 
        PointBox[{31.5, 356.617453822952}], 
        PointBox[{31.6, 358.5720848996682}], 
        PointBox[{31.7, 0.6850143302414708}], 
        PointBox[{31.8, 359.3921990921696}], 
        PointBox[{31.9, 0.7085599928051398}], 
        PointBox[{32., 1.0945505203950137`}], 
        PointBox[{32.1, 359.77282969822187`}], 
        PointBox[{32.2, 359.1503305850503}], 
        PointBox[{32.3, 1.0850316014010182`}], 
        PointBox[{32.4, 0.06216560195531042}], 
        PointBox[{32.5, 0.4385346702859992}], 
        PointBox[{32.6, 2.6464672333756045`}], 
        PointBox[{32.7, 5.199086265425768}], 
        PointBox[{32.8, 4.022632303317456}], 
        PointBox[{32.9, 5.096350762249187}], 
        PointBox[{33., 5.848795915443493}], 
        PointBox[{33.1, 4.475964577950928}], 
        PointBox[{33.2, 3.573636604333539}], 
        PointBox[{33.3, 5.5467013113580474`}], 
        PointBox[{33.4, 4.86461247294714}], 
        PointBox[{33.5, 4.776224097494727}], 
        PointBox[{33.6, 7.095804032902548}], 
        PointBox[{33.7, 10.041390200154583`}], 
        PointBox[{33.8, 9.259017099328748}], 
        PointBox[{33.9, 9.780363708964442}], 
        PointBox[{34., 11.07229014091877}], 
        PointBox[{34.1, 9.760555051724353}], 
        PointBox[{34.2, 8.461671861413656}], 
        PointBox[{34.3, 10.283566816825438`}], 
        PointBox[{34.4, 10.294647597818393`}], 
        PointBox[{34.5, 9.519235998166296}], 
        PointBox[{34.6, 11.75700759830768}], 
        PointBox[{34.7, 14.92810104213699}], 
        PointBox[{34.8, 14.965831835743847`}], 
        PointBox[{34.9, 14.606006893048963`}], 
        PointBox[{35., 16.510911847188734`}], 
        PointBox[{35.1, 15.474669950411053`}], 
        PointBox[{35.2, 13.708764231415197`}], 
        PointBox[{35.3, 15.090918461676512`}], 
        PointBox[{35.4, 16.133529191251885`}], 
        PointBox[{35.5, 14.6226704851938}], 
        PointBox[{35.6, 16.487987550738808`}], 
        PointBox[{35.7, 19.62640722280159}], 
        PointBox[{35.8, 20.909844508870147`}], 
        PointBox[{35.9, 19.52037637806357}], 
        PointBox[{36., 21.85800991288945}], 
        PointBox[{36.1, 21.44029706421213}], 
        PointBox[{36.2, 19.22157803170459}], 
        PointBox[{36.3, 19.829837541938083`}], 
        PointBox[{36.4, 22.010222467155653`}], 
        PointBox[{36.5, 20.094294006019762`}], 
        PointBox[{36.6, 21.160480957328616`}], 
        PointBox[{36.7, 24.126194315842454`}], 
        PointBox[{36.8, 26.692461184492196`}], 
        PointBox[{36.9, 24.57155801110531}], 
        PointBox[{37., 26.759774812907462`}], 
        PointBox[{37.1, 27.394640398651063`}], 
        PointBox[{37.2, 24.892652251095335`}], 
        PointBox[{37.3, 24.396574752099543`}], 
        PointBox[{37.4, 27.420419005954383`}], 
        PointBox[{37.5, 25.920873221316082`}], 
        PointBox[{37.6, 25.679274338549394`}], 
        PointBox[{37.7, 28.529472651948424`}], 
        PointBox[{37.8, 31.721875933098634`}], 
        PointBox[{37.9, 29.78612738538953}], 
        PointBox[{38., 30.86994290683783}], 
        PointBox[{38.1, 32.90192481512562}], 
        PointBox[{38.2, 30.550352298186034`}], 
        PointBox[{38.3, 28.661413911383544`}], 
        PointBox[{38.4, 31.856955393556706`}], 
        PointBox[{38.5, 31.869373194215715`}], 
        PointBox[{38.6, 29.992170969082235`}], 
        PointBox[{38.7, 32.48988161945913}], 
        PointBox[{38.8, 35.45083888775973}], 
        PointBox[{38.9, 34.90185964369635}], 
        PointBox[{39., 33.907954035275495`}], 
        PointBox[{39.1, 37.25073162507371}], 
        PointBox[{39.2, 35.83297332137038}], 
        PointBox[{39.3, 32.37407789753281}], 
        PointBox[{39.4, 34.85720404430819}], 
        PointBox[{39.5, 37.20204825429349}], 
        PointBox[{39.6, 34.03395277334429}], 
        PointBox[{39.7, 35.37685879402019}], 
        PointBox[{39.8, 38.23536149750786}], 
        PointBox[{39.9, 39.00229297704488}], 
        PointBox[{40., 35.526216376709876`}], 
        PointBox[{40.1, 39.32593461215183}], 
        PointBox[{40.2, 39.889134937626636`}], 
        PointBox[{40.3, 34.949520896141074`}], 
        PointBox[{40.4, 35.73100313653676}], 
        PointBox[{40.5, 40.52884191711949}], 
        PointBox[{40.6, 37.43506092527481}], 
        PointBox[{40.7, 36.43942841131894}], 
        PointBox[{40.8, 40.03236938903285}], 
        PointBox[{40.9, 40.25592552223458}], 
        PointBox[{41., 34.63635104166659}], 
        PointBox[{41.1, 37.19595471813796}], 
        PointBox[{41.2, 40.67809297485974}], 
        PointBox[{41.3, 34.80362819144174}], 
        PointBox[{41.4, 32.74698693175748}], 
        PointBox[{41.5, 39.6145418387355}], 
        PointBox[{41.6, 38.62719830161447}], 
        PointBox[{41.7, 34.111786410331604`}], 
        PointBox[{41.8, 38.01619185864995}], 
        PointBox[{41.9, 37.156761116790115`}], 
        PointBox[{42., 27.51952140260628}], 
        PointBox[{42.1, 26.36178029903237}], 
        PointBox[{42.2, 33.11576026071885}], 
        PointBox[{42.3, 27.019546346540295`}], 
        PointBox[{42.4, 20.926638418640017`}], 
        PointBox[{42.5, 29.87808617070194}], 
        PointBox[{42.6, 32.60219159016376}], 
        PointBox[{42.7, 23.64519099274706}], 
        PointBox[{42.8, 26.74808646003538}], 
        PointBox[{42.9, 27.968538223011823`}], 
        PointBox[{43., 5.6974680620247105`}], 
        PointBox[{43.1, 357.52190388607323`}], 
        PointBox[{43.2, 6.358942326695789}], 
        PointBox[{43.3, 359.21267932843097`}], 
        PointBox[{43.4, 350.5912477706484}], 
        PointBox[{43.5, 2.533717331476049}], 
        PointBox[{43.6, 7.466846440029781}], 
        PointBox[{43.7, 353.66270296529814`}], 
        PointBox[{43.8, 356.5656563072148}], 
        PointBox[{43.9, 1.2846490122360217`}], 
        PointBox[{44., 334.4829607463659}], 
        PointBox[{44.1, 321.77069968803966`}], 
        PointBox[{44.2, 328.81458679288096`}], 
        PointBox[{44.3, 323.2218460069501}], 
        PointBox[{44.4, 316.77434427454267`}], 
        PointBox[{44.5, 327.34958846895773`}], 
        PointBox[{44.6, 330.4473232158383}], 
        PointBox[{44.7, 318.29370046714854`}], 
        PointBox[{44.8, 320.8534975045253}], 
        PointBox[{44.9, 326.9503202401974}], 
        PointBox[{45., 314.1538590197996}], 
        PointBox[{45.1, 305.8771882909125}], 
        PointBox[{45.2, 310.41886866863706`}], 
        PointBox[{45.3, 309.3336283289594}], 
        PointBox[{45.4, 303.4552168394007}], 
        PointBox[{45.5, 309.72788702582574`}], 
        PointBox[{45.6, 313.36522153624077`}], 
        PointBox[{45.7, 305.539610101796}], 
        PointBox[{45.8, 305.10152750160427`}], 
        PointBox[{45.9, 310.9084934325928}], 
        PointBox[{46., 305.9111660299913}], 
        PointBox[{46.1, 302.4754754180733}], 
        PointBox[{46.2, 304.84885644730855`}], 
        PointBox[{46.3, 306.67586200289014`}], 
        PointBox[{46.4, 302.0298197392914}], 
        PointBox[{46.5, 304.3821694282783}], 
        PointBox[{46.6, 308.87117523132395`}], 
        PointBox[{46.7, 304.4640983266161}], 
        PointBox[{46.8, 301.74106074730565`}], 
        PointBox[{46.9, 306.0671227854039}], 
        PointBox[{47., 305.4295005086509}], 
        PointBox[{47.1, 302.7698185141393}], 
        PointBox[{47.2, 304.7602350630246}], 
        PointBox[{47.3, 307.76216603677165`}], 
        PointBox[{47.4, 305.364895419001}], 
        PointBox[{47.5, 304.66503153484405`}], 
        PointBox[{47.6, 309.1330309491502}], 
        PointBox[{47.7, 307.41652492276734`}], 
        PointBox[{47.8, 303.84630022572946`}], 
        PointBox[{47.9, 306.0662911878397}], 
        PointBox[{48., 308.03365960778564`}], 
        PointBox[{48.1, 304.89165861640186`}], 
        PointBox[{48.2, 307.35551290329477`}], 
        PointBox[{48.3, 310.4259323039403}], 
        PointBox[{48.4, 310.2990261204912}], 
        PointBox[{48.5, 308.00990834322255`}], 
        PointBox[{48.6, 311.50018090439005`}], 
        PointBox[{48.7, 311.7985242844254}], 
        PointBox[{48.8, 308.45311574684047`}], 
        PointBox[{48.9, 308.71674680493675`}], 
        PointBox[{49., 311.6450979914746}], 
        PointBox[{49.1, 309.24784368365647`}], 
        PointBox[{49.2, 311.0148139135819}], 
        PointBox[{49.3, 314.0176906689782}], 
        PointBox[{49.4, 315.49620894448066`}], 
        PointBox[{49.5, 313.17583249433795`}], 
        PointBox[{49.6, 315.03501452644906`}], 
        PointBox[{49.7, 316.69796734381686`}], 
        PointBox[{49.8, 314.1149646568712}], 
        PointBox[{49.9, 313.04539459501194`}], 
        PointBox[{50., 315.67710034994343`}], 
        PointBox[{50.1, 314.85415985377983`}], 
        PointBox[{50.2, 314.95576892648216`}], 
        PointBox[{50.3, 318.2445690807411}], 
        PointBox[{50.4, 320.57426118658395`}], 
        PointBox[{50.5, 319.20291805953946`}], 
        PointBox[{50.6, 319.3667053735501}], 
        PointBox[{50.7, 321.75966626913737`}], 
        PointBox[{50.8, 320.0939463838228}], 
        PointBox[{50.9, 318.36201818238936`}], 
        PointBox[{51., 320.08009783285354`}], 
        PointBox[{51.1, 320.77107917020345`}], 
        PointBox[{51.2, 319.5352808293659}], 
        PointBox[{51.3, 322.85118742447406`}], 
        PointBox[{51.4, 325.51301770492586`}], 
        PointBox[{51.5, 325.3265170474801}], 
        PointBox[{51.6, 324.2901554292807}], 
        PointBox[{51.7, 326.8166310995332}], 
        PointBox[{51.8, 326.02022182604054`}], 
        PointBox[{51.9, 324.11059506633114`}], 
        PointBox[{52., 324.8523914653671}], 
        PointBox[{52.1, 326.4914589271851}], 
        PointBox[{52.2, 324.77073771978456`}], 
        PointBox[{52.3, 327.57497527883396`}], 
        PointBox[{52.4, 330.3376110581022}], 
        PointBox[{52.5, 331.11298016815255`}], 
        PointBox[{52.6, 329.57761712938475`}], 
        PointBox[{52.7, 331.76742827474794`}], 
        PointBox[{52.8, 331.69837309704906`}], 
        PointBox[{52.9, 329.8801930357492}], 
        PointBox[{53., 329.8694772973579}], 
        PointBox[{53.1, 331.8336251712626}], 
        PointBox[{53.2, 330.2779906881834}], 
        PointBox[{53.3, 332.26049441521656`}], 
        PointBox[{53.4, 335.0243222975029}], 
        PointBox[{53.5, 336.40192283014295`}], 
        PointBox[{53.6, 334.91718741799093`}], 
        PointBox[{53.7, 336.524672019419}], 
        PointBox[{53.8, 336.9994437735174}], 
        PointBox[{53.9, 335.3822336403461}], 
        PointBox[{54., 334.9035404026776}], 
        PointBox[{54.1, 336.7741335475301}], 
        PointBox[{54.2, 335.67288472107214`}], 
        PointBox[{54.3, 336.8551302459938}], 
        PointBox[{54.4, 339.4910746709544}], 
        PointBox[{54.5, 341.14267061865735`}], 
        PointBox[{54.6, 339.9626132322108}], 
        PointBox[{54.7, 340.98453965599936`}], 
        PointBox[{54.8, 341.8068275224187}], 
        PointBox[{54.9, 340.4022450795739}], 
        PointBox[{55., 339.69176815065896`}], 
        PointBox[{55.1, 341.3001896067435}], 
        PointBox[{55.2, 340.65061553829594`}], 
        PointBox[{55.3, 341.24902872624625`}], 
        PointBox[{55.4, 343.60114143968656`}], 
        PointBox[{55.5, 345.27501560611495`}], 
        PointBox[{55.6, 344.4052901018046}], 
        PointBox[{55.7, 345.0070808468435}], 
        PointBox[{55.8, 345.987750241437}], 
        PointBox[{55.9, 344.75441151271957`}], 
        PointBox[{56., 343.97797074322574`}], 
        PointBox[{56.1, 345.3342979379887}], 
        PointBox[{56.2, 344.96669319948074`}], 
        PointBox[{56.3, 345.2402683987557}], 
        PointBox[{56.4, 347.16729991831727`}], 
        PointBox[{56.5, 348.68885264630296`}], 
        PointBox[{56.6, 347.9966731547806}], 
        PointBox[{56.7, 348.418816148153}], 
        PointBox[{56.8, 349.38248037336234`}], 
        PointBox[{56.9, 348.25879910911016`}], 
        PointBox[{57., 347.5277966417938}], 
        PointBox[{57.1, 348.7309845520979}], 
        PointBox[{57.2, 348.4078460624952}], 
        PointBox[{57.3, 348.5729469052285}], 
        PointBox[{57.4, 349.97465884523035`}], 
        PointBox[{57.5, 351.23899742519313`}], 
        PointBox[{57.6, 350.5509328036559}], 
        PointBox[{57.7, 351.0527069636155}], 
        PointBox[{57.8, 351.82304336941314`}], 
        PointBox[{57.9, 350.75803099750476`}], 
        PointBox[{58., 350.1548358909774}], 
        PointBox[{58.1, 351.3245221725094}], 
        PointBox[{58.2, 350.7957939327705}], 
        PointBox[{58.3, 350.9529848554211}], 
        PointBox[{58.4, 351.85445832163066`}], 
        PointBox[{58.5, 352.80761723282365`}], 
        PointBox[{58.6, 351.9773315292044}], 
        PointBox[{58.7, 352.8065870150258}], 
        PointBox[{58.8, 353.19275460845154`}], 
        PointBox[{58.9, 352.17654712078036`}], 
        PointBox[{59., 351.77732287578334`}], 
        PointBox[{59.1, 352.99116241638376`}], 
        PointBox[{59.2, 352.06073391775516`}], 
        PointBox[{59.3, 352.1401472795636}], 
        PointBox[{59.4, 352.78167655741663`}], 
        PointBox[{59.5, 353.37908246721855`}], 
        PointBox[{59.6, 352.37331743662725`}], 
        PointBox[{59.7, 353.661759581892}], 
        PointBox[{59.8, 353.51329167942714`}], 
        PointBox[{59.9, 352.59387188896596`}], 
        PointBox[{60., 352.4839159225938}], 
        PointBox[{60.1, 353.6658126561721}], 
        PointBox[{60.2, 352.3377482957347}], 
        PointBox[{60.3, 352.29412860245833`}], 
        PointBox[{60.4, 352.8882540500063}], 
        PointBox[{60.5, 353.0542263977505}], 
        PointBox[{60.6, 352.11630060153755`}], 
        PointBox[{60.7, 353.6327062703468}], 
        PointBox[{60.8, 352.98218249922803`}], 
        PointBox[{60.9, 352.25206383177573`}], 
        PointBox[{61., 352.52552599144514`}], 
        PointBox[{61.1, 353.25960728419733`}], 
        PointBox[{61.2, 351.7813899749887}], 
        PointBox[{61.3, 351.8716291565362}], 
        PointBox[{61.4, 352.36165009105304`}], 
        PointBox[{61.5, 352.0010326554874}], 
        PointBox[{61.6, 351.75744432685684`}], 
        PointBox[{61.7, 352.7935179393258}], 
        PointBox[{61.8, 351.9042586092967}], 
        PointBox[{61.9, 351.46903460170216`}], 
        PointBox[{62., 352.1755598073383}], 
        PointBox[{62.1, 351.78658095479494`}], 
        PointBox[{62.2, 350.7124315455266}], 
        PointBox[{62.3, 351.12560954920406`}], 
        PointBox[{62.4, 351.34288577891846`}], 
        PointBox[{62.5, 350.4804294293685}], 
        PointBox[{62.6, 351.4104780728905}], 
        PointBox[{62.7, 351.38030370481823`}], 
        PointBox[{62.8, 350.57828040701474`}], 
        PointBox[{62.9, 350.53169703546297`}], 
        PointBox[{63., 351.4588317796674}], 
        PointBox[{63.1, 349.82628456732476`}], 
        PointBox[{63.2, 349.68724088787627`}], 
        PointBox[{63.3, 350.1169912929109}], 
        PointBox[{63.4, 349.9078795142145}], 
        PointBox[{63.5, 349.0451953539178}], 
        PointBox[{63.6, 350.52721477119735`}], 
        PointBox[{63.7, 349.72358490671246`}], 
        PointBox[{63.8, 349.22864016020867`}], 
        PointBox[{63.9, 349.6201053166765}], 
        PointBox[{64., 349.9132151669198}], 
        PointBox[{64.1, 348.1447280223525}], 
        PointBox[{64.2, 348.67431288406476`}], 
        PointBox[{64.3, 348.8443011466099}], 
        PointBox[{64.4, 348.1473557821219}], 
        PointBox[{64.5, 348.31072153891137`}], 
        PointBox[{64.6, 348.9513687331994}], 
        PointBox[{64.7, 348.0877156387904}], 
        PointBox[{64.8, 347.9911302074624}], 
        PointBox[{64.9, 348.70299790638376`}], 
        PointBox[{65., 347.42772170488433`}], 
        PointBox[{65.1, 347.0123899925306}], 
        PointBox[{65.2, 347.5292671060693}], 
        PointBox[{65.3, 347.30460181004446`}], 
        PointBox[{65.4, 346.36833069481594`}], 
        PointBox[{65.5, 347.72610096318726`}], 
        PointBox[{65.6, 347.1244740578946}], 
        PointBox[{65.7, 346.6156856659577}], 
        PointBox[{65.8, 346.9086656308217}], 
        PointBox[{65.9, 347.34224776906996`}], 
        PointBox[{66., 345.3468982819362}], 
        PointBox[{66.1, 346.01515152408876`}], 
        PointBox[{66.2, 346.1914259121207}], 
        PointBox[{66.3, 345.5501128279202}], 
        PointBox[{66.4, 345.1826242272747}], 
        PointBox[{66.5, 346.36367252877585`}], 
        PointBox[{66.6, 345.42661075464775`}], 
        PointBox[{66.7, 345.3551066612298}], 
        PointBox[{66.8, 345.89064683196733`}], 
        PointBox[{66.9, 345.069469427039}], 
        PointBox[{67., 344.2099015256048}], 
        PointBox[{67.1, 344.9101475989162}], 
        PointBox[{67.2, 344.6762116109538}], 
        PointBox[{67.3, 343.7782207820214}], 
        PointBox[{67.4, 344.6748835379488}], 
        PointBox[{67.5, 344.56379557378546`}], 
        PointBox[{67.6, 344.0021410881285}], 
        PointBox[{67.7, 344.2871710309721}], 
        PointBox[{67.8, 344.6428468641978}], 
        PointBox[{67.9, 342.815159192383}], 
        PointBox[{68., 343.3859502011938}], 
        PointBox[{68.1, 343.6809434659664}], 
        PointBox[{68.2, 343.07729973122724`}], 
        PointBox[{68.3, 342.3822817139011}], 
        PointBox[{68.4, 343.868872573584}], 
        PointBox[{68.5, 342.9302535103903}], 
        PointBox[{68.6, 342.8783544179778}], 
        PointBox[{68.7, 343.33615780951106`}], 
        PointBox[{68.8, 342.9921985242066}], 
        PointBox[{68.9, 341.5888422460312}], 
        PointBox[{69., 342.5814594740011}], 
        PointBox[{69.1, 342.43828505307687`}], 
        PointBox[{69.2, 341.5872731261211}], 
        PointBox[{69.3, 341.6934234734516}], 
        PointBox[{69.4, 342.52837183509587`}], 
        PointBox[{69.5, 341.7128158275353}], 
        PointBox[{69.6, 342.06722537323645`}], 
        PointBox[{69.7, 342.41644355705057`}], 
        PointBox[{69.8, 341.44021044202356`}], 
        PointBox[{69.9, 341.1565193794116}], 
        PointBox[{70., 341.8904156867589}], 
        PointBox[{70.1, 341.38686838860957`}], 
        PointBox[{70.2, 340.4963405669856}], 
        PointBox[{70.3, 341.541394885502}], 
        PointBox[{70.4, 341.3243585150543}], 
        PointBox[{70.5, 341.01287286691917`}], 
        PointBox[{70.6, 341.6281383030204}], 
        PointBox[{70.7, 341.777279698528}], 
        PointBox[{70.8, 340.54118917211383`}], 
        PointBox[{70.9, 341.2367707994254}], 
        PointBox[{71., 341.58202171029586`}], 
        PointBox[{71.1, 340.8113159158823}], 
        PointBox[{71.2, 340.11777822053097`}], 
        PointBox[{71.3, 341.6397751936616}], 
        PointBox[{71.4, 340.7681307480413}], 
        PointBox[{71.5, 340.9565717639347}], 
        PointBox[{71.6, 341.72932848253777`}], 
        PointBox[{71.7, 342.059055158893}], 
        PointBox[{71.8, 340.76570303482083`}], 
        PointBox[{71.9, 341.95351022687277`}], 
        PointBox[{72., 341.97923496903707`}], 
        PointBox[{72.1, 341.023831885282}], 
        PointBox[{72.2, 340.66588454662434`}], 
        PointBox[{72.3, 342.2001209001596}], 
        PointBox[{72.4, 341.1178974226251}], 
        PointBox[{72.5, 341.7131695307623}], 
        PointBox[{72.6, 342.67937873501256`}], 
        PointBox[{72.7, 343.37779806535656`}], 
        PointBox[{72.8, 342.15340777507623`}], 
        PointBox[{72.9, 343.5326446701002}], 
        PointBox[{73., 343.3425376909535}], 
        PointBox[{73.1, 342.25734976006186`}], 
        PointBox[{73.2, 342.2101412759885}], 
        PointBox[{73.3, 343.6229191071248}], 
        PointBox[{73.4, 342.50172723243213`}], 
        PointBox[{73.5, 343.4092410511584}], 
        PointBox[{73.6, 344.729102689489}], 
        PointBox[{73.7, 345.7371306844332}], 
        PointBox[{73.8, 344.58149661179965`}], 
        PointBox[{73.9, 346.07409575296737`}], 
        PointBox[{74., 345.7745730190776}], 
        PointBox[{74.1, 344.57779073863526`}], 
        PointBox[{74.2, 344.70502044196553`}], 
        PointBox[{74.3, 346.0970541677184}], 
        PointBox[{74.4, 344.92403437940175`}], 
        PointBox[{74.5, 346.0356384712894}], 
        PointBox[{74.6, 347.7954571351832}], 
        PointBox[{74.7, 349.0943937343114}], 
        PointBox[{74.8, 347.8936749115482}], 
        PointBox[{74.9, 349.5056968335714}], 
        PointBox[{75., 349.21487367698705`}], 
        PointBox[{75.1, 347.89694191689955`}], 
        PointBox[{75.2, 348.02447715691676`}], 
        PointBox[{75.3, 349.56575163740257`}], 
        PointBox[{75.4, 348.285678045408}], 
        PointBox[{75.5, 349.44901639729335`}], 
        PointBox[{75.6, 351.5955660765583}], 
        PointBox[{75.7, 353.28559566997603`}], 
        PointBox[{75.8, 351.9323051834922}], 
        PointBox[{75.9, 353.6410805499848}], 
        PointBox[{76., 353.5072288802803}], 
        PointBox[{76.1, 352.05463539612185`}], 
        PointBox[{76.2, 352.00455451246836`}], 
        PointBox[{76.3, 353.82463645451656`}], 
        PointBox[{76.4, 352.45389494795245`}], 
        PointBox[{76.5, 353.4546920253476}], 
        PointBox[{76.6, 355.86468371119645`}], 
        PointBox[{76.7, 358.0786581271111}], 
        PointBox[{76.8, 356.5771012268821}], 
        PointBox[{76.9, 358.2459269722558}], 
        PointBox[{77., 358.460425693261}], 
        PointBox[{77.1, 356.88633278733744`}], 
        PointBox[{77.2, 356.48861028096553`}], 
        PointBox[{77.3, 358.59767176990874`}], 
        PointBox[{77.4, 357.3169715117393}], 
        PointBox[{77.5, 357.8807133060701}], 
        PointBox[{77.6, 0.4162557542663802}], 
        PointBox[{77.7, 3.200266763421785}], 
        PointBox[{77.8, 1.7577179067568287`}], 
        PointBox[{77.9, 3.07999482128119}], PointBox[{78., 3.86614449750026}],
         PointBox[{78.1, 2.2470962732827546`}], 
        PointBox[{78.2, 1.3502786834749398`}], 
        PointBox[{78.3, 3.5881107209129692`}], 
        PointBox[{78.4, 2.782657533620745}], 
        PointBox[{78.5, 2.6109598160310887`}], 
        PointBox[{78.6, 5.125364279124538}], 
        PointBox[{78.7, 8.335888111882502}], 
        PointBox[{78.8, 7.40856100062832}], 
        PointBox[{78.9, 7.9366914130861135`}], 
        PointBox[{79., 9.479705687654496}], 
        PointBox[{79.1, 8.001847994193087}], 
        PointBox[{79.2, 6.490988273176167}], 
        PointBox[{79.3, 8.531094129150791}], 
        PointBox[{79.4, 8.706695005473922}], 
        PointBox[{79.5, 7.5931254921935105`}], 
        PointBox[{79.6, 9.862865990570196}], 
        PointBox[{79.7, 13.16167845638184}], 
        PointBox[{79.8, 13.37420586141533}], 
        PointBox[{79.9, 12.697015447982134`}], 
        PointBox[{80., 14.985568559345975`}], 
        PointBox[{80.1, 13.991074004933921`}], 
        PointBox[{80.2, 11.82180431051698}], 
        PointBox[{80.3, 13.234966211642833`}], 
        PointBox[{80.4, 14.774553861092992`}], 
        PointBox[{80.5, 12.835791334706322`}], 
        PointBox[{80.6, 14.463298076642786`}], 
        PointBox[{80.7, 17.54525533729764}], 
        PointBox[{80.8, 19.299194227542774`}], 
        PointBox[{80.9, 17.36803921811281}], 
        PointBox[{81., 19.980246405044667`}], 
        PointBox[{81.1, 19.968199578833037`}], 
        PointBox[{81.2, 17.237620117566316`}], 
        PointBox[{81.3, 17.56498492391947}], 
        PointBox[{81.4, 20.43799359843115}], 
        PointBox[{81.5, 18.361232423716856`}], 
        PointBox[{81.6, 18.767805251598872`}], 
        PointBox[{81.7, 21.721798310138947`}], 
        PointBox[{81.8, 24.548838927774845`}], 
        PointBox[{81.9, 22.010444042971656`}], 
        PointBox[{82., 24.001205175153924`}], 
        PointBox[{82.1, 25.492495804447987`}], 
        PointBox[{82.2, 22.56228396075279}], 
        PointBox[{82.3, 21.360234923753055`}], 
        PointBox[{82.4, 25.022588847380792`}], 
        PointBox[{82.5, 24.02996109100725}], 
        PointBox[{82.6, 22.648411956899842`}], 
        PointBox[{82.7, 25.506249657649622`}], 
        PointBox[{82.8, 28.311097352511542`}], 
        PointBox[{82.9, 26.470850992960337`}], 
        PointBox[{83., 26.571811009621673`}], 
        PointBox[{83.1, 29.776465654924245`}], 
        PointBox[{83.2, 27.414604891547196`}], 
        PointBox[{83.3, 24.28937804570817}], 
        PointBox[{83.4, 27.842145728540142`}], 
        PointBox[{83.5, 29.185689522786443`}], 
        PointBox[{83.6, 25.94340755276702}], 
        PointBox[{83.7, 28.01359687093575}], 
        PointBox[{83.8, 30.52293328937515}], 
        PointBox[{83.9, 29.900827430855568`}], 
        PointBox[{84., 27.030435603267307`}], 
        PointBox[{84.1, 31.445986631706273`}], 
        PointBox[{84.2, 30.83147081437192}], 
        PointBox[{84.3, 25.531443988780314`}], 
        PointBox[{84.4, 27.92184561113972}], 
        PointBox[{84.5, 32.27802041209653}], 
        PointBox[{84.6, 28.131261990485264`}], 
        PointBox[{84.7, 28.105252768422076`}], 
        PointBox[{84.8, 31.59008208700855}], 
        PointBox[{84.9, 30.12920366699636}], 
        PointBox[{85., 23.629987341166757`}], 
        PointBox[{85.1, 27.882915819963138`}], 
        PointBox[{85.2, 30.273954226431385`}], 
        PointBox[{85.3, 22.790295002309634`}], 
        PointBox[{85.4, 22.916409550577725`}], 
        PointBox[{85.5, 30.39543628253423}], 
        PointBox[{85.6, 27.203210700735273`}], 
        PointBox[{85.7, 23.44713772702528}], 
        PointBox[{85.8, 28.19594464053142}], 
        PointBox[{85.9, 24.13602983693683}], 
        PointBox[{86., 10.862950597066082`}], 
        PointBox[{86.1, 12.920078147419982`}], 
        PointBox[{86.2, 18.86249617623048}], 
        PointBox[{86.3, 8.981994785542845}], 
        PointBox[{86.4, 6.384652565272091}], 
        PointBox[{86.5, 17.350284009794745`}], 
        PointBox[{86.6, 16.352568931886253`}], 
        PointBox[{86.7, 7.291166561189672}], 
        PointBox[{86.8, 12.869241770542361`}], 
        PointBox[{86.9, 9.205818217949917}], 
        PointBox[{87., 340.4200418353689}], 
        PointBox[{87.1, 338.4641369600258}], 
        PointBox[{87.2, 345.5080029123958}], 
        PointBox[{87.3, 333.5866388312697}], 
        PointBox[{87.4, 331.6257481349621}], 
        PointBox[{87.5, 344.90228867966476`}], 
        PointBox[{87.6, 343.29245486664195`}], 
        PointBox[{87.7, 330.9003276076208}], 
        PointBox[{87.8, 337.7683042712462}], 
        PointBox[{87.9, 337.63846498417024`}], 
        PointBox[{88., 312.225322880652}], 
        PointBox[{88.1, 307.1982784294033}], 
        PointBox[{88.2, 312.78845532152366`}], 
        PointBox[{88.3, 305.3111327400761}], 
        PointBox[{88.4, 303.28795400263374`}], 
        PointBox[{88.5, 313.447490633967}], 
        PointBox[{88.6, 311.95148541627685`}], 
        PointBox[{88.7, 302.35897432918983`}], 
        PointBox[{88.8, 307.2462391732381}], 
        PointBox[{88.9, 310.4652360591452}], 
        PointBox[{89., 299.37185037054303`}], 
        PointBox[{89.1, 295.4689266240677}], 
        PointBox[{89.2, 299.99325191927846`}], 
        PointBox[{89.3, 297.50299083812683`}], 
        PointBox[{89.4, 293.617743818763}], 
        PointBox[{89.5, 300.2887114280195}], 
        PointBox[{89.6, 301.39636552721015`}], 
        PointBox[{89.7, 294.32536784649596`}], 
        PointBox[{89.8, 295.65789093576325`}], 
        PointBox[{89.9, 300.29923416596654`}], 
        PointBox[{90., 294.8118839251573}], 
        PointBox[{90.1, 293.58820286113973`}], 
        PointBox[{90.2, 296.6628356135477}], 
        PointBox[{90.3, 297.45233039269215`}], 
        PointBox[{90.4, 293.2973612918357}], 
        PointBox[{90.5, 296.7447352701826}], 
        PointBox[{90.6, 299.73636523887245`}], 
        PointBox[{90.7, 295.0121022366037}], 
        PointBox[{90.8, 293.65867570194774`}], 
        PointBox[{90.9, 297.8942422804133}], 
        PointBox[{91., 295.99608128870887`}], 
        PointBox[{91.1, 294.96038498033965`}], 
        PointBox[{91.2, 297.40919870162725`}], 
        PointBox[{91.3, 299.86456881083365`}], 
        PointBox[{91.4, 297.0872958318807}], 
        PointBox[{91.5, 297.58825252468336`}], 
        PointBox[{91.6, 301.37360823838407`}], 
        PointBox[{91.7, 298.8540914719224}], 
        PointBox[{91.8, 296.13502454964635`}], 
        PointBox[{91.9, 298.8636830915466}], 
        PointBox[{92., 299.7169195079587}], 
        PointBox[{92.1, 297.43275387519304`}], 
        PointBox[{92.2, 300.29961506132764`}], 
        PointBox[{92.3, 303.2438581005668}], 
        PointBox[{92.4, 302.4397573151766}], 
        PointBox[{92.5, 300.92591385586724`}], 
        PointBox[{92.6, 304.4792153939022}], 
        PointBox[{92.7, 303.8208065605191}], 
        PointBox[{92.8, 300.83036685342523`}], 
        PointBox[{92.9, 301.8113599121095}], 
        PointBox[{93., 304.16726174456613`}], 
        PointBox[{93.1, 301.6588214438996}], 
        PointBox[{93.2, 304.2263133833753}], 
        PointBox[{93.3, 307.1959565360637}], 
        PointBox[{93.4, 308.0576762589022}], 
        PointBox[{93.5, 305.8781757552843}], 
        PointBox[{93.6, 308.3803762005228}], 
        PointBox[{93.7, 309.14431875890756`}], 
        PointBox[{93.8, 306.5271547782015}], 
        PointBox[{93.9, 306.12517353338126`}], 
        PointBox[{94., 308.74373676426944`}], 
        PointBox[{94.1, 307.1781651630743}], 
        PointBox[{94.2, 308.4030432610679}], 
        PointBox[{94.3, 311.5675026954155}], 
        PointBox[{94.4, 313.4702845487747}], 
        PointBox[{94.5, 311.7343487659178}], 
        PointBox[{94.6, 312.7985667681324}], 
        PointBox[{94.7, 314.51363439608826`}], 
        PointBox[{94.8, 312.53720433665717`}], 
        PointBox[{94.9, 311.30833234993554`}], 
        PointBox[{95., 313.3920592396992}], 
        PointBox[{95.1, 313.1640134748954}], 
        PointBox[{95.2, 312.88912970130053`}], 
        PointBox[{95.3, 316.2127909983828}], 
        PointBox[{95.4, 318.6145044412583}], 
        PointBox[{95.5, 317.82008723088757`}], 
        PointBox[{95.6, 317.5853459172397}], 
        PointBox[{95.7, 319.7781241590471}], 
        PointBox[{95.8, 318.48333719284204`}], 
        PointBox[{95.9, 316.89595994048716`}], 
        PointBox[{96., 318.1724180204963}], 
        PointBox[{96.1, 319.05889434730875`}], 
        PointBox[{96.2, 317.84820641144245`}], 
        PointBox[{96.3, 320.956681038151}], 
        PointBox[{96.4, 323.51987722557504`}], 
        PointBox[{96.5, 323.64626956658935`}], 
        PointBox[{96.6, 322.5892934541723}], 
        PointBox[{96.7, 324.83983185173975`}], 
        PointBox[{96.8, 324.1516897482221}], 
        PointBox[{96.9, 322.50226372382207`}], 
        PointBox[{97., 323.0504697428669}], 
        PointBox[{97.1, 324.57906221736926`}], 
        PointBox[{97.2, 323.04738603609974`}], 
        PointBox[{97.3, 325.6381384634434}], 
        PointBox[{97.4, 328.1799152083448}], 
        PointBox[{97.5, 328.9644441527912}], 
        PointBox[{97.6, 327.58985106599744`}], 
        PointBox[{97.7, 329.6106678927735}], 
        PointBox[{97.8, 329.3965146857588}], 
        PointBox[{97.9, 327.83369281366816`}], 
        PointBox[{98., 327.8703176232495}], 
        PointBox[{98.1, 329.6142174772229}], 
        PointBox[{98.2, 328.1484842086459}], 
        PointBox[{98.3, 330.14125641816236`}], 
        PointBox[{98.4, 332.52434305438084`}], 
        PointBox[{98.5, 333.66266311915115`}], 
        PointBox[{98.6, 332.30004115332724`}], 
        PointBox[{98.7, 333.98615002464123`}], 
        PointBox[{98.8, 334.08413761451715`}], 
        PointBox[{98.9, 332.65929515620786`}], 
        PointBox[{99., 332.4064155959281}], 
        PointBox[{99.1, 334.1120541474273}], 
        PointBox[{99.2, 332.8457368798582}], 
        PointBox[{99.3, 334.3349933836846}], 
        PointBox[{99.4, 336.420714642439}], 
        PointBox[{99.5, 337.652356569928}], 
        PointBox[{99.6, 336.4208456485026}], 
        PointBox[{99.7, 337.8321420070034}], 
        PointBox[{99.8, 338.06679695018465`}], 
        PointBox[{99.9, 336.7780184041859}], 
        PointBox[{100., 336.4148323527695}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 360}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
        40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {0, -180}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
        PointBox[{0.1, 23.372580148747716`}], 
        PointBox[{0.2, 17.811804317847418`}], 
        PointBox[{0.3, 21.179838754361526`}], 
        PointBox[{0.4, 33.832666149175566`}], 
        PointBox[{0.5, 26.428315243664997`}], 
        PointBox[{0.6, 20.018612565170656`}], 
        PointBox[{0.7, 33.97836615081712}], 
        PointBox[{0.8, 37.081379644872186`}], 
        PointBox[{0.9, 30.286789769341112`}], 
        PointBox[{1., 44.0662169679257}], PointBox[{1.1, 60.67593938296733}], 
        PointBox[{1.2, 58.62707215127887}], 
        PointBox[{1.3, 59.28680254354185}], PointBox[{1.4, 68.4998025326089}],
         PointBox[{1.5, 65.06447009943099}], 
        PointBox[{1.6, 60.35731725929395}], 
        PointBox[{1.7, 69.66549398567565}], 
        PointBox[{1.8, 74.11006679078912}], 
        PointBox[{1.9, 68.99577505302113}], PointBox[{2., 74.05147363093602}],
         PointBox[{2.1, 82.25833865521008}], 
        PointBox[{2.2, 82.92487366346995}], 
        PointBox[{2.3, 81.46459215008372}], 
        PointBox[{2.4, 87.68505814858122}], PointBox[{2.5, 88.3301572466903}],
         PointBox[{2.6, 84.08155033477351}], 
        PointBox[{2.7, 89.22319964831422}], 
        PointBox[{2.8, 95.01424745598433}], 
        PointBox[{2.9, 92.36694635784124}], PointBox[{3., 92.87635175271112}],
         PointBox[{3.1, 98.7788724280972}], 
        PointBox[{3.2, 99.46924618195408}], 
        PointBox[{3.3, 97.51524084125072}], 
        PointBox[{3.4, 100.64408145904713`}], 
        PointBox[{3.5, 103.96121320773136`}], 
        PointBox[{3.6, 100.60438828426186`}], 
        PointBox[{3.7, 102.72187509676769`}], 
        PointBox[{3.8, 108.54605319170423`}], 
        PointBox[{3.9, 108.4505166837398}], 
        PointBox[{4., 106.80050007229147`}], 
        PointBox[{4.1, 111.76054746850741`}], 
        PointBox[{4.2, 111.89636525621017`}], 
        PointBox[{4.3, 110.41840695653855`}], 
        PointBox[{4.4, 111.06297609611192`}], 
        PointBox[{4.5, 115.16977601072222`}], 
        PointBox[{4.6, 113.42100835707424`}], 
        PointBox[{4.7, 113.44314304900854`}], 
        PointBox[{4.8, 118.36229261398012`}], 
        PointBox[{4.9, 120.23948443191239`}], 
        PointBox[{5., 118.22334988780949`}], 
        PointBox[{5.1, 121.31473891002088`}], 
        PointBox[{5.2, 122.22606932159988`}], 
        PointBox[{5.3, 120.96026706770044`}], 
        PointBox[{5.4, 120.1189345148523}], 
        PointBox[{5.5, 123.43844586210616`}], 
        PointBox[{5.6, 123.61396154749127`}], 
        PointBox[{5.7, 122.35393613954511`}], 
        PointBox[{5.8, 125.98075826036938`}], 
        PointBox[{5.9, 128.9471470492672}], 
        PointBox[{6., 127.66950589101089`}], 
        PointBox[{6.1, 128.64732426155706`}], 
        PointBox[{6.2, 130.94060279056475`}], 
        PointBox[{6.3, 129.39713233500743`}], 
        PointBox[{6.4, 127.94745758851786`}], 
        PointBox[{6.5, 129.77128529871243`}], 
        PointBox[{6.6, 131.50124676526957`}], 
        PointBox[{6.7, 129.71999323720775`}], 
        PointBox[{6.8, 132.0195123338044}], 
        PointBox[{6.9, 135.29885863830896`}], 
        PointBox[{7., 135.11146690886835`}], 
        PointBox[{7.1, 134.5267276370496}], 
        PointBox[{7.2, 137.43659698246302`}], 
        PointBox[{7.3, 135.95440383929053`}], 
        PointBox[{7.4, 134.3844818074649}], 
        PointBox[{7.5, 134.77737795886242`}], 
        PointBox[{7.6, 137.21778339070988`}], 
        PointBox[{7.7, 135.57782101771772`}], 
        PointBox[{7.8, 136.68361671826915`}], 
        PointBox[{7.9, 139.77745650029374`}], 
        PointBox[{8., 140.5120079622502}], 
        PointBox[{8.1, 139.18386578865739`}], 
        PointBox[{8.2, 141.77090686365227`}], 
        PointBox[{8.3, 140.87169701523453`}], 
        PointBox[{8.4, 139.26323536634482`}], 
        PointBox[{8.5, 138.6326666373834}], 
        PointBox[{8.6, 140.9503465106318}], 
        PointBox[{8.7, 139.88081763044556`}], 
        PointBox[{8.8, 139.99899758492302`}], 
        PointBox[{8.9, 142.6582454964564}], 
        PointBox[{9., 143.94987697252054`}], 
        PointBox[{9.1, 142.5247792064929}], 
        PointBox[{9.2, 144.2597832377296}], 
        PointBox[{9.3, 144.14273235769087`}], 
        PointBox[{9.4, 142.4743354837874}], 
        PointBox[{9.5, 141.24431777136215`}], 
        PointBox[{9.6, 142.94510995656856`}], 
        PointBox[{9.7, 142.5498026065252}], 
        PointBox[{9.8, 141.91236414002014`}], 
        PointBox[{9.9, 144.05094022320827`}], 
        PointBox[{10., 145.55056390501704`}], 
        PointBox[{10.1, 144.33757644888192`}], 
        PointBox[{10.2, 145.11486076499568`}], 
        PointBox[{10.3, 145.61168651939715`}], 
        PointBox[{10.4, 143.94795929636257`}], 
        PointBox[{10.5, 142.42907634144285`}], 
        PointBox[{10.6, 143.38261111790416`}], 
        PointBox[{10.7, 143.49354913749903`}], 
        PointBox[{10.8, 142.32037716896866`}], 
        PointBox[{10.9, 143.94356497118042`}], 
        PointBox[{11., 145.39164485390575`}], 
        PointBox[{11.1, 144.41593236788685`}], 
        PointBox[{11.2, 144.38595440403242`}], 
        PointBox[{11.3, 145.18636849240193`}], 
        PointBox[{11.4, 143.6146097784058}], 
        PointBox[{11.5, 141.98722649012416`}], 
        PointBox[{11.6, 142.28375195234548`}], 
        PointBox[{11.7, 142.60839031000887`}], 
        PointBox[{11.8, 141.07010280394206`}], 
        PointBox[{11.9, 142.22992295663062`}], 
        PointBox[{12., 143.45089734689827`}], 
        PointBox[{12.1, 142.57770575498762`}], 
        PointBox[{12.2, 141.97259968115395`}], 
        PointBox[{12.3, 142.7870579106766}], 
        PointBox[{12.4, 141.3662029551706}], 
        PointBox[{12.5, 139.69919287534685`}], 
        PointBox[{12.6, 139.50839401001576`}], 
        PointBox[{12.7, 139.75034580779538`}], 
        PointBox[{12.8, 137.9532275593665}], 
        PointBox[{12.9, 138.71950137964086`}], 
        PointBox[{13., 139.59143150390082`}], 
        PointBox[{13.1, 138.62354520121517`}], 
        PointBox[{13.2, 137.66125057505815`}], 
        PointBox[{13.3, 138.27003951240295`}], 
        PointBox[{13.4, 137.02814886411215`}], 
        PointBox[{13.5, 135.301857321203}], 
        PointBox[{13.6, 134.79155116743277`}], 
        PointBox[{13.7, 134.6884557780977}], 
        PointBox[{13.8, 132.70486489596624`}], 
        PointBox[{13.9, 133.14077366361016`}], 
        PointBox[{14., 133.56643524659012`}], 
        PointBox[{14.1, 132.29805614113866`}], 
        PointBox[{14.2, 131.1787789001246}], 
        PointBox[{14.3, 131.42827532766387`}], 
        PointBox[{14.4, 130.3285576684757}], 
        PointBox[{14.5, 128.46940063142938`}], 
        PointBox[{14.6, 127.78835056825301`}], 
        PointBox[{14.7, 127.0797377578383}], 
        PointBox[{14.8, 125.02618263861586`}], 
        PointBox[{14.9, 125.16092381519593`}], 
        PointBox[{15., 125.05115842093255`}], 
        PointBox[{15.1, 123.30000057104371`}], 
        PointBox[{15.2, 122.25826213435721`}], 
        PointBox[{15.3, 122.09272536205935`}], 
        PointBox[{15.4, 120.89580871825092`}], 
        PointBox[{15.5, 118.86236784293033`}], 
        PointBox[{15.6, 118.14161485748264`}], 
        PointBox[{15.7, 116.54607947453405`}], 
        PointBox[{15.8, 114.64569229455446`}], 
        PointBox[{15.9, 114.44994386380313`}], 
        PointBox[{16., 113.72023997467295`}], 
        PointBox[{16.1, 111.37771883594905`}], 
        PointBox[{16.2, 110.67813904089417`}], 
        PointBox[{16.3, 110.1341294966096}], 
        PointBox[{16.4, 108.40901177880005`}], 
        PointBox[{16.5, 106.27556256376192`}], 
        PointBox[{16.6, 105.57381812969834`}], 
        PointBox[{16.7, 102.92986698495042`}], 
        PointBox[{16.8, 101.41514856382855`}], 
        PointBox[{16.9, 100.80335489958998`}], 
        PointBox[{17., 99.37726468402616}], 
        PointBox[{17.1, 96.5435589002227}], 
        PointBox[{17.2, 96.28919479783872}], 
        PointBox[{17.3, 95.18072367504465}], 
        PointBox[{17.4, 92.85761321948303}], 
        PointBox[{17.5, 90.81132085042918}], 
        PointBox[{17.6, 89.90163248106546}], 
        PointBox[{17.7, 86.54569618656751}], 
        PointBox[{17.8, 85.39090323786513}], 
        PointBox[{17.9, 84.26042092087482}], 
        PointBox[{18., 82.07883392554322}], 
        PointBox[{18.1, 79.32306076549685}], 
        PointBox[{18.2, 79.25211909604695}], 
        PointBox[{18.3, 77.20587238180087}], 
        PointBox[{18.4, 74.62668127356483}], 
        PointBox[{18.5, 72.88661882010638}], 
        PointBox[{18.6, 71.07204743320108}], 
        PointBox[{18.7, 67.97792818720882}], 
        PointBox[{18.8, 66.84748051459792}], 
        PointBox[{18.9, 65.1203183241123}], 
        PointBox[{19., 62.20462425097685}], 
        PointBox[{19.1, 60.49941773024693}], 
        PointBox[{19.2, 59.62456496156665}], 
        PointBox[{19.3, 56.84422446174358}], 
        PointBox[{19.4, 54.367109432963844`}], 
        PointBox[{19.5, 52.98897236525954}], 
        PointBox[{19.6, 49.77205204679012}], 
        PointBox[{19.7, 47.69259156324006}], 
        PointBox[{19.8, 46.227548054783256`}], 
        PointBox[{19.9, 43.869755912246546`}], 
        PointBox[{20., 40.5781753599731}], 
        PointBox[{20.1, 40.18462105278377}], 
        PointBox[{20.2, 37.809857189618924`}], 
        PointBox[{20.3, 34.92276975606546}], 
        PointBox[{20.4, 32.80934154559145}], 
        PointBox[{20.5, 31.28885453820112}], 
        PointBox[{20.6, 27.491522276084652`}], 
        PointBox[{20.7, 26.052059298725}], 
        PointBox[{20.8, 24.07457997614074}], 
        PointBox[{20.9, 21.132860317817176`}], 
        PointBox[{21., 18.57213415793194}], 
        PointBox[{21.1, 18.00009632691217}], 
        PointBox[{21.2, 14.835129010885794`}], 
        PointBox[{21.3, 12.231607004654506`}], 
        PointBox[{21.4, 10.586966701748679`}], 
        PointBox[{21.5, 7.9145234185380104`}], 
        PointBox[{21.6, 5.057694415469086}], 
        PointBox[{21.7, 3.4924353921524016`}], 
        PointBox[{21.8, 0.9972829362668563}], 
        PointBox[{21.9, -2.248583820695785}], 
        PointBox[{22., -3.068014132193639}], 
        PointBox[{22.1, -5.354748637380908}], 
        PointBox[{22.2, -8.394145697928252}], 
        PointBox[{22.3, -10.526824653261428`}], 
        PointBox[{22.4, -11.96550989635216}], 
        PointBox[{22.5, -15.752474499744494`}], 
        PointBox[{22.6, -17.39932875160048}], 
        PointBox[{22.7, -19.429259002572508`}], 
        PointBox[{22.8, -22.313032348620254`}], 
        PointBox[{22.9, -25.019402970867304`}], 
        PointBox[{23., -25.323299659959957`}], 
        PointBox[{23.1, -28.604723354384987`}], 
        PointBox[{23.2, -31.14331822985332}], 
        PointBox[{23.3, -32.76174507809992}], 
        PointBox[{23.4, -34.78620683246663}], 
        PointBox[{23.5, -38.18492266508838}], 
        PointBox[{23.6, -39.59614138292454}], 
        PointBox[{23.7, -42.05148971618837}], 
        PointBox[{23.8, -45.00414810704751}], 
        PointBox[{23.9, -46.15842555562631}], 
        PointBox[{24., -47.77311893636579}], 
        PointBox[{24.1, -50.83458474015424}], 
        PointBox[{24.2, -52.77609443426991}], 
        PointBox[{24.3, -54.03177345279255}], 
        PointBox[{24.4, -57.179879534396605`}], 
        PointBox[{24.5, -59.17653136028821}], 
        PointBox[{24.6, -60.9543428544639}], 
        PointBox[{24.7, -63.61455095529527}], 
        PointBox[{24.8, -65.99947184488701}], 
        PointBox[{24.9, -66.12584768033048}], 
        PointBox[{25., -68.98134258606296}], 
        PointBox[{25.1, -71.36608482079464}], 
        PointBox[{25.2, -72.72254346459886}], 
        PointBox[{25.3, -74.02098600471436}], 
        PointBox[{25.4, -77.53079453303872}], 
        PointBox[{25.5, -78.60902662690933}], 
        PointBox[{25.6, -80.74812985623066}], 
        PointBox[{25.7, -83.26495529109161}], 
        PointBox[{25.8, -84.57059828955244}], 
        PointBox[{25.9, -85.00316893443232}], 
        PointBox[{26., -87.98832285576282}], 
        PointBox[{26.1, -89.63649156226165}], 
        PointBox[{26.2, -90.48871986657468}], 
        PointBox[{26.3, -92.28507984548924}], 
        PointBox[{26.4, -94.99459787505839}], 
        PointBox[{26.5, -95.967588908974}], 
        PointBox[{26.6, -98.24028216001534}], 
        PointBox[{26.7, -100.17906971243065`}], 
        PointBox[{26.8, -100.6670168114506}], 
        PointBox[{26.9, -101.8294975494864}], 
        PointBox[{27., -104.25659403902682`}], 
        PointBox[{27.1, -105.21036738357725`}], 
        PointBox[{27.2, -105.69292008243065`}], 
        PointBox[{27.3, -108.04474412938725`}], 
        PointBox[{27.4, -109.54425398238891`}], 
        PointBox[{27.5, -110.67623576666665`}], 
        PointBox[{27.6, -112.8392719817275}], 
        PointBox[{27.7, -114.09194852185828`}], 
        PointBox[{27.8, -114.10814928024774`}], 
        PointBox[{27.9, -115.81727869728638`}], 
        PointBox[{28., -117.54006300173569`}], 
        PointBox[{28.1, -117.86183645135316`}], 
        PointBox[{28.2, -118.10933878221476`}], 
        PointBox[{28.3, -120.66081907043917`}], 
        PointBox[{28.4, -121.18018274525457`}], 
        PointBox[{28.5, -122.39825979171292`}], 
        PointBox[{28.6, -124.29988191367738`}], 
        PointBox[{28.7, -125.31586148785937`}], 
        PointBox[{28.8, -124.90510856082983`}], 
        PointBox[{28.9, -126.7753171571785}], 
        PointBox[{29., -127.87199184311976`}], 
        PointBox[{29.1, -127.63088463277745`}], 
        PointBox[{29.2, -127.70511420534604`}], 
        PointBox[{29.3, -130.11984089391626`}], 
        PointBox[{29.4, -129.9798327599674}], 
        PointBox[{29.5, -131.15121762334456`}], 
        PointBox[{29.6, -132.81208944864557`}], 
        PointBox[{29.7, -133.90399943815282`}], 
        PointBox[{29.8, -133.10064043526654`}], 
        PointBox[{29.9, -134.88055666209402`}], 
        PointBox[{30., -135.50364494810492`}], 
        PointBox[{30.1, -134.76873020770654`}], 
        PointBox[{30.2, -134.63807123391234`}], 
        PointBox[{30.3, -136.80900932880832`}], 
        PointBox[{30.4, -136.20538487374142`}], 
        PointBox[{30.5, -137.2124435440819}], 
        PointBox[{30.6, -138.77296089660376`}], 
        PointBox[{30.7, -140.0052136460763}], 
        PointBox[{30.8, -138.8637400025509}], 
        PointBox[{30.9, -140.4413269441975}], 
        PointBox[{31., -140.77569834153473`}], 
        PointBox[{31.1, -139.61030889819085`}], 
        PointBox[{31.2, -139.1841010045864}], 
        PointBox[{31.3, -141.1498789787256}], 
        PointBox[{31.4, -140.2118455773416}], 
        PointBox[{31.5, -140.9281855341942}], 
        PointBox[{31.6, -142.5015542698784}], 
        PointBox[{31.7, -143.88690759824385`}], 
        PointBox[{31.8, -142.46972291835846`}], 
        PointBox[{31.9, -143.7485206654419}], 
        PointBox[{32., -144.00216661751256`}], 
        PointBox[{32.1, -142.4701877731095}], 
        PointBox[{32.2, -141.63632676561974`}], 
        PointBox[{32.3, -143.44084992596981`}], 
        PointBox[{32.4, -142.33573933749722`}], 
        PointBox[{32.5, -142.59190740308986`}], 
        PointBox[{32.6, -144.20626347833968`}], 
        PointBox[{32.7, -145.7618724323729}], 
        PointBox[{32.8, -144.21070445119403`}], 
        PointBox[{32.9, -145.01409065574626`}], 
        PointBox[{33., -145.41013045481304`}], 
        PointBox[{33.1, -143.59761690242885`}], 
        PointBox[{33.2, -142.24605220005833`}], 
        PointBox[{33.3, -143.84376798692392`}], 
        PointBox[{33.4, -142.84553272349513`}], 
        PointBox[{33.5, -142.42742483093025`}], 
        PointBox[{33.6, -144.03467190067022`}], 
        PointBox[{33.7, -145.73578814377106`}], 
        PointBox[{33.8, -144.32969834404867`}], 
        PointBox[{33.9, -144.3747723076085}], 
        PointBox[{34., -145.11843837660126`}], 
        PointBox[{34.1, -143.16777632354933`}], 
        PointBox[{34.2, -141.20745422394248`}], 
        PointBox[{34.3, -142.42953503677927`}], 
        PointBox[{34.4, -141.9110242067618}], 
        PointBox[{34.5, -140.61914883042482`}], 
        PointBox[{34.6, -142.07822597553604`}], 
        PointBox[{34.7, -143.82088355227097`}], 
        PointBox[{34.8, -142.9656525021055}], 
        PointBox[{34.9, -141.94077451730845`}], 
        PointBox[{35., -143.13016088069708`}], 
        PointBox[{35.1, -141.2812198384854}], 
        PointBox[{35.2, -138.6636481403657}], 
        PointBox[{35.3, -139.23813640888693`}], 
        PointBox[{35.4, -139.55061536036737`}], 
        PointBox[{35.5, -137.34622424578993`}], 
        PointBox[{35.6, -138.3744753220526}], 
        PointBox[{35.7, -140.01997342963296`}], 
        PointBox[{35.8, -140.09764646133408`}], 
        PointBox[{35.9, -137.86160606453632`}], 
        PointBox[{36., -139.33484481950654`}], 
        PointBox[{36.1, -137.95372853607114`}], 
        PointBox[{36.2, -134.71407943134545`}], 
        PointBox[{36.3, -134.3231049023525}], 
        PointBox[{36.4, -135.58128554453288`}], 
        PointBox[{36.5, -132.79835913468196`}], 
        PointBox[{36.6, -132.94831024769155`}], 
        PointBox[{36.7, -134.490129138263}], 
        PointBox[{36.8, -135.5080094576042}], 
        PointBox[{36.9, -132.35200750263175`}], 
        PointBox[{37., -133.5404742090941}], 
        PointBox[{37.1, -133.08356655075477`}], 
        PointBox[{37.2, -129.41392467626065`}], 
        PointBox[{37.3, -127.74613918473915`}], 
        PointBox[{37.4, -129.66446609776904`}], 
        PointBox[{37.5, -127.12766791189279`}], 
        PointBox[{37.6, -125.86333729790567`}], 
        PointBox[{37.7, -127.40210876179117`}], 
        PointBox[{37.8, -128.78795564704342`}], 
        PointBox[{37.9, -125.59470765731385`}], 
        PointBox[{38., -125.55237583769122`}], 
        PointBox[{38.1, -126.38601019463749`}], 
        PointBox[{38.2, -122.74576569936835`}], 
        PointBox[{38.3, -119.53674840426902`}], 
        PointBox[{38.4, -121.45733229460166`}], 
        PointBox[{38.5, -120.26841779129609`}], 
        PointBox[{38.6, -117.24222049572563`}], 
        PointBox[{38.7, -118.47765087069638`}], 
        PointBox[{38.8, -119.5977474496176}], 
        PointBox[{38.9, -117.4945086446678}], 
        PointBox[{39., -115.24925835177055`}], 
        PointBox[{39.1, -117.30717757270395`}], 
        PointBox[{39.2, -114.50858378630073`}], 
        PointBox[{39.3, -109.61101586302539`}], 
        PointBox[{39.4, -110.67207145058637`}], 
        PointBox[{39.5, -111.66286731888977`}], 
        PointBox[{39.6, -107.21232799453355`}], 
        PointBox[{39.7, -107.26641908685633`}], 
        PointBox[{39.8, -108.45409406640829`}], 
        PointBox[{39.9, -107.3325019412332}], 
        PointBox[{40., -102.4615003310173}], 
        PointBox[{40.1, -104.9059177324707}], 
        PointBox[{40.2, -104.02619624427825`}], 
        PointBox[{40.3, -97.56412729325893}], 
        PointBox[{40.4, -96.80777900955945}], 
        PointBox[{40.5, -100.11798901950533`}], 
        PointBox[{40.6, -95.61355600791649}], 
        PointBox[{40.7, -93.25859893482993}], 
        PointBox[{40.8, -95.33864912580611}], 
        PointBox[{40.9, -93.52570654149531}], 
        PointBox[{41., -86.30448096232067}], 
        PointBox[{41.1, -87.44611048826482}], 
        PointBox[{41.2, -89.4511997497575}], 
        PointBox[{41.3, -82.00803186419216}], 
        PointBox[{41.4, -78.33634761099529}], 
        PointBox[{41.5, -83.61140103750586}], 
        PointBox[{41.6, -81.10122266215694}], 
        PointBox[{41.7, -75.1409972570109}], 
        PointBox[{41.8, -77.58300431666066}], 
        PointBox[{41.9, -74.83521848319288}], 
        PointBox[{42., -63.29570399327713}], 
        PointBox[{42.1, -60.64623239816865}], 
        PointBox[{42.2, -65.91108888229064}], 
        PointBox[{42.3, -58.23660407239731}], 
        PointBox[{42.4, -50.49400998182682}], 
        PointBox[{42.5, -57.785862353972334`}], 
        PointBox[{42.6, -58.90066515633225}], 
        PointBox[{42.7, -48.41856468262267}], 
        PointBox[{42.8, -50.04774208946037}], 
        PointBox[{42.9, -49.61239964180277}], 
        PointBox[{43., -25.238520127753873`}], 
        PointBox[{43.1, -15.44409678768352}], 
        PointBox[{43.2, -22.791250738999224`}], 
        PointBox[{43.3, -14.089167566602555`}], 
        PointBox[{43.4, -3.826034097597585}], 
        PointBox[{43.5, -14.085581313727744`}], 
        PointBox[{43.6, -17.35752047819915}], 
        PointBox[{43.7, -1.9670019748118648`}], 
        PointBox[{43.8, -3.3661758847629244`}], 
        PointBox[{43.9, -6.553241783651174}], 
        PointBox[{44., 22.236928335394623`}], 
        PointBox[{44.1, 36.803814075541595`}], 
        PointBox[{44.2, 31.259165417170152`}], 
        PointBox[{44.3, 38.36159622095511}], 
        PointBox[{44.4, 46.40428967498883}], 
        PointBox[{44.5, 37.48996172720217}], 
        PointBox[{44.6, 36.06388684249396}], 
        PointBox[{44.7, 49.83606368955225}], 
        PointBox[{44.8, 48.804456996560475`}], 
        PointBox[{44.9, 44.18807607749477}], 
        PointBox[{45., 58.689302819384466`}], 
        PointBox[{45.1, 69.03664646954712}], 
        PointBox[{45.2, 66.05085706913087}], 
        PointBox[{45.3, 68.58831634256421}], 
        PointBox[{45.4, 75.98425974052952}], 
        PointBox[{45.5, 71.30821206127439}], 
        PointBox[{45.6, 69.30839216094319}], 
        PointBox[{45.7, 78.74825499979488}], 
        PointBox[{45.8, 80.71911873297722}], 
        PointBox[{45.9, 76.36200889161773}], 
        PointBox[{46., 82.86346628956744}], 
        PointBox[{46.1, 88.29934069643059}], 
        PointBox[{46.2, 87.64331318561017}], 
        PointBox[{46.3, 87.21869177917688}], 
        PointBox[{46.4, 93.28284980888566}], 
        PointBox[{46.5, 92.42748534258135}], 
        PointBox[{46.6, 89.49850245547714}], 
        PointBox[{46.7, 95.47515206745447}], 
        PointBox[{46.8, 99.70715390083205}], 
        PointBox[{46.9, 96.79581734532985}], 
        PointBox[{47., 98.81700351143081}], 
        PointBox[{47.1, 103.16974413371645`}], 
        PointBox[{47.2, 103.10667599790031`}], 
        PointBox[{47.3, 101.49630283928855`}], 
        PointBox[{47.4, 105.20217536335258`}], 
        PointBox[{47.5, 107.27321385622781`}], 
        PointBox[{47.6, 104.25000635466131`}], 
        PointBox[{47.7, 107.45113836661767`}], 
        PointBox[{47.8, 112.47326308570337`}], 
        PointBox[{47.9, 111.6159427548555}], 
        PointBox[{48., 110.93746375128103`}], 
        PointBox[{48.1, 115.48795340432116`}], 
        PointBox[{48.2, 114.9561979598584}], 
        PointBox[{48.3, 113.3499186012923}], 
        PointBox[{48.4, 114.6809970509712}], 
        PointBox[{48.5, 118.19840587177168`}], 
        PointBox[{48.6, 116.00862606103328`}], 
        PointBox[{48.7, 117.07325481894804`}], 
        PointBox[{48.8, 121.77939011665876`}], 
        PointBox[{48.9, 122.80325633662869`}], 
        PointBox[{49., 121.06920391623134`}], 
        PointBox[{49.1, 124.67629804642638`}], 
        PointBox[{49.2, 124.58156492835406`}], 
        PointBox[{49.3, 123.20076461931603`}], 
        PointBox[{49.4, 122.846761918845}], 
        PointBox[{49.5, 126.24387066895724`}], 
        PointBox[{49.6, 125.52168133025407`}], 
        PointBox[{49.7, 125.0695422753779}], 
        PointBox[{49.8, 128.89044746856234`}], 
        PointBox[{49.9, 131.14654000700102`}], 
        PointBox[{50., 129.60423483059276`}], 
        PointBox[{50.1, 131.47675431607058`}], 
        PointBox[{50.2, 132.69970439777535`}], 
        PointBox[{50.3, 131.1281589297214}], 
        PointBox[{50.4, 129.88967577790754`}], 
        PointBox[{50.5, 132.18565850360028`}], 
        PointBox[{50.6, 132.98409654847637`}], 
        PointBox[{50.7, 131.62684180931683`}], 
        PointBox[{50.8, 134.38037173043267`}], 
        PointBox[{50.9, 137.17231615562196`}], 
        PointBox[{51., 136.4237425554602}], 
        PointBox[{51.1, 136.63043176020437`}], 
        PointBox[{51.2, 138.89972472826776`}], 
        PointBox[{51.3, 137.20210096927622`}], 
        PointBox[{51.4, 135.6539357798174}], 
        PointBox[{51.5, 136.6193855618767}], 
        PointBox[{51.6, 138.4359705691968}], 
        PointBox[{51.7, 136.75405554319877`}], 
        PointBox[{51.8, 138.46533080101653`}], 
        PointBox[{51.9, 141.28461244670325`}], 
        PointBox[{52., 141.37436858995352`}], 
        PointBox[{52.1, 140.47644236689666`}], 
        PointBox[{52.2, 142.99514883390657`}], 
        PointBox[{52.3, 141.5518474173732}], 
        PointBox[{52.4, 139.94884361523873`}], 
        PointBox[{52.5, 139.8153549309136}], 
        PointBox[{52.6, 141.9418962185955}], 
        PointBox[{52.7, 140.39389755798038`}], 
        PointBox[{52.8, 141.1850724172109}], 
        PointBox[{52.9, 143.74021265986084`}], 
        PointBox[{53., 144.42370900738752`}], 
        PointBox[{53.1, 143.03270522853563`}], 
        PointBox[{53.2, 145.17335162506788`}], 
        PointBox[{53.3, 144.23694165431516`}], 
        PointBox[{53.4, 142.6311517186332}], 
        PointBox[{53.5, 141.75964327090333`}], 
        PointBox[{53.6, 143.6361113429448}], 
        PointBox[{53.7, 142.45603447488247`}], 
        PointBox[{53.8, 142.49138510612102`}], 
        PointBox[{53.9, 144.65006589731638`}], 
        PointBox[{54., 145.61842409502424`}], 
        PointBox[{54.1, 144.13481810003577`}], 
        PointBox[{54.2, 145.60765002833068`}], 
        PointBox[{54.3, 145.1668564229767}], 
        PointBox[{54.4, 143.59288801016373`}], 
        PointBox[{54.5, 142.29298009729973`}], 
        PointBox[{54.6, 143.6476860007897}], 
        PointBox[{54.7, 142.82238215147663`}], 
        PointBox[{54.8, 142.27659721308737`}], 
        PointBox[{54.9, 144.00125741377997`}], 
        PointBox[{55., 144.98890211675462`}], 
        PointBox[{55.1, 143.55485680509446`}], 
        PointBox[{55.2, 144.34701813541324`}], 
        PointBox[{55.3, 144.20951385171065`}], 
        PointBox[{55.4, 142.7269371040602}], 
        PointBox[{55.5, 141.20214319481602`}], 
        PointBox[{55.6, 142.00134512237855`}], 
        PointBox[{55.7, 141.34117944378522`}], 
        PointBox[{55.8, 140.37718526140088`}], 
        PointBox[{55.9, 141.67802555402886`}], 
        PointBox[{56., 142.4831428299076}], 
        PointBox[{56.1, 141.05251855172537`}], 
        PointBox[{56.2, 141.30688928155723`}], 
        PointBox[{56.3, 141.22973395069857`}], 
        PointBox[{56.4, 139.8886659637501}], 
        PointBox[{56.5, 138.23723533681186`}], 
        PointBox[{56.6, 138.57547972143948`}], 
        PointBox[{56.7, 137.80791605587}], 
        PointBox[{56.8, 136.5702780912252}], 
        PointBox[{56.9, 137.47208398926887`}], 
        PointBox[{57., 137.94053497557616`}], 
        PointBox[{57.1, 136.36948831334303`}], 
        PointBox[{57.2, 136.28969128522294`}], 
        PointBox[{57.3, 136.06630180752836`}], 
        PointBox[{57.4, 134.85759852602496`}], 
        PointBox[{57.5, 133.09862741864345`}], 
        PointBox[{57.6, 133.10842678491463`}], 
        PointBox[{57.7, 131.93995876878034`}], 
        PointBox[{57.8, 130.5744714689572}], 
        PointBox[{57.9, 131.0898262613191}], 
        PointBox[{58., 131.094117288063}], 
        PointBox[{58.1, 129.2151035380375}], 
        PointBox[{58.2, 129.02061838946247`}], 
        PointBox[{58.3, 128.55469310563785`}], 
        PointBox[{58.4, 127.31314219305204`}], 
        PointBox[{58.5, 125.44008695930097`}], 
        PointBox[{58.6, 125.24137624417199`}], 
        PointBox[{58.7, 123.40007162735856`}], 
        PointBox[{58.8, 122.07842259564495`}], 
        PointBox[{58.9, 122.1870846424863}], 
        PointBox[{59., 121.61427898313559`}], 
        PointBox[{59.1, 119.31241155918542`}], 
        PointBox[{59.2, 119.19394990854926`}], 
        PointBox[{59.3, 118.51038549521763`}], 
        PointBox[{59.4, 116.8949777775706}], 
        PointBox[{59.5, 114.94960122373595`}], 
        PointBox[{59.6, 114.58117936584313`}], 
        PointBox[{59.7, 111.93710744869895`}], 
        PointBox[{59.8, 110.81270071070321`}], 
        PointBox[{59.9, 110.45665388429916`}], 
        PointBox[{60., 109.20652526082267`}], 
        PointBox[{60.1, 106.55159626611567`}], 
        PointBox[{60.2, 106.55755066723214`}], 
        PointBox[{60.3, 105.54733524336916`}], 
        PointBox[{60.4, 103.39904643193586`}], 
        PointBox[{60.5, 101.51576428891713`}], 
        PointBox[{60.6, 100.77282832274068`}], 
        PointBox[{60.7, 97.59419876759057}], 
        PointBox[{60.8, 96.65860135804542}], 
        PointBox[{60.9, 95.76057882048917}], 
        PointBox[{61., 93.7534865061316}], 
        PointBox[{61.1, 91.20755457917403}], 
        PointBox[{61.2, 91.17940526659368}], 
        PointBox[{61.3, 89.43499877955037}], 
        PointBox[{61.4, 86.97085248368239}], 
        PointBox[{61.5, 85.34044159569021}], 
        PointBox[{61.6, 83.64857846740051}], 
        PointBox[{61.7, 80.70913898763683}], 
        PointBox[{61.8, 79.7329841370447}], 
        PointBox[{61.9, 78.22289817170531}], 
        PointBox[{62., 75.45274910442822}], 
        PointBox[{62.1, 73.80909059452824}], 
        PointBox[{62.2, 73.11467565991916}], 
        PointBox[{62.3, 70.55701694250456}], 
        PointBox[{62.4, 68.10606042052677}], 
        PointBox[{62.5, 66.80291687733552}], 
        PointBox[{62.6, 63.73663950761693}], 
        PointBox[{62.7, 61.686664717126405`}], 
        PointBox[{62.8, 60.380582973935816`}], 
        PointBox[{62.9, 58.21276063625555}], 
        PointBox[{63., 54.970049129893596`}], 
        PointBox[{63.1, 54.519794949970674`}], 
        PointBox[{63.2, 52.47593132353359}], 
        PointBox[{63.3, 49.64491814542998}], 
        PointBox[{63.4, 47.49043552259536}], 
        PointBox[{63.5, 46.08463241436402}], 
        PointBox[{63.6, 42.33259111299412}], 
        PointBox[{63.7, 40.91302340560651}], 
        PointBox[{63.8, 39.09819409032934}], 
        PointBox[{63.9, 36.283412077515095`}], 
        PointBox[{64., 33.56449713152688}], 
        PointBox[{64.1, 33.168167700845515`}], 
        PointBox[{64.2, 30.154586931981612`}], 
        PointBox[{64.3, 27.490627626117202`}], 
        PointBox[{64.4, 25.790792902073008`}], 
        PointBox[{64.5, 23.287667087330192`}], 
        PointBox[{64.6, 20.315790879743872`}], 
        PointBox[{64.7, 18.83086180008104}], 
        PointBox[{64.8, 16.4668705405129}], 
        PointBox[{64.9, 13.20854861967382}], 
        PointBox[{65., 12.155598917554016`}], 
        PointBox[{65.1, 10.164395198102284`}], 
        PointBox[{65.2, 7.086808163810929}], 
        PointBox[{65.3, 4.832629774406087}], 
        PointBox[{65.4, 3.3991846952412743`}], 
        PointBox[{65.5, -0.33832442847051425`}], 
        PointBox[{65.6, -2.090136258950224}], 
        PointBox[{65.7, -4.022375375643605}], 
        PointBox[{65.8, -6.857507074404566}], 
        PointBox[{65.9, -9.811310987206525}], 
        PointBox[{66., -10.06155056211719}], 
        PointBox[{66.1, -13.270238066936145`}], 
        PointBox[{66.2, -15.948324316479557`}], 
        PointBox[{66.3, -17.697420871641953`}], 
        PointBox[{66.4, -19.65111325038015}], 
        PointBox[{66.5, -23.188909353986674`}], 
        PointBox[{66.6, -24.617785438029387`}], 
        PointBox[{66.7, -27.019906973182515`}], 
        PointBox[{66.8, -30.07575996250671}], 
        PointBox[{66.9, -31.524664028147527`}], 
        PointBox[{67., -32.99263081313984}], 
        PointBox[{67.1, -36.15831403872289}], 
        PointBox[{67.2, -38.28378833845636}], 
        PointBox[{67.3, -39.63988491056807}], 
        PointBox[{67.4, -42.797343339872896`}], 
        PointBox[{67.5, -44.960062174723134`}], 
        PointBox[{67.6, -46.741028543045104`}], 
        PointBox[{67.7, -49.44165018381318}], 
        PointBox[{67.8, -52.12405322527047}], 
        PointBox[{67.9, -52.31867475992476}], 
        PointBox[{68., -55.209157783137925`}], 
        PointBox[{68.1, -57.7760241104188}], 
        PointBox[{68.2, -59.33015577232436}], 
        PointBox[{68.3, -60.723953415072174`}], 
        PointBox[{68.4, -64.35985895800695}], 
        PointBox[{68.5, -65.57743243336154}], 
        PointBox[{68.6, -67.7661747300881}], 
        PointBox[{68.7, -70.44999003256089}], 
        PointBox[{68.8, -72.00600624433719}], 
        PointBox[{68.9, -72.5406678954314}], 
        PointBox[{69., -75.6519528847275}], 
        PointBox[{69.1, -77.51486444997863}], 
        PointBox[{69.2, -78.57258176129835}], 
        PointBox[{69.3, -80.57722652265511}], 
        PointBox[{69.4, -83.37287843888043}], 
        PointBox[{69.5, -84.54877553674305}], 
        PointBox[{69.6, -86.92988786708156}], 
        PointBox[{69.7, -89.12257770158612}], 
        PointBox[{69.8, -89.61606227716402}], 
        PointBox[{69.9, -91.13174963270285}], 
        PointBox[{70., -93.6703090008159}], 
        PointBox[{70.1, -94.85420918047748}], 
        PointBox[{70.2, -95.58251090610429}], 
        PointBox[{70.3, -98.29227863541018}], 
        PointBox[{70.4, -99.7799150278006}], 
        PointBox[{70.5, -101.21501019038988`}], 
        PointBox[{70.6, -103.50774148066557`}], 
        PointBox[{70.7, -104.9002155811686}], 
        PointBox[{70.8, -104.8744592805233}], 
        PointBox[{70.9, -107.08082489026128`}], 
        PointBox[{71., -108.85893932069303`}], 
        PointBox[{71.1, -109.41882837296725`}], 
        PointBox[{71.2, -110.02023247613397`}], 
        PointBox[{71.3, -112.91443806597817`}], 
        PointBox[{71.4, -113.4407704890109}], 
        PointBox[{71.5, -115.04394592763128`}], 
        PointBox[{71.6, -117.00559029207216`}], 
        PointBox[{71.7, -117.96874735093297`}], 
        PointBox[{71.8, -117.66203846547432`}], 
        PointBox[{71.9, -119.99708933634247`}], 
        PointBox[{72., -121.06377758175222`}], 
        PointBox[{72.1, -121.06481578657986`}], 
        PointBox[{72.2, -121.65694164659362`}], 
        PointBox[{72.3, -124.22759354889422`}], 
        PointBox[{72.4, -124.20348900422687`}], 
        PointBox[{72.5, -125.82346465722367`}], 
        PointBox[{72.6, -127.40122698801133`}], 
        PointBox[{72.7, -128.29667879998306`}], 
        PointBox[{72.8, -127.77272600713331`}], 
        PointBox[{72.9, -129.9252858022155}], 
        PointBox[{73., -130.39684230334387`}], 
        PointBox[{73.1, -129.90304670009937`}], 
        PointBox[{73.2, -130.46084517597046`}], 
        PointBox[{73.3, -132.56504629073606`}], 
        PointBox[{73.4, -132.1560475025326}], 
        PointBox[{73.5, -133.6919343735426}], 
        PointBox[{73.6, -135.07408214554016`}], 
        PointBox[{73.7, -135.97185686607554`}], 
        PointBox[{73.8, -135.21248211351485`}], 
        PointBox[{73.9, -137.13402227882034`}], 
        PointBox[{74., -137.15335414400033`}], 
        PointBox[{74.1, -136.21359723508067`}], 
        PointBox[{74.2, -136.6211391286488}], 
        PointBox[{74.3, -138.3791968896985}], 
        PointBox[{74.4, -137.59432663708867`}], 
        PointBox[{74.5, -138.98102792252757`}], 
        PointBox[{74.6, -140.3733105841602}], 
        PointBox[{74.7, -141.29517866179958`}], 
        PointBox[{74.8, -140.20461785195948`}], 
        PointBox[{74.9, -141.94631203560857`}], 
        PointBox[{75., -141.67790627485374`}], 
        PointBox[{75.1, -140.3228679011445}], 
        PointBox[{75.2, -140.43763711330394`}], 
        PointBox[{75.3, -142.05196540051838`}], 
        PointBox[{75.4, -140.87234094880114`}], 
        PointBox[{75.5, -142.02414386198507`}], 
        PointBox[{75.6, -143.506706266322}], 
        PointBox[{75.7, -144.5505108725847}], 
        PointBox[{75.8, -143.048269384788}], 
        PointBox[{75.9, -144.63153640328528`}], 
        PointBox[{76., -144.26832145123626`}], 
        PointBox[{76.1, -142.5236002441452}], 
        PointBox[{76.2, -142.20006976885634`}], 
        PointBox[{76.3, -143.83191477649234`}], 
        PointBox[{76.4, -142.3097822909549}], 
        PointBox[{76.5, -143.07392973183596`}], 
        PointBox[{76.6, -144.6408517125019}], 
        PointBox[{76.7, -145.92587323057523`}], 
        PointBox[{76.8, -144.03729111052235`}], 
        PointBox[{76.9, -145.36091812762606`}], 
        PointBox[{77., -145.1318974113383}], 
        PointBox[{77.1, -143.0439255289166}], 
        PointBox[{77.2, -142.14006701120525`}], 
        PointBox[{77.3, -143.82431559934048`}], 
        PointBox[{77.4, -142.16805452724657`}], 
        PointBox[{77.5, -142.3107151266231}], 
        PointBox[{77.6, -143.92194963325164`}], 
        PointBox[{77.7, -145.49009315463627`}], 
        PointBox[{77.8, -143.43018001270684`}], 
        PointBox[{77.9, -144.21312653535279`}], 
        PointBox[{78., -144.37178360174585`}], 
        PointBox[{78.1, -142.04462046024855`}], 
        PointBox[{78.2, -140.43225998566777`}], 
        PointBox[{78.3, -142.02646281915804`}], 
        PointBox[{78.4, -140.63977501876798`}], 
        PointBox[{78.5, -139.88135088642593`}], 
        PointBox[{78.6, -141.4525041369052}], 
        PointBox[{78.7, -143.19872331321676`}], 
        PointBox[{78.8, -141.4112424292689}], 
        PointBox[{78.9, -141.22266809391294`}], 
        PointBox[{79., -141.97813150043658`}], 
        PointBox[{79.1, -139.6217931054125}], 
        PointBox[{79.2, -137.20648345109657`}], 
        PointBox[{79.3, -138.3981181440031}], 
        PointBox[{79.4, -137.7981601880092}], 
        PointBox[{79.5, -135.93625086527027`}], 
        PointBox[{79.6, -137.25258253811626`}], 
        PointBox[{79.7, -138.950921156189}], 
        PointBox[{79.8, -138.01993702570326`}], 
        PointBox[{79.9, -136.45744787080184`}], 
        PointBox[{80., -137.81748133780638`}], 
        PointBox[{80.1, -135.7968762089513}], 
        PointBox[{80.2, -132.55486198197468`}], 
        PointBox[{80.3, -132.92923696400248`}], 
        PointBox[{80.4, -133.506622580775}], 
        PointBox[{80.5, -130.65649302668317`}], 
        PointBox[{80.6, -131.28904620748654`}], 
        PointBox[{80.7, -132.80060818923812`}], 
        PointBox[{80.8, -133.07158871978027`}], 
        PointBox[{80.9, -130.08461834710033`}], 
        PointBox[{81., -131.6424966169725}], 
        PointBox[{81.1, -130.4799237491534}], 
        PointBox[{81.2, -126.531355552288}], 
        PointBox[{81.3, -125.64818575619574`}], 
        PointBox[{81.4, -127.38051522129535`}], 
        PointBox[{81.5, -124.2294107034977}], 
        PointBox[{81.6, -123.55969646340964`}], 
        PointBox[{81.7, -125.07948893715366`}], 
        PointBox[{81.8, -126.10889286721795`}], 
        PointBox[{81.9, -122.32076454190246`}], 
        PointBox[{82., -123.14263727531943`}], 
        PointBox[{82.1, -123.38271882884874`}], 
        PointBox[{82.2, -119.11623701237113`}], 
        PointBox[{82.3, -116.55655238912004`}], 
        PointBox[{82.4, -118.9130675703127}], 
        PointBox[{82.5, -116.68805956123106`}], 
        PointBox[{82.6, -114.12029209213506`}], 
        PointBox[{82.7, -115.63861764089233`}], 
        PointBox[{82.8, -116.53109802481777`}], 
        PointBox[{82.9, -113.18251650522143`}], 
        PointBox[{83., -112.0048726541063}], 
        PointBox[{83.1, -113.88028896605829`}], 
        PointBox[{83.2, -110.0944653052502}], 
        PointBox[{83.3, -105.4955417159872}], 
        PointBox[{83.4, -107.59928772514104`}], 
        PointBox[{83.5, -107.56373897845333`}], 
        PointBox[{83.6, -103.01305215560569`}], 
        PointBox[{83.7, -103.74926826966112`}], 
        PointBox[{83.8, -104.48440395210491`}], 
        PointBox[{83.9, -102.02121284255554`}], 
        PointBox[{84., -97.75128470975324}], 
        PointBox[{84.1, -100.77848608740169`}], 
        PointBox[{84.2, -98.68444789245405}], 
        PointBox[{84.3, -91.83108077655197}], 
        PointBox[{84.4, -92.66076538922789}], 
        PointBox[{84.5, -95.51046245249017}], 
        PointBox[{84.6, -89.93591277403902}], 
        PointBox[{84.7, -88.52549522605841}], 
        PointBox[{84.8, -90.42979154286877}], 
        PointBox[{84.9, -86.91388893824478}], 
        PointBox[{85., -78.84421115033183}], 
        PointBox[{85.1, -81.66078498142451}], 
        PointBox[{85.2, -82.54690352962643}], 
        PointBox[{85.3, -73.4693551634191}], 
        PointBox[{85.4, -71.96233177286194}], 
        PointBox[{85.5, -77.83620080747642}], 
        PointBox[{85.6, -73.11186057055602}], 
        PointBox[{85.7, -67.89989547088771}], 
        PointBox[{85.8, -71.15447457676783}], 
        PointBox[{85.9, -65.13031290104118}], 
        PointBox[{86., -50.01499048245023}], 
        PointBox[{86.1, -50.58221973056061}], 
        PointBox[{86.2, -55.01861808860849}], 
        PointBox[{86.3, -43.541875999362674`}], 
        PointBox[{86.4, -39.2823186831738}], 
        PointBox[{86.5, -48.581784676258394`}], 
        PointBox[{86.6, -45.97284770887927}], 
        PointBox[{86.7, -35.38625822704489}], 
        PointBox[{86.8, -39.481164094751875`}], 
        PointBox[{86.9, -34.10487550263497}], 
        PointBox[{87., -3.232341173250461}], 
        PointBox[{87.1, 0.308967324817786}], 
        PointBox[{87.2, -5.241886461444665}], 
        PointBox[{87.3, 8.244580717859208}], 
        PointBox[{87.4, 11.853263700999378`}], 
        PointBox[{87.5, 0.26016850678570336`}], 
        PointBox[{87.6, 3.5262663847461226`}], 
        PointBox[{87.7, 17.495596997810935`}], 
        PointBox[{87.8, 12.12531667829171}], 
        PointBox[{87.9, 13.805996806833718`}], 
        PointBox[{88., 41.25831641802506}], 
        PointBox[{88.1, 48.06861805777589}], 
        PointBox[{88.2, 43.96228802874248}], 
        PointBox[{88.3, 52.94828594288265}], 
        PointBox[{88.4, 56.565504468431755`}], 
        PointBox[{88.5, 48.06120789430861}], 
        PointBox[{88.6, 51.2176371078458}], 
        PointBox[{88.7, 62.41145589280495}], 
        PointBox[{88.8, 59.03405349314562}], 
        PointBox[{88.9, 57.289628552076465`}], 
        PointBox[{89., 70.13938280393631}], 
        PointBox[{89.1, 76.06470190587424}], 
        PointBox[{89.2, 73.05223036314419}], 
        PointBox[{89.3, 76.98108630516799}], 
        PointBox[{89.4, 82.37481339686201}], 
        PointBox[{89.5, 77.28845087438822}], 
        PointBox[{89.6, 77.80155123666191}], 
        PointBox[{89.7, 86.46289906023594}], 
        PointBox[{89.8, 86.63500826634845}], 
        PointBox[{89.9, 83.42082206576742}], 
        PointBox[{90., 90.4242880201491}], PointBox[{90.1, 93.6724925586459}],
         PointBox[{90.2, 92.22986918087554}], 
        PointBox[{90.3, 92.81228549811203}], 
        PointBox[{90.4, 98.36759960627387}], 
        PointBox[{90.5, 96.39869312012888}], 
        PointBox[{90.6, 94.94532800970046}], 
        PointBox[{90.7, 101.20993238455412`}], 
        PointBox[{90.8, 104.0362518050897}], 
        PointBox[{90.9, 101.17979423397628`}], 
        PointBox[{91., 104.44536111660273`}], 
        PointBox[{91.1, 107.22874581180076`}], 
        PointBox[{91.2, 106.6186203557736}], 
        PointBox[{91.3, 105.49836491203314`}], 
        PointBox[{91.4, 109.5558318766416}], 
        PointBox[{91.5, 110.40093487055128`}], 
        PointBox[{91.6, 108.03377281245776`}], 
        PointBox[{91.7, 112.00471265074157`}], 
        PointBox[{91.8, 116.133638670668}], 
        PointBox[{91.9, 114.72194402685273`}], 
        PointBox[{92., 115.12304606837279`}], 
        PointBox[{92.1, 118.83641072150203`}], 
        PointBox[{92.2, 117.88280061240948`}], 
        PointBox[{92.3, 116.30504606314935`}], 
        PointBox[{92.4, 118.27044428870431`}], 
        PointBox[{92.5, 120.98083883183426`}], 
        PointBox[{92.6, 118.69653644434584`}], 
        PointBox[{92.7, 120.68205211588065`}], 
        PointBox[{92.8, 124.98705075525504`}], 
        PointBox[{92.9, 125.2403426728124}], 
        PointBox[{93., 124.03058370255167`}], 
        PointBox[{93.1, 127.73551793229126`}], 
        PointBox[{93.2, 126.8915221636853}], 
        PointBox[{93.3, 125.40938963385997`}], 
        PointBox[{93.4, 125.60738920251606`}], 
        PointBox[{93.5, 128.8244405118603}], 
        PointBox[{93.6, 127.42255605396349`}], 
        PointBox[{93.7, 127.83183020328579`}], 
        PointBox[{93.8, 131.63827688718447`}], 
        PointBox[{93.9, 133.16848423275223`}], 
        PointBox[{94., 131.5804667493503}], 
        PointBox[{94.1, 134.1607397964981}], 
        PointBox[{94.2, 134.3193789452489}], 
        PointBox[{94.3, 132.76426681506564`}], 
        PointBox[{94.4, 131.85343888073112`}], 
        PointBox[{94.5, 134.46468617024948`}], 
        PointBox[{94.6, 134.32060654142697`}], 
        PointBox[{94.7, 133.60189787330455`}], 
        PointBox[{94.8, 136.616296939319}], 
        PointBox[{94.9, 138.84342206915608`}], 
        PointBox[{95., 137.6620251567365}], 
        PointBox[{95.1, 138.7381796000991}], 
        PointBox[{95.2, 140.07300327785197`}], 
        PointBox[{95.3, 138.3370883558091}], 
        PointBox[{95.4, 136.90152853824839`}], 
        PointBox[{95.5, 138.4103695675003}], 
        PointBox[{95.6, 139.37754267694254`}], 
        PointBox[{95.7, 137.98712628497742`}], 
        PointBox[{95.8, 140.14626085446798`}], 
        PointBox[{95.9, 142.57880055559508`}], 
        PointBox[{96., 142.0601293896325}], 
        PointBox[{96.1, 141.85330590813828`}], 
        PointBox[{96.2, 143.85791647140286`}], 
        PointBox[{96.3, 142.1550883736927}], 
        PointBox[{96.4, 140.55697059172962`}], 
        PointBox[{96.5, 140.98571232199902`}], 
        PointBox[{96.6, 142.57927251709043`}], 
        PointBox[{96.7, 140.92339748048107`}], 
        PointBox[{96.8, 142.2820471419691}], 
        PointBox[{96.9, 144.60081741883187`}], 
        PointBox[{97., 144.64556367511977`}], 
        PointBox[{97.1, 143.61717445455724`}], 
        PointBox[{97.2, 145.70852198947978`}], 
        PointBox[{97.3, 144.25191361589532`}], 
        PointBox[{97.4, 142.64983993234637`}], 
        PointBox[{97.5, 142.25495990646596`}], 
        PointBox[{97.6, 143.95752920601808`}], 
        PointBox[{97.7, 142.30938559579954`}], 
        PointBox[{97.8, 142.9793381713098}], 
        PointBox[{97.9, 145.0112559315894}], 
        PointBox[{98., 145.3774171107798}], 
        PointBox[{98.1, 143.93543816107558`}], 
        PointBox[{98.2, 145.73214241309324`}], 
        PointBox[{98.3, 144.58186963789922`}], 
        PointBox[{98.4, 143.03747523060883`}], 
        PointBox[{98.5, 142.0998646945518}], 
        PointBox[{98.6, 143.56142676276795`}], 
        PointBox[{98.7, 142.00700887906714`}], 
        PointBox[{98.8, 142.12609539326513`}], 
        PointBox[{98.9, 143.79131122044055`}], 
        PointBox[{99., 144.2251233577117}], 
        PointBox[{99.1, 142.59525502545875`}], 
        PointBox[{99.2, 143.95154923654627`}], 
        PointBox[{99.3, 143.0247320675844}], 
        PointBox[{99.4, 141.57346456166124`}], 
        PointBox[{99.5, 140.30675801847246`}], 
        PointBox[{99.6, 141.3783130574011}], 
        PointBox[{99.7, 139.8313579196256}], 
        PointBox[{99.8, 139.54611225993722`}], 
        PointBox[{99.9, 140.8120850916457}], 
        PointBox[{100., 141.09516458128928`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {-180, 180}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \
\\\"input\\\" -> \\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-328., 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.880463192567504*^9, 3.8804640720848007`*^9, 
  3.8804642139321127`*^9, 3.88061297064888*^9, 3.8806131021737556`*^9, 
  3.880655522035261*^9, 3.880702742321411*^9, 3.880703457955772*^9, 
  3.890982082547735*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"b87fdc48-73f6-4701-b743-6f2428472fe3"]
}, Open  ]],

Cell["\<\
Produce the four labelled plots for the case of 2:1 resonance large libration \
amplitude.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8806136263053503`*^9, 
   3.880613658479388*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6aefa2d8-de2e-40c6-a44f-85cd518bf32c"],

Cell[BoxData[
 RowBox[{"FourPlot", "[", 
  RowBox[{"0.001", ",", " ", "init3", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.8804582595986767`*^9, 3.8804582601843576`*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"035ee2c0-f185-42cb-bd20-8ad2df6211b6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcC", "=", "gc"}]], "Input",
 CellChangeTimes->{{3.880458264285612*^9, 3.880458270518504*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"16f013e4-e382-42c4-92f9-f594159547ae"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJxFm3dcjX/8/jMKlaiIzPaSNGmfq73r7HMyE0LChyiFZGWVvbL5fGSVlRUi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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0.6000000000000013},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0.6, 
           FormBox["0.6`", TraditionalForm]}, {0.62, 
           FormBox["0.62`", TraditionalForm]}, {0.64, 
           FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0.6, 0.65}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Prolog->{
        Dashing[{Small, Small}], 
        LineBox[{{0, 0.629961}, {100, 0.629961}}]},
      Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
     ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJw9m3lcjO37/lMkJCmhbEWiEq0qbUf7NtVMzZY1JEtZk2QrJCTSQrtSCZV2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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {0.1, 
           FormBox["0.1`", TraditionalForm]}, {0.2, 
           FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 0.2}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -159.99}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJxdmnc81e///6XQ0KRBEpKV7L3Ow96c6Ryld5OmkhUtUimlIUU7LS1K0dBU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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}, {360, 
           FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 360.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJxdm3k81O/3/odKiqQokXdN9kQlJSTuUGSJ7LshSaWVFq3Tpk1alNKqTQtp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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[CurlyPhi]\
\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{-180, 
           FormBox[
            RowBox[{"-", "180"}], TraditionalForm]}, {0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {-180., 180.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -383.19}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-438.99, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.880458272033617*^9, 3.880463523901162*^9, 
  3.880464073548829*^9, 3.880464215131425*^9, 3.88061297200521*^9, 
  3.880613103907867*^9, 3.880655523073434*^9, 3.880702743434886*^9, 
  3.88070345908296*^9, 3.890982083757834*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"49e8d0d7-9307-49c9-b06c-8c35093c677e"]
}, Open  ]],

Cell["\<\
Produce the x-y plot for the case of 2:1 resonance large libration amplitude. \
 This is Fig.8.17c.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.880463224309616*^9, 
   3.88046322774268*^9}, {3.880613674374978*^9, 3.880613680695437*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b051e585-5e20-4928-8437-275c9a2f3fee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xyC", "=", "xyplot"}]], "Input",
 CellChangeTimes->{{3.880458277050151*^9, 3.880458283883898*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"31a8ca30-d2d7-4b1b-8df6-48fd15deff7d"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwtl3c81e/7x81jNRDJiCSRkFLR4H4blZSSUZGQhhUq+WiQzBQaZIQS2cmo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     "]]}, {{}, {}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-4., 4.}, {-4., 4.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Prolog->{
    Thickness[0.002], 
    LineBox[{{0, -4}, {0, 4}}], 
    LineBox[{{-4, 0}, {4, 0}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.880458284618701*^9, 3.880459516424675*^9, 
  3.880463233327229*^9, 3.880464073653989*^9, 3.880464215201725*^9, 
  3.880612972071671*^9, 3.880613104022078*^9, 3.880655523126388*^9, 
  3.88070274349091*^9, 3.880703459163333*^9, 3.890982083818388*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"affb830f-ef8d-45fd-aafb-c8888a3c53af"]
}, Open  ]],

Cell["\<\
Produce the four unlabelled plots for the case of 2:1 resonance apocentric \
libration.  This is Fig.8.16d.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, {3.8806136903256893`*^9, 3.880613702295349*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"690c46c5-db0e-456b-8da8-4885f0be8c0c"],

Cell[BoxData[
 RowBox[{"FourPlotNoLabel", "[", 
  RowBox[{"0.001", ",", " ", "init4", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.88046267960392*^9, 3.880462680234071*^9}, {
  3.880463182008906*^9, 3.880463182578125*^9}, {3.880463259858301*^9, 
  3.880463260503047*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"629ee2f7-9ddd-4948-bb78-428bc3737601"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcNLD", "=", "gcNL"}]], "Input",
 CellChangeTimes->{{3.880463026210558*^9, 3.88046302986303*^9}, {
  3.880463083413727*^9, 3.880463090373127*^9}, {3.880463186522532*^9, 
  3.880463187214306*^9}, {3.880463263263054*^9, 3.880463264012458*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"ede0cd79-f83f-435f-9ef4-912a171a7952"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
       {Dashing[{Small, Small}], LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], 
        PointBox[{0, 0.6367050000000001}], 
        PointBox[{0.1, 0.6350092605023289}], 
        PointBox[{0.2, 0.6353004364442035}], 
        PointBox[{0.3, 0.6377817112031924}], 
        PointBox[{0.4, 0.6395947951698812}], 
        PointBox[{0.5, 0.6400942952636646}], 
        PointBox[{0.6, 0.639901678974486}], 
        PointBox[{0.7, 0.6386740514285693}], 
        PointBox[{0.8, 0.6361235554255612}], 
        PointBox[{0.9, 0.6347721259106133}], 
        PointBox[{1., 0.6362134486072962}], 
        PointBox[{1.1, 0.635708824648922}], 
        PointBox[{1.2, 0.6348603734366041}], 
        PointBox[{1.3, 0.6367817422024687}], 
        PointBox[{1.4, 0.6391187089187318}], 
        PointBox[{1.5, 0.6400283073365283}], 
        PointBox[{1.6, 0.6400930158221213}], 
        PointBox[{1.7, 0.6393634968169988}], 
        PointBox[{1.8, 0.6371759867829101}], 
        PointBox[{1.9, 0.6350112845402167}], 
        PointBox[{2., 0.6354114173649766}], 
        PointBox[{2.1, 0.6365684728591865}], 
        PointBox[{2.2, 0.6348779364680401}], 
        PointBox[{2.3, 0.6358671847535954}], 
        PointBox[{2.4, 0.6384305752476532}], 
        PointBox[{2.5, 0.6398699005128076}], 
        PointBox[{2.6, 0.6402055616931487}], 
        PointBox[{2.7, 0.6398534052472269}], 
        PointBox[{2.8, 0.6382457022062125}], 
        PointBox[{2.9, 0.6356906584787828}], 
        PointBox[{3., 0.6349683404321692}], 
        PointBox[{3.1, 0.636703280084763}], 
        PointBox[{3.2, 0.6353828179605941}], 
        PointBox[{3.3, 0.635242049179769}], 
        PointBox[{3.4, 0.6375536274188583}], 
        PointBox[{3.5, 0.639568055547136}], 
        PointBox[{3.6, 0.640249128789902}], 
        PointBox[{3.7, 0.6401905912658623}], 
        PointBox[{3.8, 0.6391610793719337}], 
        PointBox[{3.9, 0.6367116343058997}], 
        PointBox[{4., 0.6350129308440805}], 
        PointBox[{4.1, 0.6360033414207804}], 
        PointBox[{4.2, 0.6362935804360188}], 
        PointBox[{4.3, 0.6350370636863896}], 
        PointBox[{4.4, 0.636624122703736}], 
        PointBox[{4.5, 0.6390628191653028}], 
        PointBox[{4.6, 0.6402056861770162}], 
        PointBox[{4.7, 0.6404185649848402}], 
        PointBox[{4.8, 0.6398584805871099}], 
        PointBox[{4.9, 0.6378853485702995}], 
        PointBox[{5., 0.6355307409709158}], 
        PointBox[{5.1, 0.6353869540462587}], 
        PointBox[{5.2, 0.6369900156519912}], 
        PointBox[{5.3, 0.6353162806107456}], 
        PointBox[{5.4, 0.635855145102574}], 
        PointBox[{5.5, 0.6383282603311301}], 
        PointBox[{5.6, 0.6400297801803619}], 
        PointBox[{5.7, 0.6405570662632886}], 
        PointBox[{5.8, 0.6403568374127758}], 
        PointBox[{5.9, 0.6389925343170602}], 
        PointBox[{6., 0.6364608227323832}], 
        PointBox[{6.1, 0.6352457523045916}], 
        PointBox[{6.2, 0.6366482598046072}], 
        PointBox[{6.3, 0.6360934733021741}], 
        PointBox[{6.4, 0.6354381886785722}], 
        PointBox[{6.5, 0.6374369825234081}], 
        PointBox[{6.6, 0.6396570649806084}], 
        PointBox[{6.7, 0.6405971188186597}], 
        PointBox[{6.8, 0.6407002102503668}], 
        PointBox[{6.9, 0.6398910419671865}], 
        PointBox[{7., 0.6376536758081902}], 
        PointBox[{7.1, 0.6356053332531285}], 
        PointBox[{7.2, 0.6359327711889031}], 
        PointBox[{7.3, 0.6370634675885509}], 
        PointBox[{7.4, 0.6354859820227413}], 
        PointBox[{7.5, 0.6365785180596097}], 
        PointBox[{7.6, 0.6390366708585392}], 
        PointBox[{7.7, 0.6405003097856902}], 
        PointBox[{7.8, 0.6409187249826703}], 
        PointBox[{7.9, 0.640550128220211}], 
        PointBox[{8., 0.6388804482579862}], 
        PointBox[{8.1, 0.6364198678878035}], 
        PointBox[{8.2, 0.6356149115677713}], 
        PointBox[{8.3, 0.6372041896137665}], 
        PointBox[{8.4, 0.636057841521243}], 
        PointBox[{8.5, 0.6359788330460152}], 
        PointBox[{8.6, 0.6381934337822145}], 
        PointBox[{8.7, 0.640203892624574}], 
        PointBox[{8.8, 0.6410133726956067}], 
        PointBox[{8.9, 0.6410010594492023}], 
        PointBox[{9., 0.639936046639441}], 
        PointBox[{9.1, 0.6375698402021175}], 
        PointBox[{9.2, 0.6358241030501801}], 
        PointBox[{9.3, 0.6365026453255405}], 
        PointBox[{9.4, 0.637047253500587}], 
        PointBox[{9.5, 0.6358056555421203}], 
        PointBox[{9.6, 0.637280078127473}], 
        PointBox[{9.7, 0.6396459136365823}], 
        PointBox[{9.8, 0.640953908364837}], 
        PointBox[{9.9, 0.6412808706294624}], 
        PointBox[{10., 0.6407285434137238}], 
        PointBox[{10.1, 0.6388366966135456}], 
        PointBox[{10.2, 0.6365180704728498}], 
        PointBox[{10.3, 0.6360209269907801}], 
        PointBox[{10.4, 0.6375914365919316}], 
        PointBox[{10.5, 0.6361543066945926}], 
        PointBox[{10.6, 0.6365331019525321}], 
        PointBox[{10.7, 0.6388240889626644}], 
        PointBox[{10.8, 0.6406821162231523}], 
        PointBox[{10.9, 0.6414018917571728}], 
        PointBox[{11., 0.6412634048308603}], 
        PointBox[{11.1, 0.6399791419984386}], 
        PointBox[{11.2, 0.6375898807749996}], 
        PointBox[{11.3, 0.6360816195286709}], 
        PointBox[{11.4, 0.6370080870759294}], 
        PointBox[{11.5, 0.6370239113910938}], 
        PointBox[{11.6, 0.6361605906112554}], 
        PointBox[{11.7, 0.6378609517365138}], 
        PointBox[{11.8, 0.6401340827239984}], 
        PointBox[{11.9, 0.641344172847682}], 
        PointBox[{12., 0.6415790523748394}], 
        PointBox[{12.1, 0.6408524756593059}], 
        PointBox[{12.2, 0.6388326859229929}], 
        PointBox[{12.3, 0.6366528566297726}], 
        PointBox[{12.4, 0.6363790771123831}], 
        PointBox[{12.5, 0.637800390668904}], 
        PointBox[{12.6, 0.6362942767899629}], 
        PointBox[{12.7, 0.6369904455689986}], 
        PointBox[{12.8, 0.6392949219851162}], 
        PointBox[{12.9, 0.6410577145995568}], 
        PointBox[{13., 0.6417000496875226}], 
        PointBox[{13.1, 0.6414321505312277}], 
        PointBox[{13.2, 0.6399911375618021}], 
        PointBox[{13.3, 0.6376269212950342}], 
        PointBox[{13.4, 0.6362867118059684}], 
        PointBox[{13.5, 0.6373936266275528}], 
        PointBox[{13.6, 0.636989176737318}], 
        PointBox[{13.7, 0.6364465172940522}], 
        PointBox[{13.8, 0.6382701586311316}], 
        PointBox[{13.9, 0.6404820806906473}], 
        PointBox[{14., 0.6416193115284599}], 
        PointBox[{14.1, 0.6417540427078021}], 
        PointBox[{14.2, 0.6408848105658553}], 
        PointBox[{14.3, 0.6388043359211769}], 
        PointBox[{14.4, 0.6367271117910237}], 
        PointBox[{14.5, 0.63663604988301}], 
        PointBox[{14.6, 0.6378476705068635}], 
        PointBox[{14.7, 0.6363865934245031}], 
        PointBox[{14.8, 0.6372882066765083}], 
        PointBox[{14.9, 0.6395980370420117}], 
        PointBox[{15., 0.6412977325004331}], 
        PointBox[{15.1, 0.6418537615726306}], 
        PointBox[{15.2, 0.6414656286898308}], 
        PointBox[{15.3, 0.639925633722048}], 
        PointBox[{15.4, 0.6375891449086477}], 
        PointBox[{15.5, 0.6363787910304218}], 
        PointBox[{15.6, 0.63763749060127}], 
        PointBox[{15.7, 0.6368961606298916}], 
        PointBox[{15.8, 0.636597696808407}], 
        PointBox[{15.9, 0.6385020479619195}], 
        PointBox[{16., 0.6406819500247813}], 
        PointBox[{16.1, 0.6417391681601999}], 
        PointBox[{16.2, 0.6417668771714828}], 
        PointBox[{16.3, 0.6407929902126949}], 
        PointBox[{16.4, 0.6386786516318753}], 
        PointBox[{16.5, 0.6366731955869149}], 
        PointBox[{16.6, 0.636777385408561}], 
        PointBox[{16.7, 0.6377417195810269}], 
        PointBox[{16.8, 0.6363699431166749}], 
        PointBox[{16.9, 0.6374177145787099}], 
        PointBox[{17., 0.6397514845298546}], 
        PointBox[{17.1, 0.6413848185375763}], 
        PointBox[{17.2, 0.6418342838453002}], 
        PointBox[{17.3, 0.6413435920135595}], 
        PointBox[{17.4, 0.6397367650591473}], 
        PointBox[{17.5, 0.637408757383328}], 
        PointBox[{17.6, 0.6363394378619194}], 
        PointBox[{17.7, 0.6377423220729849}], 
        PointBox[{17.8, 0.6367028139225271}], 
        PointBox[{17.9, 0.6365996109702504}], 
        PointBox[{18., 0.6385910719946903}], 
        PointBox[{18.1, 0.6407447297992046}], 
        PointBox[{18.2, 0.6416901624826896}], 
        PointBox[{18.3, 0.64160953640234}], 
        PointBox[{18.4, 0.6405575115045437}], 
        PointBox[{18.5, 0.6383994689184908}], 
        PointBox[{18.6, 0.6364643680486103}], 
        PointBox[{18.7, 0.636826559544134}], 
        PointBox[{18.8, 0.6374806450363293}], 
        PointBox[{18.9, 0.636225297357509}], 
        PointBox[{19., 0.6374168175110473}], 
        PointBox[{19.1, 0.6397943137012596}], 
        PointBox[{19.2, 0.6413234176544937}], 
        PointBox[{19.3, 0.6416455859845042}], 
        PointBox[{19.4, 0.6410693155324935}], 
        PointBox[{19.5, 0.639392958262966}], 
        PointBox[{19.6, 0.6370541773628496}], 
        PointBox[{19.7, 0.6361945680897493}], 
        PointBox[{19.8, 0.6377130919332121}], 
        PointBox[{19.9, 0.6363932244259443}], 
        PointBox[{20., 0.6364852784406002}], 
        PointBox[{20.1, 0.6386006516492823}], 
        PointBox[{20.2, 0.6406973327243352}], 
        PointBox[{20.3, 0.6414881954981432}], 
        PointBox[{20.4, 0.6413044349116402}], 
        PointBox[{20.5, 0.6401770500363503}], 
        PointBox[{20.6, 0.6379414857343384}], 
        PointBox[{20.7, 0.6361242398183548}], 
        PointBox[{20.8, 0.6368364347813277}], 
        PointBox[{20.9, 0.6370682138437216}], 
        PointBox[{21., 0.6359785809632891}], 
        PointBox[{21.1, 0.6373604225436245}], 
        PointBox[{21.2, 0.6397801225610594}], 
        PointBox[{21.3, 0.6411403092850695}], 
        PointBox[{21.4, 0.6413246879338061}], 
        PointBox[{21.5, 0.6406692162420208}], 
        PointBox[{21.6, 0.6388860103594994}], 
        PointBox[{21.7, 0.6365443652322017}], 
        PointBox[{21.8, 0.6360152884673713}], 
        PointBox[{21.9, 0.6375405149640928}], 
        PointBox[{22., 0.6359903055892715}], 
        PointBox[{22.1, 0.6363285173234176}], 
        PointBox[{22.2, 0.6386091160782652}], 
        PointBox[{22.3, 0.6405747792708456}], 
        PointBox[{22.4, 0.6411774002050589}], 
        PointBox[{22.5, 0.6408979261154386}], 
        PointBox[{22.6, 0.6396663627232668}], 
        PointBox[{22.7, 0.6373172098784416}], 
        PointBox[{22.8, 0.6357268140595878}], 
        PointBox[{22.9, 0.6368635478204917}], 
        PointBox[{23., 0.6365311280435977}], 
        PointBox[{23.1, 0.6356947398698172}], 
        PointBox[{23.2, 0.6373442168496906}], 
        PointBox[{23.3, 0.6397537752056572}], 
        PointBox[{23.4, 0.6408784030290133}], 
        PointBox[{23.5, 0.6409292602352513}], 
        PointBox[{23.6, 0.6401802312611283}], 
        PointBox[{23.7, 0.6382274345621585}], 
        PointBox[{23.8, 0.6359488541041303}], 
        PointBox[{23.9, 0.6358980934361919}], 
        PointBox[{24., 0.6371926605135205}], 
        PointBox[{24.1, 0.6355520979900825}], 
        PointBox[{24.2, 0.6362280713967632}], 
        PointBox[{24.3, 0.6386787933239064}], 
        PointBox[{24.4, 0.6404118678799143}], 
        PointBox[{24.5, 0.6408184177829371}], 
        PointBox[{24.6, 0.6404438859889862}], 
        PointBox[{24.7, 0.6390464337272983}], 
        PointBox[{24.8, 0.6365818424036509}], 
        PointBox[{24.9, 0.6353826290875549}], 
        PointBox[{25., 0.636918558806029}], 
        PointBox[{25.1, 0.6359316996879592}], 
        PointBox[{25.2, 0.6354673498055006}], 
        PointBox[{25.3, 0.6374526032461525}], 
        PointBox[{25.4, 0.6397393635459806}], 
        PointBox[{25.5, 0.6405917993066261}], 
        PointBox[{25.6, 0.6405218315679854}], 
        PointBox[{25.7, 0.6396371898918447}], 
        PointBox[{25.8, 0.6374540415062412}], 
        PointBox[{25.9, 0.635383494290101}], 
        PointBox[{26., 0.6359355731847061}], 
        PointBox[{26.1, 0.636661343961369}], 
        PointBox[{26.2, 0.6351673851996693}], 
        PointBox[{26.3, 0.6362865907175687}], 
        PointBox[{26.4, 0.6388316496804356}], 
        PointBox[{26.5, 0.6402448610615287}], 
        PointBox[{26.6, 0.6404745375155194}], 
        PointBox[{26.7, 0.6399877247223378}], 
        PointBox[{26.8, 0.6383386861136092}], 
        PointBox[{26.9, 0.6358391099113984}], 
        PointBox[{27., 0.635207368626817}], 
        PointBox[{27.1, 0.6369129246077548}], 
        PointBox[{27.2, 0.6353665774961671}], 
        PointBox[{27.3, 0.6354016321191108}], 
        PointBox[{27.4, 0.6377260844526453}], 
        PointBox[{27.5, 0.6397444642175364}], 
        PointBox[{27.6, 0.6403359797563765}], 
        PointBox[{27.7, 0.6401529500195735}], 
        PointBox[{27.8, 0.6390583867154296}], 
        PointBox[{27.9, 0.6366336860491963}], 
        PointBox[{28., 0.6349761541292676}], 
        PointBox[{28.1, 0.6361615275321291}], 
        PointBox[{28.2, 0.6360236385517908}], 
        PointBox[{28.3, 0.6349360254746503}], 
        PointBox[{28.4, 0.6365711638510948}], 
        PointBox[{28.5, 0.6390464406969133}], 
        PointBox[{28.6, 0.6401121802678879}], 
        PointBox[{28.7, 0.6401954117178662}], 
        PointBox[{28.8, 0.6395516539760712}], 
        PointBox[{28.9, 0.6375742576490738}], 
        PointBox[{29., 0.6352229300703371}], 
        PointBox[{29.1, 0.6352828136357646}], 
        PointBox[{29.2, 0.6366965585549976}], 
        PointBox[{29.3, 0.6349432176716653}], 
        PointBox[{29.4, 0.6355847687624336}], 
        PointBox[{29.5, 0.6381335637843772}], 
        PointBox[{29.6, 0.6397795178436009}], 
        PointBox[{29.7, 0.6401567382761836}], 
        PointBox[{29.8, 0.6398488934674513}], 
        PointBox[{29.9, 0.6384500839597763}], 
        PointBox[{30., 0.6358821562997892}], 
        PointBox[{30.1, 0.6348248857490734}], 
        PointBox[{30.2, 0.6364876210416204}], 
        PointBox[{30.3, 0.6354331562405795}], 
        PointBox[{30.4, 0.6349486027163366}], 
        PointBox[{30.5, 0.6370753277741151}], 
        PointBox[{30.6, 0.6392927842223008}], 
        PointBox[{30.7, 0.6400512603914633}], 
        PointBox[{30.8, 0.6400092716394385}], 
        PointBox[{30.9, 0.6391340186508802}], 
        PointBox[{31., 0.6368191961926238}], 
        PointBox[{31.1, 0.634850241951286}], 
        PointBox[{31.2, 0.6356263763300627}], 
        PointBox[{31.3, 0.6362536601770273}], 
        PointBox[{31.4, 0.6347545503939223}], 
        PointBox[{31.5, 0.6360463224231505}], 
        PointBox[{31.6, 0.6386056199261891}], 
        PointBox[{31.7, 0.6398667362749979}], 
        PointBox[{31.8, 0.6400818401701274}], 
        PointBox[{31.9, 0.639609072231279}], 
        PointBox[{32., 0.6378297455765984}], 
        PointBox[{32.1, 0.6353285600258467}], 
        PointBox[{32.2, 0.6349677567159291}], 
        PointBox[{32.3, 0.6366936734780985}], 
        PointBox[{32.4, 0.6350366053127202}], 
        PointBox[{32.5, 0.6352567361262424}], 
        PointBox[{32.6, 0.6377180366759992}], 
        PointBox[{32.7, 0.6395641587540781}], 
        PointBox[{32.8, 0.6400900334056119}], 
        PointBox[{32.9, 0.6399193700503097}], 
        PointBox[{33., 0.638725083792805}], 
        PointBox[{33.1, 0.6361842276801624}], 
        PointBox[{33.2, 0.6347760680107135}], 
        PointBox[{33.3, 0.6361580458923712}], 
        PointBox[{33.4, 0.6357747970627483}], 
        PointBox[{33.5, 0.6348568984710393}], 
        PointBox[{33.6, 0.6367317009876551}], 
        PointBox[{33.7, 0.6390890209618855}], 
        PointBox[{33.8, 0.6400314187425763}], 
        PointBox[{33.9, 0.6401180504196481}], 
        PointBox[{34., 0.6394162266843475}], 
        PointBox[{34.1, 0.6372581822501161}], 
        PointBox[{34.2, 0.6350589148897162}], 
        PointBox[{34.3, 0.6353798232904886}], 
        PointBox[{34.4, 0.636627231258674}], 
        PointBox[{34.5, 0.6349167692529448}], 
        PointBox[{34.6, 0.6358417003072969}], 
        PointBox[{34.7, 0.638399203791385}], 
        PointBox[{34.8, 0.639876124229211}], 
        PointBox[{34.9, 0.6402379696157785}], 
        PointBox[{35., 0.6399091357165873}], 
        PointBox[{35.1, 0.63833680465594}], 
        PointBox[{35.2, 0.6357777778430236}], 
        PointBox[{35.3, 0.6349824887727554}], 
        PointBox[{35.4, 0.6366917799350178}], 
        PointBox[{35.5, 0.6354648929544162}], 
        PointBox[{35.6, 0.6352496945470918}], 
        PointBox[{35.7, 0.6375235524653693}], 
        PointBox[{35.8, 0.6395705578492055}], 
        PointBox[{35.9, 0.6402859432258431}], 
        PointBox[{36., 0.6402502497350613}], 
        PointBox[{36.1, 0.6392533329307317}], 
        PointBox[{36.2, 0.6368285671637827}], 
        PointBox[{36.3, 0.6350743073657228}], 
        PointBox[{36.4, 0.6359751314322093}], 
        PointBox[{36.5, 0.6363998495377732}], 
        PointBox[{36.6, 0.6350826854930791}], 
        PointBox[{36.7, 0.6366051464187324}], 
        PointBox[{36.8, 0.6390543708077516}], 
        PointBox[{36.9, 0.6402408195177507}], 
        PointBox[{37., 0.6404807709814399}], 
        PointBox[{37.1, 0.6399485279128316}], 
        PointBox[{37.2, 0.6380161432876599}], 
        PointBox[{37.3, 0.6356375147555832}], 
        PointBox[{37.4, 0.6353989290335283}], 
        PointBox[{37.5, 0.6370383279522656}], 
        PointBox[{37.6, 0.6354050491199865}], 
        PointBox[{37.7, 0.635861233734417}], 
        PointBox[{37.8, 0.6383080509052114}], 
        PointBox[{37.9, 0.6400548732803473}], 
        PointBox[{38., 0.6406186163045094}], 
        PointBox[{38.1, 0.6404443743086128}], 
        PointBox[{38.2, 0.6391224606242146}], 
        PointBox[{38.3, 0.636605123653648}], 
        PointBox[{38.4, 0.6353094348709232}], 
        PointBox[{38.5, 0.6366245057279248}], 
        PointBox[{38.6, 0.6362226993167401}], 
        PointBox[{38.7, 0.6354795334193517}], 
        PointBox[{38.8, 0.6374135730163231}], 
        PointBox[{38.9, 0.6396625398206809}], 
        PointBox[{39., 0.6406512937312443}], 
        PointBox[{39.1, 0.6407836371858722}], 
        PointBox[{39.2, 0.6400112567499052}], 
        PointBox[{39.3, 0.6378177208724288}], 
        PointBox[{39.4, 0.6357200937570124}], 
        PointBox[{39.5, 0.6359297977363003}], 
        PointBox[{39.6, 0.6371696216285418}], 
        PointBox[{39.7, 0.6355694443866188}], 
        PointBox[{39.8, 0.6365685399511702}], 
        PointBox[{39.9, 0.6390168847695505}], 
        PointBox[{40., 0.6405371263390035}], 
        PointBox[{40.1, 0.6409941281338807}], 
        PointBox[{40.2, 0.6406576582744493}], 
        PointBox[{40.3, 0.639041850135465}], 
        PointBox[{40.4, 0.6365783355664287}], 
        PointBox[{40.5, 0.63566632113758}], 
        PointBox[{40.6, 0.6371951188912691}], 
        PointBox[{40.7, 0.6361881884351519}], 
        PointBox[{40.8, 0.6359994061986042}], 
        PointBox[{40.9, 0.6381544808430348}], 
        PointBox[{41., 0.6402113488221279}], 
        PointBox[{41.1, 0.6410735148924739}], 
        PointBox[{41.2, 0.641094059003449}], 
        PointBox[{41.3, 0.640078209088567}], 
        PointBox[{41.4, 0.6377527161367473}], 
        PointBox[{41.5, 0.6359307869658644}], 
        PointBox[{41.6, 0.6364742478654363}], 
        PointBox[{41.7, 0.6371868220434274}], 
        PointBox[{41.8, 0.6358674738430391}], 
        PointBox[{41.9, 0.6372416075259096}], 
        PointBox[{42., 0.6396155724013108}], 
        PointBox[{42.1, 0.6409879324061861}], 
        PointBox[{42.2, 0.6413557578042529}], 
        PointBox[{42.3, 0.6408443972223494}], 
        PointBox[{42.4, 0.6390146270214452}], 
        PointBox[{42.5, 0.636672021729086}], 
        PointBox[{42.6, 0.6360450598773788}], 
        PointBox[{42.7, 0.6376060543700832}], 
        PointBox[{42.8, 0.6362655093215829}], 
        PointBox[{42.9, 0.6365180107092255}], 
        PointBox[{43., 0.6387598269417596}], 
        PointBox[{43.1, 0.6406775031455071}], 
        PointBox[{43.2, 0.6414524196486424}], 
        PointBox[{43.3, 0.6413515871628931}], 
        PointBox[{43.4, 0.6401289201484228}], 
        PointBox[{43.5, 0.6377709416823851}], 
        PointBox[{43.6, 0.6361639217320338}], 
        PointBox[{43.7, 0.6369495087367563}], 
        PointBox[{43.8, 0.6371663501226076}], 
        PointBox[{43.9, 0.6361855129202785}], 
        PointBox[{44., 0.6377841990859755}], 
        PointBox[{44.1, 0.6400816008571985}], 
        PointBox[{44.2, 0.6413609110784946}], 
        PointBox[{44.3, 0.6416384756162338}], 
        PointBox[{44.4, 0.640962594541782}], 
        PointBox[{44.5, 0.6390084339581268}], 
        PointBox[{44.6, 0.6367841449792944}], 
        PointBox[{44.7, 0.636364860693693}], 
        PointBox[{44.8, 0.6378375656354699}], 
        PointBox[{44.9, 0.6363701188334699}], 
        PointBox[{45., 0.636930318753104}], 
        PointBox[{45.1, 0.6391982573662113}], 
        PointBox[{45.2, 0.6410297041163046}], 
        PointBox[{45.3, 0.641727250135273}], 
        PointBox[{45.4, 0.6415022067564528}], 
        PointBox[{45.5, 0.6401314870374157}], 
        PointBox[{45.6, 0.637786553076461}], 
        PointBox[{45.7, 0.6363319845144166}], 
        PointBox[{45.8, 0.6373072763678364}], 
        PointBox[{45.9, 0.6371102781088253}], 
        PointBox[{46., 0.6364256346715699}], 
        PointBox[{46.1, 0.6381521065130342}], 
        PointBox[{46.2, 0.640401380460854}], 
        PointBox[{46.3, 0.6416086291778162}], 
        PointBox[{46.4, 0.6417865795147717}], 
        PointBox[{46.5, 0.640976274703426}], 
        PointBox[{46.6, 0.6389590713023916}], 
        PointBox[{46.7, 0.6368217381396388}], 
        PointBox[{46.8, 0.6365786812724056}], 
        PointBox[{46.9, 0.6378982940774148}], 
        PointBox[{47., 0.636418422049522}], 
        PointBox[{47.1, 0.6371824208402922}], 
        PointBox[{47.2, 0.6394689402288748}], 
        PointBox[{47.3, 0.6412414562391427}], 
        PointBox[{47.4, 0.6418500205646169}], 
        PointBox[{47.5, 0.6415087257201761}], 
        PointBox[{47.6, 0.6400428251487078}], 
        PointBox[{47.7, 0.6377130302808355}], 
        PointBox[{47.8, 0.6363798111940723}], 
        PointBox[{47.9, 0.6375322026718266}], 
        PointBox[{48., 0.6369814285896963}], 
        PointBox[{48.1, 0.6365301543958369}], 
        PointBox[{48.2, 0.6383470029284541}], 
        PointBox[{48.3, 0.6405735959773917}], 
        PointBox[{48.4, 0.6416971168386623}], 
        PointBox[{48.5, 0.6417668970366313}], 
        PointBox[{48.6, 0.6408565099849469}], 
        PointBox[{48.7, 0.6387986431175696}], 
        PointBox[{48.8, 0.6367218195249089}], 
        PointBox[{48.9, 0.6366774300732411}], 
        PointBox[{49., 0.6377931416610727}], 
        PointBox[{49.1, 0.6363550929524112}], 
        PointBox[{49.2, 0.6372716137677144}], 
        PointBox[{49.3, 0.6395957272044024}], 
        PointBox[{49.4, 0.6413010601834572}], 
        PointBox[{49.5, 0.6417973928910882}], 
        PointBox[{49.6, 0.6413553646063719}], 
        PointBox[{49.7, 0.6398213465171793}], 
        PointBox[{49.8, 0.6374868244806915}], 
        PointBox[{49.9, 0.6362938827036084}], 
        PointBox[{50., 0.637631253616218}], 
        PointBox[{50.1, 0.6367447150572442}], 
        PointBox[{50.2, 0.6364909761118844}], 
        PointBox[{50.3, 0.6384097048928634}], 
        PointBox[{50.4, 0.6406164444265667}], 
        PointBox[{50.5, 0.641619604454342}], 
        PointBox[{50.6, 0.6415784949042}], 
        PointBox[{50.7, 0.6405906248910054}], 
        PointBox[{50.8, 0.6384781619205222}], 
        PointBox[{50.9, 0.6364645700758764}], 
        PointBox[{51., 0.6366927446973512}], 
        PointBox[{51.1, 0.6375226162140757}], 
        PointBox[{51.2, 0.6361685990085819}], 
        PointBox[{51.3, 0.6372430582239378}], 
        PointBox[{51.4, 0.6396254806384178}], 
        PointBox[{51.5, 0.6412198812357653}], 
        PointBox[{51.6, 0.641581378828122}], 
        PointBox[{51.7, 0.6410533129770647}], 
        PointBox[{51.8, 0.6394432844937001}], 
        PointBox[{51.9, 0.6370845104502295}], 
        PointBox[{52., 0.6361084662368236}], 
        PointBox[{52.1, 0.6376150007051292}], 
        PointBox[{52.2, 0.636392880360084}], 
        PointBox[{52.3, 0.636347454723779}], 
        PointBox[{52.4, 0.6384101059126607}], 
        PointBox[{52.5, 0.640561180274171}], 
        PointBox[{52.6, 0.641397983082743}], 
        PointBox[{52.7, 0.6412503860430747}], 
        PointBox[{52.8, 0.6401836228336084}], 
        PointBox[{52.9, 0.6379792485811799}], 
        PointBox[{53., 0.636081184727281}], 
        PointBox[{53.1, 0.6366845060640866}], 
        PointBox[{53.2, 0.6370926814475091}], 
        PointBox[{53.3, 0.6358899877266974}], 
        PointBox[{53.4, 0.6371764301530675}], 
        PointBox[{53.5, 0.6396152751319838}], 
        PointBox[{53.6, 0.6410285839319281}], 
        PointBox[{53.7, 0.6412446427740777}], 
        PointBox[{53.8, 0.6406346927336524}], 
        PointBox[{53.9, 0.6389067082400918}], 
        PointBox[{54., 0.6365324794470298}], 
        PointBox[{54.1, 0.6359013191378746}], 
        PointBox[{54.2, 0.6374719701063903}], 
        PointBox[{54.3, 0.6359545619036326}], 
        PointBox[{54.4, 0.6361770951858504}], 
        PointBox[{54.5, 0.6384283471081087}], 
        PointBox[{54.6, 0.6404442085894293}], 
        PointBox[{54.7, 0.6410802972173335}], 
        PointBox[{54.8, 0.6408335351198402}], 
        PointBox[{54.9, 0.6396554784857849}], 
        PointBox[{55., 0.6373200418309274}], 
        PointBox[{55.1, 0.6356529747186366}], 
        PointBox[{55.2, 0.6367163544116744}], 
        PointBox[{55.3, 0.6365333362714095}], 
        PointBox[{55.4, 0.6355883881641571}], 
        PointBox[{55.5, 0.6371695210776617}], 
        PointBox[{55.6, 0.6396078659939144}], 
        PointBox[{55.7, 0.6407707313592239}], 
        PointBox[{55.8, 0.6408469046742893}], 
        PointBox[{55.9, 0.6401394926417208}], 
        PointBox[{56., 0.6382268852635802}], 
        PointBox[{56.1, 0.6359061460845734}], 
        PointBox[{56.2, 0.635774094126588}], 
        PointBox[{56.3, 0.6371579528169155}], 
        PointBox[{56.4, 0.6354932675932372}], 
        PointBox[{56.5, 0.6360812999714257}], 
        PointBox[{56.6, 0.6385254526429645}], 
        PointBox[{56.7, 0.6402978616382318}], 
        PointBox[{56.8, 0.6407278190832718}], 
        PointBox[{56.9, 0.6403825367403909}], 
        PointBox[{57., 0.6390287892890693}], 
        PointBox[{57.1, 0.6365600266394608}], 
        PointBox[{57.2, 0.6352960730082796}], 
        PointBox[{57.3, 0.6368018675436528}], 
        PointBox[{57.4, 0.635913976802434}], 
        PointBox[{57.5, 0.6353599366874663}], 
        PointBox[{57.6, 0.6373060344833994}], 
        PointBox[{57.7, 0.639622054300243}], 
        PointBox[{57.8, 0.6404996223369652}], 
        PointBox[{57.9, 0.6404507449609219}], 
        PointBox[{58., 0.6396015660737386}], 
        PointBox[{58.1, 0.6374402998482058}], 
        PointBox[{58.2, 0.6353273812138347}], 
        PointBox[{58.3, 0.6358203362697585}], 
        PointBox[{58.4, 0.6366492112083654}], 
        PointBox[{58.5, 0.6351011677106907}], 
        PointBox[{58.6, 0.6361617822487838}], 
        PointBox[{58.7, 0.6387152610587911}], 
        PointBox[{58.8, 0.6401550438998234}], 
        PointBox[{58.9, 0.6404021086992292}], 
        PointBox[{59., 0.6399408785310013}], 
        PointBox[{59.1, 0.638323010278377}], 
        PointBox[{59.2, 0.6358069420826432}], 
        PointBox[{59.3, 0.6351250851259603}], 
        PointBox[{59.4, 0.6368454593161519}], 
        PointBox[{59.5, 0.6353383765246213}], 
        PointBox[{59.6, 0.6353087836538583}], 
        PointBox[{59.7, 0.6376174815089458}], 
        PointBox[{59.8, 0.6396596323178144}], 
        PointBox[{59.9, 0.6402679818617192}], 
        PointBox[{60., 0.6401032193752609}], 
        PointBox[{60.1, 0.6390367028584959}], 
        PointBox[{60.2, 0.6366179923917061}], 
        PointBox[{60.3, 0.6349237040619512}], 
        PointBox[{60.4, 0.6360710846216358}], 
        PointBox[{60.5, 0.6360201607494533}], 
        PointBox[{60.6, 0.6348775019655172}], 
        PointBox[{60.7, 0.6364792075207926}], 
        PointBox[{60.8, 0.6389677220222264}], 
        PointBox[{60.9, 0.6400510273682674}], 
        PointBox[{61., 0.640148813323998}], 
        PointBox[{61.1, 0.6395264559969634}], 
        PointBox[{61.2, 0.6375672313215509}], 
        PointBox[{61.3, 0.6351953716871822}], 
        PointBox[{61.4, 0.6352162843551011}], 
        PointBox[{61.5, 0.6366779408017432}], 
        PointBox[{61.6, 0.6349177017145791}], 
        PointBox[{61.7, 0.6355175444354282}], 
        PointBox[{61.8, 0.6380639386061425}], 
        PointBox[{61.9, 0.6397269858666778}], 
        PointBox[{62., 0.6401175513535082}], 
        PointBox[{62.1, 0.6398256111140874}], 
        PointBox[{62.2, 0.6384470454272324}], 
        PointBox[{62.3, 0.635875464613787}], 
        PointBox[{62.4, 0.6347876761009636}], 
        PointBox[{62.5, 0.63643469338087}], 
        PointBox[{62.6, 0.6354366295734314}], 
        PointBox[{62.7, 0.6349094133316429}], 
        PointBox[{62.8, 0.6370192005570048}], 
        PointBox[{62.9, 0.6392490337801371}], 
        PointBox[{63., 0.6400215561787652}], 
        PointBox[{63.1, 0.6399925238583939}], 
        PointBox[{63.2, 0.6391345326779562}], 
        PointBox[{63.3, 0.6368284727841903}], 
        PointBox[{63.4, 0.6348394660978394}], 
        PointBox[{63.5, 0.6355806326689395}], 
        PointBox[{63.6, 0.6362695289612447}], 
        PointBox[{63.7, 0.6347434605873679}], 
        PointBox[{63.8, 0.6360088184495314}], 
        PointBox[{63.9, 0.6385705561246703}], 
        PointBox[{64., 0.6398465660345692}], 
        PointBox[{64.1, 0.6400742762674569}], 
        PointBox[{64.2, 0.639615534225953}], 
        PointBox[{64.3, 0.6378504189949179}], 
        PointBox[{64.4, 0.6353417123726885}], 
        PointBox[{64.5, 0.6349489110939515}], 
        PointBox[{64.6, 0.6366865768162895}], 
        PointBox[{64.7, 0.6350530701305931}], 
        PointBox[{64.8, 0.6352412933504026}], 
        PointBox[{64.9, 0.637692555776697}], 
        PointBox[{65., 0.6395521161045038}], 
        PointBox[{65.1, 0.6400922790429591}], 
        PointBox[{65.2, 0.6399340610561418}], 
        PointBox[{65.3, 0.6387542703417642}], 
        PointBox[{65.4, 0.6362178984719876}], 
        PointBox[{65.5, 0.6347847797887229}], 
        PointBox[{65.6, 0.6361341590273862}], 
        PointBox[{65.7, 0.635814400659123}], 
        PointBox[{65.8, 0.634864645302679}], 
        PointBox[{65.9, 0.6367182136185133}], 
        PointBox[{66., 0.6390821094776948}], 
        PointBox[{66.1, 0.640041621703418}], 
        PointBox[{66.2, 0.6401412651691556}], 
        PointBox[{66.3, 0.6394524986346942}], 
        PointBox[{66.4, 0.6373075226826282}], 
        PointBox[{66.5, 0.6350941423712614}], 
        PointBox[{66.6, 0.6353734534125345}], 
        PointBox[{66.7, 0.6366642979752734}], 
        PointBox[{66.8, 0.6349488456051556}], 
        PointBox[{66.9, 0.6358442628468376}], 
        PointBox[{67., 0.6383953532313612}], 
        PointBox[{67.1, 0.6398909659198807}], 
        PointBox[{67.2, 0.6402688552038815}], 
        PointBox[{67.3, 0.6399522024602212}], 
        PointBox[{67.4, 0.6383954999082544}], 
        PointBox[{67.5, 0.6358373915842433}], 
        PointBox[{67.6, 0.635004454943218}], 
        PointBox[{67.7, 0.6366936841518004}], 
        PointBox[{67.8, 0.635522076619824}], 
        PointBox[{67.9, 0.6352711565534643}], 
        PointBox[{68., 0.6375237727244666}], 
        PointBox[{68.1, 0.6395853460050744}], 
        PointBox[{68.2, 0.640321771135051}], 
        PointBox[{68.3, 0.6402996911949524}], 
        PointBox[{68.4, 0.639317827226058}], 
        PointBox[{68.5, 0.6369075333504753}], 
        PointBox[{68.6, 0.6351263609689963}], 
        PointBox[{68.7, 0.6359733090230526}], 
        PointBox[{68.8, 0.6364716959405454}], 
        PointBox[{68.9, 0.6351262940893929}], 
        PointBox[{69., 0.6366142730023892}], 
        PointBox[{69.1, 0.6390647795589294}], 
        PointBox[{69.2, 0.6402772662226395}], 
        PointBox[{69.3, 0.6405348815180645}], 
        PointBox[{69.4, 0.6400166551734642}], 
        PointBox[{69.5, 0.6381058106238173}], 
        PointBox[{69.6, 0.6357181615639829}], 
        PointBox[{69.7, 0.6354232401061635}], 
        PointBox[{69.8, 0.6370750915324078}], 
        PointBox[{69.9, 0.6354735052688013}], 
        PointBox[{70., 0.6358852085510441}], 
        PointBox[{70.1, 0.6383118738204664}], 
        PointBox[{70.2, 0.640084873956061}], 
        PointBox[{70.3, 0.6406729377434851}], 
        PointBox[{70.4, 0.6405137571493419}], 
        PointBox[{70.5, 0.6392137198263504}], 
        PointBox[{70.6, 0.6367089525365246}], 
        PointBox[{70.7, 0.6353663002923773}], 
        PointBox[{70.8, 0.6366217711685513}], 
        PointBox[{70.9, 0.6363140808867581}], 
        PointBox[{71., 0.6355228218282393}], 
        PointBox[{71.1, 0.6374160663673443}], 
        PointBox[{71.2, 0.639679179177063}], 
        PointBox[{71.3, 0.6407002588937248}], 
        PointBox[{71.4, 0.6408517847112029}], 
        PointBox[{71.5, 0.6400991366430494}], 
        PointBox[{71.6, 0.6379333517079269}], 
        PointBox[{71.7, 0.6358095412660746}], 
        PointBox[{71.8, 0.6359433218388337}], 
        PointBox[{71.9, 0.6372415786040281}], 
        PointBox[{72., 0.635636935261008}], 
        PointBox[{72.1, 0.6365794842546201}], 
        PointBox[{72.2, 0.6390158446303656}], 
        PointBox[{72.3, 0.6405727805202707}], 
        PointBox[{72.4, 0.6410562680635595}], 
        PointBox[{72.5, 0.6407384260025811}], 
        PointBox[{72.6, 0.6391546344467259}], 
        PointBox[{72.7, 0.6366948104801989}], 
        PointBox[{72.8, 0.6357147247602536}], 
        PointBox[{72.9, 0.6371944920144113}], 
        PointBox[{73., 0.6362828135763298}], 
        PointBox[{73.1, 0.6360278374284487}], 
        PointBox[{73.2, 0.6381401962191673}], 
        PointBox[{73.3, 0.6402248688923492}], 
        PointBox[{73.4, 0.6411236604061176}], 
        PointBox[{73.5, 0.641165126728294}], 
        PointBox[{73.6, 0.6401781894819503}], 
        PointBox[{73.7, 0.6378822054201302}], 
        PointBox[{73.8, 0.6360141648468144}], 
        PointBox[{73.9, 0.6364665795007828}], 
        PointBox[{74., 0.6372801655911807}], 
        PointBox[{74.1, 0.6359191369485704}], 
        PointBox[{74.2, 0.6372265152175937}], 
        PointBox[{74.3, 0.6396007675904709}], 
        PointBox[{74.4, 0.6410175142760852}], 
        PointBox[{74.5, 0.6414130901133122}], 
        PointBox[{74.6, 0.6409263241265968}], 
        PointBox[{74.7, 0.639138289214804}], 
        PointBox[{74.8, 0.6367846621492723}], 
        PointBox[{74.9, 0.6360718509910332}], 
        PointBox[{75., 0.6376120685252942}], 
        PointBox[{75.1, 0.6363464727595511}], 
        PointBox[{75.2, 0.636516710237581}], 
        PointBox[{75.3, 0.6387209022350685}], 
        PointBox[{75.4, 0.6406778008004065}], 
        PointBox[{75.5, 0.6414909278223826}], 
        PointBox[{75.6, 0.641413896148968}], 
        PointBox[{75.7, 0.640230426126083}], 
        PointBox[{75.8, 0.6378978409669157}], 
        PointBox[{75.9, 0.6362278286537596}], 
        PointBox[{76., 0.6369159865474467}], 
        PointBox[{76.1, 0.6372613564447069}], 
        PointBox[{76.2, 0.6362088793441875}], 
        PointBox[{76.3, 0.6377364642134532}], 
        PointBox[{76.4, 0.640046643389524}], 
        PointBox[{76.5, 0.6413739508764041}], 
        PointBox[{76.6, 0.6416796753056444}], 
        PointBox[{76.7, 0.6410356800806606}], 
        PointBox[{76.8, 0.6391273678553475}], 
        PointBox[{76.9, 0.6368780231164396}], 
        PointBox[{77., 0.6363616954376935}], 
        PointBox[{77.1, 0.6378520593306091}], 
        PointBox[{77.2, 0.636425034933591}], 
        PointBox[{77.3, 0.6368931438192076}], 
        PointBox[{77.4, 0.6391313929034868}], 
        PointBox[{77.5, 0.6410090378323337}], 
        PointBox[{77.6, 0.6417442123495507}], 
        PointBox[{77.7, 0.6415459010099205}], 
        PointBox[{77.8, 0.6402216112975764}], 
        PointBox[{77.9, 0.6378946212660108}], 
        PointBox[{78., 0.6363654160581862}], 
        PointBox[{78.1, 0.6372479972561859}], 
        PointBox[{78.2, 0.6371891456478397}], 
        PointBox[{78.3, 0.6364124939634409}], 
        PointBox[{78.4, 0.6380696990441578}], 
        PointBox[{78.5, 0.6403415982697238}], 
        PointBox[{78.6, 0.6415966666873615}], 
        PointBox[{78.7, 0.6418022050135386}], 
        PointBox[{78.8, 0.6410297495208124}], 
        PointBox[{78.9, 0.639057720351051}], 
        PointBox[{79., 0.6368842383186799}], 
        PointBox[{79.1, 0.63654042293963}], 
        PointBox[{79.2, 0.6379163457679462}], 
        PointBox[{79.3, 0.6364382683126295}], 
        PointBox[{79.4, 0.637107771498277}], 
        PointBox[{79.5, 0.6393743942144454}], 
        PointBox[{79.6, 0.64119567681994}], 
        PointBox[{79.7, 0.6418386650166751}], 
        PointBox[{79.8, 0.6415265116079942}], 
        PointBox[{79.9, 0.6401105905188252}], 
        PointBox[{80., 0.6377895117215746}], 
        PointBox[{80.1, 0.6363764192292719}], 
        PointBox[{80.2, 0.6374530491717091}], 
        PointBox[{80.3, 0.6370317333501961}], 
        PointBox[{80.4, 0.6364797044507076}], 
        PointBox[{80.5, 0.638234706569011}], 
        PointBox[{80.6, 0.6404910658514569}], 
        PointBox[{80.7, 0.6416582689331056}], 
        PointBox[{80.8, 0.641754022446817}], 
        PointBox[{80.9, 0.6408848479429081}], 
        PointBox[{81., 0.6388672149823433}], 
        PointBox[{81.1, 0.6367458196742336}], 
        PointBox[{81.2, 0.6366063950770896}], 
        PointBox[{81.3, 0.6378090344505659}], 
        PointBox[{81.4, 0.6363383852016483}], 
        PointBox[{81.5, 0.637165560447148}], 
        PointBox[{81.6, 0.6394803907425952}], 
        PointBox[{81.7, 0.6412330035802045}], 
        PointBox[{81.8, 0.6417581733123046}], 
        PointBox[{81.9, 0.6413463839925189}], 
        PointBox[{82., 0.6398608120713378}], 
        PointBox[{82.1, 0.6375247970523411}], 
        PointBox[{82.2, 0.6362540795917611}], 
        PointBox[{82.3, 0.6375435454280179}], 
        PointBox[{82.4, 0.6367616252330267}], 
        PointBox[{82.5, 0.6364087330156988}], 
        PointBox[{82.6, 0.6382778756041082}], 
        PointBox[{82.7, 0.6405183976307545}], 
        PointBox[{82.8, 0.6415571740083306}], 
        PointBox[{82.9, 0.6415396719490871}], 
        PointBox[{83., 0.6405928496215688}], 
        PointBox[{83.1, 0.6385118835178014}], 
        PointBox[{83.2, 0.6364496516535033}], 
        PointBox[{83.3, 0.6365967647880084}], 
        PointBox[{83.4, 0.6375304669223238}], 
        PointBox[{83.5, 0.6361196322150816}], 
        PointBox[{83.6, 0.6371166389488717}], 
        PointBox[{83.7, 0.6395024371040012}], 
        PointBox[{83.8, 0.6411367811049266}], 
        PointBox[{83.9, 0.6415205038994702}], 
        PointBox[{84., 0.6410220862432178}], 
        PointBox[{84.1, 0.6394546491170977}], 
        PointBox[{84.2, 0.6370846332405911}], 
        PointBox[{84.3, 0.6360395038296399}], 
        PointBox[{84.4, 0.6375336587918495}], 
        PointBox[{84.5, 0.6363776513902519}], 
        PointBox[{84.6, 0.6362446833712863}], 
        PointBox[{84.7, 0.6382742462040895}], 
        PointBox[{84.8, 0.6404588400555887}], 
        PointBox[{84.9, 0.641320697070815}], 
        PointBox[{85., 0.6411940047958322}], 
        PointBox[{85.1, 0.64016492159731}], 
        PointBox[{85.2, 0.6379800406848878}], 
        PointBox[{85.3, 0.6360336824614584}], 
        PointBox[{85.4, 0.6365776015237666}], 
        PointBox[{85.5, 0.637087049931926}], 
        PointBox[{85.6, 0.6358180569562185}], 
        PointBox[{85.7, 0.637047061699704}], 
        PointBox[{85.8, 0.6394978318626062}], 
        PointBox[{85.9, 0.6409395621431321}], 
        PointBox[{86., 0.6411718353297826}], 
        PointBox[{86.1, 0.6405893688534853}], 
        PointBox[{86.2, 0.6388942119375629}], 
        PointBox[{86.3, 0.6364997211479951}], 
        PointBox[{86.4, 0.6358157587184664}], 
        PointBox[{86.5, 0.6374087292524696}], 
        PointBox[{86.6, 0.6359135318834848}], 
        PointBox[{86.7, 0.6360681153121699}], 
        PointBox[{86.8, 0.63830489657949}], 
        PointBox[{86.9, 0.6403473947532092}], 
        PointBox[{87., 0.6409987139836021}], 
        PointBox[{87.1, 0.6407701729093183}], 
        PointBox[{87.2, 0.6396234701221346}], 
        PointBox[{87.3, 0.6372935629872847}], 
        PointBox[{87.4, 0.6355871855847207}], 
        PointBox[{87.5, 0.6366163257099305}], 
        PointBox[{87.6, 0.6365121909084208}], 
        PointBox[{87.7, 0.6355067501681652}], 
        PointBox[{87.8, 0.637053027684062}], 
        PointBox[{87.9, 0.6395075100826053}], 
        PointBox[{88., 0.6406863053585882}], 
        PointBox[{88.1, 0.6407746326572492}], 
        PointBox[{88.2, 0.6400904702541906}], 
        PointBox[{88.3, 0.6381973938081928}], 
        PointBox[{88.4, 0.6358542579412136}], 
        PointBox[{88.5, 0.6356885826322222}], 
        PointBox[{88.6, 0.6371156133799727}], 
        PointBox[{88.7, 0.6354386933087764}], 
        PointBox[{88.8, 0.6359825446521108}], 
        PointBox[{88.9, 0.6384268702901955}], 
        PointBox[{89., 0.6402150331843577}], 
        PointBox[{89.1, 0.6406537138050613}], 
        PointBox[{89.2, 0.6403241604334495}], 
        PointBox[{89.3, 0.6389916605429663}], 
        PointBox[{89.4, 0.6365173555319822}], 
        PointBox[{89.5, 0.6352284340094024}], 
        PointBox[{89.6, 0.6367249688656618}], 
        PointBox[{89.7, 0.6358810584194627}], 
        PointBox[{89.8, 0.6352838699908238}], 
        PointBox[{89.9, 0.637216694827629}], 
        PointBox[{90., 0.639544723342976}], 
        PointBox[{90.1, 0.6404287698500821}], 
        PointBox[{90.2, 0.6403899701526052}], 
        PointBox[{90.3, 0.639557784277912}], 
        PointBox[{90.4, 0.6374019560924193}], 
        PointBox[{90.5, 0.6352724401900411}], 
        PointBox[{90.6, 0.6357491782708725}], 
        PointBox[{90.7, 0.636619442972044}], 
        PointBox[{90.8, 0.6350469599195009}], 
        PointBox[{90.9, 0.6360870418957213}], 
        PointBox[{91., 0.6386464140014269}], 
        PointBox[{91.1, 0.6400911047515582}], 
        PointBox[{91.2, 0.6403440789200026}], 
        PointBox[{91.3, 0.639894972204033}], 
        PointBox[{91.4, 0.6382864069192201}], 
        PointBox[{91.5, 0.6357615070515932}], 
        PointBox[{91.6, 0.6350697267883438}], 
        PointBox[{91.7, 0.63679827590358}], 
        PointBox[{91.8, 0.6353030236776169}], 
        PointBox[{91.9, 0.6352514872100019}], 
        PointBox[{92., 0.6375605589497281}], 
        PointBox[{92.1, 0.6396057796044026}], 
        PointBox[{92.2, 0.6402168636080309}], 
        PointBox[{92.3, 0.6400602061014155}], 
        PointBox[{92.4, 0.6390027881352985}], 
        PointBox[{92.5, 0.6365806487773018}], 
        PointBox[{92.6, 0.634881104268902}], 
        PointBox[{92.7, 0.6360237929153537}], 
        PointBox[{92.8, 0.6359972181242421}], 
        PointBox[{92.9, 0.634837375521408}], 
        PointBox[{93., 0.6364363962685322}], 
        PointBox[{93.1, 0.6389267778655688}], 
        PointBox[{93.2, 0.6400099593983597}], 
        PointBox[{93.3, 0.6401130626555318}], 
        PointBox[{93.4, 0.6394978258942682}], 
        PointBox[{93.5, 0.6375376244588633}], 
        PointBox[{93.6, 0.6351625063120496}], 
        PointBox[{93.7, 0.635182391384799}], 
        PointBox[{93.8, 0.6366560805693573}], 
        PointBox[{93.9, 0.6348927121704308}], 
        PointBox[{94., 0.6354884775384355}], 
        PointBox[{94.1, 0.6380371643465099}], 
        PointBox[{94.2, 0.6396976229771754}], 
        PointBox[{94.3, 0.6400911586774013}], 
        PointBox[{94.4, 0.6398046470885862}], 
        PointBox[{94.5, 0.6384263331298465}], 
        PointBox[{94.6, 0.6358511965518768}], 
        PointBox[{94.7, 0.6347662317156989}], 
        PointBox[{94.8, 0.6364131682165308}], 
        PointBox[{94.9, 0.6354242584855921}], 
        PointBox[{95., 0.6348927914963087}], 
        PointBox[{95.1, 0.6370061554566017}], 
        PointBox[{95.2, 0.6392326134341588}], 
        PointBox[{95.3, 0.6400056942526062}], 
        PointBox[{95.4, 0.6399814347395167}], 
        PointBox[{95.5, 0.6391244688972614}], 
        PointBox[{95.6, 0.6368138796865798}], 
        PointBox[{95.7, 0.6348284214028135}], 
        PointBox[{95.8, 0.6355688939524585}], 
        PointBox[{95.9, 0.6362661710838002}], 
        PointBox[{96., 0.6347380652021789}], 
        PointBox[{96.1, 0.6360078526773265}], 
        PointBox[{96.2, 0.6385671306178021}], 
        PointBox[{96.3, 0.6398413890461417}], 
        PointBox[{96.4, 0.6400732518772135}], 
        PointBox[{96.5, 0.6396165719324903}], 
        PointBox[{96.6, 0.6378469694814577}], 
        PointBox[{96.7, 0.6353401750037702}], 
        PointBox[{96.8, 0.6349490191737593}], 
        PointBox[{96.9, 0.6366871054205091}], 
        PointBox[{97., 0.6350582148221808}], 
        PointBox[{97.1, 0.6352500950394036}], 
        PointBox[{97.2, 0.6377014521756436}], 
        PointBox[{97.3, 0.6395572507666365}], 
        PointBox[{97.4, 0.6401011205098127}], 
        PointBox[{97.5, 0.6399462509637878}], 
        PointBox[{97.6, 0.6387632806987072}], 
        PointBox[{97.7, 0.636226471246049}], 
        PointBox[{97.8, 0.6347967160098035}], 
        PointBox[{97.9, 0.6361396499601799}], 
        PointBox[{98., 0.6358298235663304}], 
        PointBox[{98.1, 0.6348817791732118}], 
        PointBox[{98.2, 0.6367375589378269}], 
        PointBox[{98.3, 0.6390963708837634}], 
        PointBox[{98.4, 0.6400592296881576}], 
        PointBox[{98.5, 0.6401637770045432}], 
        PointBox[{98.6, 0.6394740946559236}], 
        PointBox[{98.7, 0.6373265827190361}], 
        PointBox[{98.8, 0.63511759667445}], 
        PointBox[{98.9, 0.6353888441961585}], 
        PointBox[{99., 0.6366857455698866}], 
        PointBox[{99.1, 0.6349740709117349}], 
        PointBox[{99.2, 0.635871766282899}], 
        PointBox[{99.3, 0.638417155232182}], 
        PointBox[{99.4, 0.6399152247038068}], 
        PointBox[{99.5, 0.640299610132101}], 
        PointBox[{99.6, 0.6399850535371452}], 
        PointBox[{99.7, 0.6384266286697103}], 
        PointBox[{99.8, 0.6358725671420898}], 
        PointBox[{99.9, 0.6350326613705441}], 
        PointBox[{100., 0.6367119762975253}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0.6, 0.65}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], 
        PointBox[{0, 0.060145999999999124`}], 
        PointBox[{0.1, 0.05982466789095328}], 
        PointBox[{0.2, 0.057606477163866625`}], 
        PointBox[{0.3, 0.060644083756338556`}], 
        PointBox[{0.4, 0.05969844551830036}], 
        PointBox[{0.5, 0.056848802881649306`}], 
        PointBox[{0.6, 0.058362518228617384`}], 
        PointBox[{0.7, 0.06110773747040919}], 
        PointBox[{0.8, 0.058340332249132376`}], 
        PointBox[{0.9, 0.05868750787676766}], 
        PointBox[{1., 0.0602620933871352}], 
        PointBox[{1.1, 0.06006444749716806}], 
        PointBox[{1.2, 0.05758971544079518}], 
        PointBox[{1.3, 0.05893188455650285}], 
        PointBox[{1.4, 0.060379094791105085`}], 
        PointBox[{1.5, 0.05714379438497267}], 
        PointBox[{1.6, 0.05687137207429886}], 
        PointBox[{1.7, 0.0601354231782226}], 
        PointBox[{1.8, 0.059362385338717565`}], 
        PointBox[{1.9, 0.057335274390351666`}], 
        PointBox[{2., 0.05980433050880389}], 
        PointBox[{2.1, 0.05932547801626109}], 
        PointBox[{2.2, 0.057910108986670726`}], 
        PointBox[{2.3, 0.056822836891429494`}], 
        PointBox[{2.4, 0.059860768188686186`}], 
        PointBox[{2.5, 0.05755472918656146}], 
        PointBox[{2.6, 0.05556286472869869}], 
        PointBox[{2.7, 0.05810554828049577}], 
        PointBox[{2.8, 0.05969610566096869}], 
        PointBox[{2.9, 0.05649695910109848}], 
        PointBox[{3., 0.05819785849293156}], 
        PointBox[{3.1, 0.05852628070115092}], 
        PointBox[{3.2, 0.05782126171777261}], 
        PointBox[{3.3, 0.055239914393268356`}], 
        PointBox[{3.4, 0.057885962645430396`}], 
        PointBox[{3.5, 0.05769808801999667}], 
        PointBox[{3.6, 0.054600551764830564`}], 
        PointBox[{3.7, 0.05557873098940734}], 
        PointBox[{3.8, 0.05864505058423208}], 
        PointBox[{3.9, 0.05636901758268747}], 
        PointBox[{4., 0.05585746259543145}], 
        PointBox[{4.1, 0.05774518391125333}], 
        PointBox[{4.2, 0.05678207333740114}], 
        PointBox[{4.3, 0.05439778365929104}], 
        PointBox[{4.4, 0.054883246216037594`}], 
        PointBox[{4.5, 0.057013364258613045`}], 
        PointBox[{4.6, 0.053965958457289694`}], 
        PointBox[{4.7, 0.053050476991120143`}], 
        PointBox[{4.8, 0.05622032033952174}], 
        PointBox[{4.9, 0.056275005970866494`}], 
        PointBox[{5., 0.05360573635057879}], 
        PointBox[{5.1, 0.055913384932387525`}], 
        PointBox[{5.2, 0.055168919554159764`}], 
        PointBox[{5.3, 0.05374870695615349}], 
        PointBox[{5.4, 0.05188599699384956}], 
        PointBox[{5.5, 0.05498029648498145}], 
        PointBox[{5.6, 0.05341478938383354}], 
        PointBox[{5.7, 0.050869364170323644`}], 
        PointBox[{5.8, 0.05292192050097172}], 
        PointBox[{5.9, 0.055203088156354996`}], 
        PointBox[{6., 0.05212821748874997}], 
        PointBox[{6.1, 0.05297021831829654}], 
        PointBox[{6.2, 0.05383916833061894}], 
        PointBox[{6.3, 0.05252549218930577}], 
        PointBox[{6.4, 0.04972604424738264}], 
        PointBox[{6.5, 0.05157795058815116}], 
        PointBox[{6.6, 0.05244476292193831}], 
        PointBox[{6.7, 0.04920025658516049}], 
        PointBox[{6.8, 0.049377740517212845`}], 
        PointBox[{6.9, 0.052673437987079026`}], 
        PointBox[{7., 0.05130118470429899}], 
        PointBox[{7.1, 0.049675610479992305`}], 
        PointBox[{7.2, 0.051911254408920283`}], 
        PointBox[{7.3, 0.05049207704958718}], 
        PointBox[{7.4, 0.0483370774658881}], 
        PointBox[{7.5, 0.047627153942264126`}], 
        PointBox[{7.6, 0.05041836907153923}], 
        PointBox[{7.7, 0.0479590745367362}], 
        PointBox[{7.8, 0.04614581247712915}], 
        PointBox[{7.9, 0.048956861915441754`}], 
        PointBox[{8., 0.050141800867836143`}], 
        PointBox[{8.1, 0.047008704186227566`}], 
        PointBox[{8.2, 0.048705943953515254`}], 
        PointBox[{8.3, 0.048570207344696886`}], 
        PointBox[{8.4, 0.046957484493415795`}], 
        PointBox[{8.5, 0.044343169988533625`}], 
        PointBox[{8.6, 0.04698555571286984}], 
        PointBox[{8.7, 0.04673263811124433}], 
        PointBox[{8.8, 0.043617960526554284`}], 
        PointBox[{8.9, 0.044742054235854915`}], 
        PointBox[{9., 0.04774075023058543}], 
        PointBox[{9.1, 0.045407354184947464`}], 
        PointBox[{9.2, 0.04481439875200782}], 
        PointBox[{9.3, 0.04662377227131198}], 
        PointBox[{9.4, 0.044908611998319414`}], 
        PointBox[{9.5, 0.04228048380189735}], 
        PointBox[{9.6, 0.04265738288858093}], 
        PointBox[{9.7, 0.04483712059461848}], 
        PointBox[{9.8, 0.0419059244149804}], 
        PointBox[{9.9, 0.040806653270468875`}], 
        PointBox[{10., 0.04401847819739681}], 
        PointBox[{10.1, 0.04417671904813196}], 
        PointBox[{10.2, 0.041396781430471874`}], 
        PointBox[{10.3, 0.04349358717837348}], 
        PointBox[{10.4, 0.04268856810678079}], 
        PointBox[{10.5, 0.04090369716224253}], 
        PointBox[{10.6, 0.03879127722219106}], 
        PointBox[{10.7, 0.041710293247850264`}], 
        PointBox[{10.8, 0.04069800666921044}], 
        PointBox[{10.9, 0.03782031441691394}], 
        PointBox[{11., 0.03963218360823317}], 
        PointBox[{11.1, 0.042155546332825186`}], 
        PointBox[{11.2, 0.039362086852309755`}], 
        PointBox[{11.3, 0.039511600389479165`}], 
        PointBox[{11.4, 0.04088364116209022}], 
        PointBox[{11.5, 0.039257090949500625`}], 
        PointBox[{11.6, 0.036504119046230875`}], 
        PointBox[{11.7, 0.03761526756689727}], 
        PointBox[{11.8, 0.039272238456475005`}], 
        PointBox[{11.9, 0.03613211819973048}], 
        PointBox[{12., 0.035569015778358894`}], 
        PointBox[{12.1, 0.038907167113727555`}], 
        PointBox[{12.2, 0.03837401748252426}], 
        PointBox[{12.3, 0.03599058216417776}], 
        PointBox[{12.4, 0.0382410264127402}], 
        PointBox[{12.5, 0.03728787167030406}], 
        PointBox[{12.6, 0.03559248878055478}], 
        PointBox[{12.7, 0.033957390778056235`}], 
        PointBox[{12.8, 0.03691353894092619}], 
        PointBox[{12.9, 0.03551324266756495}], 
        PointBox[{13., 0.032808905034005034`}], 
        PointBox[{13.1, 0.03500536034373374}], 
        PointBox[{13.2, 0.03714999507547728}], 
        PointBox[{13.3, 0.0342243122592669}], 
        PointBox[{13.4, 0.03479109046814598}], 
        PointBox[{13.5, 0.03597279475021677}], 
        PointBox[{13.6, 0.03490369705313912}], 
        PointBox[{13.7, 0.03226292565299858}], 
        PointBox[{13.8, 0.033735561809224775`}], 
        PointBox[{13.9, 0.03514521270317643}], 
        PointBox[{14., 0.03192396520148529}], 
        PointBox[{14.1, 0.03162094554410373}], 
        PointBox[{14.2, 0.034961448406152715`}], 
        PointBox[{14.3, 0.03413379426364912}], 
        PointBox[{14.4, 0.03199001435764514}], 
        PointBox[{14.5, 0.034344265465878286`}], 
        PointBox[{14.6, 0.033853104612137044`}], 
        PointBox[{14.7, 0.03253497306424342}], 
        PointBox[{14.8, 0.03117945615001261}], 
        PointBox[{14.9, 0.034149563614955365`}], 
        PointBox[{15., 0.03263987822837081}], 
        PointBox[{15.1, 0.029976877402823208`}], 
        PointBox[{15.2, 0.03229383497365315}], 
        PointBox[{15.3, 0.03428881640954377}], 
        PointBox[{15.4, 0.031375771332205926`}], 
        PointBox[{15.5, 0.03213244561027588}], 
        PointBox[{15.6, 0.03347842435825873}], 
        PointBox[{15.7, 0.033371443280649296`}], 
        PointBox[{15.8, 0.030917873711173206`}], 
        PointBox[{15.9, 0.032523935349979896`}], 
        PointBox[{16., 0.0339066830923392}], 
        PointBox[{16.1, 0.030653114863375144`}], 
        PointBox[{16.2, 0.03039463746711644}], 
        PointBox[{16.3, 0.033713613367709706`}], 
        PointBox[{16.4, 0.03284960400275741}], 
        PointBox[{16.5, 0.03080867548039183}], 
        PointBox[{16.6, 0.033315341436115954`}], 
        PointBox[{16.7, 0.03372704885720261}], 
        PointBox[{16.8, 0.03283627140012765}], 
        PointBox[{16.9, 0.031631769870478076`}], 
        PointBox[{17., 0.034647231514515764`}], 
        PointBox[{17.1, 0.0330968547144316}], 
        PointBox[{17.2, 0.030443900891257886`}], 
        PointBox[{17.3, 0.03276812708534633}], 
        PointBox[{17.4, 0.034729617034259745`}], 
        PointBox[{17.5, 0.031844538975206414`}], 
        PointBox[{17.6, 0.03276324389483299}], 
        PointBox[{17.7, 0.034467012367497336`}], 
        PointBox[{17.8, 0.0352815699035415}], 
        PointBox[{17.9, 0.03296042610507452}], 
        PointBox[{18., 0.034705159160963985`}], 
        PointBox[{18.1, 0.03602207234049137}], 
        PointBox[{18.2, 0.03272901706025686}], 
        PointBox[{18.3, 0.03256059497397884}], 
        PointBox[{18.4, 0.03584859536696451}], 
        PointBox[{18.5, 0.034912020131931516`}], 
        PointBox[{18.6, 0.0330196428049688}], 
        PointBox[{18.7, 0.0357156057918023}], 
        PointBox[{18.8, 0.03696913365612873}], 
        PointBox[{18.9, 0.03619834117430668}], 
        PointBox[{19., 0.03521593962438518}], 
        PointBox[{19.1, 0.03826463700251858}], 
        PointBox[{19.2, 0.03648322623603364}], 
        PointBox[{19.3, 0.033988739425549516`}], 
        PointBox[{19.4, 0.03641456352494966}], 
        PointBox[{19.5, 0.03822123049854039}], 
        PointBox[{19.6, 0.03529343740190914}], 
        PointBox[{19.7, 0.0365672365452752}], 
        PointBox[{19.8, 0.03849807304194501}], 
        PointBox[{19.9, 0.03972648878909296}], 
        PointBox[{20., 0.03745074859112395}], 
        PointBox[{20.1, 0.03952706127942921}], 
        PointBox[{20.2, 0.04048042766915207}], 
        PointBox[{20.3, 0.037138326110615856`}], 
        PointBox[{20.4, 0.03732567441051782}], 
        PointBox[{20.5, 0.04055273662923406}], 
        PointBox[{20.6, 0.03926592500905538}], 
        PointBox[{20.7, 0.037769383784556486`}], 
        PointBox[{20.8, 0.040592014145966984`}], 
        PointBox[{20.9, 0.042272812368802454`}], 
        PointBox[{21., 0.041204893669845026`}], 
        PointBox[{21.1, 0.04068308058409412}], 
        PointBox[{21.2, 0.04364384665168662}], 
        PointBox[{21.3, 0.041364191525992786`}], 
        PointBox[{21.4, 0.03929267938013198}], 
        PointBox[{21.5, 0.04198490339136194}], 
        PointBox[{21.6, 0.043350653908802085`}], 
        PointBox[{21.7, 0.04037007669386158}], 
        PointBox[{21.8, 0.042237566617786715`}], 
        PointBox[{21.9, 0.044104008381152096`}], 
        PointBox[{22., 0.04514183752533639}], 
        PointBox[{22.1, 0.042942017043487136`}], 
        PointBox[{22.2, 0.04553828951031369}], 
        PointBox[{22.3, 0.04571488843413122}], 
        PointBox[{22.4, 0.04244152108011118}], 
        PointBox[{22.5, 0.04326328398068855}], 
        PointBox[{22.6, 0.0463187559096672}], 
        PointBox[{22.7, 0.04438185458023124}], 
        PointBox[{22.8, 0.043671780563825514`}], 
        PointBox[{22.9, 0.046381297614929325`}], 
        PointBox[{23., 0.0480788161506715}], 
        PointBox[{23.1, 0.046446242663028645`}], 
        PointBox[{23.2, 0.046725983235182636`}], 
        PointBox[{23.3, 0.04926622869058049}], 
        PointBox[{23.4, 0.04639201026054427}], 
        PointBox[{23.5, 0.0450461096433261}], 
        PointBox[{23.6, 0.04806951046024344}], 
        PointBox[{23.7, 0.048619079301045705`}], 
        PointBox[{23.8, 0.045829970533476865`}], 
        PointBox[{23.9, 0.04832387317774302}], 
        PointBox[{24., 0.04989681020570517}], 
        PointBox[{24.1, 0.050230059184474686`}], 
        PointBox[{24.2, 0.04836351788030406}], 
        PointBox[{24.3, 0.05144466438719231}], 
        PointBox[{24.4, 0.05049455147808643}], 
        PointBox[{24.5, 0.047583036492750995`}], 
        PointBox[{24.6, 0.04920776829574306}], 
        PointBox[{24.7, 0.05182565401962959}], 
        PointBox[{24.8, 0.04914148811400744}], 
        PointBox[{24.9, 0.04960175891548311}], 
        PointBox[{25., 0.05181372825754671}], 
        PointBox[{25.1, 0.053206877535274685`}], 
        PointBox[{25.2, 0.05102258523681375}], 
        PointBox[{25.3, 0.05242295456120568}], 
        PointBox[{25.4, 0.054006502419886165`}], 
        PointBox[{25.5, 0.050740660275612685`}], 
        PointBox[{25.6, 0.050383788227405295`}], 
        PointBox[{25.7, 0.053618821573202774`}], 
        PointBox[{25.8, 0.052974751035716056`}], 
        PointBox[{25.9, 0.05093191396878964}], 
        PointBox[{26., 0.0537106430599425}], 
        PointBox[{26.1, 0.054913961686648444`}], 
        PointBox[{26.2, 0.05418851041491633}], 
        PointBox[{26.3, 0.05315001666384751}], 
        PointBox[{26.4, 0.05628108347239845}], 
        PointBox[{26.5, 0.05413389964431191}], 
        PointBox[{26.6, 0.05196693677706368}], 
        PointBox[{26.7, 0.05440268299371565}], 
        PointBox[{26.8, 0.05613978889853962}], 
        PointBox[{26.9, 0.053031643812692576`}], 
        PointBox[{27., 0.054747117441211}], 
        PointBox[{27.1, 0.05615632529744703}], 
        PointBox[{27.2, 0.056907709415731575`}], 
        PointBox[{27.3, 0.05454995463260603}], 
        PointBox[{27.4, 0.05710528170741545}], 
        PointBox[{27.5, 0.057222568108723816`}], 
        PointBox[{27.6, 0.05402226881178157}], 
        PointBox[{27.7, 0.05480380273429069}], 
        PointBox[{27.8, 0.05790521434518807}], 
        PointBox[{27.9, 0.055903895523203996`}], 
        PointBox[{28., 0.055240458729698017`}], 
        PointBox[{28.1, 0.0576519305601347}], 
        PointBox[{28.2, 0.05848903163381036}], 
        PointBox[{28.3, 0.05666941181218033}], 
        PointBox[{28.4, 0.057007661103493715`}], 
        PointBox[{28.5, 0.05939678035094944}], 
        PointBox[{28.6, 0.05638345440608234}], 
        PointBox[{28.7, 0.05529528828267244}], 
        PointBox[{28.8, 0.058350710514469314`}], 
        PointBox[{28.9, 0.05869383189450447}], 
        PointBox[{29., 0.05595437711630163}], 
        PointBox[{29.1, 0.05847936136957092}], 
        PointBox[{29.2, 0.059097656794954795`}], 
        PointBox[{29.3, 0.05880922798272722}], 
        PointBox[{29.4, 0.05699762850547308}], 
        PointBox[{29.5, 0.06018427258468619}], 
        PointBox[{29.6, 0.05870892417576893}], 
        PointBox[{29.7, 0.05610329770838324}], 
        PointBox[{29.8, 0.058006269741258165`}], 
        PointBox[{29.9, 0.06040612590363524}], 
        PointBox[{30., 0.057403631991062305`}], 
        PointBox[{30.1, 0.058360428233726114`}], 
        PointBox[{30.2, 0.05979436990916993}], 
        PointBox[{30.3, 0.06017661562981759}], 
        PointBox[{30.4, 0.057699833925357935`}], 
        PointBox[{30.5, 0.05961149585244132}], 
        PointBox[{30.6, 0.06050806831364113}], 
        PointBox[{30.7, 0.05724134944375306}], 
        PointBox[{30.8, 0.05741679681347064}], 
        PointBox[{30.9, 0.06066522489834302}], 
        PointBox[{31., 0.0593329537610124}], 
        PointBox[{31.1, 0.05786450309460877}], 
        PointBox[{31.2, 0.060345341869894306`}], 
        PointBox[{31.3, 0.06041423312821834}], 
        PointBox[{31.4, 0.058879128654179}], 
        PointBox[{31.5, 0.058401064536586035`}], 
        PointBox[{31.6, 0.061227749843594664`}], 
        PointBox[{31.7, 0.05854546436206025}], 
        PointBox[{31.8, 0.056951376850975725`}], 
        PointBox[{31.9, 0.05975423557136598}], 
        PointBox[{32., 0.06081265995131288}], 
        PointBox[{32.1, 0.05773197868079037}], 
        PointBox[{32.2, 0.05987754660453221}], 
        PointBox[{32.3, 0.06016871146936525}], 
        PointBox[{32.4, 0.059806333418819586`}], 
        PointBox[{32.5, 0.05751871844820728}], 
        PointBox[{32.6, 0.06050986309904771}], 
        PointBox[{32.7, 0.059676556631048705`}], 
        PointBox[{32.8, 0.0567833974569586}], 
        PointBox[{32.9, 0.05821687474160114}], 
        PointBox[{33., 0.0610209048854379}], 
        PointBox[{33.1, 0.058315623747129064`}], 
        PointBox[{33.2, 0.05853509803548767}], 
        PointBox[{33.3, 0.06015016631346777}], 
        PointBox[{33.4, 0.05982406682914249}], 
        PointBox[{33.5, 0.05735643290472944}], 
        PointBox[{33.6, 0.058575631054603026`}], 
        PointBox[{33.7, 0.060130409514278595`}], 
        PointBox[{33.8, 0.056911281084895494`}], 
        PointBox[{33.9, 0.05654652813553327}], 
        PointBox[{34., 0.05980502017192444}], 
        PointBox[{34.1, 0.05915049592877863}], 
        PointBox[{34.2, 0.05701780157696867}], 
        PointBox[{34.3, 0.05947544476765154}], 
        PointBox[{34.4, 0.058912989789437986`}], 
        PointBox[{34.5, 0.05750730791214779}], 
        PointBox[{34.6, 0.05630030724591092}], 
        PointBox[{34.7, 0.05936520759941396}], 
        PointBox[{34.8, 0.057149691656028324`}], 
        PointBox[{34.9, 0.05507714414098109}], 
        PointBox[{35., 0.057559214455713256`}], 
        PointBox[{35.1, 0.05925389238614357}], 
        PointBox[{35.2, 0.056049774183324956`}], 
        PointBox[{35.3, 0.05764464110042852}], 
        PointBox[{35.4, 0.0580185221147422}], 
        PointBox[{35.5, 0.05722339834162598}], 
        PointBox[{35.6, 0.054594380126485716`}], 
        PointBox[{35.7, 0.05714963357249518}], 
        PointBox[{35.8, 0.057103168110655446`}], 
        PointBox[{35.9, 0.05397199191460499}], 
        PointBox[{36., 0.05484867965739356}], 
        PointBox[{36.1, 0.05795905281457179}], 
        PointBox[{36.2, 0.05578984997388898}], 
        PointBox[{36.3, 0.05512262940315891}], 
        PointBox[{36.4, 0.057068585667044106`}], 
        PointBox[{36.5, 0.055995751157488366`}], 
        PointBox[{36.6, 0.05363538057878926}], 
        PointBox[{36.7, 0.053960302106796115`}], 
        PointBox[{36.8, 0.0561995337580023}], 
        PointBox[{36.9, 0.05320714511777745}], 
        PointBox[{37., 0.05217266110686368}], 
        PointBox[{37.1, 0.05531089647179845}], 
        PointBox[{37.2, 0.05551772385413457}], 
        PointBox[{37.3, 0.052756048889471226`}], 
        PointBox[{37.4, 0.055010120095918956`}], 
        PointBox[{37.5, 0.05428857521088625}], 
        PointBox[{37.6, 0.05284699056981725}], 
        PointBox[{37.7, 0.05086033374835937}], 
        PointBox[{37.8, 0.05393074495948698}], 
        PointBox[{37.9, 0.05252211901898138}], 
        PointBox[{38., 0.04988491050555155}], 
        PointBox[{38.1, 0.05183238928676873}], 
        PointBox[{38.2, 0.054225595568867434`}], 
        PointBox[{38.3, 0.05121165544426851}], 
        PointBox[{38.4, 0.05187624204531794}], 
        PointBox[{38.5, 0.05287375185907721}], 
        PointBox[{38.6, 0.05146467791909739}], 
        PointBox[{38.7, 0.04865578124176755}], 
        PointBox[{38.8, 0.05033323938769597}], 
        PointBox[{38.9, 0.051390332086103566`}], 
        PointBox[{39., 0.048148927409006136`}], 
        PointBox[{39.1, 0.04816739656808851}], 
        PointBox[{39.2, 0.05148060008560297}], 
        PointBox[{39.3, 0.050296529309290794`}], 
        PointBox[{39.4, 0.04848446908112144}], 
        PointBox[{39.5, 0.050750229846219026`}], 
        PointBox[{39.6, 0.04933185105740489}], 
        PointBox[{39.7, 0.047223401315203396`}], 
        PointBox[{39.8, 0.04630224364051664}], 
        PointBox[{39.9, 0.049168915354158675`}], 
        PointBox[{40., 0.04686087218692846}], 
        PointBox[{40.1, 0.04488831301840031}], 
        PointBox[{40.2, 0.04760254274577642}], 
        PointBox[{40.3, 0.04898426042424522}], 
        PointBox[{40.4, 0.0458285233280054}], 
        PointBox[{40.5, 0.04736318187195767}], 
        PointBox[{40.6, 0.04741342957460246}], 
        PointBox[{40.7, 0.0457672040363668}], 
        PointBox[{40.8, 0.043068858263912935`}], 
        PointBox[{40.9, 0.045563450470606025`}], 
        PointBox[{41., 0.04556964435648712}], 
        PointBox[{41.1, 0.04239222972447836}], 
        PointBox[{41.2, 0.04331692541715913}], 
        PointBox[{41.3, 0.046408263553414805`}], 
        PointBox[{41.4, 0.04427072575553583}], 
        PointBox[{41.5, 0.043410848181662264`}], 
        PointBox[{41.6, 0.04535329667159651}], 
        PointBox[{41.7, 0.04365236537928394}], 
        PointBox[{41.8, 0.041110435088151036`}], 
        PointBox[{41.9, 0.041200367035080926`}], 
        PointBox[{42., 0.043566473207430616`}], 
        PointBox[{42.1, 0.04076724525717736}], 
        PointBox[{42.2, 0.03943157898359629}], 
        PointBox[{42.3, 0.04257135511025298}], 
        PointBox[{42.4, 0.043013547857558704`}], 
        PointBox[{42.5, 0.04010911810776562}], 
        PointBox[{42.6, 0.04208619230234035}], 
        PointBox[{42.7, 0.0415123068817438}], 
        PointBox[{42.8, 0.03980295957836279}], 
        PointBox[{42.9, 0.0375120228203348}], 
        PointBox[{43., 0.04033997456600391}], 
        PointBox[{43.1, 0.039643653076959}], 
        PointBox[{43.2, 0.036630224030843844`}], 
        PointBox[{43.3, 0.038202030880434425`}], 
        PointBox[{43.4, 0.04091157885229443}], 
        PointBox[{43.5, 0.03829797007233346}], 
        PointBox[{43.6, 0.03812108379846789}], 
        PointBox[{43.7, 0.03973068810809234}], 
        PointBox[{43.8, 0.038185438137491014`}], 
        PointBox[{43.9, 0.035534686613257024`}], 
        PointBox[{44., 0.03630342832847174}], 
        PointBox[{44.1, 0.038250363198433335`}], 
        PointBox[{44.2, 0.03522455763465566}], 
        PointBox[{44.3, 0.034340638465499125`}], 
        PointBox[{44.4, 0.0376415317111733}], 
        PointBox[{44.5, 0.037472037272902214`}], 
        PointBox[{44.6, 0.034869683449676246`}], 
        PointBox[{44.7, 0.037048612124495346`}], 
        PointBox[{44.8, 0.036372952019952935`}], 
        PointBox[{44.9, 0.03489455645883351}], 
        PointBox[{45., 0.03299621420237429}], 
        PointBox[{45.1, 0.03591762054851833}], 
        PointBox[{45.2, 0.03488580541512321}], 
        PointBox[{45.3, 0.031980223746718925`}], 
        PointBox[{45.4, 0.033893254364642175`}], 
        PointBox[{45.5, 0.03631352518140428}], 
        PointBox[{45.6, 0.03355153105616499}], 
        PointBox[{45.7, 0.03374648456864871}], 
        PointBox[{45.8, 0.03524989382886565}], 
        PointBox[{45.9, 0.0343686121457002}], 
        PointBox[{46., 0.03184290141120503}], 
        PointBox[{46.1, 0.032935910443049866`}], 
        PointBox[{46.2, 0.034711478793185084`}], 
        PointBox[{46.3, 0.0316012398794738}], 
        PointBox[{46.4, 0.030905238440937455`}], 
        PointBox[{46.5, 0.03423325671022736}], 
        PointBox[{46.6, 0.033828673977573644`}], 
        PointBox[{46.7, 0.03140469407327415}], 
        PointBox[{46.8, 0.03371885225603802}], 
        PointBox[{46.9, 0.03353657291001826}], 
        PointBox[{47., 0.032561244410452474`}], 
        PointBox[{47.1, 0.030897588887081027`}], 
        PointBox[{47.2, 0.03386309009985342}], 
        PointBox[{47.3, 0.032753732854944054`}], 
        PointBox[{47.4, 0.02985961402706463}], 
        PointBox[{47.5, 0.03186070807848028}], 
        PointBox[{47.6, 0.03418027932410427}], 
        PointBox[{47.7, 0.0314246357256064}], 
        PointBox[{47.8, 0.03178660928513987}], 
        PointBox[{47.9, 0.0334777256553065}], 
        PointBox[{48., 0.03362820766654034}], 
        PointBox[{48.1, 0.03129419914504969}], 
        PointBox[{48.2, 0.0325161227495661}], 
        PointBox[{48.3, 0.03428288404091621}], 
        PointBox[{48.4, 0.031139089065714703`}], 
        PointBox[{48.5, 0.03047485593475571}], 
        PointBox[{48.6, 0.03378583281741873}], 
        PointBox[{48.7, 0.033352935367616736`}], 
        PointBox[{48.8, 0.03101792396442828}], 
        PointBox[{48.9, 0.033495703165919016`}], 
        PointBox[{49., 0.03416699317175819}], 
        PointBox[{49.1, 0.03365322335840269}], 
        PointBox[{49.2, 0.03214445966152056}], 
        PointBox[{49.3, 0.0351695946087519}], 
        PointBox[{49.4, 0.033990630830638816`}], 
        PointBox[{49.5, 0.031121527076314083`}], 
        PointBox[{49.6, 0.03314714833175246}], 
        PointBox[{49.7, 0.03542135426154252}], 
        PointBox[{49.8, 0.03266777661840325}], 
        PointBox[{49.9, 0.03322094059727632}], 
        PointBox[{50., 0.03520300970352439}], 
        PointBox[{50.1, 0.036247762300909134`}], 
        PointBox[{50.2, 0.034013623625519636`}], 
        PointBox[{50.3, 0.03542377302245315}], 
        PointBox[{50.4, 0.03708786046614816}], 
        PointBox[{50.5, 0.03387278033743353}], 
        PointBox[{50.6, 0.0333582883200886}], 
        PointBox[{50.7, 0.036647097867487634`}], 
        PointBox[{50.8, 0.03608224059890566}], 
        PointBox[{50.9, 0.03391137188176933}], 
        PointBox[{51., 0.03659519958377775}], 
        PointBox[{51.1, 0.037981509514487546`}], 
        PointBox[{51.2, 0.03752977425239743}], 
        PointBox[{51.3, 0.03626831455058453}], 
        PointBox[{51.4, 0.0393584341803485}], 
        PointBox[{51.5, 0.037861232125138755`}], 
        PointBox[{51.6, 0.035178951752061496`}], 
        PointBox[{51.7, 0.03737648232774081}], 
        PointBox[{51.8, 0.0394555711210388}], 
        PointBox[{51.9, 0.036593973694799116`}], 
        PointBox[{52., 0.037582040671801535`}], 
        PointBox[{52.1, 0.039676130317734856`}], 
        PointBox[{52.2, 0.041072711121774665`}], 
        PointBox[{52.3, 0.038818936400221195`}], 
        PointBox[{52.4, 0.04064856022927747}], 
        PointBox[{52.5, 0.04189046845484056}], 
        PointBox[{52.6, 0.03857102927876144}], 
        PointBox[{52.7, 0.03849650476770647}], 
        PointBox[{52.8, 0.04175370475568159}], 
        PointBox[{52.9, 0.040743998190885436`}], 
        PointBox[{53., 0.0389922324734085}], 
        PointBox[{53.1, 0.04183320476591378}], 
        PointBox[{53.2, 0.043531422746316856`}], 
        PointBox[{53.3, 0.042688438696884844`}], 
        PointBox[{53.4, 0.04191732117192352}], 
        PointBox[{53.5, 0.044966396081084145`}], 
        PointBox[{53.6, 0.042865897058684585`}], 
        PointBox[{53.7, 0.04063284975134125}], 
        PointBox[{53.8, 0.043181168662598475`}], 
        PointBox[{53.9, 0.04477903092117637}], 
        PointBox[{54., 0.04178243280089745}], 
        PointBox[{54.1, 0.04346553294774886}], 
        PointBox[{54.2, 0.045381407566278065`}], 
        PointBox[{54.3, 0.04654744289463646}], 
        PointBox[{54.4, 0.044299448046216695`}], 
        PointBox[{54.5, 0.046752770834331034`}], 
        PointBox[{54.6, 0.047148976327913095`}], 
        PointBox[{54.7, 0.04384947053695848}], 
        PointBox[{54.8, 0.04448755091392927}], 
        PointBox[{54.9, 0.047608454687985774`}], 
        PointBox[{55., 0.045844037562690565`}], 
        PointBox[{55.1, 0.04491892239378796}], 
        PointBox[{55.2, 0.04766611212214958}], 
        PointBox[{55.3, 0.049320645521127804`}], 
        PointBox[{55.4, 0.047812184063417924`}], 
        PointBox[{55.5, 0.047887760832531476`}], 
        PointBox[{55.6, 0.05054852727123528}], 
        PointBox[{55.7, 0.047760264600833435`}], 
        PointBox[{55.8, 0.04628238355010925}], 
        PointBox[{55.9, 0.049236562906249906`}], 
        PointBox[{56., 0.04997298585542616}], 
        PointBox[{56.1, 0.04710193160318756}], 
        PointBox[{56.2, 0.04950856993370014}], 
        PointBox[{56.3, 0.05103875977951941}], 
        PointBox[{56.4, 0.051474484164025266`}], 
        PointBox[{56.5, 0.04951041951985381}], 
        PointBox[{56.6, 0.05254835484626306}], 
        PointBox[{56.7, 0.051739367420954856`}], 
        PointBox[{56.8, 0.048776448687924294`}], 
        PointBox[{56.9, 0.05028478830481781}], 
        PointBox[{57., 0.052991323770123874`}], 
        PointBox[{57.1, 0.05037796289303731}], 
        PointBox[{57.2, 0.05068843616542206}], 
        PointBox[{57.3, 0.05292169692657167}], 
        PointBox[{57.4, 0.05426137974769677}], 
        PointBox[{57.5, 0.05211084009377658}], 
        PointBox[{57.6, 0.05337607766582831}], 
        PointBox[{57.7, 0.05507440644012252}], 
        PointBox[{57.8, 0.051830245435639716`}], 
        PointBox[{57.9, 0.0513751684773229}], 
        PointBox[{58., 0.05459886205179739}], 
        PointBox[{58.1, 0.05408142753531063}], 
        PointBox[{58.2, 0.05193545459948624}], 
        PointBox[{58.3, 0.054692154783213306`}], 
        PointBox[{58.4, 0.05579870912930127}], 
        PointBox[{58.5, 0.05514063999107755}], 
        PointBox[{58.6, 0.053993824319905605`}], 
        PointBox[{58.7, 0.057149457626961886`}], 
        PointBox[{58.8, 0.05507256865673453}], 
        PointBox[{58.9, 0.052851155291439945`}], 
        PointBox[{59., 0.055225899329527324`}], 
        PointBox[{59.1, 0.05705239827241088}], 
        PointBox[{59.2, 0.053938367560786495`}], 
        PointBox[{59.3, 0.05557396741311225}], 
        PointBox[{59.4, 0.056955194379334}], 
        PointBox[{59.5, 0.05767260692224568}], 
        PointBox[{59.6, 0.055287075254726696`}], 
        PointBox[{59.7, 0.05778201379503035}], 
        PointBox[{59.8, 0.05797975241191056}], 
        PointBox[{59.9, 0.05476920945432623}], 
        PointBox[{60., 0.0554862614518579}], 
        PointBox[{60.1, 0.0586120660562458}], 
        PointBox[{60.2, 0.05667192599964275}], 
        PointBox[{60.3, 0.05592393142167162}], 
        PointBox[{60.4, 0.05833434732260666}], 
        PointBox[{60.5, 0.05906224533683082}], 
        PointBox[{60.6, 0.05726532243499924}], 
        PointBox[{60.7, 0.05752077910701626}], 
        PointBox[{60.8, 0.05995686783728902}], 
        PointBox[{60.9, 0.05696808606553234}], 
        PointBox[{61., 0.0558342507758335}], 
        PointBox[{61.1, 0.058869743724518975`}], 
        PointBox[{61.2, 0.05928023915676309}], 
        PointBox[{61.3, 0.05649976151261556}], 
        PointBox[{61.4, 0.05899287100845229}], 
        PointBox[{61.5, 0.059532032359009945`}], 
        PointBox[{61.6, 0.05923073981553383}], 
        PointBox[{61.7, 0.05736763259907684}], 
        PointBox[{61.8, 0.060546481716375174`}], 
        PointBox[{61.9, 0.059115456966473606`}], 
        PointBox[{62., 0.05648841359584507}], 
        PointBox[{62.1, 0.05835550041586127}], 
        PointBox[{62.2, 0.0607925764390155}], 
        PointBox[{62.3, 0.05780171266508376}], 
        PointBox[{62.4, 0.05870467670175745}], 
        PointBox[{62.5, 0.06012343920143046}], 
        PointBox[{62.6, 0.06041239943729355}], 
        PointBox[{62.7, 0.05792348813354351}], 
        PointBox[{62.8, 0.05978911621686904}], 
        PointBox[{62.9, 0.06072801021344806}], 
        PointBox[{63., 0.05746290676058894}], 
        PointBox[{63.1, 0.05760387182696803}], 
        PointBox[{63.2, 0.060857374517042186`}], 
        PointBox[{63.3, 0.05956450170550412}], 
        PointBox[{63.4, 0.05804959488902839}], 
        PointBox[{63.5, 0.06052023671624016}], 
        PointBox[{63.6, 0.06048419504144367}], 
        PointBox[{63.7, 0.05894235454117291}], 
        PointBox[{63.8, 0.05841432330983343}], 
        PointBox[{63.9, 0.06125773313347964}], 
        PointBox[{64., 0.0585985882928751}], 
        PointBox[{64.1, 0.056977856945675094`}], 
        PointBox[{64.2, 0.05976516649677407}], 
        PointBox[{64.3, 0.06086092537281134}], 
        PointBox[{64.4, 0.0577649526554559}], 
        PointBox[{64.5, 0.0598770133609133}], 
        PointBox[{64.6, 0.06012297396823645}], 
        PointBox[{64.7, 0.059699270049951056`}], 
        PointBox[{64.8, 0.05738076860982786}], 
        PointBox[{64.9, 0.06035196881680207}], 
        PointBox[{65., 0.05955753283795544}], 
        PointBox[{65.1, 0.05665054334850515}], 
        PointBox[{65.2, 0.05805692067741221}], 
        PointBox[{65.3, 0.060880884417995586`}], 
        PointBox[{65.4, 0.058195822111540695`}], 
        PointBox[{65.5, 0.05836506486501272}], 
        PointBox[{65.6, 0.05998085990482348}], 
        PointBox[{65.7, 0.059548631194929987`}], 
        PointBox[{65.8, 0.05707047164516582}], 
        PointBox[{65.9, 0.058242388129754914`}], 
        PointBox[{66., 0.059833581851837764`}], 
        PointBox[{66.1, 0.05662270960303737}], 
        PointBox[{66.2, 0.056223882728111484`}], 
        PointBox[{66.3, 0.05948159246329796}], 
        PointBox[{66.4, 0.05886823765979605}], 
        PointBox[{66.5, 0.056694540344078004`}], 
        PointBox[{66.6, 0.059138279887874255`}], 
        PointBox[{66.7, 0.058502830735577924`}], 
        PointBox[{66.8, 0.057071388994289894`}], 
        PointBox[{66.9, 0.055815163277768046`}], 
        PointBox[{67., 0.058884910350438094`}], 
        PointBox[{67.1, 0.056709231245802204`}], 
        PointBox[{67.2, 0.05460303680089878}], 
        PointBox[{67.3, 0.05706300630570973}], 
        PointBox[{67.4, 0.05879657473088746}], 
        PointBox[{67.5, 0.055592446248363646`}], 
        PointBox[{67.6, 0.05713438153404788}], 
        PointBox[{67.7, 0.05751511151063491}], 
        PointBox[{67.8, 0.05663622836255929}], 
        PointBox[{67.9, 0.053981395457085773`}], 
        PointBox[{68., 0.05649214875576607}], 
        PointBox[{68.1, 0.056509640561706945`}], 
        PointBox[{68.2, 0.05336396703778588}], 
        PointBox[{68.3, 0.054195829168518374`}], 
        PointBox[{68.4, 0.057324697763823616`}], 
        PointBox[{68.5, 0.05520458980407991}], 
        PointBox[{68.6, 0.054462120006239595`}], 
        PointBox[{68.7, 0.05642903825655251}], 
        PointBox[{68.8, 0.05527110059082206}], 
        PointBox[{68.9, 0.05290902980322749}], 
        PointBox[{69., 0.0531554819448501}], 
        PointBox[{69.1, 0.0554432366935543}], 
        PointBox[{69.2, 0.0524826947924318}], 
        PointBox[{69.3, 0.0513873384188548}], 
        PointBox[{69.4, 0.05451121844423585}], 
        PointBox[{69.5, 0.05479061604203069}], 
        PointBox[{69.6, 0.05198597977962966}], 
        PointBox[{69.7, 0.054203686266446664`}], 
        PointBox[{69.8, 0.053487287331235575`}], 
        PointBox[{69.9, 0.05200903415099761}], 
        PointBox[{70., 0.04995858369199958}], 
        PointBox[{70.1, 0.05300727758232547}], 
        PointBox[{70.2, 0.051689000885685336`}], 
        PointBox[{70.3, 0.04900124786025421}], 
        PointBox[{70.4, 0.050892464002084206`}], 
        PointBox[{70.5, 0.05334188722127722}], 
        PointBox[{70.6, 0.050367890047119605`}], 
        PointBox[{70.7, 0.05092690166813462}], 
        PointBox[{70.8, 0.05199597257571519}], 
        PointBox[{70.9, 0.05051553154484578}], 
        PointBox[{71., 0.047701194138140814`}], 
        PointBox[{71.1, 0.04927406198730956}], 
        PointBox[{71.2, 0.05044033027621926}], 
        PointBox[{71.3, 0.047205617300111545`}], 
        PointBox[{71.4, 0.04712943102846265}], 
        PointBox[{71.5, 0.05045021239319385}], 
        PointBox[{71.6, 0.049377567591120615`}], 
        PointBox[{71.7, 0.04745818761956592}], 
        PointBox[{71.8, 0.04973358302755459}], 
        PointBox[{71.9, 0.048320850229798734`}], 
        PointBox[{72., 0.04623345157596355}], 
        PointBox[{72.1, 0.045188075418318305`}], 
        PointBox[{72.2, 0.0480895700720507}], 
        PointBox[{72.3, 0.04588444498622711}], 
        PointBox[{72.4, 0.04381249861201514}], 
        PointBox[{72.5, 0.04646448034801723}], 
        PointBox[{72.6, 0.04796270210489982}], 
        PointBox[{72.7, 0.044805603156033644`}], 
        PointBox[{72.8, 0.046227339952924426`}], 
        PointBox[{72.9, 0.04640303912346426}], 
        PointBox[{73., 0.04473540718389134}], 
        PointBox[{73.1, 0.04199468874387703}], 
        PointBox[{73.2, 0.04438243086196253}], 
        PointBox[{73.3, 0.04455974848052562}], 
        PointBox[{73.4, 0.04134861064454807}], 
        PointBox[{73.5, 0.042140095005815746`}], 
        PointBox[{73.6, 0.04528386342905453}], 
        PointBox[{73.7, 0.04328338583404201}], 
        PointBox[{73.8, 0.042249427781871296`}], 
        PointBox[{73.9, 0.044270146163047655`}], 
        PointBox[{74., 0.04260015532603102}], 
        PointBox[{74.1, 0.040126661440547357`}], 
        PointBox[{74.2, 0.04002653488099141}], 
        PointBox[{74.3, 0.042505084068437136`}], 
        PointBox[{74.4, 0.03980973608658548}], 
        PointBox[{74.5, 0.038314018407032226`}], 
        PointBox[{74.6, 0.041396151117317224`}], 
        PointBox[{74.7, 0.04202817564570749}], 
        PointBox[{74.8, 0.03905758641199819}], 
        PointBox[{74.9, 0.04093626070680222}], 
        PointBox[{75., 0.0405403081217622}], 
        PointBox[{75.1, 0.03889876172001775}], 
        PointBox[{75.2, 0.03650588099348301}], 
        PointBox[{75.3, 0.03924993551697475}], 
        PointBox[{75.4, 0.03878154888019326}], 
        PointBox[{75.5, 0.03568618038872818}], 
        PointBox[{75.6, 0.037081576715915464`}], 
        PointBox[{75.7, 0.03990718737022874}], 
        PointBox[{75.8, 0.037439388856449915`}], 
        PointBox[{75.9, 0.03703215558355576}], 
        PointBox[{76., 0.03879624843050527}], 
        PointBox[{76.1, 0.0373458156862919}], 
        PointBox[{76.2, 0.034796412840891675`}], 
        PointBox[{76.3, 0.03531974231198395}], 
        PointBox[{76.4, 0.03745689290013869}], 
        PointBox[{76.5, 0.034535059999732644`}], 
        PointBox[{76.6, 0.03342399379710853}], 
        PointBox[{76.7, 0.036678999062959364`}], 
        PointBox[{76.8, 0.03676902877867265}], 
        PointBox[{76.9, 0.034037913064367945`}], 
        PointBox[{77., 0.036139937570209196`}], 
        PointBox[{77.1, 0.035693994685930056`}], 
        PointBox[{77.2, 0.03439682323988987}], 
        PointBox[{77.3, 0.03234085444347312}], 
        PointBox[{77.4, 0.03520504234025418}], 
        PointBox[{77.5, 0.03444979199844588}], 
        PointBox[{77.6, 0.0314207000237102}], 
        PointBox[{77.7, 0.03311393444476219}], 
        PointBox[{77.8, 0.035711858114970525`}], 
        PointBox[{77.9, 0.03309969705011521}], 
        PointBox[{78., 0.03302152706564156}], 
        PointBox[{78.1, 0.03474134028173454}], 
        PointBox[{78.2, 0.034036971125993326`}], 
        PointBox[{78.3, 0.03163648841348592}], 
        PointBox[{78.4, 0.032448509506384574`}], 
        PointBox[{78.5, 0.03446647053418629}], 
        PointBox[{78.6, 0.03146564316982956}], 
        PointBox[{78.7, 0.03049213711370943}], 
        PointBox[{78.8, 0.03378135063737262}], 
        PointBox[{78.9, 0.033683854701953474`}], 
        PointBox[{79., 0.03109321829597756}], 
        PointBox[{79.1, 0.03334433028707931}], 
        PointBox[{79.2, 0.03341687615709961}], 
        PointBox[{79.3, 0.03270895472559291}], 
        PointBox[{79.4, 0.030861575915892323`}], 
        PointBox[{79.5, 0.03378462913745707}], 
        PointBox[{79.6, 0.032970428725192284`}], 
        PointBox[{79.7, 0.02994020278748334}], 
        PointBox[{79.8, 0.03169876341981745}], 
        PointBox[{79.9, 0.034223230247847125`}], 
        PointBox[{80., 0.03161583901818467}], 
        PointBox[{80.1, 0.03169191339569762}], 
        PointBox[{80.2, 0.03361168958819888}], 
        PointBox[{80.3, 0.03396910210409263}], 
        PointBox[{80.4, 0.03175969623982017}], 
        PointBox[{80.5, 0.032704903143106645`}], 
        PointBox[{80.6, 0.03471763820402097}], 
        PointBox[{80.7, 0.03167679357014262}], 
        PointBox[{80.8, 0.030740743788670744`}], 
        PointBox[{80.9, 0.03401442954059289}], 
        PointBox[{81., 0.03388332940965285}], 
        PointBox[{81.1, 0.031377044954184447`}], 
        PointBox[{81.2, 0.03380297706270184}], 
        PointBox[{81.3, 0.03467501287887503}], 
        PointBox[{81.4, 0.034429532108346456`}], 
        PointBox[{81.5, 0.0327433069604463}], 
        PointBox[{81.6, 0.03574165552036164}], 
        PointBox[{81.7, 0.034819804716375184`}], 
        PointBox[{81.8, 0.031829541467004084`}], 
        PointBox[{81.9, 0.033640938040836774`}], 
        PointBox[{82., 0.03610349223410716}], 
        PointBox[{82.1, 0.033467313243294855`}], 
        PointBox[{82.2, 0.03377113859743043}], 
        PointBox[{82.3, 0.03593021905331094}], 
        PointBox[{82.4, 0.03713120195455455}], 
        PointBox[{82.5, 0.03498342945090303}], 
        PointBox[{82.6, 0.03616591018609724}], 
        PointBox[{82.7, 0.038041923198288516`}], 
        PointBox[{82.8, 0.03489415665234882}], 
        PointBox[{82.9, 0.03416412067640434}], 
        PointBox[{83., 0.03743066724183606}], 
        PointBox[{83.1, 0.037110189852417375`}], 
        PointBox[{83.2, 0.03477951997563506}], 
        PointBox[{83.3, 0.03743538978916703}], 
        PointBox[{83.4, 0.03891338184152184}], 
        PointBox[{83.5, 0.03866859664789719}], 
        PointBox[{83.6, 0.03724633732363808}], 
        PointBox[{83.7, 0.04034341620900333}], 
        PointBox[{83.8, 0.03902573118337232}], 
        PointBox[{83.9, 0.036242419786567615`}], 
        PointBox[{84., 0.038289665209571576`}], 
        PointBox[{84.1, 0.04052574521735628}], 
        PointBox[{84.2, 0.037722267366709646`}], 
        PointBox[{84.3, 0.038531152724668394`}], 
        PointBox[{84.4, 0.040722248424165115`}], 
        PointBox[{84.5, 0.04221058090393909}], 
        PointBox[{84.6, 0.03998608891164627}], 
        PointBox[{84.7, 0.041660754068147045`}], 
        PointBox[{84.8, 0.043066858180767005`}], 
        PointBox[{84.9, 0.03976949003681056}], 
        PointBox[{85., 0.039546041001374696`}], 
        PointBox[{85.1, 0.042808242095248764`}], 
        PointBox[{85.2, 0.041965077316021254`}], 
        PointBox[{85.3, 0.04007232473667497}], 
        PointBox[{85.4, 0.04291364899539191}], 
        PointBox[{85.5, 0.044612404775709935`}], 
        PointBox[{85.6, 0.043899487055802267`}], 
        PointBox[{85.7, 0.04299197731627651}], 
        PointBox[{85.8, 0.0460810786139474}], 
        PointBox[{85.9, 0.04407868449360915}], 
        PointBox[{86., 0.04176697432250926}], 
        PointBox[{86.1, 0.044229873588684805`}], 
        PointBox[{86.2, 0.045951524456276725`}], 
        PointBox[{86.3, 0.042951754293969274`}], 
        PointBox[{86.4, 0.044534330736013296`}], 
        PointBox[{86.5, 0.046467370335807674`}], 
        PointBox[{86.6, 0.04768465383901814}], 
        PointBox[{86.7, 0.04541636008861993}], 
        PointBox[{86.8, 0.047791871861622925`}], 
        PointBox[{86.9, 0.048293975213561345`}], 
        PointBox[{87., 0.04498735686349016}], 
        PointBox[{87.1, 0.045535015254856814`}], 
        PointBox[{87.2, 0.04868349891367724}], 
        PointBox[{87.3, 0.04700599313345255}], 
        PointBox[{87.4, 0.04597880206430429}], 
        PointBox[{87.5, 0.04873476013083286}], 
        PointBox[{87.6, 0.050341429886927275`}], 
        PointBox[{87.7, 0.04889090925965227}], 
        PointBox[{87.8, 0.048870021935944793`}], 
        PointBox[{87.9, 0.05158169254483001}], 
        PointBox[{88., 0.04882984963458433}], 
        PointBox[{88.1, 0.04730027145150565}], 
        PointBox[{88.2, 0.050219581018249644`}], 
        PointBox[{88.3, 0.05103862408090425}], 
        PointBox[{88.4, 0.048132088917190056`}], 
        PointBox[{88.5, 0.05049935642240293}], 
        PointBox[{88.6, 0.05198240742115728}], 
        PointBox[{88.7, 0.05244296027826307}], 
        PointBox[{88.8, 0.05043625520143852}], 
        PointBox[{88.9, 0.05345689197072971}], 
        PointBox[{89., 0.05269443648940924}], 
        PointBox[{89.1, 0.049718790447528645`}], 
        PointBox[{89.2, 0.051183015549389664`}], 
        PointBox[{89.3, 0.053922770018607756`}], 
        PointBox[{89.4, 0.05133102497464002}], 
        PointBox[{89.5, 0.05159150080566938}], 
        PointBox[{89.6, 0.053811396899271655`}], 
        PointBox[{89.7, 0.05508987745014075}], 
        PointBox[{89.8, 0.052944261552631336`}], 
        PointBox[{89.9, 0.05416603413207463}], 
        PointBox[{90., 0.055892965821290955`}], 
        PointBox[{90.1, 0.05265559945268181}], 
        PointBox[{90.2, 0.05217688394985811}], 
        PointBox[{90.3, 0.055396432075521994`}], 
        PointBox[{90.4, 0.0549116668408021}], 
        PointBox[{90.5, 0.052738036311143856`}], 
        PointBox[{90.6, 0.05547960759869385}], 
        PointBox[{90.7, 0.05650395577276851}], 
        PointBox[{90.8, 0.05584394092696566}], 
        PointBox[{90.9, 0.05466725776715842}], 
        PointBox[{91., 0.05782767400076753}], 
        PointBox[{91.1, 0.05575617220364647}], 
        PointBox[{91.2, 0.05353285742139423}], 
        PointBox[{91.3, 0.05589607728001418}], 
        PointBox[{91.4, 0.057738549361487895`}], 
        PointBox[{91.5, 0.054616777106697365`}], 
        PointBox[{91.6, 0.05624127089612494}], 
        PointBox[{91.7, 0.05757118448527619}], 
        PointBox[{91.8, 0.05823065582484029}], 
        PointBox[{91.9, 0.05583077755929376}], 
        PointBox[{92., 0.058323106775547515`}], 
        PointBox[{92.1, 0.05851435604097868}], 
        PointBox[{92.2, 0.05530874982071596}], 
        PointBox[{92.3, 0.0560259120694795}], 
        PointBox[{92.4, 0.05915406767144414}], 
        PointBox[{92.5, 0.05720689995348664}], 
        PointBox[{92.6, 0.056461378383487505`}], 
        PointBox[{92.7, 0.05884515431719613}], 
        PointBox[{92.8, 0.05948361314534242}], 
        PointBox[{92.9, 0.057664929318133114`}], 
        PointBox[{93., 0.05792323699888178}], 
        PointBox[{93.1, 0.060347858288777784`}], 
        PointBox[{93.2, 0.057354059592999204`}], 
        PointBox[{93.3, 0.056232629706414246`}], 
        PointBox[{93.4, 0.05927200648773412}], 
        PointBox[{93.5, 0.059668672284271994`}], 
        PointBox[{93.6, 0.05689174221115302}], 
        PointBox[{93.7, 0.059378688235187646`}], 
        PointBox[{93.8, 0.05983966248871482}], 
        PointBox[{93.9, 0.059484586166551744`}], 
        PointBox[{94., 0.05762152283074315}], 
        PointBox[{94.1, 0.06080167027578061}], 
        PointBox[{94.2, 0.059347949805537765`}], 
        PointBox[{94.3, 0.05673495109915407}], 
        PointBox[{94.4, 0.058616160895015666`}], 
        PointBox[{94.5, 0.061041462921752714`}], 
        PointBox[{94.6, 0.058036804659843205`}], 
        PointBox[{94.7, 0.058956893507224245`}], 
        PointBox[{94.8, 0.060325051742692766`}], 
        PointBox[{94.9, 0.06053044767435999}], 
        PointBox[{95., 0.05802260907545915}], 
        PointBox[{95.1, 0.05990860411129029}], 
        PointBox[{95.2, 0.0608163127414598}], 
        PointBox[{95.3, 0.05755444476401637}], 
        PointBox[{95.4, 0.05771705550266262}], 
        PointBox[{95.5, 0.06097133465643199}], 
        PointBox[{95.6, 0.0596474689801043}], 
        PointBox[{95.7, 0.058156393078479196`}], 
        PointBox[{95.8, 0.06060328509698351}], 
        PointBox[{95.9, 0.0604813845879061}], 
        PointBox[{96., 0.058893129924239826`}], 
        PointBox[{96.1, 0.05838779478835973}], 
        PointBox[{96.2, 0.06121232869004803}], 
        PointBox[{96.3, 0.05853855194667907}], 
        PointBox[{96.4, 0.056938522661094636`}], 
        PointBox[{96.5, 0.05974083684238531}], 
        PointBox[{96.6, 0.06080653409826422}], 
        PointBox[{96.7, 0.05771642986016181}], 
        PointBox[{96.8, 0.059832353028087856`}], 
        PointBox[{96.9, 0.060013258977539445`}], 
        PointBox[{97., 0.05951659882742274}], 
        PointBox[{97.1, 0.057199969851083464`}], 
        PointBox[{97.2, 0.06017844444395503}], 
        PointBox[{97.3, 0.05935614711166573}], 
        PointBox[{97.4, 0.05646014748881531}], 
        PointBox[{97.5, 0.057888696130501203`}], 
        PointBox[{97.6, 0.060699509445119586`}], 
        PointBox[{97.7, 0.057995255576708295`}], 
        PointBox[{97.8, 0.058184705915446354`}], 
        PointBox[{97.9, 0.059764160715149915`}], 
        PointBox[{98., 0.059247960389333304`}], 
        PointBox[{98.1, 0.05674259379486228}], 
        PointBox[{98.2, 0.05793685481243865}], 
        PointBox[{98.3, 0.05950206849418209}], 
        PointBox[{98.4, 0.05628994335641442}], 
        PointBox[{98.5, 0.05590932628225666}], 
        PointBox[{98.6, 0.05917294435995061}], 
        PointBox[{98.7, 0.05853086827354033}], 
        PointBox[{98.8, 0.05637308768775516}], 
        PointBox[{98.9, 0.058803396078058}], 
        PointBox[{99., 0.05809899648747561}], 
        PointBox[{99.1, 0.056615325005581384`}], 
        PointBox[{99.2, 0.055371694831651656`}], 
        PointBox[{99.3, 0.05843039227392761}], 
        PointBox[{99.4, 0.056247278057738305`}], 
        PointBox[{99.5, 0.054148663204705835`}], 
        PointBox[{99.6, 0.05662223444018602}], 
        PointBox[{99.7, 0.058338212153266594`}], 
        PointBox[{99.8, 0.055134403865223613`}], 
        PointBox[{99.9, 0.05667358584835519}], 
        PointBox[{100., 0.05702180728488508}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 0.2}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 180.}], 
        PointBox[{0.1, 186.16945971352018`}], 
        PointBox[{0.2, 185.5620286627668}], 
        PointBox[{0.3, 185.03703131602978`}], 
        PointBox[{0.4, 188.1734338057672}], 
        PointBox[{0.5, 186.7533017448917}], 
        PointBox[{0.6, 184.01415091949488`}], 
        PointBox[{0.7, 185.86520685007784`}], 
        PointBox[{0.8, 187.70147804422982`}], 
        PointBox[{0.9, 185.4307022720043}], 
        PointBox[{1., 189.42517824963136`}], 
        PointBox[{1.1, 196.66733607524287`}], 
        PointBox[{1.2, 198.86202037634104`}], 
        PointBox[{1.3, 196.6259106333319}], 
        PointBox[{1.4, 199.60475497121914`}], 
        PointBox[{1.5, 200.09593366212985`}], 
        PointBox[{1.6, 196.96430474269687`}], 
        PointBox[{1.7, 196.86464982623187`}], 
        PointBox[{1.8, 200.0972544063163}], 
        PointBox[{1.9, 198.19332104426357`}], 
        PointBox[{2., 199.38774744943512`}], 
        PointBox[{2.1, 206.37041885432743`}], 
        PointBox[{2.2, 211.37941303910094`}], 
        PointBox[{2.3, 209.40126659331594`}], 
        PointBox[{2.4, 210.58551901376654`}], 
        PointBox[{2.5, 212.96859659998998`}], 
        PointBox[{2.6, 210.49244324615427`}], 
        PointBox[{2.7, 208.5476076117248}], 
        PointBox[{2.8, 211.5023250042443}], 
        PointBox[{2.9, 211.7131873178034}], 
        PointBox[{3., 210.33316773114205`}], 
        PointBox[{3.1, 215.81582646862498`}], 
        PointBox[{3.2, 222.78279861463258`}], 
        PointBox[{3.3, 223.04986677397739`}], 
        PointBox[{3.4, 221.79900877348155`}], 
        PointBox[{3.5, 225.16887895658815`}], 
        PointBox[{3.6, 224.30026565386413`}], 
        PointBox[{3.7, 221.18559224202588`}], 
        PointBox[{3.8, 222.53104862644176`}], 
        PointBox[{3.9, 225.07302802120233`}], 
        PointBox[{4., 222.5801273020209}], 
        PointBox[{4.1, 225.59131246596849`}], 
        PointBox[{4.2, 233.1475818155886}], 
        PointBox[{4.3, 236.62185159492256`}], 
        PointBox[{4.4, 234.09788517241302`}], 
        PointBox[{4.5, 236.73700378074142`}], 
        PointBox[{4.6, 238.01698561551427`}], 
        PointBox[{4.7, 234.79142801940978`}], 
        PointBox[{4.8, 233.98523530324738`}], 
        PointBox[{4.9, 237.51276492033742`}], 
        PointBox[{5., 236.15709526926673`}], 
        PointBox[{5.1, 236.20751069634073`}], 
        PointBox[{5.2, 242.91044890095978`}], 
        PointBox[{5.3, 249.29970917361086`}], 
        PointBox[{5.4, 247.87064536575906`}], 
        PointBox[{5.5, 248.13981521098572`}], 
        PointBox[{5.6, 251.27562104080107`}], 
        PointBox[{5.7, 249.17376849290451`}], 
        PointBox[{5.8, 246.46204001190424`}], 
        PointBox[{5.9, 249.1519878067321}], 
        PointBox[{6., 250.43543847850341`}], 
        PointBox[{6.1, 248.15861165821224`}], 
        PointBox[{6.2, 252.8122666515441}], 
        PointBox[{6.3, 260.7856048507411}], 
        PointBox[{6.4, 262.5049098866757}], 
        PointBox[{6.5, 260.31252708397386`}], 
        PointBox[{6.6, 263.87397087446146`}], 
        PointBox[{6.7, 263.9533887236221}], 
        PointBox[{6.8, 260.2674556928051}], 
        PointBox[{6.9, 260.81481152675934`}], 
        PointBox[{7., 264.2929832469546}], PointBox[{7.1, 261.8298861068927}],
         PointBox[{7.2, 263.4631479712311}], 
        PointBox[{7.3, 271.29261302672484`}], 
        PointBox[{7.4, 276.81401865905207`}], 
        PointBox[{7.5, 274.2284049952582}], 
        PointBox[{7.6, 276.0389740278313}], 
        PointBox[{7.7, 278.61661581864075`}], 
        PointBox[{7.8, 275.42176713541363`}], 
        PointBox[{7.9, 273.4291663491144}], 
        PointBox[{8., 277.16666040272787`}], 
        PointBox[{8.1, 277.03781533086635`}], 
        PointBox[{8.2, 275.47716476405753`}], 
        PointBox[{8.3, 281.6509979202418}], 
        PointBox[{8.4, 289.95200452159156`}], 
        PointBox[{8.5, 289.96217891431013`}], 
        PointBox[{8.6, 288.6578246226595}], 
        PointBox[{8.7, 292.7112143861939}], 
        PointBox[{8.8, 291.6140169856344}], 
        PointBox[{8.9, 287.6988508120738}], PointBox[{9., 289.6349725741551}],
         PointBox[{9.1, 292.6235354145508}], 
        PointBox[{9.2, 289.54792819342697`}], 
        PointBox[{9.3, 292.7408048902293}], 
        PointBox[{9.4, 301.78066874434336`}], 
        PointBox[{9.5, 306.2816022398945}], 
        PointBox[{9.6, 303.1120324786068}], 
        PointBox[{9.7, 306.2172875712942}], 
        PointBox[{9.8, 308.17997416143993`}], 
        PointBox[{9.9, 303.9895308304945}], 
        PointBox[{10., 302.89251920703293`}], 
        PointBox[{10.1, 307.3455671600224}], 
        PointBox[{10.2, 305.9663623415004}], 
        PointBox[{10.3, 305.29398379953125`}], 
        PointBox[{10.4, 313.0592173305782}], 
        PointBox[{10.5, 321.674238026396}], 
        PointBox[{10.6, 320.246546942264}], 
        PointBox[{10.7, 319.9557729108886}], 
        PointBox[{10.8, 324.3354109046698}], 
        PointBox[{10.9, 322.1412127481565}], 
        PointBox[{11., 318.11848731787813`}], 
        PointBox[{11.1, 321.31148090624816`}], 
        PointBox[{11.2, 323.7023948719513}], 
        PointBox[{11.3, 320.304694319373}], 
        PointBox[{11.4, 325.0413821255872}], 
        PointBox[{11.5, 335.4787313257345}], 
        PointBox[{11.6, 339.04020020878676`}], 
        PointBox[{11.7, 335.6263455583349}], 
        PointBox[{11.8, 339.75759398783464`}], 
        PointBox[{11.9, 341.2494702976527}], 
        PointBox[{12., 336.1259820932994}], 
        PointBox[{12.1, 335.88034908605783`}], 
        PointBox[{12.2, 340.8430204743371}], 
        PointBox[{12.3, 338.50450571477734`}], 
        PointBox[{12.4, 338.6765057236335}], 
        PointBox[{12.5, 348.25455741138876`}], 
        PointBox[{12.6, 357.1937925533042}], 
        PointBox[{12.7, 354.71398704501917`}], 
        PointBox[{12.8, 355.2118823001313}], 
        PointBox[{12.9, 359.9602340445689}], 
        PointBox[{13., 356.86242683134753`}], 
        PointBox[{13.1, 352.70388250702536`}], 
        PointBox[{13.2, 356.87159406869614`}], 
        PointBox[{13.3, 358.86325464458815`}], 
        PointBox[{13.4, 355.2322349996561}], 
        PointBox[{13.5, 1.5027443279777744`}], 
        PointBox[{13.6, 13.333526939878979`}], 
        PointBox[{13.7, 16.22423266862333}], 
        PointBox[{13.8, 12.640992871407981`}], 
        PointBox[{13.9, 17.503143847260432`}], 
        PointBox[{14., 18.818804690392067`}], 
        PointBox[{14.1, 12.921931321657345`}], 
        PointBox[{14.2, 13.210472642384264`}], 
        PointBox[{14.3, 18.571303741468878`}], 
        PointBox[{14.4, 15.643023478654664`}], 
        PointBox[{14.5, 16.47850599427102}], 
        PointBox[{14.6, 27.80491515983788}], 
        PointBox[{14.7, 36.80393066879235}], 
        PointBox[{14.8, 33.72915109915309}], 
        PointBox[{14.9, 34.5857704399824}], 
        PointBox[{15., 39.68784807451733}], 
        PointBox[{15.1, 36.116681099971856`}], 
        PointBox[{15.2, 31.775095838915114`}], 
        PointBox[{15.3, 36.42929424627381}], 
        PointBox[{15.4, 38.31847400206828}], 
        PointBox[{15.5, 34.55165041426426}], 
        PointBox[{15.6, 42.06843227558426}], 
        PointBox[{15.7, 54.45438511950749}], 
        PointBox[{15.8, 56.862800822114295`}], 
        PointBox[{15.9, 53.19767846573576}], 
        PointBox[{16., 58.325547495429724`}], 
        PointBox[{16.1, 59.65612125908734}], 
        PointBox[{16.2, 53.4927834395749}], 
        PointBox[{16.3, 53.89723121797046}], 
        PointBox[{16.4, 59.36490188914047}], 
        PointBox[{16.5, 56.27589883166827}], 
        PointBox[{16.6, 57.57366752554435}], 
        PointBox[{16.7, 69.62341006461114}], 
        PointBox[{16.8, 77.87565236924753}], 
        PointBox[{16.9, 74.65674079433401}], 
        PointBox[{17., 75.59210706124618}], 
        PointBox[{17.1, 80.65103541153519}], 
        PointBox[{17.2, 77.07348897217742}], 
        PointBox[{17.3, 72.84586303612393}], 
        PointBox[{17.4, 77.41337206319794}], 
        PointBox[{17.5, 79.17764501552428}], 
        PointBox[{17.6, 75.61613440665552}], 
        PointBox[{17.7, 83.66961151564044}], 
        PointBox[{17.8, 95.07180552207082}], 
        PointBox[{17.9, 96.85253003361166}], 
        PointBox[{18., 93.45963559698345}], 
        PointBox[{18.1, 98.41525910309936}], 
        PointBox[{18.2, 99.48644602077508}], 
        PointBox[{18.3, 93.73702935363717}], 
        PointBox[{18.4, 94.21069839223739}], 
        PointBox[{18.5, 99.27405363836542}], 
        PointBox[{18.6, 96.23240389369151}], 
        PointBox[{18.7, 98.05905299467793}], 
        PointBox[{18.8, 109.41145603256807`}], 
        PointBox[{18.9, 116.18776205021115`}], 
        PointBox[{19., 113.02416436511307`}], 
        PointBox[{19.1, 114.22192586712472`}], 
        PointBox[{19.2, 118.65947112280077`}], 
        PointBox[{19.3, 115.14457320187617`}], 
        PointBox[{19.4, 111.59022887853776`}], 
        PointBox[{19.5, 115.84852902161661`}], 
        PointBox[{19.6, 117.05967195129375`}], 
        PointBox[{19.7, 114.1646708990985}], 
        PointBox[{19.8, 122.22582093026125`}], 
        PointBox[{19.9, 131.81253140303284`}], 
        PointBox[{20., 132.70040607597574`}], 
        PointBox[{20.1, 129.98483126987506`}], 
        PointBox[{20.2, 134.6426991730791}], 
        PointBox[{20.3, 134.96924627094396`}], 
        PointBox[{20.4, 129.97936073524116`}], 
        PointBox[{20.5, 130.8391729011117}], 
        PointBox[{20.6, 135.13085898715096`}], 
        PointBox[{20.7, 132.0710390330909}], 
        PointBox[{20.8, 134.76490145128827`}], 
        PointBox[{20.9, 144.83951608956892`}], 
        PointBox[{21., 149.97935226808684`}], 
        PointBox[{21.1, 146.86853283254965`}], 
        PointBox[{21.2, 148.6876644843347}], 
        PointBox[{21.3, 152.10492286389916`}], 
        PointBox[{21.4, 148.5179301284055}], 
        PointBox[{21.5, 145.98817337779417`}], 
        PointBox[{21.6, 150.0390097222058}], 
        PointBox[{21.7, 150.27139690514122`}], 
        PointBox[{21.8, 148.44530315098655`}], 
        PointBox[{21.9, 156.42855772756693`}], 
        PointBox[{22., 164.26275257258658`}], 
        PointBox[{22.1, 164.10616172775966`}], 
        PointBox[{22.2, 162.3815122215149}], 
        PointBox[{22.3, 166.6896117248496}], 
        PointBox[{22.4, 165.99718502716877`}], 
        PointBox[{22.5, 161.8493746089288}], 
        PointBox[{22.6, 163.3703141201249}], 
        PointBox[{22.7, 166.67001140025025`}], 
        PointBox[{22.8, 163.63848174499418`}], 
        PointBox[{22.9, 167.48878981444483`}], 
        PointBox[{23., 176.34862946152597`}], 
        PointBox[{23.1, 179.8986476328441}], 
        PointBox[{23.2, 176.9206473693299}], 
        PointBox[{23.3, 179.54317494626244`}], 
        PointBox[{23.4, 181.69259934385983`}], 
        PointBox[{23.5, 178.03088458644118`}], 
        PointBox[{23.6, 176.6581089033306}], 
        PointBox[{23.7, 180.55477700224267`}], 
        PointBox[{23.8, 179.60586803147024`}], 
        PointBox[{23.9, 179.22985372654023`}], 
        PointBox[{24., 187.14455783549118`}], 
        PointBox[{24.1, 193.45490010076736`}], 
        PointBox[{24.2, 192.23324766377362`}], 
        PointBox[{24.3, 191.79385350374096`}], 
        PointBox[{24.4, 195.52017677630235`}], 
        PointBox[{24.5, 193.8033731836376}], 
        PointBox[{24.6, 190.56649635039972`}], 
        PointBox[{24.7, 192.85505032232388`}], 
        PointBox[{24.8, 194.88909901854564`}], 
        PointBox[{24.9, 192.26808347830058`}], 
        PointBox[{25., 197.3336194343297}], 
        PointBox[{25.1, 205.12580808467928`}], 
        PointBox[{25.2, 207.06757525292207`}], 
        PointBox[{25.3, 204.55373174807372`}], 
        PointBox[{25.4, 207.84161353834833`}], 
        PointBox[{25.5, 208.58077880826062`}], 
        PointBox[{25.6, 205.0116122470432}], 
        PointBox[{25.7, 204.86184412176203`}], 
        PointBox[{25.8, 208.40819903312544`}], 
        PointBox[{25.9, 206.40885169980854`}], 
        PointBox[{26., 207.7849757166837}], 
        PointBox[{26.1, 215.5594454420718}], 
        PointBox[{26.2, 220.39219298999447`}], 
        PointBox[{26.3, 218.2903483075261}], 
        PointBox[{26.4, 219.33381502378808`}], 
        PointBox[{26.5, 222.09276083980083`}], 
        PointBox[{26.6, 219.55195458856141`}], 
        PointBox[{26.7, 217.35504482401205`}], 
        PointBox[{26.8, 220.3314492974167}], 
        PointBox[{26.9, 220.807403829249}], 
        PointBox[{27., 219.23742624227617`}], 
        PointBox[{27.1, 225.33425213326413`}], 
        PointBox[{27.2, 232.09441482595383`}], 
        PointBox[{27.3, 232.38264876713424`}], 
        PointBox[{27.4, 230.8932740161833}], 
        PointBox[{27.5, 234.3640654398733}], 
        PointBox[{27.6, 233.71165623115687`}], 
        PointBox[{27.7, 230.50607049386426`}], 
        PointBox[{27.8, 231.6114247431382}], 
        PointBox[{27.9, 234.33202552151934`}], 
        PointBox[{28., 231.85674966411804`}], 
        PointBox[{28.1, 235.0553000627312}], 
        PointBox[{28.2, 242.5479577036777}], 
        PointBox[{28.3, 245.750827755284}], 
        PointBox[{28.4, 243.29207411541634`}], 
        PointBox[{28.5, 245.69014097677837`}], 
        PointBox[{28.6, 247.13681115827586`}], 
        PointBox[{28.7, 244.10638150089807`}], 
        PointBox[{28.8, 243.12157949963085`}], 
        PointBox[{28.9, 246.4434562784931}], 
        PointBox[{29., 245.33615102814326`}], 
        PointBox[{29.1, 245.42098835922445`}], 
        PointBox[{29.2, 252.22584352973874`}], 
        PointBox[{29.3, 257.82754195170304`}], 
        PointBox[{29.4, 256.5934976866926}], 
        PointBox[{29.5, 256.657707024528}], 
        PointBox[{29.6, 259.64232115750036`}], 
        PointBox[{29.7, 257.80323006357173`}], 
        PointBox[{29.8, 255.28270605474387`}], 
        PointBox[{29.9, 257.5564992688988}], 
        PointBox[{30., 258.8647286442779}], 
        PointBox[{30.1, 256.82743677451714`}], 
        PointBox[{30.2, 261.6362022397555}], 
        PointBox[{30.3, 268.65479283462696`}], 
        PointBox[{30.4, 270.0236937609247}], 
        PointBox[{30.5, 268.05583215854904`}], 
        PointBox[{30.6, 271.2388671384639}], 
        PointBox[{30.7, 271.24150280505626`}], 
        PointBox[{30.8, 268.12223966553944`}], 
        PointBox[{30.9, 268.5036245417879}], 
        PointBox[{31., 271.5238366383038}], 
        PointBox[{31.1, 269.34289340121495`}], 
        PointBox[{31.2, 271.35634949922564`}], 
        PointBox[{31.3, 278.54258071298995`}], 
        PointBox[{31.4, 282.69511917503166`}], 
        PointBox[{31.5, 280.47114863472393`}], 
        PointBox[{31.6, 282.1974262304484}], 
        PointBox[{31.7, 284.1280170251977}], 
        PointBox[{31.8, 281.4409611060015}], 
        PointBox[{31.9, 279.9389187519734}], 
        PointBox[{32., 283.0387716709846}], 
        PointBox[{32.1, 282.630018285489}], 
        PointBox[{32.2, 281.8959919732175}], 
        PointBox[{32.3, 287.9411417491976}], 
        PointBox[{32.4, 294.22552753037434`}], 
        PointBox[{32.5, 293.74962523236866`}], 
        PointBox[{32.6, 293.1109817330464}], 
        PointBox[{32.7, 296.2784613621893}], 
        PointBox[{32.8, 294.94129859345526`}], 
        PointBox[{32.9, 292.1550472033017}], 
        PointBox[{33., 293.9245173495214}], 
        PointBox[{33.1, 295.86515751215217`}], 
        PointBox[{33.2, 293.55565009503266`}], 
        PointBox[{33.3, 297.3930252257452}], 
        PointBox[{33.4, 304.6760172732715}], 
        PointBox[{33.5, 307.04726098210244`}], 
        PointBox[{33.6, 304.7638500932861}], 
        PointBox[{33.7, 307.69753668409317`}], 
        PointBox[{33.8, 308.29362998862445`}], 
        PointBox[{33.9, 305.15445331350725`}], 
        PointBox[{34., 304.9565394910037}], 
        PointBox[{34.1, 308.2308983257214}], 
        PointBox[{34.2, 306.3936043049524}], 
        PointBox[{34.3, 307.4235896532581}], 
        PointBox[{34.4, 314.36046410324866`}], 
        PointBox[{34.5, 319.5554431449805}], 
        PointBox[{34.6, 317.6397718368764}], 
        PointBox[{34.7, 318.7052504006955}], 
        PointBox[{34.8, 321.18777571656284`}], 
        PointBox[{34.9, 318.75683930892666`}], 
        PointBox[{35., 316.71443593124553`}], 
        PointBox[{35.1, 319.6372052230512}], 
        PointBox[{35.2, 319.9854819452275}], 
        PointBox[{35.3, 318.4753361021428}], 
        PointBox[{35.4, 323.841332617636}], 
        PointBox[{35.5, 330.94949672445654`}], 
        PointBox[{35.6, 331.39059799139494`}], 
        PointBox[{35.7, 330.01028581491596`}], 
        PointBox[{35.8, 333.41827370409715`}], 
        PointBox[{35.9, 332.6596388931631}], 
        PointBox[{36., 329.47028632552644`}], 
        PointBox[{36.1, 330.7205314763991}], 
        PointBox[{36.2, 333.3906013093589}], 
        PointBox[{36.3, 330.87523483216904`}], 
        PointBox[{36.4, 333.7092810651821}], 
        PointBox[{36.5, 341.3121840224524}], 
        PointBox[{36.6, 345.04103077559995`}], 
        PointBox[{36.7, 342.4814698461225}], 
        PointBox[{36.8, 345.03965246374355`}], 
        PointBox[{36.9, 346.47910405115744`}], 
        PointBox[{37., 343.2398278683422}], 
        PointBox[{37.1, 342.2927535876219}], 
        PointBox[{37.2, 345.86575314687474`}], 
        PointBox[{37.3, 344.63831422001}], 
        PointBox[{37.4, 344.47695260628944`}], 
        PointBox[{37.5, 351.121237360473}], 
        PointBox[{37.6, 357.7698114595408}], 
        PointBox[{37.7, 356.4791474862563}], 
        PointBox[{37.8, 356.55969028631864`}], 
        PointBox[{37.9, 359.8335114170965}], 
        PointBox[{38., 357.8246332040014}], 
        PointBox[{38.1, 354.9592912075212}], 
        PointBox[{38.2, 357.58204325326176`}], 
        PointBox[{38.3, 359.08033167443176`}], 
        PointBox[{38.4, 356.6586970029307}], 
        PointBox[{38.5, 1.147905714283185}], 
        PointBox[{38.6, 9.288779705759856}], 
        PointBox[{38.7, 11.32466879126219}], 
        PointBox[{38.8, 8.969307057003144}], 
        PointBox[{38.9, 12.530694257218308`}], 
        PointBox[{39., 12.821594064559596`}], 
        PointBox[{39.1, 9.036749930419306}], 
        PointBox[{39.2, 9.407519643120395}], 
        PointBox[{39.3, 13.046200844612702`}], 
        PointBox[{39.4, 10.647638610424902`}], 
        PointBox[{39.5, 12.00405579817976}], 
        PointBox[{39.6, 19.858744657268705`}], 
        PointBox[{39.7, 25.785741546044374`}], 
        PointBox[{39.8, 23.254133131311022`}], 
        PointBox[{39.9, 24.851701497302162`}], 
        PointBox[{40., 27.683500598164635`}], 
        PointBox[{40.1, 24.54086455371931}], 
        PointBox[{40.2, 22.29954247834504}], 
        PointBox[{40.3, 26.03350755255822}], 
        PointBox[{40.4, 26.191122991020084`}], 
        PointBox[{40.5, 24.341987808052135`}], 
        PointBox[{40.6, 30.388535457697344`}], 
        PointBox[{40.7, 39.01935710596522}], 
        PointBox[{40.8, 39.39604968094545}], 
        PointBox[{40.9, 37.78231828907032}], 
        PointBox[{41., 41.95176238433593}], 
        PointBox[{41.1, 41.1180422888512}], 
        PointBox[{41.2, 36.986357421561735`}], 
        PointBox[{41.3, 38.718118415265884`}], 
        PointBox[{41.4, 42.01804289922271}], 
        PointBox[{41.5, 38.893187330066176`}], 
        PointBox[{41.6, 41.75914202980948}], 
        PointBox[{41.7, 50.94489476339895}], 
        PointBox[{41.8, 56.02616669956637}], 
        PointBox[{41.9, 52.77552566566237}], 
        PointBox[{42., 55.67260791562208}], 
        PointBox[{42.1, 58.026571124369354`}], 
        PointBox[{42.2, 53.83049405851882}], 
        PointBox[{42.3, 52.36485142763949}], 
        PointBox[{42.4, 56.91426895121077}], 
        PointBox[{42.5, 55.87591818504851}], 
        PointBox[{42.6, 54.757482363215274`}], 
        PointBox[{42.7, 62.44827621605936}], 
        PointBox[{42.8, 71.59379531553532}], 
        PointBox[{42.9, 70.57118862797711}], 
        PointBox[{43., 69.81252096933075}], 
        PointBox[{43.1, 74.44005746207479}], 
        PointBox[{43.2, 72.58449813745398}], 
        PointBox[{43.3, 68.19448224154348}], 
        PointBox[{43.4, 71.15073444961972}], 
        PointBox[{43.5, 74.03055146030768}], 
        PointBox[{43.6, 70.44675330214285}], 
        PointBox[{43.7, 74.79980941479567}], 
        PointBox[{43.8, 85.52010677082471}], 
        PointBox[{43.9, 89.84859767163127}], 
        PointBox[{44., 86.19760810492554}], 
        PointBox[{44.1, 90.11233316347665}], 
        PointBox[{44.2, 92.16102000268046}], 
        PointBox[{44.3, 86.98952155367836}], 
        PointBox[{44.4, 86.21896180661254}], 
        PointBox[{44.5, 91.38013893940462}], 
        PointBox[{44.6, 89.44979939589389}], 
        PointBox[{44.7, 89.00080530363232}], 
        PointBox[{44.8, 98.5289346122936}], 
        PointBox[{44.9, 108.1632500509226}], 
        PointBox[{45., 106.14402915937985`}], 
        PointBox[{45.1, 105.99949196604744`}], 
        PointBox[{45.2, 111.09309259964343`}], 
        PointBox[{45.3, 108.46878154412863`}], 
        PointBox[{45.4, 103.79698171766623`}], 
        PointBox[{45.5, 107.64963510217999`}], 
        PointBox[{45.6, 110.30456005361687`}], 
        PointBox[{45.7, 106.382488627154}], 
        PointBox[{45.8, 112.15193349084637`}], 
        PointBox[{45.9, 124.29876647380819`}], 
        PointBox[{46., 128.0874978863997}], 
        PointBox[{46.1, 124.16539908640601`}], 
        PointBox[{46.2, 128.72987689423437`}], 
        PointBox[{46.3, 130.74751528202577`}], 
        PointBox[{46.4, 124.85717059795334`}], 
        PointBox[{46.5, 124.44909024485374`}], 
        PointBox[{46.6, 130.02982123520104`}], 
        PointBox[{46.7, 127.61829099283011`}], 
        PointBox[{46.8, 127.66054043235422`}], 
        PointBox[{46.9, 138.81898598328183`}], 
        PointBox[{47., 148.47268453565746`}], 
        PointBox[{47.1, 145.93895471270673`}], 
        PointBox[{47.2, 146.01959843927267`}], 
        PointBox[{47.3, 151.4367091767796}], 
        PointBox[{47.4, 148.5008831023697}], 
        PointBox[{47.5, 143.62421275943876`}], 
        PointBox[{47.6, 147.8248111928706}], 
        PointBox[{47.7, 150.45012764007714`}], 
        PointBox[{47.8, 146.39314611781256`}], 
        PointBox[{47.9, 153.2054478191241}], 
        PointBox[{48., 165.70873903903015`}], 
        PointBox[{48.1, 168.97104746016322`}], 
        PointBox[{48.2, 165.00241313895287`}], 
        PointBox[{48.3, 169.71572526734815`}], 
        PointBox[{48.4, 171.7362682723575}], 
        PointBox[{48.5, 165.73645761891177`}], 
        PointBox[{48.6, 165.39157744060375`}], 
        PointBox[{48.7, 170.97353748982061`}], 
        PointBox[{48.8, 168.46696186761972`}], 
        PointBox[{48.9, 168.90722933374232`}], 
        PointBox[{49., 180.54964072110104`}], 
        PointBox[{49.1, 189.22655069914305`}], 
        PointBox[{49.2, 186.55440819887454`}], 
        PointBox[{49.3, 186.75050834205814`}], 
        PointBox[{49.4, 191.99033590232696`}], 
        PointBox[{49.5, 189.06006111984172`}], 
        PointBox[{49.6, 184.4497618590549}], 
        PointBox[{49.7, 188.50015485027419`}], 
        PointBox[{49.8, 190.89357265262535`}], 
        PointBox[{49.9, 187.11582587278573`}], 
        PointBox[{50., 194.3557999135612}], 
        PointBox[{50.1, 205.67568805485377`}], 
        PointBox[{50.2, 208.1231349918944}], 
        PointBox[{50.3, 204.5177698966562}], 
        PointBox[{50.4, 209.06623841198277`}], 
        PointBox[{50.5, 210.66183439698827`}], 
        PointBox[{50.6, 205.14649452639608`}], 
        PointBox[{50.7, 205.00769329340392`}], 
        PointBox[{50.8, 210.09287745654396`}], 
        PointBox[{50.9, 207.53773103564748`}], 
        PointBox[{51., 208.61168652258624`}], 
        PointBox[{51.1, 219.4972384643954}], 
        PointBox[{51.2, 226.54156956005164`}], 
        PointBox[{51.3, 223.80214073901385`}], 
        PointBox[{51.4, 224.42871510363256`}], 
        PointBox[{51.5, 228.96904794919047`}], 
        PointBox[{51.6, 225.94830065940494`}], 
        PointBox[{51.7, 222.15669726951316`}], 
        PointBox[{51.8, 225.9932312186889}], 
        PointBox[{51.9, 227.66929177799295`}], 
        PointBox[{52., 224.58293494335885`}], 
        PointBox[{52.1, 231.95149616163064`}], 
        PointBox[{52.2, 241.45536328334117`}], 
        PointBox[{52.3, 242.82996533305123`}], 
        PointBox[{52.4, 239.9315779787565}], 
        PointBox[{52.5, 244.30902851392105`}], 
        PointBox[{52.6, 244.99941290850543`}], 
        PointBox[{52.7, 240.1807408545326}], 
        PointBox[{52.8, 240.60842548066609`}], 
        PointBox[{52.9, 244.93132500244147`}], 
        PointBox[{53., 242.17486767956467`}], 
        PointBox[{53.1, 244.2835664022048}], 
        PointBox[{53.2, 254.0266132922339}], 
        PointBox[{53.3, 259.38929922483663`}], 
        PointBox[{53.4, 256.53376877201663`}], 
        PointBox[{53.5, 257.95697418050196`}], 
        PointBox[{53.6, 261.4714850700234}], 
        PointBox[{53.7, 258.2051560627037}], 
        PointBox[{53.8, 255.5000484331954}], 
        PointBox[{53.9, 259.2810580692437}], 
        PointBox[{54., 259.8483091110805}], 
        PointBox[{54.1, 257.81287344962675`}], 
        PointBox[{54.2, 265.31758248172804`}], 
        PointBox[{54.3, 273.1444952863105}], 
        PointBox[{54.4, 273.3336366967642}], 
        PointBox[{54.5, 271.4219679860637}], 
        PointBox[{54.6, 275.5905597431507}], 
        PointBox[{54.7, 275.1492526555382}], 
        PointBox[{54.8, 271.079110886631}], 
        PointBox[{54.9, 272.30754543681945`}], 
        PointBox[{55., 275.68756484484595`}], 
        PointBox[{55.1, 272.78742262265234`}], 
        PointBox[{55.2, 276.21004122557713`}], 
        PointBox[{55.3, 284.8960629255446}], 
        PointBox[{55.4, 288.65114391934907`}], 
        PointBox[{55.5, 285.7768550923236}], 
        PointBox[{55.6, 288.1521085389808}], 
        PointBox[{55.7, 290.4043512098064}], 
        PointBox[{55.8, 286.92892255657983`}], 
        PointBox[{55.9, 285.4065371011136}], 
        PointBox[{56., 289.1690693380077}], 
        PointBox[{56.1, 288.44363884028826`}], 
        PointBox[{56.2, 287.8544937121954}], 
        PointBox[{56.3, 295.4790197310882}], 
        PointBox[{56.4, 301.84339921815683`}], 
        PointBox[{56.5, 300.8442156522874}], 
        PointBox[{56.6, 300.2309117506203}], 
        PointBox[{56.7, 303.9184607788703}], 
        PointBox[{56.8, 302.36923403651593`}], 
        PointBox[{56.9, 299.1394566925681}], 
        PointBox[{57., 301.2414249171038}], 
        PointBox[{57.1, 303.38536142783244`}], 
        PointBox[{57.2, 300.7728989084497}], 
        PointBox[{57.3, 305.5444289593945}], 
        PointBox[{57.4, 313.27704742185597`}], 
        PointBox[{57.5, 315.39352978873285`}], 
        PointBox[{57.6, 312.87571510559394`}], 
        PointBox[{57.7, 316.0357839486485}], 
        PointBox[{57.8, 316.8685462787114}], 
        PointBox[{57.9, 313.39120581919593`}], 
        PointBox[{58., 313.11794723210863`}], 
        PointBox[{58.1, 316.6307641744172}], 
        PointBox[{58.2, 314.75061428695}], 
        PointBox[{58.3, 315.9391956025489}], 
        PointBox[{58.4, 323.56046438831356`}], 
        PointBox[{58.5, 328.4792352221532}], 
        PointBox[{58.6, 326.48977893025415`}], 
        PointBox[{58.7, 327.40402537940446`}], 
        PointBox[{58.8, 330.17712066733094`}], 
        PointBox[{58.9, 327.7385224425729}], 
        PointBox[{59., 325.5089220264422}], 
        PointBox[{59.1, 328.3850885738291}], 
        PointBox[{59.2, 328.9616650042127}], 
        PointBox[{59.3, 327.3353470211749}], 
        PointBox[{59.4, 333.2461412991082}], 
        PointBox[{59.5, 340.01754804512234`}], 
        PointBox[{59.6, 340.4320224652465}], 
        PointBox[{59.7, 338.88785692762235`}], 
        PointBox[{59.8, 342.31255837502164`}], 
        PointBox[{59.9, 341.7324242723359}], 
        PointBox[{60., 338.5562503976128}], 
        PointBox[{60.1, 339.57270571891667`}], 
        PointBox[{60.2, 342.3173941860125}], 
        PointBox[{60.3, 339.8783723771219}], 
        PointBox[{60.4, 342.93070053964686`}], 
        PointBox[{60.5, 350.3654690199452}], 
        PointBox[{60.6, 353.6590667071213}], 
        PointBox[{60.7, 351.2290044687768}], 
        PointBox[{60.8, 353.5548028705686}], 
        PointBox[{60.9, 355.03463276406836`}], 
        PointBox[{61., 352.05502813318316`}], 
        PointBox[{61.1, 351.02442550680945`}], 
        PointBox[{61.2, 354.31281819205435`}], 
        PointBox[{61.3, 353.2693461959898}], 
        PointBox[{61.4, 353.2774779483356}], 
        PointBox[{61.5, 359.97993730030873`}], 
        PointBox[{61.6, 5.6337388600448}], 
        PointBox[{61.7, 4.4692975907438495`}], 
        PointBox[{61.8, 4.475736120760094}], 
        PointBox[{61.9, 7.460125100962464}], 
        PointBox[{62., 5.667520321874697}], 
        PointBox[{62.1, 3.1386264459608335`}], 
        PointBox[{62.2, 5.363260747371154}], 
        PointBox[{62.3, 6.714635518060298}], 
        PointBox[{62.4, 4.661427077832304}], 
        PointBox[{62.5, 9.36693387715735}], 
        PointBox[{62.6, 16.39573499482425}], 
        PointBox[{62.7, 17.839912355999594`}], 
        PointBox[{62.8, 15.85288648714066}], 
        PointBox[{62.9, 19.011539080311085`}], 
        PointBox[{63., 19.04914358361436}], 
        PointBox[{63.1, 15.940363050059524`}], 
        PointBox[{63.2, 16.281956960520866`}], 
        PointBox[{63.3, 19.312971093071813`}], 
        PointBox[{63.4, 17.154883280229065`}], 
        PointBox[{63.5, 19.091488009211}], 
        PointBox[{63.6, 26.24386531771254}], 
        PointBox[{63.7, 30.468885528263268`}], 
        PointBox[{63.8, 28.263787170992394`}], 
        PointBox[{63.9, 29.952127397147756`}], 
        PointBox[{64., 31.907832656807013`}], 
        PointBox[{64.1, 29.238873379507485`}], 
        PointBox[{64.2, 27.708818554088467`}], 
        PointBox[{64.3, 30.797803297698298`}], 
        PointBox[{64.4, 30.42816586439882}], 
        PointBox[{64.5, 29.64607640058788}], 
        PointBox[{64.6, 35.63059191299703}], 
        PointBox[{64.7, 41.97652329060793}], 
        PointBox[{64.8, 41.5504260563277}], 
        PointBox[{64.9, 40.87285820008333}], 
        PointBox[{65., 44.053593740742436`}], 
        PointBox[{65.1, 42.743433814361026`}], 
        PointBox[{65.2, 39.93528263423872}], 
        PointBox[{65.3, 41.681933143896515`}], 
        PointBox[{65.4, 43.66140243714885}], 
        PointBox[{65.5, 41.33369464693976}], 
        PointBox[{65.6, 45.10309717430408}], 
        PointBox[{65.7, 52.416134713010464`}], 
        PointBox[{65.8, 54.868590280649364`}], 
        PointBox[{65.9, 52.56267544959208}], 
        PointBox[{66., 55.48625360961846}], 
        PointBox[{66.1, 56.12401578570592}], 
        PointBox[{66.2, 52.9704271458977}], 
        PointBox[{66.3, 52.737589354659924`}], 
        PointBox[{66.4, 56.03791553213351}], 
        PointBox[{66.5, 54.22115267689296}], 
        PointBox[{66.6, 55.179316375961605`}], 
        PointBox[{66.7, 62.10400589272244}], 
        PointBox[{66.8, 67.40533002292405}], 
        PointBox[{66.9, 65.50763029577068}], 
        PointBox[{67., 66.52946063772418}], 
        PointBox[{67.1, 69.06308163080598}], 
        PointBox[{67.2, 66.63971406359329}], 
        PointBox[{67.3, 64.54773347729274}], 
        PointBox[{67.4, 67.47308139293555}], 
        PointBox[{67.5, 67.88028440946479}], 
        PointBox[{67.6, 66.30414652477685}], 
        PointBox[{67.7, 71.62211889917762}], 
        PointBox[{67.8, 78.82861092312318}], 
        PointBox[{67.9, 79.35201729383435}], 
        PointBox[{68., 77.90859692350455}], 
        PointBox[{68.1, 81.34839060733933}], 
        PointBox[{68.2, 80.63900738508949}], 
        PointBox[{68.3, 77.39490945505229}], 
        PointBox[{68.4, 78.61262418320581}], 
        PointBox[{68.5, 81.35393742528622}], 
        PointBox[{68.6, 78.81749297550869}], 
        PointBox[{68.7, 81.56582221491522}], 
        PointBox[{68.8, 89.21983206528797}], 
        PointBox[{68.9, 93.10066031988391}], 
        PointBox[{69., 90.51112145573744}], 
        PointBox[{69.1, 93.03951163711206}], 
        PointBox[{69.2, 94.57159712314501}], 
        PointBox[{69.3, 91.30404887095804}], 
        PointBox[{69.4, 90.28187412273752}], 
        PointBox[{69.5, 93.89846778917848}], 
        PointBox[{69.6, 92.73433413745882}], 
        PointBox[{69.7, 92.45285271345915}], 
        PointBox[{69.8, 99.08669028876984}], 
        PointBox[{69.9, 105.91612984016443`}], 
        PointBox[{70., 104.69488420303296`}], 
        PointBox[{70.1, 104.6721872454418}], 
        PointBox[{70.2, 108.04114781293515`}], 
        PointBox[{70.3, 106.07512554823862`}], 
        PointBox[{70.4, 103.10419232560346`}], 
        PointBox[{70.5, 105.70827714750119`}], 
        PointBox[{70.6, 107.33568901767538`}], 
        PointBox[{70.7, 104.81933441577743`}], 
        PointBox[{70.8, 109.2261015572052}], 
        PointBox[{70.9, 117.50571297818729`}], 
        PointBox[{71., 119.74294976600711`}], 
        PointBox[{71.1, 117.28188136635066`}], 
        PointBox[{71.2, 120.85696146226942`}], 
        PointBox[{71.3, 121.28364394530479`}], 
        PointBox[{71.4, 117.41386367210136`}], 
        PointBox[{71.5, 117.68290033317163`}], 
        PointBox[{71.6, 121.43556016763088`}], 
        PointBox[{71.7, 119.07189381410873`}], 
        PointBox[{71.8, 120.25693296207416`}], 
        PointBox[{71.9, 128.1632102769226}], 
        PointBox[{72., 134.37796818524654`}], 
        PointBox[{72.1, 131.87409477855775`}], 
        PointBox[{72.2, 133.339009064873}], 
        PointBox[{72.3, 136.35058214275122`}], 
        PointBox[{72.4, 133.22884027872598`}], 
        PointBox[{72.5, 130.813744323592}], 
        PointBox[{72.6, 134.5629615477555}], 
        PointBox[{72.7, 134.91124223853996`}], 
        PointBox[{72.8, 132.8675274678299}], 
        PointBox[{72.9, 138.85596633143308`}], 
        PointBox[{73., 147.74454710261327`}], 
        PointBox[{73.1, 148.37298835204413`}], 
        PointBox[{73.2, 146.55033599828707`}], 
        PointBox[{73.3, 150.80649163956414`}], 
        PointBox[{73.4, 150.1581202457163}], 
        PointBox[{73.5, 145.85933766724955`}], 
        PointBox[{73.6, 147.45944770695093`}], 
        PointBox[{73.7, 150.97833329067112`}], 
        PointBox[{73.8, 147.82436310874365`}], 
        PointBox[{73.9, 150.47358513849795`}], 
        PointBox[{74., 159.80096307936338`}], 
        PointBox[{74.1, 165.30254311040267`}], 
        PointBox[{74.2, 162.00259265047399`}], 
        PointBox[{74.3, 164.74804509470144`}], 
        PointBox[{74.4, 167.38917009507279`}], 
        PointBox[{74.5, 163.18470194234482`}], 
        PointBox[{74.6, 161.4511068418915}], 
        PointBox[{74.7, 166.07040367507187`}], 
        PointBox[{74.8, 165.28549130324188`}], 
        PointBox[{74.9, 163.8539376141266}], 
        PointBox[{75., 171.52256456796803`}], 
        PointBox[{75.1, 181.06507037027933`}], 
        PointBox[{75.2, 180.3501501841097}], 
        PointBox[{75.3, 179.2547112527761}], 
        PointBox[{75.4, 184.05286017220718`}], 
        PointBox[{75.5, 182.45745114581587`}], 
        PointBox[{75.6, 177.79745984055754`}], 
        PointBox[{75.7, 180.57514881740596`}], 
        PointBox[{75.8, 183.8038524272913}], 
        PointBox[{75.9, 180.11303781202443`}], 
        PointBox[{76., 184.19284230735514`}], 
        PointBox[{76.1, 195.1415190421867}], 
        PointBox[{76.2, 200.02763261732034`}], 
        PointBox[{76.3, 196.23857926194933`}], 
        PointBox[{76.4, 199.96392232308895`}], 
        PointBox[{76.5, 202.42351896531213`}], 
        PointBox[{76.6, 197.24285182089795`}], 
        PointBox[{76.7, 196.0774158970246}], 
        PointBox[{76.8, 201.35522184528608`}], 
        PointBox[{76.9, 199.7578392813593}], 
        PointBox[{77., 198.86446110122134`}], 
        PointBox[{77.1, 208.36700351793868`}], 
        PointBox[{77.2, 218.47874380924023`}], 
        PointBox[{77.3, 216.83920409701966`}], 
        PointBox[{77.4, 216.220559602047}], 
        PointBox[{77.5, 221.5260679312841}], 
        PointBox[{77.6, 219.28396441205774`}], 
        PointBox[{77.7, 214.26172526437063`}], 
        PointBox[{77.8, 217.8449922777722}], 
        PointBox[{77.9, 220.9651671625196}], 
        PointBox[{78., 216.89461329444052`}], 
        PointBox[{78.1, 222.28054268598484`}], 
        PointBox[{78.2, 234.62118249809456`}], 
        PointBox[{78.3, 239.03504539974466`}], 
        PointBox[{78.4, 234.94055845868456`}], 
        PointBox[{78.5, 239.22464888480823`}], 
        PointBox[{78.6, 241.73387780959888`}], 
        PointBox[{78.7, 235.9203568525737}], 
        PointBox[{78.8, 234.99871963031086`}], 
        PointBox[{78.9, 240.66761738080996`}], 
        PointBox[{79., 238.68678308597683`}], 
        PointBox[{79.1, 238.17566181535724`}], 
        PointBox[{79.2, 249.169480571347}], 
        PointBox[{79.3, 259.19536300301735`}], 
        PointBox[{79.4, 257.1058358869423}], 
        PointBox[{79.5, 256.6393241420156}], 
        PointBox[{79.6, 262.20338518161736`}], 
        PointBox[{79.7, 259.7558783832626}], 
        PointBox[{79.8, 254.5687902880379}], 
        PointBox[{79.9, 258.3856844531092}], 
        PointBox[{80., 261.48682851641973`}], 
        PointBox[{80.1, 257.32111619359887`}], 
        PointBox[{80.2, 263.5968658711993}], 
        PointBox[{80.3, 276.0818214437908}], 
        PointBox[{80.4, 279.88417256507995`}], 
        PointBox[{80.5, 275.8012482284572}], 
        PointBox[{80.6, 280.15770065785847`}], 
        PointBox[{80.7, 282.6099286721334}], 
        PointBox[{80.8, 276.81277590756423`}], 
        PointBox[{80.9, 275.9628123481091}], 
        PointBox[{81., 281.5316925666447}], 
        PointBox[{81.1, 279.47413001252556`}], 
        PointBox[{81.2, 279.3629590786617}], 
        PointBox[{81.3, 290.64393208668685`}], 
        PointBox[{81.4, 299.49737751681346`}], 
        PointBox[{81.5, 297.240995496994}], 
        PointBox[{81.6, 296.96029433929584`}], 
        PointBox[{81.7, 302.24210655324845`}], 
        PointBox[{81.8, 299.7612429479921}], 
        PointBox[{81.9, 294.9786700972877}], 
        PointBox[{82., 298.6333426548378}], 
        PointBox[{82.1, 301.390870604994}], 
        PointBox[{82.2, 297.559312309936}], 
        PointBox[{82.3, 304.22228380284497`}], 
        PointBox[{82.4, 315.3831877777351}], 
        PointBox[{82.5, 318.21896223695006`}], 
        PointBox[{82.6, 314.55446276906173`}], 
        PointBox[{82.7, 318.7886205251959}], 
        PointBox[{82.8, 320.6764262048484}], 
        PointBox[{82.9, 315.3819522642973}], 
        PointBox[{83., 314.87014771392785`}], 
        PointBox[{83.1, 319.8942461644955}], 
        PointBox[{83.2, 317.6818652437677}], 
        PointBox[{83.3, 318.3098430879155}], 
        PointBox[{83.4, 328.8162794586606}], 
        PointBox[{83.5, 335.948767965696}], 
        PointBox[{83.6, 333.5120324660376}], 
        PointBox[{83.7, 333.7968056109372}], 
        PointBox[{83.8, 338.34084265020834`}], 
        PointBox[{83.9, 335.63712593265933`}], 
        PointBox[{84., 331.76199268467104`}], 
        PointBox[{84.1, 335.3010115932027}], 
        PointBox[{84.2, 337.2243847893304}], 
        PointBox[{84.3, 334.0827372135346}], 
        PointBox[{84.4, 340.98962589536836`}], 
        PointBox[{84.5, 350.36205484122684`}], 
        PointBox[{84.6, 352.0060255964501}], 
        PointBox[{84.7, 349.04948065188734`}], 
        PointBox[{84.8, 353.22251474527667`}], 
        PointBox[{84.9, 354.09673479975754`}], 
        PointBox[{85., 349.4326957354288}], 
        PointBox[{85.1, 349.61576431945866`}], 
        PointBox[{85.2, 353.90442407972535`}], 
        PointBox[{85.3, 351.3501150384678}], 
        PointBox[{85.4, 353.1345119845915}], 
        PointBox[{85.5, 2.611797398009215}], 
        PointBox[{85.6, 8.05202685589185}], 
        PointBox[{85.7, 5.372273675805062}], 
        PointBox[{85.8, 6.574483181233243}], 
        PointBox[{85.9, 10.098352958214441`}], 
        PointBox[{86., 7.029334364558167}], 
        PointBox[{86.1, 4.266897941893608}], 
        PointBox[{86.2, 7.865605115633023}], 
        PointBox[{86.3, 8.596924050565487}], 
        PointBox[{86.4, 6.4877091543693695`}], 
        PointBox[{86.5, 13.683652985887171`}], 
        PointBox[{86.6, 21.448959556602432`}], 
        PointBox[{86.7, 21.817886136296174`}], 
        PointBox[{86.8, 19.837764186395447`}], 
        PointBox[{86.9, 23.898915915724338`}], 
        PointBox[{87., 23.57265206834077}], 
        PointBox[{87.1, 19.587300208865283`}], 
        PointBox[{87.2, 20.661168157351263`}], 
        PointBox[{87.3, 24.04547932399835}], 
        PointBox[{87.4, 21.23743330493463}], 
        PointBox[{87.5, 24.437600156734028`}], 
        PointBox[{87.6, 32.97377764482905}], 
        PointBox[{87.7, 36.802443728395254`}], 
        PointBox[{87.8, 34.006103947578005`}], 
        PointBox[{87.9, 36.25516301076188}], 
        PointBox[{88., 38.521185612959755`}], 
        PointBox[{88.1, 35.160445254977645`}], 
        PointBox[{88.2, 33.59108568322024}], 
        PointBox[{88.3, 37.26090117710336}], 
        PointBox[{88.4, 36.631624249702796`}], 
        PointBox[{88.5, 35.96982160804069}], 
        PointBox[{88.6, 43.408282189093484`}], 
        PointBox[{88.7, 49.758568957458934`}], 
        PointBox[{88.8, 48.863205837717594`}], 
        PointBox[{88.9, 48.192755589137406`}], 
        PointBox[{89., 51.829487868386515`}], 
        PointBox[{89.1, 50.34933865120257}], 
        PointBox[{89.2, 47.15842942486284}], 
        PointBox[{89.3, 49.17236635121658}], 
        PointBox[{89.4, 51.33365942508651}], 
        PointBox[{89.5, 48.75112871534143}], 
        PointBox[{89.6, 53.380094418108115`}], 
        PointBox[{89.7, 61.04199302386565}], 
        PointBox[{89.8, 63.21195259766897}], 
        PointBox[{89.9, 60.7166725694008}], 
        PointBox[{90., 63.815313618574955`}], 
        PointBox[{90.1, 64.65563402568273}], 
        PointBox[{90.2, 61.24134601010174}], 
        PointBox[{90.3, 60.93602682787311}], 
        PointBox[{90.4, 64.41010329873306}], 
        PointBox[{90.5, 62.573404296175504`}], 
        PointBox[{90.6, 63.70918152948178}], 
        PointBox[{90.7, 71.22879459149407}], 
        PointBox[{90.8, 76.15207982507499}], 
        PointBox[{90.9, 74.20748138438196}], 
        PointBox[{91., 75.09418644653323}], 
        PointBox[{91.1, 77.83683661700559}], 
        PointBox[{91.2, 75.43671660461348}], 
        PointBox[{91.3, 73.22479333396817}], 
        PointBox[{91.4, 76.06086599343878}], 
        PointBox[{91.5, 76.64250315316609}], 
        PointBox[{91.6, 75.02780554047018}], 
        PointBox[{91.7, 80.85380915624262}], 
        PointBox[{91.8, 87.59962618487755}], 
        PointBox[{91.9, 88.03618226136129}], 
        PointBox[{92., 86.50311881491699}], 
        PointBox[{92.1, 89.89623669530793}], 
        PointBox[{92.2, 89.31515984015414}], 
        PointBox[{92.3, 86.17271951594454}], 
        PointBox[{92.4, 87.17810894150146}], 
        PointBox[{92.5, 89.90079153146728}], 
        PointBox[{92.6, 87.48078728559318}], 
        PointBox[{92.7, 90.50228345598066}], 
        PointBox[{92.8, 97.89170923194965}], 
        PointBox[{92.9, 101.18499093214328`}], 
        PointBox[{93., 98.77119114961488}], 
        PointBox[{93.1, 101.0930434994627}], 
        PointBox[{93.2, 102.54599985633178`}], 
        PointBox[{93.3, 99.5853532190312}], 
        PointBox[{93.4, 98.57032799089755}], 
        PointBox[{93.5, 101.84362428529386`}], 
        PointBox[{93.6, 100.79041988036109`}], 
        PointBox[{93.7, 100.81262916359344`}], 
        PointBox[{93.8, 107.47180533479514`}], 
        PointBox[{93.9, 113.1196012400371}], 
        PointBox[{94., 111.95109492437987`}], 
        PointBox[{94.1, 111.97992358269198`}], 
        PointBox[{94.2, 114.93905073895448`}], 
        PointBox[{94.3, 113.13897467528301`}], 
        PointBox[{94.4, 110.63124192670462`}], 
        PointBox[{94.5, 112.8640891535818}], 
        PointBox[{94.6, 114.18760455472494`}], 
        PointBox[{94.7, 112.15306179538268`}], 
        PointBox[{94.8, 116.84337015227092`}], 
        PointBox[{94.9, 123.86425058855983`}], 
        PointBox[{95., 125.2926289609099}], 
        PointBox[{95.1, 123.32378627102763`}], 
        PointBox[{95.2, 126.48313671187043`}], 
        PointBox[{95.3, 126.49543782346089`}], 
        PointBox[{95.4, 123.39358921735715`}], 
        PointBox[{95.5, 123.75912593803322`}], 
        PointBox[{95.6, 126.77654513549868`}], 
        PointBox[{95.7, 124.609187077727}], 
        PointBox[{95.8, 126.56123465919802`}], 
        PointBox[{95.9, 133.7048026275321}], 
        PointBox[{96., 137.92603681067257`}], 
        PointBox[{96.1, 135.71088827905118`}], 
        PointBox[{96.2, 137.42716617093586`}], 
        PointBox[{96.3, 139.3601892190453}], 
        PointBox[{96.4, 136.67790122543514`}], 
        PointBox[{96.5, 135.16785561560567`}], 
        PointBox[{96.6, 138.27213720066086`}], 
        PointBox[{96.7, 137.87167285655073`}], 
        PointBox[{96.8, 137.10981411186066`}], 
        PointBox[{96.9, 143.09366519341344`}], 
        PointBox[{97., 149.4562432476073}], 
        PointBox[{97.1, 149.0038503053452}], 
        PointBox[{97.2, 148.35389103268903`}], 
        PointBox[{97.3, 151.53401718268606`}], 
        PointBox[{97.4, 150.19982053956232`}], 
        PointBox[{97.5, 147.39133213181128`}], 
        PointBox[{97.6, 149.17006392629733`}], 
        PointBox[{97.7, 151.13056644835083`}], 
        PointBox[{97.8, 148.80033171038923`}], 
        PointBox[{97.9, 152.58224953595425`}], 
        PointBox[{98., 159.92075276530133`}], 
        PointBox[{98.1, 162.36611732136566`}], 
        PointBox[{98.2, 160.05746151104216`}], 
        PointBox[{98.3, 163.00512908032334`}], 
        PointBox[{98.4, 163.62761091861165`}], 
        PointBox[{98.5, 160.4515315456231}], 
        PointBox[{98.6, 160.24221982500208`}], 
        PointBox[{98.7, 163.5567574401861}], 
        PointBox[{98.8, 161.71631657202863`}], 
        PointBox[{98.9, 162.6852581032052}], 
        PointBox[{99., 169.632511861928}], 
        PointBox[{99.1, 174.96876485510296`}], 
        PointBox[{99.2, 173.04478799589705`}], 
        PointBox[{99.3, 174.09203103575948`}], 
        PointBox[{99.4, 176.6347573443802}], 
        PointBox[{99.5, 174.18278854998934`}], 
        PointBox[{99.6, 172.08494057806152`}], 
        PointBox[{99.7, 175.04559304831142`}], 
        PointBox[{99.8, 175.43994033498726`}], 
        PointBox[{99.9, 173.85254978288236`}], 
        PointBox[{100., 179.18686314335432`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 360}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
        40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {0, -180}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 180.}], 
        PointBox[{0.1, 175.5908575741434}], 
        PointBox[{0.2, 177.40611451957636`}], 
        PointBox[{0.3, 179.0873877842405}], 
        PointBox[{0.4, 177.17875561712356`}], 
        PointBox[{0.5, 179.9066296074975}], 
        PointBox[{0.6, -176.0314231512923}], 
        PointBox[{0.7, -176.61964561778353`}], 
        PointBox[{0.8, -177.27897613020554`}], 
        PointBox[{0.9, -173.84863139391564`}], 
        PointBox[{1., -176.38081100401678`}], 
        PointBox[{1.1, 178.3568837293601}], 
        PointBox[{1.2, 177.49985736005453`}], 
        PointBox[{1.3, -179.10852119191725`}], 
        PointBox[{1.4, 179.11152728603793`}], 
        PointBox[{1.5, 179.9078212399777}], 
        PointBox[{1.6, -175.62902766499212`}], 
        PointBox[{1.7, -174.2308953568853}], 
        PointBox[{1.8, -176.2511955471208}], 
        PointBox[{1.9, -173.19069663483526`}], 
        PointBox[{2., -173.11092364909916`}], 
        PointBox[{2.1, -178.17459020171327`}], 
        PointBox[{2.2, 178.40765380162793`}], 
        PointBox[{2.3, -178.42764317021124`}], 
        PointBox[{2.4, -178.43031323723676`}], 
        PointBox[{2.5, -179.54878790073803`}], 
        PointBox[{2.6, -175.7391200258212}], 
        PointBox[{2.7, -172.46386648704947`}], 
        PointBox[{2.8, -174.16095154923664`}], 
        PointBox[{2.9, -173.19214724329595`}], 
        PointBox[{3., -170.61606963921258`}], 
        PointBox[{3.1, -174.45978484812645`}], 
        PointBox[{3.2, -179.52767088654764`}], 
        PointBox[{3.3, -178.5192032807031}], 
        PointBox[{3.4, -176.0880871736972}], 
        PointBox[{3.5, -178.21440831676364`}], 
        PointBox[{3.6, -176.01701839000725`}], 
        PointBox[{3.7, -171.54634582998096`}], 
        PointBox[{3.8, -171.58500651628947`}], 
        PointBox[{3.9, -172.90682108844248`}], 
        PointBox[{4., -169.23107917214293`}], 
        PointBox[{4.1, -170.8548867497002}], 
        PointBox[{4.2, -176.39812037463435`}], 
        PointBox[{4.3, -178.40405414098495`}], 
        PointBox[{4.4, -174.67778831588566`}], 
        PointBox[{4.5, -176.08715580641865`}], 
        PointBox[{4.6, -176.0487571853323}], 
        PointBox[{4.7, -171.449457384344}], 
        PointBox[{4.8, -169.289530523934}], 
        PointBox[{4.9, -171.54413309804522`}], 
        PointBox[{5., -168.98311086603326`}], 
        PointBox[{5.1, -167.76895993237258`}], 
        PointBox[{5.2, -172.6441241314301}], 
        PointBox[{5.3, -177.25179635505674`}], 
        PointBox[{5.4, -174.5573328168466}], 
        PointBox[{5.5, -173.59855788717323`}], 
        PointBox[{5.6, -175.42920958473087`}], 
        PointBox[{5.7, -171.94474345428262`}], 
        PointBox[{5.8, -167.83914793866825`}], 
        PointBox[{5.9, -169.19718115424257`}], 
        PointBox[{6., -169.23184744673472`}], 
        PointBox[{6.1, -165.72299235579067`}], 
        PointBox[{6.2, -168.84031688858067`}], 
        PointBox[{6.3, -174.78161493021435`}], 
        PointBox[{6.4, -175.09312233425499`}], 
        PointBox[{6.5, -171.6570170811974}], 
        PointBox[{6.6, -173.92455462994712`}], 
        PointBox[{6.7, -172.6214200424074}], 
        PointBox[{6.8, -167.51121029437036`}], 
        PointBox[{6.9, -166.6686900593786}], 
        PointBox[{7., -168.84118348715037`}], 
        PointBox[{7.1, -165.12943714703306`}], 
        PointBox[{7.2, -165.40459985379312`}], 
        PointBox[{7.3, -171.2519759478855}], 
        PointBox[{7.4, -175.09368527053448`}], 
        PointBox[{7.5, -171.21854890768554`}], 
        PointBox[{7.6, -171.73908359506368`}], 
        PointBox[{7.7, -172.94154686661204`}], 
        PointBox[{7.8, -168.30357115468905`}], 
        PointBox[{7.9, -164.87054297056784`}], 
        PointBox[{8., -167.23816924383937`}], 
        PointBox[{8.1, -165.81788602212146`}], 
        PointBox[{8.2, -162.96017633593056`}], 
        PointBox[{8.3, -167.43629770132065`}], 
        PointBox[{8.4, -173.73632263564195`}], 
        PointBox[{8.5, -172.3512710909672}], 
        PointBox[{8.6, -169.74797527469036`}], 
        PointBox[{8.7, -172.43692118881154`}], 
        PointBox[{8.8, -169.89024721714122`}], 
        PointBox[{8.9, -164.4960581161049}], 
        PointBox[{9., -164.99861602234887`}], 
        PointBox[{9.1, -166.63839696892137`}], 
        PointBox[{9.2, -162.26115750975896`}], 
        PointBox[{9.3, -163.9900335178063}], 
        PointBox[{9.4, -170.9480459901588}], 
        PointBox[{9.5, -173.83276105353252`}], 
        PointBox[{9.6, -169.33290637667324`}], 
        PointBox[{9.7, -171.08222219565323`}], 
        PointBox[{9.8, -171.60077238709528`}], 
        PointBox[{9.9, -165.9074660028382}], 
        PointBox[{10., -163.32150174576782`}], 
        PointBox[{10.1, -166.36130526148463`}], 
        PointBox[{10.2, -163.6431117339598}], 
        PointBox[{10.3, -161.60324086493983`}], 
        PointBox[{10.4, -167.52278933123853`}], 
        PointBox[{10.5, -174.1873262788613}], 
        PointBox[{10.6, -171.35166481944452`}], 
        PointBox[{10.7, -169.7053338637861}], 
        PointBox[{10.8, -172.65450933006923`}], 
        PointBox[{10.9, -168.9498206339158}], 
        PointBox[{11., -163.39705714627598`}], 
        PointBox[{11.1, -165.11328457648142`}], 
        PointBox[{11.2, -166.11195375742045`}], 
        PointBox[{11.3, -161.36003141689525`}], 
        PointBox[{11.4, -164.52908104829567`}], 
        PointBox[{11.5, -172.833794924607}], 
        PointBox[{11.6, -174.8120168948435}], 
        PointBox[{11.7, -170.0261257418024}], 
        PointBox[{11.8, -172.74323554780494`}], 
        PointBox[{11.9, -172.7327672185511}], 
        PointBox[{12., -166.0560993767176}], 
        PointBox[{12.1, -164.2796699622677}], 
        PointBox[{12.2, -167.7903704029177}], 
        PointBox[{12.3, -164.07091715823844`}], 
        PointBox[{12.4, -162.8110950047576}], 
        PointBox[{12.5, -170.42552119528773`}], 
        PointBox[{12.6, -177.46778376857583`}], 
        PointBox[{12.7, -173.56241484157908`}], 
        PointBox[{12.8, -172.65852545890266`}], 
        PointBox[{12.9, -175.92515757456567`}], 
        PointBox[{13., -171.2705900728597}], 
        PointBox[{13.1, -165.54355320071772`}], 
        PointBox[{13.2, -168.20143659688074`}], 
        PointBox[{13.3, -168.76775817144699`}], 
        PointBox[{13.4, -163.74053798199566`}], 
        PointBox[{13.5, -168.35316689786669`}], 
        PointBox[{13.6, -178.0377938620295}], 
        PointBox[{13.7, -179.36657105576705`}], 
        PointBox[{13.8, -174.3812158851979}], 
        PointBox[{13.9, -177.78869837628372`}], 
        PointBox[{14., -177.56296299805035`}], 
        PointBox[{14.1, -170.08027494971975`}], 
        PointBox[{14.2, -168.81170356838084`}], 
        PointBox[{14.3, -172.6967131094425}], 
        PointBox[{14.4, -168.36068186370358`}], 
        PointBox[{14.5, -167.71488868339839`}], 
        PointBox[{14.6, -176.99398766955164`}], 
        PointBox[{14.7, 175.84779908309065`}], 
        PointBox[{14.8, -179.64431110540863`}], 
        PointBox[{14.9, -179.07243039756395`}], 
        PointBox[{15., 177.33616575236738`}], 
        PointBox[{15.1, -177.51137782407204`}], 
        PointBox[{15.2, -171.58295905438717`}], 
        PointBox[{15.3, -174.7133432071696}], 
        PointBox[{15.4, -175.1633112883519}], 
        PointBox[{15.5, -169.97662243806553`}], 
        PointBox[{15.6, -175.76289425071263`}], 
        PointBox[{15.7, 173.980043526195}], 
        PointBox[{15.8, 173.10712341055478`}], 
        PointBox[{15.9, 178.18443081909027`}], 
        PointBox[{16., 174.52786506942357`}], 
        PointBox[{16.1, 174.75332909541612`}], 
        PointBox[{16.2, -177.48822652011768`}], 
        PointBox[{16.3, -176.33167772073648`}], 
        PointBox[{16.4, 179.6779477674445}], 
        PointBox[{16.5, -175.81992596260716`}], 
        PointBox[{16.6, -175.60503762090593`}], 
        PointBox[{16.7, 174.4449761383985}], 
        PointBox[{16.8, 167.96726192792266`}], 
        PointBox[{16.9, 172.60836902532174`}], 
        PointBox[{17., 173.10430226530116`}], 
        PointBox[{17.1, 169.5596293723247}], 
        PointBox[{17.2, 174.71808031560795`}], 
        PointBox[{17.3, -179.4735923145745}], 
        PointBox[{17.4, 177.47228149733746`}], 
        PointBox[{17.5, 177.13719362963639`}], 
        PointBox[{17.6, -177.87873015523473`}], 
        PointBox[{17.7, 175.85684794661574`}], 
        PointBox[{17.8, 166.53567869900326`}], 
        PointBox[{17.9, 166.24906437123173`}], 
        PointBox[{18., 171.04153106139347`}], 
        PointBox[{18.1, 167.54899840841426`}], 
        PointBox[{18.2, 168.02363261774553`}], 
        PointBox[{18.3, 175.3525671033367}], 
        PointBox[{18.4, 176.41857713309946`}], 
        PointBox[{18.5, 172.80876283381986`}], 
        PointBox[{18.6, 177.24597173058464`}], 
        PointBox[{18.7, 176.94888174378139`}], 
        PointBox[{18.8, 167.72113705466654`}], 
        PointBox[{18.9, 162.63589181148018`}], 
        PointBox[{19., 167.1902935389444}], 
        PointBox[{19.1, 167.40359418231856`}], 
        PointBox[{19.2, 164.46045099980984`}], 
        PointBox[{19.3, 169.5322273715592}], 
        PointBox[{19.4, 174.6367373791727}], 
        PointBox[{19.5, 171.85627512034262`}], 
        PointBox[{19.6, 172.0407095336741}], 
        PointBox[{19.7, 176.34302000703974`}], 
        PointBox[{19.8, 170.12420567767003`}], 
        PointBox[{19.9, 162.5360165318998}], 
        PointBox[{20., 163.08334687842398`}], 
        PointBox[{20.1, 167.16577229180075`}], 
        PointBox[{20.2, 163.9420644965412}], 
        PointBox[{20.3, 165.1303415380862}], 
        PointBox[{20.4, 171.66215731902594`}], 
        PointBox[{20.5, 172.29745692670986`}], 
        PointBox[{20.6, 169.41272469452088`}], 
        PointBox[{20.7, 173.8317196734297}], 
        PointBox[{20.8, 172.68094505948284`}], 
        PointBox[{20.9, 164.7281383052723}], 
        PointBox[{21., 161.17716073248266`}], 
        PointBox[{21.1, 165.6308646250509}], 
        PointBox[{21.2, 165.18555021726934`}], 
        PointBox[{21.3, 163.22608110556212`}], 
        PointBox[{21.4, 168.3278957553266}], 
        PointBox[{21.5, 172.35736802373867`}], 
        PointBox[{21.6, 169.72823415151288`}], 
        PointBox[{21.7, 170.8400359711468}], 
        PointBox[{21.8, 174.04984971533486`}], 
        PointBox[{21.9, 167.9665525699129}], 
        PointBox[{22., 162.01035719868742`}], 
        PointBox[{22.1, 163.5303035855286}], 
        PointBox[{22.2, 166.57645899032832`}], 
        PointBox[{22.3, 163.6613217517879}], 
        PointBox[{22.4, 165.82455308608405`}], 
        PointBox[{22.5, 171.46133441128768`}], 
        PointBox[{22.6, 171.37388052043752`}], 
        PointBox[{22.7, 169.41891567321363`}], 
        PointBox[{22.8, 173.7636146973564}], 
        PointBox[{22.9, 171.48444161264706`}], 
        PointBox[{23., 164.70792540712318`}], 
        PointBox[{23.1, 162.6319496973374}], 
        PointBox[{23.2, 166.89692235798975`}], 
        PointBox[{23.3, 165.60326292582613`}], 
        PointBox[{23.4, 164.86758579922753`}], 
        PointBox[{23.5, 169.99206038849297`}], 
        PointBox[{23.6, 172.8017311825206}], 
        PointBox[{23.7, 170.25812272984695`}], 
        PointBox[{23.8, 172.49174806820156`}], 
        PointBox[{23.9, 174.23475099053394`}], 
        PointBox[{24., 168.28214006299095`}], 
        PointBox[{24.1, 163.69495688270035`}], 
        PointBox[{24.2, 166.20477983968885`}], 
        PointBox[{24.3, 167.9174115165515}], 
        PointBox[{24.4, 165.54092778269114`}], 
        PointBox[{24.5, 168.68050826871695`}], 
        PointBox[{24.6, 173.3464364212632}], 
        PointBox[{24.7, 172.42137440153965`}], 
        PointBox[{24.8, 171.66462556608167`}], 
        PointBox[{24.9, 175.5560801305437}], 
        PointBox[{25., 172.1246924736697}], 
        PointBox[{25.1, 166.3270553372604}], 
        PointBox[{25.2, 165.74502841100548`}], 
        PointBox[{25.3, 169.49232745480185`}], 
        PointBox[{25.4, 167.49135707913956`}], 
        PointBox[{25.5, 168.12408953249906`}], 
        PointBox[{25.6, 173.10268014812027`}], 
        PointBox[{25.7, 174.62305308075884`}], 
        PointBox[{25.8, 172.3591022270266}], 
        PointBox[{25.9, 175.58763916320822`}], 
        PointBox[{26., 175.58913012980338`}], 
        PointBox[{26.1, 169.82483825946474`}], 
        PointBox[{26.2, 166.54471492436642`}], 
        PointBox[{26.3, 169.86819409722375`}], 
        PointBox[{26.4, 170.05713087025288`}], 
        PointBox[{26.5, 168.612919842868}], 
        PointBox[{26.6, 172.53277653369514`}], 
        PointBox[{26.7, 176.10038975958378`}], 
        PointBox[{26.8, 174.41875262184476`}], 
        PointBox[{26.9, 175.15897552946626`}], 
        PointBox[{27., 177.9753264108549}], 
        PointBox[{27.1, 173.62048035930275`}], 
        PointBox[{27.2, 168.70677721894754`}], 
        PointBox[{27.3, 169.68036561709232`}], 
        PointBox[{27.4, 172.36197061433995`}], 
        PointBox[{27.5, 170.14880534851181`}], 
        PointBox[{27.6, 172.14090122381094`}], 
        PointBox[{27.7, 176.7088158202132}], 
        PointBox[{27.8, 176.91257830092218`}], 
        PointBox[{27.9, 175.41224421383595`}], 
        PointBox[{28., 179.0769219797403}], 
        PointBox[{28.1, 177.31632435311258`}], 
        PointBox[{28.2, 171.83273869237746`}], 
        PointBox[{28.3, 170.02600876088036`}], 
        PointBox[{28.4, 173.65869547048715`}], 
        PointBox[{28.5, 172.46826743960628`}], 
        PointBox[{28.6, 172.31591568969816`}], 
        PointBox[{28.7, 176.69204268294925`}], 
        PointBox[{28.8, 178.99761794706865`}], 
        PointBox[{28.9, 176.91212040649407`}], 
        PointBox[{29., 179.19078766565508`}], 
        PointBox[{29.1, -179.6364007089469}], 
        PointBox[{29.2, 175.4309523780903}], 
        PointBox[{29.3, 171.48707584368458`}], 
        PointBox[{29.4, 173.91402586615004`}], 
        PointBox[{29.5, 175.0202584746694}], 
        PointBox[{29.6, 173.2829654858433}], 
        PointBox[{29.7, 176.44364440556092`}], 
        PointBox[{29.8, -179.70893765444634`}], 
        PointBox[{29.9, 179.27681355736058`}], 
        PointBox[{30., 179.1444037961519}], 
        PointBox[{30.1, -177.64185808111142`}], 
        PointBox[{30.2, 179.11207572538842`}], 
        PointBox[{30.3, 174.02332654200654`}], 
        PointBox[{30.4, 173.93385277039852`}], 
        PointBox[{30.5, 177.05279601137954`}], 
        PointBox[{30.6, 175.0744716009831}], 
        PointBox[{30.7, 176.3633042737638}], 
        PointBox[{30.8, -179.19092957669636`}], 
        PointBox[{30.9, -178.2879769909232}], 
        PointBox[{31., 179.88780502756708`}], 
        PointBox[{31.1, -176.78091743936238`}], 
        PointBox[{31.2, -177.47377524883996`}], 
        PointBox[{31.3, 177.30930567792893`}], 
        PointBox[{31.4, 174.63524800656523`}], 
        PointBox[{31.5, 178.0178641887651}], 
        PointBox[{31.6, 177.46403280706}], 
        PointBox[{31.7, 176.79141402542882`}], 
        PointBox[{31.8, -179.20198021477336`}], 
        PointBox[{31.9, -176.39348746990072`}], 
        PointBox[{32., -178.26581714710846`}], 
        PointBox[{32.1, -176.70225941185709`}], 
        PointBox[{32.2, -174.76808092802457`}], 
        PointBox[{32.3, -179.0764546707578}], 
        PointBox[{32.4, 176.41985900982763`}], 
        PointBox[{32.5, 178.1088646120661}], 
        PointBox[{32.6, 179.90257404748627`}], 
        PointBox[{32.7, 177.9604521243382}], 
        PointBox[{32.8, -179.39604027612586`}], 
        PointBox[{32.9, -175.28644054839606`}], 
        PointBox[{33., -175.7909355136435}], 
        PointBox[{33.1, -176.55276424825206`}], 
        PointBox[{33.2, -173.08510124000168`}], 
        PointBox[{33.3, -175.477755789987}], 
        PointBox[{33.4, 179.2252069497954}], 
        PointBox[{33.5, 178.20626931353036`}], 
        PointBox[{33.6, -178.3521489047198}], 
        PointBox[{33.7, 179.91346769607844`}], 
        PointBox[{33.8, -179.39454487742842`}], 
        PointBox[{33.9, -174.92146408153712`}], 
        PointBox[{34., -173.42076687184453`}], 
        PointBox[{34.1, -175.47788596900136`}], 
        PointBox[{34.2, -172.48096910236563`}], 
        PointBox[{34.3, -172.2433329315936}], 
        PointBox[{34.4, -177.2749605322715}], 
        PointBox[{34.5, 179.14634625926192`}], 
        PointBox[{34.6, -177.7438217854433}], 
        PointBox[{34.7, -177.62439159142377`}], 
        PointBox[{34.8, -178.83966781098934`}], 
        PointBox[{34.9, -175.07118992299002`}], 
        PointBox[{35., -171.69226757886645`}], 
        PointBox[{35.1, -173.34989257533744`}], 
        PointBox[{35.2, -172.51189698854796`}], 
        PointBox[{35.3, -169.80441541563414`}], 
        PointBox[{35.4, -173.55054165069305`}], 
        PointBox[{35.5, -178.73821617762223`}], 
        PointBox[{35.6, -177.88878980204026`}], 
        PointBox[{35.7, -175.32187388564125`}], 
        PointBox[{35.8, -177.48160048084537`}], 
        PointBox[{35.9, -175.38879373077725`}], 
        PointBox[{36., -170.83594618916686`}], 
        PointBox[{36.1, -170.7699339501196}], 
        PointBox[{36.2, -172.21026358026575`}], 
        PointBox[{36.3, -168.50559476617855`}], 
        PointBox[{36.4, -169.9610598144136}], 
        PointBox[{36.5, -175.55143375336047`}], 
        PointBox[{36.6, -177.7857483470907}], 
        PointBox[{36.7, -174.01397122775234`}], 
        PointBox[{36.8, -175.33572075114716`}], 
        PointBox[{36.9, -175.4503420949477}], 
        PointBox[{37., -170.82900283076015`}], 
        PointBox[{37.1, -168.51751989525656`}], 
        PointBox[{37.2, -170.8056927245998}], 
        PointBox[{37.3, -168.3627927050802}], 
        PointBox[{37.4, -166.9354601086925}], 
        PointBox[{37.5, -171.77101699335617`}], 
        PointBox[{37.6, -176.60529766187028`}], 
        PointBox[{37.7, -174.03367295064163`}], 
        PointBox[{37.8, -172.87748780338006`}], 
        PointBox[{37.9, -174.83868418770362`}], 
        PointBox[{38., -171.43843493077657`}], 
        PointBox[{38.1, -167.16795073479807`}], 
        PointBox[{38.2, -168.44538229010504`}], 
        PointBox[{38.3, -168.68203741234538`}], 
        PointBox[{38.4, -165.0204261345898}], 
        PointBox[{38.5, -167.9878261757949}], 
        PointBox[{38.6, -174.08213082701695`}], 
        PointBox[{38.7, -174.68460276717087`}], 
        PointBox[{38.8, -171.07427157487473`}], 
        PointBox[{38.9, -173.33327577365708`}], 
        PointBox[{39., -172.2328880804671}], 
        PointBox[{39.1, -167.01258139224592`}], 
        PointBox[{39.2, -165.97955849916252`}], 
        PointBox[{39.3, -168.29779612837592`}], 
        PointBox[{39.4, -164.63868910762176`}], 
        PointBox[{39.5, -164.63865391309446`}], 
        PointBox[{39.6, -170.5258921457753}], 
        PointBox[{39.7, -174.73511903676626`}], 
        PointBox[{39.8, -170.89871068695356`}], 
        PointBox[{39.9, -171.1967626145888}], 
        PointBox[{40., -172.64492601153688`}], 
        PointBox[{40.1, -168.04876325053556`}], 
        PointBox[{40.2, -164.35354199885478`}], 
        PointBox[{40.3, -166.70203207407758`}], 
        PointBox[{40.4, -165.55392474426117`}], 
        PointBox[{40.5, -162.40083072145353`}], 
        PointBox[{40.6, -166.77165032018092`}], 
        PointBox[{40.7, -173.3729898740021}], 
        PointBox[{40.8, -172.33098149195575`}], 
        PointBox[{40.9, -169.40760198149655`}], 
        PointBox[{41., -172.2044821280324}], 
        PointBox[{41.1, -169.9123011532829}], 
        PointBox[{41.2, -164.2895100790447}], 
        PointBox[{41.3, -164.5725693102686}], 
        PointBox[{41.4, -166.50822683524893`}], 
        PointBox[{41.5, -162.07040335471902`}], 
        PointBox[{41.6, -163.48035142524168`}], 
        PointBox[{41.7, -170.59104032797404`}], 
        PointBox[{41.8, -174.01843239531445`}], 
        PointBox[{41.9, -169.4243023275667}], 
        PointBox[{42., -170.95760464874184`}], 
        PointBox[{42.1, -171.86023615406157`}], 
        PointBox[{42.2, -166.15149009251763`}], 
        PointBox[{42.3, -163.18353000072602`}], 
        PointBox[{42.4, -166.30435558307727`}], 
        PointBox[{42.5, -163.91378247887405`}], 
        PointBox[{42.6, -161.42483440155047`}], 
        PointBox[{42.7, -167.29842002810256`}], 
        PointBox[{42.8, -174.45542887357806`}], 
        PointBox[{42.9, -172.00537473726217`}], 
        PointBox[{43., -169.88333072173555`}], 
        PointBox[{43.1, -173.07501224845328`}], 
        PointBox[{43.2, -169.70210144054363`}], 
        PointBox[{43.3, -163.77155492901147`}], 
        PointBox[{43.4, -165.23725846390516`}], 
        PointBox[{43.5, -166.71128696767846`}], 
        PointBox[{43.6, -161.76509958497263`}], 
        PointBox[{43.7, -164.56720301237874`}], 
        PointBox[{43.8, -173.15300798421595`}], 
        PointBox[{43.9, -175.86518542981867`}], 
        PointBox[{44., -170.83317547265324`}], 
        PointBox[{44.1, -173.32987408238114`}], 
        PointBox[{44.2, -173.87254541199945`}], 
        PointBox[{44.3, -167.1410203488449}], 
        PointBox[{44.4, -164.8288788838072}], 
        PointBox[{44.5, -168.52558005175888`}], 
        PointBox[{44.6, -165.2045598871664}], 
        PointBox[{44.7, -163.32688536223213`}], 
        PointBox[{44.8, -170.92348488976495`}], 
        PointBox[{44.9, -178.61940182769104`}], 
        PointBox[{45., -175.1609144278009}], 
        PointBox[{45.1, -173.6116854357315}], 
        PointBox[{45.2, -177.22284571516138`}], 
        PointBox[{45.3, -173.03905938912794`}], 
        PointBox[{45.4, -166.79200020557982`}], 
        PointBox[{45.5, -169.1248113516267}], 
        PointBox[{45.6, -170.3450411487829}], 
        PointBox[{45.7, -165.02384823479224`}], 
        PointBox[{45.8, -169.161423334368}], 
        PointBox[{45.9, -179.15266963175964`}], 
        PointBox[{46., 178.64642981105862`}], 
        PointBox[{46.1, -176.02613397947425`}], 
        PointBox[{46.2, -179.13748789714737`}], 
        PointBox[{46.3, -179.61510709343565`}], 
        PointBox[{46.4, -172.13671315745887`}], 
        PointBox[{46.5, -170.16524342302}], 
        PointBox[{46.6, -174.26246278615872`}], 
        PointBox[{46.7, -170.438684852008}], 
        PointBox[{46.8, -169.01017509848316`}], 
        PointBox[{46.9, -178.15359588903812`}], 
        PointBox[{47., 174.07286622806714`}], 
        PointBox[{47.1, 178.04660734321806`}], 
        PointBox[{47.2, 179.39148512649263`}], 
        PointBox[{47.3, 175.4801824573151}], 
        PointBox[{47.4, 179.99481965638552`}], 
        PointBox[{47.5, -173.5399607509462}], 
        PointBox[{47.6, -176.21195154233283`}], 
        PointBox[{47.7, -177.3942659558088}], 
        PointBox[{47.8, -171.9208145259836}], 
        PointBox[{47.9, -177.03697110597568`}], 
        PointBox[{48., 172.60388607982168`}], 
        PointBox[{48.1, 170.8945675584764}], 
        PointBox[{48.2, 176.27234132446756`}], 
        PointBox[{48.3, 173.0228792260241}], 
        PointBox[{48.4, 172.55143600719748`}], 
        PointBox[{48.5, -179.8568304915534}], 
        PointBox[{48.6, -177.95022727359174`}], 
        PointBox[{48.7, 177.94688820401643`}], 
        PointBox[{48.8, -178.13514188622503`}], 
        PointBox[{48.9, -177.08097243768862`}], 
        PointBox[{49., 173.34694486461376`}], 
        PointBox[{49.1, 166.47760447549808`}], 
        PointBox[{49.2, 170.57175812016794`}], 
        PointBox[{49.3, 171.79801454528933`}], 
        PointBox[{49.4, 168.06196777704463`}], 
        PointBox[{49.5, 172.56526513791323`}], 
        PointBox[{49.6, 178.75252535395703`}], 
        PointBox[{49.7, 176.21440742027335`}], 
        PointBox[{49.8, 175.24782869139744`}], 
        PointBox[{49.9, -179.56189299141988`}], 
        PointBox[{50., 174.94666148476244`}], 
        PointBox[{50.1, 165.72679399501794`}], 
        PointBox[{50.2, 164.78217863474856`}], 
        PointBox[{50.3, 169.77815756839118`}], 
        PointBox[{50.4, 166.6800220831865}], 
        PointBox[{50.5, 166.61832027726632`}], 
        PointBox[{50.6, 173.70495998521073`}], 
        PointBox[{50.7, 175.3787616279442}], 
        PointBox[{50.8, 171.74306822491053`}], 
        PointBox[{50.9, 175.68609194143937`}], 
        PointBox[{51., 176.11657662093057`}], 
        PointBox[{51.1, 167.33228863102704`}], 
        PointBox[{51.2, 162.0031534604932}], 
        PointBox[{51.3, 166.12691761708265`}], 
        PointBox[{51.4, 166.89766019856324`}], 
        PointBox[{51.5, 163.83681773069839`}], 
        PointBox[{51.6, 168.40224908622622`}], 
        PointBox[{51.7, 173.73554965340736`}], 
        PointBox[{51.8, 171.3705428113899}], 
        PointBox[{51.9, 171.08225390646112`}], 
        PointBox[{52., 175.56019600613945`}], 
        PointBox[{52.1, 169.9912083919553}], 
        PointBox[{52.2, 162.50647482517525`}], 
        PointBox[{52.3, 162.567837502771}], 
        PointBox[{52.4, 166.81974319736037`}], 
        PointBox[{52.5, 163.86001219195896`}], 
        PointBox[{52.6, 164.66914072797226`}], 
        PointBox[{52.7, 171.0178440085583}], 
        PointBox[{52.8, 172.07632614074828`}], 
        PointBox[{52.9, 169.151628191059}], 
        PointBox[{53., 173.2548586135672}], 
        PointBox[{53.1, 172.65890120054246`}], 
        PointBox[{53.2, 165.0229459713155}], 
        PointBox[{53.3, 161.26325585479935`}], 
        PointBox[{53.4, 165.4506233934153}], 
        PointBox[{53.5, 165.3845620771972}], 
        PointBox[{53.6, 163.3105689434742}], 
        PointBox[{53.7, 168.07709161505772`}], 
        PointBox[{53.8, 172.27043130350648`}], 
        PointBox[{53.9, 169.90115358634648`}], 
        PointBox[{54., 170.6664833087052}], 
        PointBox[{54.1, 174.06589863292902`}], 
        PointBox[{54.2, 168.4215809824309}], 
        PointBox[{54.3, 162.49182204876706`}], 
        PointBox[{54.4, 163.6606387289503}], 
        PointBox[{54.5, 166.87814561081177`}], 
        PointBox[{54.6, 164.084619750196}], 
        PointBox[{54.7, 165.98026358010975`}], 
        PointBox[{54.8, 171.52580359499552`}], 
        PointBox[{54.9, 171.71954910169006`}], 
        PointBox[{55., 169.67273154457507`}], 
        PointBox[{55.1, 173.87086934343824`}], 
        PointBox[{55.2, 171.98644598331157`}], 
        PointBox[{55.3, 165.37884186774318`}], 
        PointBox[{55.4, 163.10275309781719`}], 
        PointBox[{55.5, 167.25070476897963`}], 
        PointBox[{55.6, 166.18709260839387`}], 
        PointBox[{55.7, 165.3313632759673}], 
        PointBox[{55.8, 170.2546643006135}], 
        PointBox[{55.9, 173.20151186030853`}], 
        PointBox[{56., 170.7805186987316}], 
        PointBox[{56.1, 172.7774397755129}], 
        PointBox[{56.2, 174.71193060775113`}], 
        PointBox[{56.3, 169.01899852778297`}], 
        PointBox[{56.4, 164.39207130399882`}], 
        PointBox[{56.5, 166.67053497546294`}], 
        PointBox[{56.6, 168.54151890209323`}], 
        PointBox[{56.7, 166.18693757012807`}], 
        PointBox[{56.8, 169.1435753654805}], 
        PointBox[{56.9, 173.78933420708927`}], 
        PointBox[{57., 173.03934740553086`}], 
        PointBox[{57.1, 172.16064725423348`}], 
        PointBox[{57.2, 176.02785380570276`}], 
        PointBox[{57.3, 172.85860623799817`}], 
        PointBox[{57.4, 167.12403709858336`}], 
        PointBox[{57.5, 166.36583183424955`}], 
        PointBox[{57.6, 170.1040957939549}], 
        PointBox[{57.7, 168.21546995769313`}], 
        PointBox[{57.8, 168.73960389891}], 
        PointBox[{57.9, 173.61328811506974`}], 
        PointBox[{58., 175.24584298484115`}], 
        PointBox[{58.1, 173.00440993461962`}], 
        PointBox[{58.2, 176.10113572113187`}], 
        PointBox[{58.3, 176.26873665259336`}], 
        PointBox[{58.4, 170.63986078252492`}], 
        PointBox[{58.5, 167.28153459065652`}], 
        PointBox[{58.6, 170.48322873825236`}], 
        PointBox[{58.7, 170.7880714483399}], 
        PointBox[{58.8, 169.31587936749565`}], 
        PointBox[{58.9, 173.1210866807014}], 
        PointBox[{59., 176.71064683955046`}], 
        PointBox[{59.1, 175.11941436084453`}], 
        PointBox[{59.2, 175.74849392816395`}], 
        PointBox[{59.3, 178.6068101845085}], 
        PointBox[{59.4, 174.41161977859156`}], 
        PointBox[{59.5, 169.49466351041337`}], 
        PointBox[{59.6, 170.3378664157499}], 
        PointBox[{59.7, 173.06364425508218`}], 
        PointBox[{59.8, 170.88463040666102`}], 
        PointBox[{59.9, 172.79325554479146`}], 
        PointBox[{60., 177.3220306149451}], 
        PointBox[{60.1, 177.60614105017157`}], 
        PointBox[{60.2, 176.07312604954495`}], 
        PointBox[{60.3, 179.69125941485981`}], 
        PointBox[{60.4, 178.05736005053768`}], 
        PointBox[{60.5, 172.62608662971616`}], 
        PointBox[{60.6, 170.73160404477676`}], 
        PointBox[{60.7, 174.3281078772343}], 
        PointBox[{60.8, 173.2003368207952}], 
        PointBox[{60.9, 173.00525750733505`}], 
        PointBox[{61., 177.3221489339121}], 
        PointBox[{61.1, 179.66632709683472`}], 
        PointBox[{61.2, 177.6075937139758}], 
        PointBox[{61.3, 179.81496937268093`}], 
        PointBox[{61.4, -178.94745424525172`}], 
        PointBox[{61.5, 176.20512141822837`}], 
        PointBox[{61.6, 172.2176597856087}], 
        PointBox[{61.7, 174.57148999425408`}], 
        PointBox[{61.8, 175.72857833388844`}], 
        PointBox[{61.9, 173.98404424416367`}], 
        PointBox[{62., 177.09154517038405`}], 
        PointBox[{62.1, -179.05824141129415`}], 
        PointBox[{62.2, 179.97186197613337`}], 
        PointBox[{62.3, 179.79129499311966`}], 
        PointBox[{62.4, -176.98610940289655`}], 
        PointBox[{62.5, 179.85469925176585`}], 
        PointBox[{62.6, 174.75954703881143`}], 
        PointBox[{62.7, 174.5965248706707}], 
        PointBox[{62.8, 177.73064750843332`}], 
        PointBox[{62.9, 175.77164664222073`}], 
        PointBox[{63., 177.02077595436276`}], 
        PointBox[{63.1, -178.5477258153769}], 
        PointBox[{63.2, -177.60786254752747`}], 
        PointBox[{63.3, -179.445540778368}], 
        PointBox[{63.4, -176.1407466497185}], 
        PointBox[{63.5, -176.76613701775204`}], 
        PointBox[{63.6, 178.0440392161545}], 
        PointBox[{63.7, 175.30553540193796`}], 
        PointBox[{63.8, 178.66858144060097`}], 
        PointBox[{63.9, 178.15018091160164`}], 
        PointBox[{64., 177.44984502693842`}], 
        PointBox[{64.1, -178.56352068948036`}], 
        PointBox[{64.2, -175.72792217469396`}], 
        PointBox[{64.3, -177.58973394486384`}], 
        PointBox[{64.4, -176.06605817105446`}], 
        PointBox[{64.5, -174.08757983164833`}], 
        PointBox[{64.6, -178.34745361131354`}], 
        PointBox[{64.7, 177.09770044899778`}], 
        PointBox[{64.8, 178.74029166833498`}], 
        PointBox[{64.9, -179.4269325670757}], 
        PointBox[{65., 178.6173214367227}], 
        PointBox[{65.1, -178.76608874859085`}], 
        PointBox[{65.2, -174.6335646363077}], 
        PointBox[{65.3, -175.1134052025518}], 
        PointBox[{65.4, -175.91224339535256`}], 
        PointBox[{65.5, -172.42623122576333`}], 
        PointBox[{65.6, -174.75898262188275`}], 
        PointBox[{65.7, 179.91706138979498`}], 
        PointBox[{65.8, 178.82579683360382`}], 
        PointBox[{65.9, -177.70724913865706`}], 
        PointBox[{66., -179.42971613256668`}], 
        PointBox[{66.1, -178.77749555875198`}], 
        PointBox[{66.2, -174.28724606870674`}], 
        PointBox[{66.3, -172.74790621426655`}], 
        PointBox[{66.4, -174.82683161909517`}], 
        PointBox[{66.5, -171.84726309746475`}], 
        PointBox[{66.6, -171.5396348893919}], 
        PointBox[{66.7, -176.5658201762999}], 
        PointBox[{66.8, 179.76387448229798`}], 
        PointBox[{66.9, -177.1382116336681}], 
        PointBox[{67., -176.97123516246938`}], 
        PointBox[{67.1, -178.2340104016257}], 
        PointBox[{67.2, -174.46884190222772`}], 
        PointBox[{67.3, -171.03503606660524`}], 
        PointBox[{67.4, -172.68911446836137`}], 
        PointBox[{67.5, -171.9043530938652}], 
        PointBox[{67.6, -169.1280684148005}], 
        PointBox[{67.7, -172.83485026765266`}], 
        PointBox[{67.8, -178.10830912170786`}], 
        PointBox[{67.9, -177.33062431820144`}], 
        PointBox[{68., -174.69461618579226`}], 
        PointBox[{68.1, -176.88096582129947`}], 
        PointBox[{68.2, -174.83189871198556`}], 
        PointBox[{68.3, -170.21769947749272`}], 
        PointBox[{68.4, -170.1114140175705}], 
        PointBox[{68.5, -171.61507210381387`}], 
        PointBox[{68.6, -167.8831537300066}], 
        PointBox[{68.7, -169.2552975581857}], 
        PointBox[{68.8, -174.8963422668312}], 
        PointBox[{68.9, -177.26528366567072`}], 
        PointBox[{69., -173.45510128718888`}], 
        PointBox[{69.1, -174.74037236393633`}], 
        PointBox[{69.2, -174.9410793398274}], 
        PointBox[{69.3, -170.28391132836987`}], 
        PointBox[{69.4, -167.8884203417183}], 
        PointBox[{69.5, -170.21051907786023`}], 
        PointBox[{69.6, -167.82228334372485`}], 
        PointBox[{69.7, -166.27123194749583`}], 
        PointBox[{69.8, -171.10588510600792`}], 
        PointBox[{69.9, -176.10025961805513`}], 
        PointBox[{70., -173.58607768682123`}], 
        PointBox[{70.1, -172.31865280012426`}], 
        PointBox[{70.2, -174.3677215405769}], 
        PointBox[{70.3, -171.0023701974933}], 
        PointBox[{70.4, -166.61683076935878`}], 
        PointBox[{70.5, -167.8648544384996}], 
        PointBox[{70.6, -168.22015478619142`}], 
        PointBox[{70.7, -164.45632428277167`}], 
        PointBox[{70.8, -167.3473783439913}], 
        PointBox[{70.9, -173.5713535034738}], 
        PointBox[{71., -174.3569809738765}], 
        PointBox[{71.1, -170.63148489498417`}], 
        PointBox[{71.2, -172.89632330885797`}], 
        PointBox[{71.3, -171.9237605004746}], 
        PointBox[{71.4, -166.60908009746345`}], 
        PointBox[{71.5, -165.4631831485749}], 
        PointBox[{71.6, -167.88366713859432`}], 
        PointBox[{71.7, -164.24949956177443`}], 
        PointBox[{71.8, -164.0763754518557}], 
        PointBox[{71.9, -170.02377297771454`}], 
        PointBox[{72., -174.495239638949}], 
        PointBox[{72.1, -170.67462171065563`}], 
        PointBox[{72.2, -170.83174169870472`}], 
        PointBox[{72.3, -172.4520614602734}], 
        PointBox[{72.4, -167.86801798822853`}], 
        PointBox[{72.5, -163.98832670767297`}], 
        PointBox[{72.6, -166.33994747867837`}], 
        PointBox[{72.7, -165.37117021028098`}], 
        PointBox[{72.8, -162.01674421505595`}], 
        PointBox[{72.9, -166.34123902183637`}], 
        PointBox[{73., -173.18257919754979`}], 
        PointBox[{73.1, -172.37515178132162`}], 
        PointBox[{73.2, -169.23409042530693`}], 
        PointBox[{73.3, -172.110543517294}], 
        PointBox[{73.4, -169.99611932624975`}], 
        PointBox[{73.5, -164.19670395465073`}], 
        PointBox[{73.6, -164.3365584729181}], 
        PointBox[{73.7, -166.47933822798223`}], 
        PointBox[{73.8, -162.0031857769136}], 
        PointBox[{73.9, -163.19921697265818`}], 
        PointBox[{74., -170.45685859039077`}], 
        PointBox[{74.1, -174.27856713731308`}], 
        PointBox[{74.2, -169.62502793661406`}], 
        PointBox[{74.3, -171.00016385082563`}], 
        PointBox[{74.4, -172.1839335433615}], 
        PointBox[{74.5, -166.45914770151285`}], 
        PointBox[{74.6, -163.21323850174667`}], 
        PointBox[{74.7, -166.39251975259685`}], 
        PointBox[{74.8, -164.24531236844632`}], 
        PointBox[{74.9, -161.43953771760425`}], 
        PointBox[{75., -167.30848590732057`}], 
        PointBox[{75.1, -174.8384914935814}], 
        PointBox[{75.2, -172.6819999096042}], 
        PointBox[{75.3, -170.21705444696272`}], 
        PointBox[{75.4, -173.57485655012715`}], 
        PointBox[{75.5, -170.4567639567249}], 
        PointBox[{75.6, -164.24850985938247`}], 
        PointBox[{75.7, -165.525708766967}], 
        PointBox[{75.8, -167.33870096396276`}], 
        PointBox[{75.9, -162.27899360228912`}], 
        PointBox[{76., -164.81690062354755`}], 
        PointBox[{76.1, -173.6320673714581}], 
        PointBox[{76.2, -176.87881744605693`}], 
        PointBox[{76.3, -171.7021124052044}], 
        PointBox[{76.4, -174.00630536535027`}], 
        PointBox[{76.5, -174.95706480880472`}], 
        PointBox[{76.6, -168.21150963740365`}], 
        PointBox[{76.7, -165.49697581709916`}], 
        PointBox[{76.8, -169.30152919250395`}], 
        PointBox[{76.9, -166.30641998485225`}], 
        PointBox[{77., -163.98534013907192`}], 
        PointBox[{77.1, -171.5778355134753}], 
        PointBox[{77.2, -179.72465551865025`}], 
        PointBox[{77.3, -176.63621965033963`}], 
        PointBox[{77.4, -174.6108314414305}], 
        PointBox[{77.5, -178.43346735896193`}], 
        PointBox[{77.6, -174.63026831097523`}], 
        PointBox[{77.7, -168.02844665972225`}], 
        PointBox[{77.8, -170.08536248225573`}], 
        PointBox[{77.9, -171.76463932876504`}], 
        PointBox[{78., -166.29281259746494`}], 
        PointBox[{78.1, -170.06287045558565`}], 
        PointBox[{78.2, 179.75512761360733`}], 
        PointBox[{78.3, 176.9467753541976}], 
        PointBox[{78.4, -177.55156069977238`}], 
        PointBox[{78.5, 179.61586019712558`}], 
        PointBox[{78.6, 178.64498770677164`}], 
        PointBox[{78.7, -173.9527947468814}], 
        PointBox[{78.8, -171.46438457628392`}], 
        PointBox[{78.9, -175.64535730363423`}], 
        PointBox[{79., -172.24986102267576`}], 
        PointBox[{79.1, -170.2747414657424}], 
        PointBox[{79.2, -179.27670602773287`}], 
        PointBox[{79.3, 172.60247073494975`}], 
        PointBox[{79.4, 176.13604705188482`}], 
        PointBox[{79.5, 178.02508612877864`}], 
        PointBox[{79.6, 173.9623645234169}], 
        PointBox[{79.7, 177.985664354841}], 
        PointBox[{79.8, -175.23890425606078`}], 
        PointBox[{79.9, -177.52537878580915`}], 
        PointBox[{80., -179.18222721186612`}], 
        PointBox[{80.1, -173.60316150115978`}], 
        PointBox[{80.2, -178.20508255665482`}], 
        PointBox[{80.3, 171.46023918520223`}], 
        PointBox[{80.4, 169.22186102460546`}], 
        PointBox[{80.5, 174.71050559431023`}], 
        PointBox[{80.6, 171.81135670765798`}], 
        PointBox[{80.7, 170.90186672205164`}], 
        PointBox[{80.8, 178.28700277436292`}], 
        PointBox[{80.9, -179.30264171728777`}], 
        PointBox[{81., 176.60699149795983`}], 
        PointBox[{81.1, -179.92674111059023`}], 
        PointBox[{81.2, -178.333616263124}], 
        PointBox[{81.3, 172.43361277624354`}], 
        PointBox[{81.4, 165.4078750227709}], 
        PointBox[{81.5, 169.0845928844792}], 
        PointBox[{81.6, 170.77981891626405`}], 
        PointBox[{81.7, 166.9927263655627}], 
        PointBox[{81.8, 171.0392006735783}], 
        PointBox[{81.9, 177.39395693098777`}], 
        PointBox[{82., 175.24853527540836`}], 
        PointBox[{82.1, 173.9140746596022}], 
        PointBox[{82.2, 179.1499330057777}], 
        PointBox[{82.3, 174.20873285378912`}], 
        PointBox[{82.4, 165.15601466562657`}], 
        PointBox[{82.5, 163.82709703415458`}], 
        PointBox[{82.6, 168.87409701469733`}], 
        PointBox[{82.7, 166.079477846004}], 
        PointBox[{82.8, 165.71518807245593`}], 
        PointBox[{82.9, 172.5729239446373}], 
        PointBox[{83., 174.61393996694096`}], 
        PointBox[{83.1, 171.03398929507966`}], 
        PointBox[{83.2, 174.62682719949225`}], 
        PointBox[{83.3, 175.48598627663887`}], 
        PointBox[{83.4, 167.06237167429936`}], 
        PointBox[{83.5, 161.65834884714423`}], 
        PointBox[{83.6, 165.47280463860807`}], 
        PointBox[{83.7, 166.57382814791345`}], 
        PointBox[{83.8, 163.49690104476758`}], 
        PointBox[{83.9, 167.73456211168377`}], 
        PointBox[{84., 173.1429489140137}], 
        PointBox[{84.1, 171.06832906830095`}], 
        PointBox[{84.2, 170.52478317347413`}], 
        PointBox[{84.3, 175.04577421628346`}], 
        PointBox[{84.4, 169.91041218463215`}], 
        PointBox[{84.5, 162.56587693816982`}], 
        PointBox[{84.6, 162.35576735876384`}], 
        PointBox[{84.7, 166.65445438747702`}], 
        PointBox[{84.8, 163.88570697508112`}], 
        PointBox[{84.9, 164.4982069429243}], 
        PointBox[{85., 170.6815133960772}], 
        PointBox[{85.1, 171.97558812487114`}], 
        PointBox[{85.2, 169.0762340321162}], 
        PointBox[{85.3, 172.96650265116477`}], 
        PointBox[{85.4, 172.6745155587414}], 
        PointBox[{85.5, 165.2915378357211}], 
        PointBox[{85.6, 161.4599995396129}], 
        PointBox[{85.7, 165.46168688566104`}], 
        PointBox[{85.8, 165.60314828245464`}], 
        PointBox[{85.9, 163.5058504023982}], 
        PointBox[{86., 168.0626069491409}], 
        PointBox[{86.1, 172.30258282490104`}], 
        PointBox[{86.2, 170.1057905561247}], 
        PointBox[{86.3, 170.6964401970181}], 
        PointBox[{86.4, 174.15499142256886`}], 
        PointBox[{86.5, 168.79407056373748`}], 
        PointBox[{86.6, 162.93304958644876`}], 
        PointBox[{86.7, 163.91550666515832`}], 
        PointBox[{86.8, 167.18870617385983`}], 
        PointBox[{86.9, 164.48847459859098`}], 
        PointBox[{87., 166.25571317449067`}], 
        PointBox[{87.1, 171.70464444944082`}], 
        PointBox[{87.2, 172.04234166462265`}], 
        PointBox[{87.3, 169.98051934700925`}], 
        PointBox[{87.4, 174.07426893555385`}], 
        PointBox[{87.5, 172.3915634836667}], 
        PointBox[{87.6, 165.92712008747185`}], 
        PointBox[{87.7, 163.57663336323458`}], 
        PointBox[{87.8, 167.63544901430578`}], 
        PointBox[{87.9, 166.68458166754863`}], 
        PointBox[{88., 165.80161867172137`}], 
        PointBox[{88.1, 170.59796356510924`}], 
        PointBox[{88.2, 173.58073088587844`}], 
        PointBox[{88.3, 171.24177554684138`}], 
        PointBox[{88.4, 173.1312784454858}], 
        PointBox[{88.5, 175.12358747614053`}], 
        PointBox[{88.6, 169.597930188771}], 
        PointBox[{88.7, 164.9885170012567}], 
        PointBox[{88.8, 167.15461250497174`}], 
        PointBox[{88.9, 169.07064059725963`}], 
        PointBox[{89., 166.75408558209165`}], 
        PointBox[{89.1, 169.62959273924935`}], 
        PointBox[{89.2, 174.22547209568438`}], 
        PointBox[{89.3, 173.55316195367777`}], 
        PointBox[{89.4, 172.64661997951043`}], 
        PointBox[{89.5, 176.47211713413708`}], 
        PointBox[{89.6, 173.42732121695008`}], 
        PointBox[{89.7, 167.7611664928554}], 
        PointBox[{89.8, 166.94479714836052`}], 
        PointBox[{89.9, 170.6502234866348}], 
        PointBox[{90., 168.81152896308777`}], 
        PointBox[{90.1, 169.31688136223966`}], 
        PointBox[{90.2, 174.11706858433172`}], 
        PointBox[{90.3, 175.77190542666358`}], 
        PointBox[{90.4, 173.55953452867834`}], 
        PointBox[{90.5, 176.60272626376536`}], 
        PointBox[{90.6, 176.8101462434206}], 
        PointBox[{90.7, 171.2719990462938}], 
        PointBox[{90.8, 167.908462983527}], 
        PointBox[{90.9, 171.05719312325527`}], 
        PointBox[{91., 171.37975881504826`}], 
        PointBox[{91.1, 169.928041446532}], 
        PointBox[{91.2, 173.6853157833175}], 
        PointBox[{91.3, 177.24829610071902`}], 
        PointBox[{91.4, 175.68850845796987`}], 
        PointBox[{91.5, 176.30381567667064`}], 
        PointBox[{91.6, 179.14084002224263`}], 
        PointBox[{91.7, 175.017560046399}], 
        PointBox[{91.8, 170.12533570743108`}], 
        PointBox[{91.9, 170.94098544727603`}], 
        PointBox[{92., 173.64777629134187`}], 
        PointBox[{92.1, 171.4920192641439}], 
        PointBox[{92.2, 173.39356327912537`}], 
        PointBox[{92.3, 177.88095759344287`}], 
        PointBox[{92.4, 178.16877744926023`}], 
        PointBox[{92.5, 176.6504544805648}], 
        PointBox[{92.6, -179.7579133600666}], 
        PointBox[{92.7, 178.62961982600973`}], 
        PointBox[{92.8, 173.23889198908}], 
        PointBox[{92.9, 171.34211980919645`}], 
        PointBox[{93., 174.91662456838822`}], 
        PointBox[{93.1, 173.78642391688481`}], 
        PointBox[{93.2, 173.61197309865383`}], 
        PointBox[{93.3, 177.9039001808269}], 
        PointBox[{93.4, -179.7732990682416}], 
        PointBox[{93.5, 178.1773151401576}], 
        PointBox[{93.6, -179.61125792244275`}], 
        PointBox[{93.7, -178.3940250059095}], 
        PointBox[{93.8, 176.79514535830822`}], 
        PointBox[{93.9, 172.81296387783368`}], 
        PointBox[{94., 175.16725904560008`}], 
        PointBox[{94.1, 176.29758810611384`}], 
        PointBox[{94.2, 174.57398202165496`}], 
        PointBox[{94.3, 177.68474624241935`}], 
        PointBox[{94.4, -178.49028285243548`}], 
        PointBox[{94.5, -179.47245642375492`}], 
        PointBox[{94.6, -179.62910326186102`}], 
        PointBox[{94.7, -176.42920041506295`}], 
        PointBox[{94.8, -179.57829394483997`}], 
        PointBox[{94.9, 175.33329388951825`}], 
        PointBox[{95., 175.18458883087442`}], 
        PointBox[{95.1, 178.2981512787228}], 
        PointBox[{95.2, 176.33606981601042`}], 
        PointBox[{95.3, 177.60824304187554`}], 
        PointBox[{95.4, -177.96939767913136`}], 
        PointBox[{95.5, -177.0556821418577}], 
        PointBox[{95.6, -178.88188768172404`}], 
        PointBox[{95.7, -175.56989622504625`}], 
        PointBox[{95.8, -176.21332385249843`}], 
        PointBox[{95.9, 178.60368450309034`}], 
        PointBox[{96., 175.86947001046792`}], 
        PointBox[{96.1, 179.24211310771352`}], 
        PointBox[{96.2, 178.69526018589386`}], 
        PointBox[{96.3, 178.01724333901075`}], 
        PointBox[{96.4, -177.9831310039881}], 
        PointBox[{96.5, -175.16788414381153`}], 
        PointBox[{96.6, -177.04533516756783`}], 
        PointBox[{96.7, -175.49105421813147`}], 
        PointBox[{96.8, -173.53330593531427`}], 
        PointBox[{96.9, -177.7941456393164}], 
        PointBox[{97., 177.6360770513129}], 
        PointBox[{97.1, 179.30636373178277`}], 
        PointBox[{97.2, -178.88721917831572`}], 
        PointBox[{97.3, 179.15908274921821`}], 
        PointBox[{97.4, -178.19882555994263`}], 
        PointBox[{97.5, -174.06450489912822`}], 
        PointBox[{97.6, -174.5749585798476}], 
        PointBox[{97.7, -175.35321518218552`}], 
        PointBox[{97.8, -171.86325490409217`}], 
        PointBox[{97.9, -174.2084438035381}], 
        PointBox[{98., -179.55630985437892`}], 
        PointBox[{98.1, 179.36286857919185`}], 
        PointBox[{98.2, -177.1645012464287}], 
        PointBox[{98.3, -178.90799442828575`}], 
        PointBox[{98.4, -178.23735125007806`}], 
        PointBox[{98.5, -173.7214385685802}], 
        PointBox[{98.6, -172.20239874332037`}], 
        PointBox[{98.7, -174.29220014416205`}], 
        PointBox[{98.8, -171.28572296432685`}], 
        PointBox[{98.9, -170.98671475546143`}], 
        PointBox[{99., -176.03497077334032`}], 
        PointBox[{99.1, -179.73482313967543`}], 
        PointBox[{99.2, -176.6060467724892}], 
        PointBox[{99.3, -176.4599845335615}], 
        PointBox[{99.4, -177.7272536027449}], 
        PointBox[{99.5, -173.92882516993268`}], 
        PointBox[{99.6, -170.4843295936007}], 
        PointBox[{99.7, -172.16871384314436`}], 
        PointBox[{99.8, -171.36610103076964`}], 
        PointBox[{99.9, -168.5744169985701}], 
        PointBox[{100., -172.2969380501454}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {-180, 180}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \
\\\"input\\\" -> \\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-328., 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.880463269108961*^9, 3.880464075254601*^9, 
  3.8804642167590303`*^9, 3.880612973673315*^9, 3.880613106010303*^9, 
  3.880655524482452*^9, 3.8807027449729757`*^9, 3.880703460663118*^9, 
  3.8909820850789957`*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"ce15915f-e697-4820-b956-36008917ad94"]
}, Open  ]],

Cell["\<\
Produce the four labelled plots for the case of 2:1 resonance apocentric \
libration.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, {3.8806136903256893`*^9, 3.880613721105887*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"115d7290-dee2-471c-a5a3-3fdde75d2bbb"],

Cell[BoxData[
 RowBox[{"FourPlot", "[", 
  RowBox[{"0.001", ",", " ", "init4", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.8804583016293163`*^9, 3.880458302243639*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"d3705ddf-7fca-4510-8a93-659664ea076c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcD", "=", "gc"}]], "Input",
 CellChangeTimes->{{3.880458308355776*^9, 3.8804583122036467`*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"531e801c-4c08-44c3-b1e9-b599576789f8"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.0055000000000000005`], Thickness[0.0075], PointBox[CompressedData["
1:eJxFe3c81f/7vgYamkRaZCUjeybnstfB2ecYldEmZFQqUnZp0V6K3opUJBVS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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0.6000000000000013},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0.6, 
           FormBox["0.6`", TraditionalForm]}, {0.62, 
           FormBox["0.62`", TraditionalForm]}, {0.64, 
           FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0.6, 0.65}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Prolog->{
        Dashing[{Small, Small}], 
        LineBox[{{0, 0.629961}, {100, 0.629961}}]},
      Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
     ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.0055000000000000005`], Thickness[0.0075], PointBox[CompressedData["
1:eJw9m3c81WH7x6XS0kAyUokiK7NsPvbmHGcKkXZpUtKioUlLQyqrkF0p0lRK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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {0.1, 
           FormBox["0.1`", TraditionalForm]}, {0.2, 
           FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 0.2}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -159.99}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.0055000000000000005`], Thickness[0.0075], PointBox[CompressedData["
1:eJxVmnc81f/7/2UmUhkVSUgyIntzHvY6OMs5ByklKQkR7dJEqURLWkqSNFXa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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}, {360, 
           FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 360.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.0055000000000000005`], Thickness[0.0075], PointBox[CompressedData["
1:eJxVm3lYTdv/xw+RKURESgMpKpqEUC0hUpnKkKmkMmVISBTHGMoUIWOmkG5K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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[CurlyPhi]\
\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{-180, 
           FormBox[
            RowBox[{"-", "180"}], TraditionalForm]}, {0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {-180., 180.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -383.19}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-438.99, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.8804583136126003`*^9, 3.8804632800375443`*^9, 
  3.8804640764438562`*^9, 3.880464217993331*^9, 3.880612975168919*^9, 
  3.880613107360836*^9, 3.880655525522627*^9, 3.880702746077354*^9, 
  3.880703461760642*^9, 3.89098208618041*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"b51a873f-3cb4-415b-ba29-57098907e104"]
}, Open  ]],

Cell["\<\
Produce the x-y plot for the case of 2:1 resonance apocentric libration.  \
This is Fig.8.17d.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, {3.8804632967128077`*^9, 3.880463299471642*^9}, {
   3.8806137270909567`*^9, 3.880613736811059*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e91bee86-1403-4183-84ae-0d685d41c793"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xyD", "=", "xyplot"}]], "Input",
 CellChangeTimes->{{3.880458318316165*^9, 3.880458323483968*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"0efa79fd-80e5-4d56-b138-2f19d40f8f8a"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.0055000000000000005`],
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVV3c81d8bT+Qr0aAooqFEg0olSkcaKE0lRFmFqFRWREOUmaIIyczee77t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     "]]}, {{}, {}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-4., 4.}, {-4., 4.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Prolog->{
    Thickness[0.002], 
    LineBox[{{0, -4}, {0, 4}}], 
    LineBox[{{-4, 0}, {4, 0}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.88045832444053*^9, 3.880459527942947*^9, 
  3.880463303258978*^9, 3.880464076506053*^9, 3.880464218063623*^9, 
  3.880612975246264*^9, 3.88061310742233*^9, 3.880655525576284*^9, 
  3.880702746133462*^9, 3.880703461826021*^9, 3.890982086243382*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"a643adf9-05ec-43a3-93fd-0afbbef763fc"]
}, Open  ]],

Cell["\<\
Produce the four unlabelled plots for the case of 2:1 resonance inner \
circulation.  This is Fig.8.16e.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, {3.880614064638723*^9, 
   3.880614086344872*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8e603af6-05d8-48ed-935b-3ace235e720e"],

Cell[BoxData[
 RowBox[{"FourPlotNoLabel", "[", 
  RowBox[{"0.001", ",", " ", "init5", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.88046267960392*^9, 3.880462680234071*^9}, {
  3.880463182008906*^9, 3.880463182578125*^9}, {3.880463259858301*^9, 
  3.880463260503047*^9}, {3.880463330912463*^9, 3.8804633314215603`*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"b0b58d4c-36e8-4b5c-8d1f-11d4b8783c7e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcNLE", "=", "gcNL"}]], "Input",
 CellChangeTimes->{{3.880463026210558*^9, 3.88046302986303*^9}, {
  3.880463083413727*^9, 3.880463090373127*^9}, {3.880463186522532*^9, 
  3.880463187214306*^9}, {3.880463263263054*^9, 3.880463264012458*^9}, {
  3.8804633381433487`*^9, 3.8804633387719584`*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"fbd990aa-6da9-409a-8742-0c500883eded"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
       {Dashing[{Small, Small}], LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], 
        PointBox[{0, 0.6382220000000002}], 
        PointBox[{0.1, 0.6369270341522284}], 
        PointBox[{0.2, 0.637553053320335}], 
        PointBox[{0.3, 0.6396510421023557}], 
        PointBox[{0.4, 0.6415759293531875}], 
        PointBox[{0.5, 0.6424007639077278}], 
        PointBox[{0.6, 0.6420920425155128}], 
        PointBox[{0.7, 0.6406841793500048}], 
        PointBox[{0.8, 0.6385054816870271}], 
        PointBox[{0.9, 0.636919073710223}], 
        PointBox[{1., 0.6376001788662509}], 
        PointBox[{1.1, 0.6374931886769117}], 
        PointBox[{1.2, 0.6369042194396559}], 
        PointBox[{1.3, 0.6384513640454678}], 
        PointBox[{1.4, 0.640688033647853}], 
        PointBox[{1.5, 0.6420905708159974}], 
        PointBox[{1.6, 0.6422665295396439}], 
        PointBox[{1.7, 0.6413892398217619}], 
        PointBox[{1.8, 0.639522780799744}], 
        PointBox[{1.9, 0.6373924153301536}], 
        PointBox[{2., 0.6368170820439923}], 
        PointBox[{2.1, 0.6380828481082095}], 
        PointBox[{2.2, 0.6367257453924772}], 
        PointBox[{2.3, 0.6373411246609832}], 
        PointBox[{2.4, 0.6394775440363173}], 
        PointBox[{2.5, 0.6414470420026479}], 
        PointBox[{2.6, 0.6421427710166914}], 
        PointBox[{2.7, 0.6417338898570519}], 
        PointBox[{2.8, 0.6403603909555782}], 
        PointBox[{2.9, 0.6381706966228894}], 
        PointBox[{3., 0.6365730402981696}], 
        PointBox[{3.1, 0.6374828381323957}], 
        PointBox[{3.2, 0.6370981241462994}], 
        PointBox[{3.3, 0.6365486892135478}], 
        PointBox[{3.4, 0.6381196825173139}], 
        PointBox[{3.5, 0.6404497752462637}], 
        PointBox[{3.6, 0.6417422564021511}], 
        PointBox[{3.7, 0.6417658145636433}], 
        PointBox[{3.8, 0.640878294117823}], 
        PointBox[{3.9, 0.6390177780100886}], 
        PointBox[{4., 0.6368250200498776}], 
        PointBox[{4.1, 0.6364817799974154}], 
        PointBox[{4.2, 0.637659419904659}], 
        PointBox[{4.3, 0.6362148612870937}], 
        PointBox[{4.4, 0.6368724096679823}], 
        PointBox[{4.5, 0.6391431175921726}], 
        PointBox[{4.6, 0.6410596505406808}], 
        PointBox[{4.7, 0.6415459753451909}], 
        PointBox[{4.8, 0.6410677342111091}], 
        PointBox[{4.9, 0.6396983145524391}], 
        PointBox[{5., 0.6374132137419998}], 
        PointBox[{5.1, 0.6359486645840559}], 
        PointBox[{5.2, 0.6372314490938683}], 
        PointBox[{5.3, 0.636403570145923}], 
        PointBox[{5.4, 0.6359512396950712}], 
        PointBox[{5.5, 0.6376881545967806}], 
        PointBox[{5.6, 0.6400767176750946}], 
        PointBox[{5.7, 0.6411146830206588}], 
        PointBox[{5.8, 0.640991249216366}], 
        PointBox[{5.9, 0.6400875284219474}], 
        PointBox[{6., 0.6381203972409338}], 
        PointBox[{6.1, 0.6359188181693882}], 
        PointBox[{6.2, 0.6360903331384973}], 
        PointBox[{6.3, 0.636924493192562}], 
        PointBox[{6.4, 0.6354687886092767}], 
        PointBox[{6.5, 0.6363302089132178}], 
        PointBox[{6.6, 0.6388106929286204}], 
        PointBox[{6.7, 0.6404834549625936}], 
        PointBox[{6.8, 0.6407218076321642}], 
        PointBox[{6.9, 0.6401876875521537}], 
        PointBox[{7., 0.6387208716196812}], 
        PointBox[{7.1, 0.6362776112179213}], 
        PointBox[{7.2, 0.6352471587661512}], 
        PointBox[{7.3, 0.6368690911186565}], 
        PointBox[{7.4, 0.6354645936042641}], 
        PointBox[{7.5, 0.6352798299803869}], 
        PointBox[{7.6, 0.6373690604199259}], 
        PointBox[{7.7, 0.6396406856567266}], 
        PointBox[{7.8, 0.6403128015695764}], 
        PointBox[{7.9, 0.640068379949138}], 
        PointBox[{8., 0.6390810267584687}], 
        PointBox[{8.1, 0.6368559743055277}], 
        PointBox[{8.2, 0.6348823776750582}], 
        PointBox[{8.3, 0.6358424337912056}], 
        PointBox[{8.4, 0.6358694341061985}], 
        PointBox[{8.5, 0.6346377166867851}], 
        PointBox[{8.6, 0.6359527836155194}], 
        PointBox[{8.7, 0.63857254037955}], PointBox[{8.8, 0.639788468976741}],
         PointBox[{8.9, 0.6398052835823229}], 
        PointBox[{9., 0.6391890553802229}], 
        PointBox[{9.1, 0.6374449419126427}], 
        PointBox[{9.2, 0.6349383437116206}], 
        PointBox[{9.3, 0.634753606628951}], 
        PointBox[{9.4, 0.6362171454455756}], 
        PointBox[{9.5, 0.6344218285530527}], 
        PointBox[{9.6, 0.6347694675146008}], 
        PointBox[{9.7, 0.637307701995743}], 
        PointBox[{9.8, 0.6391469248334478}], 
        PointBox[{9.9, 0.6394534782225362}], 
        PointBox[{10., 0.6391042250819001}], 
        PointBox[{10.1, 0.6378793249163134}], 
        PointBox[{10.2, 0.6353164998111875}], 
        PointBox[{10.3, 0.6340415690475706}], 
        PointBox[{10.4, 0.6357582889471196}], 
        PointBox[{10.5, 0.6346044992774067}], 
        PointBox[{10.6, 0.6339401296782367}], 
        PointBox[{10.7, 0.635954953554549}], 
        PointBox[{10.8, 0.6383672659541539}], 
        PointBox[{10.9, 0.6390441869587558}], 
        PointBox[{11., 0.6388974177359912}], 
        PointBox[{11.1, 0.6380986297741954}], 
        PointBox[{11.2, 0.6358659061626152}], 
        PointBox[{11.3, 0.6337287513863755}], 
        PointBox[{11.4, 0.6347028184004132}], 
        PointBox[{11.5, 0.6350455952947782}], 
        PointBox[{11.6, 0.633487884304884}], 
        PointBox[{11.7, 0.6346841360396218}], 
        PointBox[{11.8, 0.6374274563487701}], 
        PointBox[{11.9, 0.6385858514398943}], 
        PointBox[{12., 0.6386230854678759}], 
        PointBox[{12.1, 0.6381286659260595}], 
        PointBox[{12.2, 0.6364102811508352}], 
        PointBox[{12.3, 0.6337711389568129}], 
        PointBox[{12.4, 0.6337186761986146}], 
        PointBox[{12.5, 0.6353161780522794}], 
        PointBox[{12.6, 0.6333870749845963}], 
        PointBox[{12.7, 0.6336474651912097}], 
        PointBox[{12.8, 0.636334546158105}], 
        PointBox[{12.9, 0.6380666805008641}], 
        PointBox[{13., 0.6383127933243042}], 
        PointBox[{13.1, 0.6380255861369452}], 
        PointBox[{13.2, 0.6368177324891608}], 
        PointBox[{13.3, 0.6341004275933559}], 
        PointBox[{13.4, 0.6330371291242122}], 
        PointBox[{13.5, 0.6349311555976695}], 
        PointBox[{13.6, 0.633590621114787}], 
        PointBox[{13.7, 0.632920447216612}], 
        PointBox[{13.8, 0.6351536747163801}], 
        PointBox[{13.9, 0.6374615372178236}], 
        PointBox[{14., 0.6379807259590857}], 
        PointBox[{14.1, 0.6378416999839481}], 
        PointBox[{14.2, 0.637042713475692}], 
        PointBox[{14.3, 0.6346062449528841}], 
        PointBox[{14.4, 0.6326679022526897}], 
        PointBox[{14.5, 0.6340427989468643}], 
        PointBox[{14.6, 0.6339941123464453}], 
        PointBox[{14.7, 0.6325017436866825}], 
        PointBox[{14.8, 0.6340028889206283}], 
        PointBox[{14.9, 0.6367397346225243}], 
        PointBox[{15., 0.6376265000882395}], 
        PointBox[{15.1, 0.6376117284852089}], 
        PointBox[{15.2, 0.6371019655801003}], 
        PointBox[{15.3, 0.635144166673649}], 
        PointBox[{15.4, 0.6325836902081577}], 
        PointBox[{15.5, 0.633115054925053}], 
        PointBox[{15.6, 0.6343500684778725}], 
        PointBox[{15.7, 0.632355173239722}], 
        PointBox[{15.8, 0.6330024177620316}], 
        PointBox[{15.9, 0.6358815856550972}], 
        PointBox[{16., 0.637238051281121}], 
        PointBox[{16.1, 0.6373539428413416}], 
        PointBox[{16.2, 0.6370362601724107}], 
        PointBox[{16.3, 0.6355900450885122}], 
        PointBox[{16.4, 0.6327482705998575}], 
        PointBox[{16.5, 0.6323685771010125}], 
        PointBox[{16.6, 0.6343131949888559}], 
        PointBox[{16.7, 0.6324345573385054}], 
        PointBox[{16.8, 0.6322246404234086}], 
        PointBox[{16.9, 0.6348988896218467}], 
        PointBox[{17., 0.6367947925828087}], 
        PointBox[{17.1, 0.6370746713583234}], 
        PointBox[{17.2, 0.6368834072724021}], 
        PointBox[{17.3, 0.6358744707699525}], 
        PointBox[{17.4, 0.6330983794014345}], 
        PointBox[{17.5, 0.6318376279360625}], 
        PointBox[{17.6, 0.6337718016143145}], 
        PointBox[{17.7, 0.6326796835118822}], 
        PointBox[{17.8, 0.6316801465319519}], 
        PointBox[{17.9, 0.6338488181784464}], 
        PointBox[{18., 0.6362693232848962}], 
        PointBox[{18.1, 0.636771005147187}], 
        PointBox[{18.2, 0.6366681875424138}], 
        PointBox[{18.3, 0.6359862620232692}], 
        PointBox[{18.4, 0.6335369389656527}], 
        PointBox[{18.5, 0.6315050247313323}], 
        PointBox[{18.6, 0.6329552959202954}], 
        PointBox[{18.7, 0.6329909970549091}], 
        PointBox[{18.8, 0.6313362177800766}], 
        PointBox[{18.9, 0.6328125245764886}], 
        PointBox[{19., 0.6356332031311152}], 
        PointBox[{19.1, 0.6364332853875697}], 
        PointBox[{19.2, 0.6364018762819561}], 
        PointBox[{19.3, 0.6359431822062303}], 
        PointBox[{19.4, 0.6339502944694255}], 
        PointBox[{19.5, 0.6313439477721787}], 
        PointBox[{19.6, 0.6321117109354265}], 
        PointBox[{19.7, 0.6332072461860654}], 
        PointBox[{19.8, 0.631143169854919}], 
        PointBox[{19.9, 0.6318648049985353}], 
        PointBox[{20., 0.6348657001020651}], 
        PointBox[{20.1, 0.6360459074132971}], 
        PointBox[{20.2, 0.6360853052668564}], 
        PointBox[{20.3, 0.6357695001506917}], 
        PointBox[{20.4, 0.6342396339707502}], 
        PointBox[{20.5, 0.6313190212795005}], 
        PointBox[{20.6, 0.6313446737693135}], 
        PointBox[{20.7, 0.6331533542939421}], 
        PointBox[{20.8, 0.6310429826234102}], 
        PointBox[{20.9, 0.6310417390234168}], 
        PointBox[{21., 0.6339639578435591}], 
        PointBox[{21.1, 0.6355899069960519}], 
        PointBox[{21.2, 0.6357112027267906}], 
        PointBox[{21.3, 0.6354808299301288}], 
        PointBox[{21.4, 0.6343455010300647}], 
        PointBox[{21.5, 0.6313758670313884}], 
        PointBox[{21.6, 0.6306615954293817}], 
        PointBox[{21.7, 0.6327550363782843}], 
        PointBox[{21.8, 0.6309705295211433}], 
        PointBox[{21.9, 0.630327810315153}], 
        PointBox[{22., 0.6329457928085467}], 
        PointBox[{22.1, 0.6350415138128053}], 
        PointBox[{22.2, 0.6352638409381316}], 
        PointBox[{22.3, 0.6350787755980655}], 
        PointBox[{22.4, 0.634242284046831}], 
        PointBox[{22.5, 0.6314346576071969}], 
        PointBox[{22.6, 0.6300293027935414}], 
        PointBox[{22.7, 0.6320752223623205}], 
        PointBox[{22.8, 0.6308459230684194}], 
        PointBox[{22.9, 0.6296724835034906}], 
        PointBox[{23., 0.6318425232834801}], 
        PointBox[{23.1, 0.6343762266043156}], 
        PointBox[{23.2, 0.6347201738494198}], 
        PointBox[{23.3, 0.634551841234182}], 
        PointBox[{23.4, 0.6339204788843225}], 
        PointBox[{23.5, 0.631396666710351}], 
        PointBox[{23.6, 0.6293957377093742}], 
        PointBox[{23.7, 0.6312208596785582}], 
        PointBox[{23.8, 0.6305748248934868}], 
        PointBox[{23.9, 0.6289996540059186}], 
        PointBox[{24., 0.630677965022253}], 
        PointBox[{24.1, 0.6335696367575958}], 
        PointBox[{24.2, 0.6340474460442677}], 
        PointBox[{24.3, 0.6338724858518897}], 
        PointBox[{24.4, 0.6333676202497075}], 
        PointBox[{24.5, 0.631158929562838}], 
        PointBox[{24.6, 0.6286921573756094}], 
        PointBox[{24.7, 0.6302560991801767}], 
        PointBox[{24.8, 0.6300562853758743}], 
        PointBox[{24.9, 0.6282172593571947}], 
        PointBox[{25., 0.6294510983534597}], 
        PointBox[{25.1, 0.6326013759995808}], 
        PointBox[{25.2, 0.6332032655108912}], 
        PointBox[{25.3, 0.6329977344167188}], 
        PointBox[{25.4, 0.6325579959008854}], 
        PointBox[{25.5, 0.6306235741093048}], 
        PointBox[{25.6, 0.6278292543887486}], 
        PointBox[{25.7, 0.6291872760781736}], 
        PointBox[{25.8, 0.6291890186741528}], 
        PointBox[{25.9, 0.6272218283944032}], 
        PointBox[{26., 0.628130508139402}], 
        PointBox[{26.1, 0.631457351623445}], 
        PointBox[{26.2, 0.6321325803717561}], 
        PointBox[{26.3, 0.6318687857738691}], 
        PointBox[{26.4, 0.6314450373852324}], 
        PointBox[{26.5, 0.6296979097383792}], 
        PointBox[{26.6, 0.6266981980437343}], 
        PointBox[{26.7, 0.6279837129719458}], 
        PointBox[{26.8, 0.6278682732407792}], 
        PointBox[{26.9, 0.6259143644648988}], 
        PointBox[{27., 0.6266721084855055}], 
        PointBox[{27.1, 0.6301344227411353}], 
        PointBox[{27.2, 0.6307716839991977}], 
        PointBox[{27.3, 0.6304169433849125}], 
        PointBox[{27.4, 0.6299707351414241}], 
        PointBox[{27.5, 0.6282920546049039}], 
        PointBox[{27.6, 0.6251902983551756}], 
        PointBox[{27.7, 0.6265907014997579}], 
        PointBox[{27.8, 0.625999319515678}], 
        PointBox[{27.9, 0.6242375114254431}], 
        PointBox[{28., 0.6250703134092623}], 
        PointBox[{28.1, 0.6286507002644153}], 
        PointBox[{28.2, 0.6290653247923724}], 
        PointBox[{28.3, 0.628590384878903}], 
        PointBox[{28.4, 0.6280877905156718}], 
        PointBox[{28.5, 0.6263218243876395}], 
        PointBox[{28.6, 0.6232608552466146}], 
        PointBox[{28.7, 0.6248855933340265}], 
        PointBox[{28.8, 0.6235979399189071}], 
        PointBox[{28.9, 0.6222501330403449}], 
        PointBox[{29., 0.623440977442526}], 
        PointBox[{29.1, 0.6270435139236309}], 
        PointBox[{29.2, 0.6270068191668011}], 
        PointBox[{29.3, 0.6264016015594727}], 
        PointBox[{29.4, 0.6258068688061977}], 
        PointBox[{29.5, 0.6237383397305047}], 
        PointBox[{29.6, 0.6210621767390839}], 
        PointBox[{29.7, 0.6225565967745406}], 
        PointBox[{29.8, 0.6209395429786378}], 
        PointBox[{29.9, 0.6201923715788926}], 
        PointBox[{30., 0.6220947280498625}], 
        PointBox[{30.1, 0.6253227308349655}], 
        PointBox[{30.2, 0.6246903185692186}], 
        PointBox[{30.3, 0.6239766994796451}], 
        PointBox[{30.4, 0.6232271463312713}], 
        PointBox[{30.5, 0.6205830173604632}], 
        PointBox[{30.6, 0.61904155473066}], 
        PointBox[{30.7, 0.6196033528003535}], 
        PointBox[{30.8, 0.6185055296688993}], 
        PointBox[{30.9, 0.6184580431980214}], 
        PointBox[{31., 0.6214262491207801}], 
        PointBox[{31.1, 0.6234270445264276}], 
        PointBox[{31.2, 0.6223080406541233}], 
        PointBox[{31.3, 0.6215194381545526}], 
        PointBox[{31.4, 0.6204889256203522}], 
        PointBox[{31.5, 0.6171580215269199}], 
        PointBox[{31.6, 0.6173315090462899}], 
        PointBox[{31.7, 0.6170057665937118}], 
        PointBox[{31.8, 0.6166974772152342}], 
        PointBox[{31.9, 0.6174699092800577}], 
        PointBox[{32., 0.6213860381310538}], 
        PointBox[{32.1, 0.6213556617607651}], 
        PointBox[{32.2, 0.6200567859745801}], 
        PointBox[{32.3, 0.6191961903212333}], 
        PointBox[{32.4, 0.6176310068706711}], 
        PointBox[{32.5, 0.6144466024718398}], 
        PointBox[{32.6, 0.6153760071016603}], 
        PointBox[{32.7, 0.6153806344062013}], 
        PointBox[{32.8, 0.6157018421018726}], 
        PointBox[{32.9, 0.6175819078607359}], 
        PointBox[{33., 0.6209897151248417}], 
        PointBox[{33.1, 0.6192886598808819}], 
        PointBox[{33.2, 0.6180501094770192}], 
        PointBox[{33.3, 0.6170500494162189}], 
        PointBox[{33.4, 0.6146323071404476}], 
        PointBox[{33.5, 0.6133473158696516}], 
        PointBox[{33.6, 0.6141693636433369}], 
        PointBox[{33.7, 0.6146860601539725}], 
        PointBox[{33.8, 0.6155833082201205}], 
        PointBox[{33.9, 0.6187931540697689}], 
        PointBox[{34., 0.6195249691129068}], 
        PointBox[{34.1, 0.6174382321552351}], 
        PointBox[{34.2, 0.6163192463583197}], 
        PointBox[{34.3, 0.6150235008132457}], 
        PointBox[{34.4, 0.6121210288221828}], 
        PointBox[{34.5, 0.6128472765072823}], 
        PointBox[{34.6, 0.6139468958002275}], 
        PointBox[{34.7, 0.6147593483799542}], 
        PointBox[{34.8, 0.6163867160518123}], 
        PointBox[{34.9, 0.6198317322441287}], 
        PointBox[{35., 0.6176337307865137}], 
        PointBox[{35.1, 0.6159205400788972}], 
        PointBox[{35.2, 0.6148628361927636}], 
        PointBox[{35.3, 0.6130896869379526}], 
        PointBox[{35.4, 0.6114556402757222}], 
        PointBox[{35.5, 0.6132620470114564}], 
        PointBox[{35.6, 0.6144029566336044}], 
        PointBox[{35.7, 0.6154883355341585}], 
        PointBox[{35.8, 0.6180318911182489}], 
        PointBox[{35.9, 0.6189793601434894}], 
        PointBox[{36., 0.6160555668176684}], 
        PointBox[{36.1, 0.6147906011441471}], 
        PointBox[{36.2, 0.6137061276921922}], 
        PointBox[{36.3, 0.6116984869533985}], 
        PointBox[{36.4, 0.6122491037496134}], 
        PointBox[{36.5, 0.6142818892473912}], 
        PointBox[{36.6, 0.6153515533045856}], 
        PointBox[{36.7, 0.6168091832107796}], 
        PointBox[{36.8, 0.6196468182385168}], 
        PointBox[{36.9, 0.6171635539044568}], 
        PointBox[{37., 0.61504523963039}], 
        PointBox[{37.1, 0.6141122647475604}], 
        PointBox[{37.2, 0.612995448486379}], 
        PointBox[{37.3, 0.6116173659772483}], 
        PointBox[{37.4, 0.6140863634241046}], 
        PointBox[{37.5, 0.6156341029766996}], 
        PointBox[{37.6, 0.6167049460317483}], 
        PointBox[{37.7, 0.6186025074656255}], 
        PointBox[{37.8, 0.6195588310961745}], 
        PointBox[{37.9, 0.6159113594098796}], 
        PointBox[{38., 0.6146708130086257}], 
        PointBox[{38.1, 0.6140166774866372}], 
        PointBox[{38.2, 0.6131288869523329}], 
        PointBox[{38.3, 0.6132649635073385}], 
        PointBox[{38.4, 0.616127370059683}], 
        PointBox[{38.5, 0.617257658695302}], 
        PointBox[{38.6, 0.6184134232030792}], 
        PointBox[{38.7, 0.6204192227232246}], 
        PointBox[{38.8, 0.6182192774988465}], 
        PointBox[{38.9, 0.6156022271802459}], 
        PointBox[{39., 0.6150117123763843}], 
        PointBox[{39.1, 0.6147598609622351}], 
        PointBox[{39.2, 0.6139149637102135}], 
        PointBox[{39.3, 0.6162297060548597}], 
        PointBox[{39.4, 0.6182423296911813}], 
        PointBox[{39.5, 0.6191527697405466}], 
        PointBox[{39.6, 0.6204065161258715}], 
        PointBox[{39.7, 0.6214407216855786}], 
        PointBox[{39.8, 0.6175231435252019}], 
        PointBox[{39.9, 0.6162046414694897}], 
        PointBox[{40., 0.616205156256845}], 
        PointBox[{40.1, 0.6165405076590116}], 
        PointBox[{40.2, 0.615753347507274}], 
        PointBox[{40.3, 0.6192179746064351}], 
        PointBox[{40.4, 0.6205058489802554}], 
        PointBox[{40.5, 0.6213117251148406}], 
        PointBox[{40.6, 0.6225259184649892}], 
        PointBox[{40.7, 0.6216155722435253}], 
        PointBox[{40.8, 0.6180167937350739}], 
        PointBox[{40.9, 0.617656769992369}], 
        PointBox[{41., 0.618382111803538}], 
        PointBox[{41.1, 0.618462103430769}], 
        PointBox[{41.2, 0.6189559393528625}], 
        PointBox[{41.3, 0.6220445463763435}], 
        PointBox[{41.4, 0.622929602927108}], 
        PointBox[{41.5, 0.6236638284778326}], 
        PointBox[{41.6, 0.6245620560537466}], 
        PointBox[{41.7, 0.6219734599057356}], 
        PointBox[{41.8, 0.6194435851827982}], 
        PointBox[{41.9, 0.6198312509198491}], 
        PointBox[{42., 0.6213155720090306}], 
        PointBox[{42.1, 0.6202596371347879}], 
        PointBox[{42.2, 0.6222924033361411}], 
        PointBox[{42.3, 0.6247252246637218}], 
        PointBox[{42.4, 0.6253983325965623}], 
        PointBox[{42.5, 0.6260414906434666}], 
        PointBox[{42.6, 0.6264130725154563}], 
        PointBox[{42.7, 0.623038779244599}], 
        PointBox[{42.8, 0.6213879625157965}], 
        PointBox[{42.9, 0.6224166004678001}], 
        PointBox[{43., 0.6240571079467361}], 
        PointBox[{43.1, 0.6223740831998426}], 
        PointBox[{43.2, 0.6251484673169723}], 
        PointBox[{43.3, 0.6271565305024615}], 
        PointBox[{43.4, 0.6277102107939246}], 
        PointBox[{43.5, 0.6282355222774951}], 
        PointBox[{43.6, 0.6281083425014488}], 
        PointBox[{43.7, 0.6245676626489907}], 
        PointBox[{43.8, 0.6234232883858694}], 
        PointBox[{43.9, 0.6249442126373668}], 
        PointBox[{44., 0.626054314148547}], 
        PointBox[{44.1, 0.624408310220489}], 
        PointBox[{44.2, 0.6273825206905158}], 
        PointBox[{44.3, 0.629213732609082}], 
        PointBox[{44.4, 0.6296971318523622}], 
        PointBox[{44.5, 0.6301012914372631}], 
        PointBox[{44.6, 0.6296646118668552}], 
        PointBox[{44.7, 0.6261916961972218}], 
        PointBox[{44.8, 0.625233672972943}], 
        PointBox[{44.9, 0.6270336583616254}], 
        PointBox[{45., 0.6275808751256717}], 
        PointBox[{45.1, 0.6260807530347314}], 
        PointBox[{45.2, 0.6290141014737164}], 
        PointBox[{45.3, 0.6308523007440451}], 
        PointBox[{45.4, 0.6313025593648229}], 
        PointBox[{45.5, 0.6316069974282954}], 
        PointBox[{45.6, 0.6310552960718689}], 
        PointBox[{45.7, 0.6277152784427833}], 
        PointBox[{45.8, 0.6266907104256172}], 
        PointBox[{45.9, 0.6285680152030297}], 
        PointBox[{46., 0.6288611072999879}], 
        PointBox[{46.1, 0.6273639998163422}], 
        PointBox[{46.2, 0.6301213381434136}], 
        PointBox[{46.3, 0.6321026155700924}], 
        PointBox[{46.4, 0.6325592924922965}], 
        PointBox[{46.5, 0.6327943589426425}], 
        PointBox[{46.6, 0.6322612532751032}], 
        PointBox[{46.7, 0.6290996566405448}], 
        PointBox[{46.8, 0.6278137022537911}], 
        PointBox[{46.9, 0.6296072789557136}], 
        PointBox[{47., 0.6299808913998011}], 
        PointBox[{47.1, 0.6283442087607365}], 
        PointBox[{47.2, 0.6308002700858646}], 
        PointBox[{47.3, 0.6330226404231133}], 
        PointBox[{47.4, 0.6335328366839099}], 
        PointBox[{47.5, 0.633727777775258}], 
        PointBox[{47.6, 0.6332845410793256}], 
        PointBox[{47.7, 0.6303739123502091}], 
        PointBox[{47.8, 0.6286903888353513}], 
        PointBox[{47.9, 0.6302572996062349}], 
        PointBox[{48., 0.6309802096786894}], 
        PointBox[{48.1, 0.6291291901883715}], 
        PointBox[{48.2, 0.6311478361639135}], 
        PointBox[{48.3, 0.633663596511285}], 
        PointBox[{48.4, 0.6342869495322602}], 
        PointBox[{48.5, 0.6344669133309793}], 
        PointBox[{48.6, 0.6341377621031851}], 
        PointBox[{48.7, 0.6315716158582618}], 
        PointBox[{48.8, 0.629424834135492}], 
        PointBox[{48.9, 0.6306256048056947}], 
        PointBox[{49., 0.6318620717257554}], 
        PointBox[{49.1, 0.629814258638384}], 
        PointBox[{49.2, 0.6312657027698853}], 
        PointBox[{49.3, 0.6340593654854344}], 
        PointBox[{49.4, 0.6348714713025913}], 
        PointBox[{49.5, 0.6350606874750466}], 
        PointBox[{49.6, 0.6348427433266268}], 
        PointBox[{49.7, 0.6327005386262525}], 
        PointBox[{49.8, 0.6301138253960509}], 
        PointBox[{49.9, 0.6308169513946913}], 
        PointBox[{50., 0.6325766186328342}], 
        PointBox[{50.1, 0.6304748469640573}], 
        PointBox[{50.2, 0.6312594251058095}], 
        PointBox[{50.3, 0.6342272915859409}], 
        PointBox[{50.4, 0.6353190894633305}], 
        PointBox[{50.5, 0.6355462108396661}], 
        PointBox[{50.6, 0.6354240651938731}], 
        PointBox[{50.7, 0.6337437494600342}], 
        PointBox[{50.8, 0.6308390501268711}], 
        PointBox[{50.9, 0.6309289165432}], 
        PointBox[{51., 0.6330275935019162}], 
        PointBox[{51.1, 0.6311682339898624}], 
        PointBox[{51.2, 0.6312298265831486}], 
        PointBox[{51.3, 0.6341787096739564}], 
        PointBox[{51.4, 0.6356468893779219}], 
        PointBox[{51.5, 0.635949628703963}], 
        PointBox[{51.6, 0.635906819600486}], 
        PointBox[{51.7, 0.6346720406686266}], 
        PointBox[{51.8, 0.6316588743844653}], 
        PointBox[{51.9, 0.6310453841775578}], 
        PointBox[{52., 0.6331438238218268}], 
        PointBox[{52.1, 0.6319335011810435}], 
        PointBox[{52.2, 0.6312617999607146}], 
        PointBox[{52.3, 0.6339369459745996}], 
        PointBox[{52.4, 0.6358568893428836}], 
        PointBox[{52.5, 0.63628946066885}], 
        PointBox[{52.6, 0.6363148174097442}], 
        PointBox[{52.7, 0.6354672112177745}], 
        PointBox[{52.8, 0.6325968771408116}], 
        PointBox[{52.9, 0.6312368642058547}], 
        PointBox[{53., 0.6329758151502954}], 
        PointBox[{53.1, 0.63277470244561}], 
        PointBox[{53.2, 0.631414651578397}], 
        PointBox[{53.3, 0.6335556060450472}], 
        PointBox[{53.4, 0.6359369972154953}], 
        PointBox[{53.5, 0.6365754922283388}], 
        PointBox[{53.6, 0.6366691697693128}], 
        PointBox[{53.7, 0.636129288598607}], 
        PointBox[{53.8, 0.6336290162213472}], 
        PointBox[{53.9, 0.6315634121789353}], 
        PointBox[{54., 0.6326834770164864}], 
        PointBox[{54.1, 0.6336117302806932}], 
        PointBox[{54.2, 0.6317287564390506}], 
        PointBox[{54.3, 0.6331280344311525}], 
        PointBox[{54.4, 0.6358655504786199}], 
        PointBox[{54.5, 0.6368099304107333}], 
        PointBox[{54.6, 0.6369859342297247}], 
        PointBox[{54.7, 0.6366768881388855}], 
        PointBox[{54.8, 0.634687574928395}], 
        PointBox[{54.9, 0.6320783904645123}], 
        PointBox[{55., 0.6324308943803499}], 
        PointBox[{55.1, 0.6342224519812961}], 
        PointBox[{55.2, 0.6322320431451229}], 
        PointBox[{55.3, 0.632765797385439}], 
        PointBox[{55.4, 0.6356218076202538}], 
        PointBox[{55.5, 0.636983410443951}], 
        PointBox[{55.6, 0.637275960080637}], 
        PointBox[{55.7, 0.6371373590769728}], 
        PointBox[{55.8, 0.6356906902535455}], 
        PointBox[{55.9, 0.6328195211598093}], 
        PointBox[{56., 0.6323265678370441}], 
        PointBox[{56.1, 0.6343545071838311}], 
        PointBox[{56.2, 0.632946056468726}], 
        PointBox[{56.3, 0.6325712308208938}], 
        PointBox[{56.4, 0.6352102393337395}], 
        PointBox[{56.5, 0.6370740731453992}], 
        PointBox[{56.6, 0.6375437693796645}], 
        PointBox[{56.7, 0.6375384118949371}], 
        PointBox[{56.8, 0.6365764183749065}], 
        PointBox[{56.9, 0.6337872995111584}], 
        PointBox[{57., 0.6324356063281226}], 
        PointBox[{57.1, 0.6340506984272887}], 
        PointBox[{57.2, 0.633853230273694}], 
        PointBox[{57.3, 0.6326143651567643}], 
        PointBox[{57.4, 0.6346882886977726}], 
        PointBox[{57.5, 0.6370470694559014}], 
        PointBox[{57.6, 0.6377851249575276}], 
        PointBox[{57.7, 0.6379021557928097}], 
        PointBox[{57.8, 0.6373256474868761}], 
        PointBox[{57.9, 0.6349226606262651}], 
        PointBox[{58., 0.6328065728817122}], 
        PointBox[{58.1, 0.6336388304307289}], 
        PointBox[{58.2, 0.6347808085548595}], 
        PointBox[{58.3, 0.632934947585286}], 
        PointBox[{58.4, 0.6341721680541993}], 
        PointBox[{58.5, 0.6368610622227434}], 
        PointBox[{58.6, 0.637984421721786}], 
        PointBox[{58.7, 0.6382422565003437}], 
        PointBox[{58.8, 0.6379535512607672}], 
        PointBox[{58.9, 0.6361109577401436}], 
        PointBox[{59., 0.6334797541470554}], 
        PointBox[{59.1, 0.6333933553820179}], 
        PointBox[{59.2, 0.6352917613284258}], 
        PointBox[{59.3, 0.6335617292750998}], 
        PointBox[{59.4, 0.6338052946294513}], 
        PointBox[{59.5, 0.6364911749105205}], 
        PointBox[{59.6, 0.6381101135617339}], 
        PointBox[{59.7, 0.6385610157675462}], 
        PointBox[{59.8, 0.6384897745347746}], 
        PointBox[{59.9, 0.6372302446241862}], 
        PointBox[{60., 0.6344653705320005}], 
        PointBox[{60.1, 0.6334380669220255}], 
        PointBox[{60.2, 0.6351197582290152}], 
        PointBox[{60.3, 0.6344998343840352}], 
        PointBox[{60.4, 0.6337080084129921}], 
        PointBox[{60.5, 0.6359691996081926}], 
        PointBox[{60.6, 0.6381131118078119}], 
        PointBox[{60.7, 0.6388472981109321}], 
        PointBox[{60.8, 0.6389614425168335}], 
        PointBox[{60.9, 0.6382038462236058}], 
        PointBox[{61., 0.6357054874678727}], 
        PointBox[{61.1, 0.6338263766610805}], 
        PointBox[{61.2, 0.6346713965084771}], 
        PointBox[{61.3, 0.6355833113440463}], 
        PointBox[{61.4, 0.6339543045959549}], 
        PointBox[{61.5, 0.6354113403933568}], 
        PointBox[{61.6, 0.63793571644077}], 
        PointBox[{61.7, 0.6390728862474632}], 
        PointBox[{61.8, 0.63938238671224}], 
        PointBox[{61.9, 0.6390153339641365}], 
        PointBox[{62., 0.6370594977147903}], 
        PointBox[{62.1, 0.6345886526981392}], 
        PointBox[{62.2, 0.6344274826549319}], 
        PointBox[{62.3, 0.6362050361551144}], 
        PointBox[{62.4, 0.6345922566168027}], 
        PointBox[{62.5, 0.6349907756176264}], 
        PointBox[{62.6, 0.63754258458614}], 
        PointBox[{62.7, 0.639187409535726}], 
        PointBox[{62.8, 0.6397486440933609}], 
        PointBox[{62.9, 0.639683186418068}], 
        PointBox[{63., 0.6383542716063894}], 
        PointBox[{63.1, 0.6357146424978535}], 
        PointBox[{63.2, 0.6345694989140364}], 
        PointBox[{63.3, 0.635963004062836}], 
        PointBox[{63.4, 0.635625785888725}], 
        PointBox[{63.5, 0.6348681377372828}], 
        PointBox[{63.6, 0.6369747678001939}], 
        PointBox[{63.7, 0.6391220770395486}], 
        PointBox[{63.8, 0.6400333191537403}], 
        PointBox[{63.9, 0.6402304858344667}], 
        PointBox[{64., 0.6394658057740972}], 
        PointBox[{64.1, 0.6371037213692173}], 
        PointBox[{64.2, 0.6351354409640945}], 
        PointBox[{64.3, 0.6355178969686217}], 
        PointBox[{64.4, 0.6367346078763498}], 
        PointBox[{64.5, 0.6351505807853495}], 
        PointBox[{64.6, 0.6363801117918745}], 
        PointBox[{64.7, 0.6388119428860638}], 
        PointBox[{64.8, 0.640185391616156}], 
        PointBox[{64.9, 0.6406632300887394}], 
        PointBox[{65., 0.640352049469899}], 
        PointBox[{65.1, 0.6385595946515371}], 
        PointBox[{65.2, 0.6361168233565702}], 
        PointBox[{65.3, 0.6354379440079257}], 
        PointBox[{65.4, 0.6369963184428624}], 
        PointBox[{65.5, 0.6359058002868004}], 
        PointBox[{65.6, 0.6359669850974987}], 
        PointBox[{65.7, 0.6382500075147205}], 
        PointBox[{65.8, 0.6401313188567146}], 
        PointBox[{65.9, 0.6409616957930324}], 
        PointBox[{66., 0.6410218730689724}], 
        PointBox[{66.1, 0.6398705520938454}], 
        PointBox[{66.2, 0.6374318527935751}], 
        PointBox[{66.3, 0.6358356446611615}], 
        PointBox[{66.4, 0.6364931980491642}], 
        PointBox[{66.5, 0.637038551621466}], 
        PointBox[{66.6, 0.63591513655952}], 
        PointBox[{66.7, 0.6375471364808073}], 
        PointBox[{66.8, 0.6397974550344931}], 
        PointBox[{66.9, 0.6410778079630606}], 
        PointBox[{67., 0.6414899804668182}], 
        PointBox[{67.1, 0.6409093734764122}], 
        PointBox[{67.2, 0.6388880765190021}], 
        PointBox[{67.3, 0.6366831532568925}], 
        PointBox[{67.4, 0.6362153366469969}], 
        PointBox[{67.5, 0.6376863389972974}], 
        PointBox[{67.6, 0.6363488334114071}], 
        PointBox[{67.7, 0.6369189334492753}], 
        PointBox[{67.8, 0.6391638511149133}], 
        PointBox[{67.9, 0.6409408429221658}], 
        PointBox[{68., 0.6417498115248907}], 
        PointBox[{68.1, 0.6416459864789702}], 
        PointBox[{68.2, 0.6402371085789861}], 
        PointBox[{68.3, 0.6378833639310074}], 
        PointBox[{68.4, 0.6364565122789353}], 
        PointBox[{68.5, 0.6372153010842873}], 
        PointBox[{68.6, 0.6372890068762267}], 
        PointBox[{68.7, 0.6365905576142593}], 
        PointBox[{68.8, 0.638330688971821}], 
        PointBox[{68.9, 0.6404823669725531}], 
        PointBox[{69., 0.6417654843654386}], 
        PointBox[{69.1, 0.6420951890679758}], 
        PointBox[{69.2, 0.6412953991291485}], 
        PointBox[{69.3, 0.6392388471932189}], 
        PointBox[{69.4, 0.6371732194078241}], 
        PointBox[{69.5, 0.6367545237894385}], 
        PointBox[{69.6, 0.6380736567326738}], 
        PointBox[{69.7, 0.63673251280263}], 
        PointBox[{69.8, 0.6375188688377711}], 
        PointBox[{69.9, 0.6396937463365576}], 
        PointBox[{70., 0.6414788562200194}], 
        PointBox[{70.1, 0.6422676275520914}], 
        PointBox[{70.2, 0.6420007737663234}], 
        PointBox[{70.3, 0.6404901149108106}], 
        PointBox[{70.4, 0.6382379818786228}], 
        PointBox[{70.5, 0.6368336439734917}], 
        PointBox[{70.6, 0.6376335833185531}], 
        PointBox[{70.7, 0.6374281337811911}], 
        PointBox[{70.8, 0.636972700999871}], 
        PointBox[{70.9, 0.6386898290292929}], 
        PointBox[{71., 0.6408366393231344}], 
        PointBox[{71.1, 0.6421466951225475}], 
        PointBox[{71.2, 0.642366371914147}], 
        PointBox[{71.3, 0.6414397907632179}], 
        PointBox[{71.4, 0.6394378752148421}], 
        PointBox[{71.5, 0.6374056122860691}], 
        PointBox[{71.6, 0.6369858377573031}], 
        PointBox[{71.7, 0.6381900799482013}], 
        PointBox[{71.8, 0.6368799311518749}], 
        PointBox[{71.9, 0.637704081243738}], 
        PointBox[{72., 0.6398513989845414}], 
        PointBox[{72.1, 0.6416924744955564}], 
        PointBox[{72.2, 0.6424189377825553}], 
        PointBox[{72.3, 0.6420190057910026}], 
        PointBox[{72.4, 0.6405133212614705}], 
        PointBox[{72.5, 0.6383157975847831}], 
        PointBox[{72.6, 0.6368744821962817}], 
        PointBox[{72.7, 0.6377627463907756}], 
        PointBox[{72.8, 0.6373483167564311}], 
        PointBox[{72.9, 0.6369836150028838}], 
        PointBox[{73., 0.638661440097683}], 
        PointBox[{73.1, 0.6408686411030168}], 
        PointBox[{73.2, 0.6421637122550752}], 
        PointBox[{73.3, 0.6422489965452988}], 
        PointBox[{73.4, 0.6412788243143863}], 
        PointBox[{73.5, 0.6393368587094984}], 
        PointBox[{73.6, 0.6372686076185877}], 
        PointBox[{73.7, 0.6369139469369096}], 
        PointBox[{73.8, 0.638031148638849}], 
        PointBox[{73.9, 0.6367074302522909}], 
        PointBox[{74., 0.637513466972709}], 
        PointBox[{74.1, 0.6397045550108122}], 
        PointBox[{74.2, 0.6415804509182647}], 
        PointBox[{74.3, 0.642174210332061}], 
        PointBox[{74.4, 0.6416828602429193}], 
        PointBox[{74.5, 0.6402165502040674}], 
        PointBox[{74.6, 0.6380042962050425}], 
        PointBox[{74.7, 0.6365635695990047}], 
        PointBox[{74.8, 0.6376588023299559}], 
        PointBox[{74.9, 0.6369784270164853}], 
        PointBox[{75., 0.636647748544596}], 
        PointBox[{75.1, 0.6383523269171507}], 
        PointBox[{75.2, 0.6406450831146591}], 
        PointBox[{75.3, 0.6418216753609954}], 
        PointBox[{75.4, 0.6417635708218175}], 
        PointBox[{75.5, 0.6407924158804186}], 
        PointBox[{75.6, 0.6388525297373319}], 
        PointBox[{75.7, 0.6367303828806411}], 
        PointBox[{75.8, 0.6366241394360018}], 
        PointBox[{75.9, 0.6375777911018838}], 
        PointBox[{76., 0.6362199065141155}], 
        PointBox[{76.1, 0.6370638275892154}], 
        PointBox[{76.2, 0.6393847986953984}], 
        PointBox[{76.3, 0.6411904766803794}], 
        PointBox[{76.4, 0.6415828632565034}], 
        PointBox[{76.5, 0.6410339358487198}], 
        PointBox[{76.6, 0.6395726950626203}], 
        PointBox[{76.7, 0.6372666559939226}], 
        PointBox[{76.8, 0.6359866955040743}], 
        PointBox[{76.9, 0.6373892883552439}], 
        PointBox[{77., 0.6363087548446035}], 
        PointBox[{77.1, 0.6360689202813504}], 
        PointBox[{77.2, 0.6379382733705342}], 
        PointBox[{77.3, 0.6402631826533793}], 
        PointBox[{77.4, 0.6411869173794544}], 
        PointBox[{77.5, 0.6409972177512084}], 
        PointBox[{77.6, 0.6400141009059985}], 
        PointBox[{77.7, 0.6379651955069116}], 
        PointBox[{77.8, 0.6358646806488392}], 
        PointBox[{77.9, 0.6362786743031222}], 
        PointBox[{78., 0.6368088807709964}], 
        PointBox[{78.1, 0.6354978101061703}], 
        PointBox[{78.2, 0.6365421557057843}], 
        PointBox[{78.3, 0.6390454053585527}], 
        PointBox[{78.4, 0.6405926797417322}], 
        PointBox[{78.5, 0.6407559564361637}], 
        PointBox[{78.6, 0.6401596496104606}], 
        PointBox[{78.7, 0.6385955553803297}], 
        PointBox[{78.8, 0.6361559948972773}], 
        PointBox[{78.9, 0.6353441213493548}], 
        PointBox[{79., 0.6369466358749694}], 
        PointBox[{79.1, 0.6353995712046886}], 
        PointBox[{79.2, 0.6354209216013103}], 
        PointBox[{79.3, 0.6376238490469514}], 
        PointBox[{79.4, 0.6397923193809809}], 
        PointBox[{79.5, 0.6403689203263021}], 
        PointBox[{79.6, 0.6400722704328755}], 
        PointBox[{79.7, 0.639000919420767}], 
        PointBox[{79.8, 0.6367027383137035}], 
        PointBox[{79.9, 0.6348851463566405}], 
        PointBox[{80., 0.6360492239675496}], 
        PointBox[{80.1, 0.6357394697070812}], 
        PointBox[{80.2, 0.6346955638887156}], 
        PointBox[{80.3, 0.6361850416371355}], 
        PointBox[{80.4, 0.6387690219012149}], 
        PointBox[{80.5, 0.6398651748485038}], 
        PointBox[{80.6, 0.6398283702956165}], 
        PointBox[{80.7, 0.6391497365930864}], 
        PointBox[{80.8, 0.6373005092840104}], 
        PointBox[{80.9, 0.6348591084385994}], 
        PointBox[{81., 0.6349126165966549}], 
        PointBox[{81.1, 0.6361602172433585}], 
        PointBox[{81.2, 0.6343940484156158}], 
        PointBox[{81.3, 0.6349424850429443}], 
        PointBox[{81.4, 0.6375393145665209}], 
        PointBox[{81.5, 0.6392486730734295}], 
        PointBox[{81.6, 0.6394888595787054}], 
        PointBox[{81.7, 0.6390930155084321}], 
        PointBox[{81.8, 0.6377690041237828}], 
        PointBox[{81.9, 0.6351769689660407}], 
        PointBox[{82., 0.6341146464471173}], 
        PointBox[{82.1, 0.6358909674303226}], 
        PointBox[{82.2, 0.6344978117541088}], 
        PointBox[{82.3, 0.634036636691947}], 
        PointBox[{82.4, 0.6361934681565667}], 
        PointBox[{82.5, 0.6385009196281359}], 
        PointBox[{82.6, 0.6390881381568785}], 
        PointBox[{82.7, 0.638902178835097}], 
        PointBox[{82.8, 0.6380268551351894}], 
        PointBox[{82.9, 0.6356992603928525}], 
        PointBox[{83., 0.6337174101938212}], 
        PointBox[{83.1, 0.6348970281727578}], 
        PointBox[{83.2, 0.6349030991618189}], 
        PointBox[{83.3, 0.6335056737492477}], 
        PointBox[{83.4, 0.6348919261371107}], 
        PointBox[{83.5, 0.6375978197303287}], 
        PointBox[{83.6, 0.6386393509746122}], 
        PointBox[{83.7, 0.638634925780726}], 
        PointBox[{83.8, 0.6380865380659041}], 
        PointBox[{83.9, 0.6362508427459185}], 
        PointBox[{84., 0.6336819299663244}], 
        PointBox[{84.1, 0.6338639153193518}], 
        PointBox[{84.2, 0.6352551755728646}], 
        PointBox[{84.3, 0.633329515132764}], 
        PointBox[{84.4, 0.6337968007965922}], 
        PointBox[{84.5, 0.6365375067049978}], 
        PointBox[{84.6, 0.6381350438808404}], 
        PointBox[{84.7, 0.6383274072881847}], 
        PointBox[{84.8, 0.6380015391412497}], 
        PointBox[{84.9, 0.6366883760142117}], 
        PointBox[{85., 0.6339479837902983}], 
        PointBox[{85.1, 0.6331088913086004}], 
        PointBox[{85.2, 0.6350291194289907}], 
        PointBox[{85.3, 0.6334647043814793}], 
        PointBox[{85.4, 0.6329977594519011}], 
        PointBox[{85.5, 0.6353695690529498}], 
        PointBox[{85.6, 0.6375522756232472}], 
        PointBox[{85.7, 0.6379963268016126}], 
        PointBox[{85.8, 0.6378260481069842}], 
        PointBox[{85.9, 0.6369457619488965}], 
        PointBox[{86., 0.6344156500178645}], 
        PointBox[{86.1, 0.632664230890491}], 
        PointBox[{86.2, 0.634214866360595}], 
        PointBox[{86.3, 0.6338272075211937}], 
        PointBox[{86.4, 0.6325071218722849}], 
        PointBox[{86.5, 0.6342005115427669}], 
        PointBox[{86.6, 0.6368609729346313}], 
        PointBox[{86.7, 0.6376441953502154}], 
        PointBox[{86.8, 0.6375977895061857}], 
        PointBox[{86.9, 0.6370305566031869}], 
        PointBox[{87., 0.6349471753070768}], 
        PointBox[{87.1, 0.6325052191101244}], 
        PointBox[{87.2, 0.633266536560111}], 
        PointBox[{87.3, 0.6342141609013886}], 
        PointBox[{87.4, 0.6322922811296169}], 
        PointBox[{87.5, 0.6331541230887332}], 
        PointBox[{87.6, 0.6360370058378594}], 
        PointBox[{87.7, 0.6372616747795784}], 
        PointBox[{87.8, 0.6373380365896434}], 
        PointBox[{87.9, 0.6369802442610151}], 
        PointBox[{88., 0.635409773832193}], 
        PointBox[{88.1, 0.6325984621237645}], 
        PointBox[{88.2, 0.63246362046412}], 
        PointBox[{88.3, 0.6342945678278236}], 
        PointBox[{88.4, 0.6323067569737116}], 
        PointBox[{88.5, 0.6323134178713304}], 
        PointBox[{88.6, 0.6350826699551024}], 
        PointBox[{88.7, 0.6368300169335203}], 
        PointBox[{88.8, 0.6370545840514305}], 
        PointBox[{88.9, 0.6368333316197424}], 
        PointBox[{89., 0.6357208556919242}], 
        PointBox[{89.1, 0.6328893378576271}], 
        PointBox[{89.2, 0.6318671486430029}], 
        PointBox[{89.3, 0.6338735142568604}], 
        PointBox[{89.4, 0.6324948370179493}], 
        PointBox[{89.5, 0.6317002261844629}], 
        PointBox[{89.6, 0.634040197055368}], 
        PointBox[{89.7, 0.6363235901795306}], 
        PointBox[{89.8, 0.6367457012842745}], 
        PointBox[{89.9, 0.6366167296671408}], 
        PointBox[{90., 0.6358561348735537}], 
        PointBox[{90.1, 0.6332895144183586}], 
        PointBox[{90.2, 0.6314642455776611}], 
        PointBox[{90.3, 0.6331045431850402}], 
        PointBox[{90.4, 0.6327715356537794}], 
        PointBox[{90.5, 0.6312884070350822}], 
        PointBox[{90.6, 0.6329854507084928}], 
        PointBox[{90.7, 0.6357144087292456}], 
        PointBox[{90.8, 0.6364032405075085}], 
        PointBox[{90.9, 0.6363436621659682}], 
        PointBox[{91., 0.6358280347631029}], 
        PointBox[{91.1, 0.6336879029711703}], 
        PointBox[{91.2, 0.6312277255129662}], 
        PointBox[{91.3, 0.6322466020613559}], 
        PointBox[{91.4, 0.6330003147230068}], 
        PointBox[{91.5, 0.6310286284449106}], 
        PointBox[{91.6, 0.6319934225883572}], 
        PointBox[{91.7, 0.6349788903624455}], 
        PointBox[{91.8, 0.6360123117000979}], 
        PointBox[{91.9, 0.6360157209525662}], 
        PointBox[{92., 0.635658503491461}], 
        PointBox[{92.1, 0.6339808337822718}], 
        PointBox[{92.2, 0.6311232016954798}], 
        PointBox[{92.3, 0.6314355398573359}], 
        PointBox[{92.4, 0.633015029704681}], 
        PointBox[{92.5, 0.630861376557626}], 
        PointBox[{92.6, 0.6311067879312983}], 
        PointBox[{92.7, 0.634107001261706}], 
        PointBox[{92.8, 0.6355540160914323}], 
        PointBox[{92.9, 0.6356252089361779}], 
        PointBox[{93., 0.6353631813011089}], 
        PointBox[{93.1, 0.6340964686723016}], 
        PointBox[{93.2, 0.6310994544545722}], 
        PointBox[{93.3, 0.6306944315307185}], 
        PointBox[{93.4, 0.6327107056262735}], 
        PointBox[{93.5, 0.6307199357131121}], 
        PointBox[{93.6, 0.6303209598601991}], 
        PointBox[{93.7, 0.6331069261892484}], 
        PointBox[{93.8, 0.635005307270655}], 
        PointBox[{93.9, 0.6351556807807037}], 
        PointBox[{94., 0.6349444789951921}], 
        PointBox[{94.1, 0.6339983670311611}], 
        PointBox[{94.2, 0.6310821304355365}], 
        PointBox[{94.3, 0.629995021495052}], 
        PointBox[{94.4, 0.6321060452330797}], 
        PointBox[{94.5, 0.6305247192292085}], 
        PointBox[{94.6, 0.6295885752033854}], 
        PointBox[{94.7, 0.6320036473185725}], 
        PointBox[{94.8, 0.6343408508208441}], 
        PointBox[{94.9, 0.6345826023284686}], 
        PointBox[{95., 0.6343895143274886}], 
        PointBox[{95.1, 0.6336690330415524}], 
        PointBox[{95.2, 0.6309749632625572}], 
        PointBox[{95.3, 0.6292849329194411}], 
        PointBox[{95.4, 0.631288754001704}], 
        PointBox[{95.5, 0.6301814143855071}], 
        PointBox[{95.6, 0.628835371546506}], 
        PointBox[{95.7, 0.6308164686389964}], 
        PointBox[{95.8, 0.6335345720661657}], 
        PointBox[{95.9, 0.6338711371547467}], 
        PointBox[{96., 0.6336696367444322}], 
        PointBox[{96.1, 0.6330919492148205}], 
        PointBox[{96.2, 0.6306703785752862}], 
        PointBox[{96.3, 0.6284937837756417}], 
        PointBox[{96.4, 0.6303258449075864}], 
        PointBox[{96.5, 0.6295845669223468}], 
        PointBox[{96.6, 0.627966711242936}], 
        PointBox[{96.7, 0.6295472488085938}], 
        PointBox[{96.8, 0.6325617703325953}], 
        PointBox[{96.9, 0.6329740868388142}], 
        PointBox[{97., 0.6327386800280218}], 
        PointBox[{97.1, 0.6322371091496194}], 
        PointBox[{97.2, 0.6300607558635234}], 
        PointBox[{97.3, 0.6275331886952732}], 
        PointBox[{97.4, 0.629233097963547}], 
        PointBox[{97.5, 0.6286236706827191}], 
        PointBox[{97.6, 0.6268811893796867}], 
        PointBox[{97.7, 0.6281754268052958}], 
        PointBox[{97.8, 0.631402998860392}], 
        PointBox[{97.9, 0.6318326051579042}], 
        PointBox[{98., 0.6315356750003832}], 
        PointBox[{98.1, 0.6310569108006698}], 
        PointBox[{98.2, 0.629041521193339}], 
        PointBox[{98.3, 0.6263014041635891}], 
        PointBox[{98.4, 0.6279781644862827}], 
        PointBox[{98.5, 0.6271897330291719}], 
        PointBox[{98.6, 0.6254861156445067}], 
        PointBox[{98.7, 0.626674512460773}], 
        PointBox[{98.8, 0.6300481362129164}], 
        PointBox[{98.9, 0.6303806768479494}], 
        PointBox[{99., 0.629993516825329}], 
        PointBox[{99.1, 0.6294933076661543}], 
        PointBox[{99.2, 0.6275085493863415}], 
        PointBox[{99.3, 0.6247119860341129}], 
        PointBox[{99.4, 0.6264725446755904}], 
        PointBox[{99.5, 0.625212782157944}], 
        PointBox[{99.6, 0.6237455001246353}], 
        PointBox[{99.7, 0.6250734538211107}], 
        PointBox[{99.8, 0.6285043095351519}], 
        PointBox[{99.9, 0.6285696482782424}], 
        PointBox[{100., 0.6280706984091117}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0.6, 0.65}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], 
        PointBox[{0, 0.018454500000006}], 
        PointBox[{0.1, 0.018302980016150026`}], 
        PointBox[{0.2, 0.016222620726993632`}], 
        PointBox[{0.3, 0.01882176606747196}], 
        PointBox[{0.4, 0.019046331618021647`}], 
        PointBox[{0.5, 0.015658613099822367`}], 
        PointBox[{0.6, 0.016680071710092007`}], 
        PointBox[{0.7, 0.0195884466326019}], 
        PointBox[{0.8, 0.01768696558886705}], 
        PointBox[{0.9, 0.016771380089363602`}], 
        PointBox[{1., 0.019458047391263972`}], 
        PointBox[{1.1, 0.02157776688129039}], 
        PointBox[{1.2, 0.020442579332469353`}], 
        PointBox[{1.3, 0.02012097539812574}], 
        PointBox[{1.4, 0.023019069915701525`}], 
        PointBox[{1.5, 0.021104794435608823`}], 
        PointBox[{1.6, 0.01865219073102994}], 
        PointBox[{1.7, 0.021420943633944818`}], 
        PointBox[{1.8, 0.022754404030237298`}], 
        PointBox[{1.9, 0.01998819669455986}], 
        PointBox[{2., 0.021640497099628075`}], 
        PointBox[{2.1, 0.02483972199294028}], 
        PointBox[{2.2, 0.02694264724938342}], 
        PointBox[{2.3, 0.02484735924574658}], 
        PointBox[{2.4, 0.027028542321284044`}], 
        PointBox[{2.5, 0.028138740150596978`}], 
        PointBox[{2.6, 0.02475533431795107}], 
        PointBox[{2.7, 0.02483285973663195}], 
        PointBox[{2.8, 0.028026418945901858`}], 
        PointBox[{2.9, 0.026861646712965315`}], 
        PointBox[{3., 0.025432839646026925`}], 
        PointBox[{3.1, 0.02894955443224773}], 
        PointBox[{3.2, 0.032798826115354486`}], 
        PointBox[{3.3, 0.0319875760111909}], 
        PointBox[{3.4, 0.03152090514275454}], 
        PointBox[{3.5, 0.03458881786692273}], 
        PointBox[{3.6, 0.03261317195772726}], 
        PointBox[{3.7, 0.030220427320931147`}], 
        PointBox[{3.8, 0.03279854856151709}], 
        PointBox[{3.9, 0.03431874992050046}], 
        PointBox[{4., 0.03151719576931311}], 
        PointBox[{4.1, 0.03346411081563442}], 
        PointBox[{4.2, 0.03738520365092062}], 
        PointBox[{4.3, 0.039430759089683826`}], 
        PointBox[{4.4, 0.03739773356362973}], 
        PointBox[{4.5, 0.03988745195338261}], 
        PointBox[{4.6, 0.040501633454288595`}], 
        PointBox[{4.7, 0.037111656799152785`}], 
        PointBox[{4.8, 0.037641950262425006`}], 
        PointBox[{4.9, 0.04072473528115493}], 
        PointBox[{5., 0.03915004881438915}], 
        PointBox[{5.1, 0.03827335802057437}], 
        PointBox[{5.2, 0.04199866070567455}], 
        PointBox[{5.3, 0.045726176991237134`}], 
        PointBox[{5.4, 0.04443498612462108}], 
        PointBox[{5.5, 0.04460328266961017}], 
        PointBox[{5.6, 0.04740181327496825}], 
        PointBox[{5.7, 0.04467154648151956}], 
        PointBox[{5.8, 0.04306081376436843}], 
        PointBox[{5.9, 0.04594748602374099}], 
        PointBox[{6., 0.046783263666404624`}], 
        PointBox[{6.1, 0.04400494830000094}], 
        PointBox[{6.2, 0.04679941831496562}], 
        PointBox[{6.3, 0.0504646880207604}], 
        PointBox[{6.4, 0.05150928168083449}], 
        PointBox[{6.5, 0.04974004107348756}], 
        PointBox[{6.6, 0.052847546130005224`}], 
        PointBox[{6.7, 0.0521116760194168}], 
        PointBox[{6.8, 0.0490902531292608}], 
        PointBox[{6.9, 0.050555986813083736`}], 
        PointBox[{7., 0.05323694667824311}], 
        PointBox[{7.1, 0.0507296816513078}], 
        PointBox[{7.2, 0.05125481595066044}], 
        PointBox[{7.3, 0.054662098142429054`}], 
        PointBox[{7.4, 0.05759155394927391}], 
        PointBox[{7.5, 0.055639996474404256`}], 
        PointBox[{7.6, 0.057077473972088434`}], 
        PointBox[{7.7, 0.05876690710420515}], 
        PointBox[{7.8, 0.05545331704858473}], 
        PointBox[{7.9, 0.05509027011404793}], 
        PointBox[{8., 0.05825575573499641}], 
        PointBox[{8.1, 0.0576902404403949}], 
        PointBox[{8.2, 0.055754431744938056`}], 
        PointBox[{8.3, 0.05908898281134142}], 
        PointBox[{8.4, 0.06220442360532933}], 
        PointBox[{8.5, 0.06175248021968818}], 
        PointBox[{8.6, 0.06093251455173099}], 
        PointBox[{8.7, 0.06414373823815865}], 
        PointBox[{8.8, 0.06177352571116764}], 
        PointBox[{8.9, 0.059782625171140406`}], 
        PointBox[{9., 0.06224531722171407}], 
        PointBox[{9.1, 0.06385723300707549}], 
        PointBox[{9.2, 0.060766522669403786`}], 
        PointBox[{9.3, 0.06305451298066185}], 
        PointBox[{9.4, 0.06575735031235665}], 
        PointBox[{9.5, 0.0672937060394999}], 
        PointBox[{9.6, 0.06516613000683771}], 
        PointBox[{9.7, 0.06809357008341024}], 
        PointBox[{9.8, 0.06766885804928834}], 
        PointBox[{9.9, 0.06462347240982456}], 
        PointBox[{10., 0.0657369728340972}], 
        PointBox[{10.1, 0.06866830059562344}], 
        PointBox[{10.2, 0.06628768981734565}], 
        PointBox[{10.3, 0.06645605180266574}], 
        PointBox[{10.4, 0.0693076301611322}], 
        PointBox[{10.5, 0.07174220627622176}], 
        PointBox[{10.6, 0.06984623233523841}], 
        PointBox[{10.7, 0.07099059986890656}], 
        PointBox[{10.8, 0.07277690618658317}], 
        PointBox[{10.9, 0.06949126264362375}], 
        PointBox[{11., 0.06908913926882858}], 
        PointBox[{11.1, 0.07221878602697299}], 
        PointBox[{11.2, 0.07176160487624311}], 
        PointBox[{11.3, 0.06972447508803499}], 
        PointBox[{11.4, 0.07282745027391817}], 
        PointBox[{11.5, 0.07501390305535129}], 
        PointBox[{11.6, 0.07452178593175246}], 
        PointBox[{11.7, 0.07358871728812282}], 
        PointBox[{11.8, 0.07680722545392873}], 
        PointBox[{11.9, 0.07423149914723054}], 
        PointBox[{12., 0.07246274205204696}], 
        PointBox[{12.1, 0.07494393067732014}], 
        PointBox[{12.2, 0.0764822934212721}], 
        PointBox[{12.3, 0.07328678314574574}], 
        PointBox[{12.4, 0.07574337976763106}], 
        PointBox[{12.5, 0.07762198567325083}], 
        PointBox[{12.6, 0.07869762603461408}], 
        PointBox[{12.7, 0.07650926707918605}], 
        PointBox[{12.8, 0.07967056478238263}], 
        PointBox[{12.9, 0.07867621126459787}], 
        PointBox[{13., 0.07589886697818328}], 
        PointBox[{13.1, 0.07727587942759055}], 
        PointBox[{13.2, 0.08008981810929061}], 
        PointBox[{13.3, 0.07728227625743637}], 
        PointBox[{13.4, 0.07807696774732586}], 
        PointBox[{13.5, 0.08029938946590938}], 
        PointBox[{13.6, 0.08207953795681557}], 
        PointBox[{13.7, 0.07987499078621384}], 
        PointBox[{13.8, 0.08162059886416752}], 
        PointBox[{13.9, 0.08264476154676288}], 
        PointBox[{14., 0.07938689419220969}], 
        PointBox[{14.1, 0.07950843450910763}], 
        PointBox[{14.2, 0.08268816826455841}], 
        PointBox[{14.3, 0.08144961962691376}], 
        PointBox[{14.4, 0.08017762311274507}], 
        PointBox[{14.5, 0.0830051267471468}], 
        PointBox[{14.6, 0.08463733420927459}], 
        PointBox[{14.7, 0.08342668919931008}], 
        PointBox[{14.8, 0.08322191525243294}], 
        PointBox[{14.9, 0.0859595400246118}], 
        PointBox[{15., 0.08289507233121322}], 
        PointBox[{15.1, 0.08180583596233182}], 
        PointBox[{15.2, 0.0846310302820714}], 
        PointBox[{15.3, 0.08530475618953347}], 
        PointBox[{15.4, 0.08244103992689704}], 
        PointBox[{15.5, 0.08532153198718816}], 
        PointBox[{15.6, 0.08666588811742147}], 
        PointBox[{15.7, 0.08683487085610003}], 
        PointBox[{15.8, 0.08506344761942847}], 
        PointBox[{15.9, 0.0885115975608958}], 
        PointBox[{16., 0.08637936167568487}], 
        PointBox[{16.1, 0.08425424500283316}], 
        PointBox[{16.2, 0.0862885980475384}], 
        PointBox[{16.3, 0.08848948652261769}], 
        PointBox[{16.4, 0.08515171471902815}], 
        PointBox[{16.5, 0.08718511626516695}], 
        PointBox[{16.6, 0.08868317960916514}], 
        PointBox[{16.7, 0.08987825151135763}], 
        PointBox[{16.8, 0.08744993423410474}], 
        PointBox[{16.9, 0.09036035858797004}], 
        PointBox[{17., 0.08977988767167011}], 
        PointBox[{17.1, 0.08690141773617914}], 
        PointBox[{17.2, 0.08794408383326473}], 
        PointBox[{17.3, 0.09096328867637288}], 
        PointBox[{17.4, 0.08835857143377641}], 
        PointBox[{17.5, 0.0888089040650585}], 
        PointBox[{17.6, 0.09094713078554327}], 
        PointBox[{17.7, 0.0924876423920521}], 
        PointBox[{17.8, 0.09035417624177819}], 
        PointBox[{17.9, 0.09180602412374986}], 
        PointBox[{18., 0.09302413896767979}], 
        PointBox[{18.1, 0.0897801387075255}], 
        PointBox[{18.2, 0.089787219697198}], 
        PointBox[{18.3, 0.09294556568654405}], 
        PointBox[{18.4, 0.09185875514082065}], 
        PointBox[{18.5, 0.0904977614476114}], 
        PointBox[{18.6, 0.09328879715116309}], 
        PointBox[{18.7, 0.09475257853737996}], 
        PointBox[{18.8, 0.09359084708223638}], 
        PointBox[{18.9, 0.09331607289006051}], 
        PointBox[{19., 0.0960464826677533}], 
        PointBox[{19.1, 0.09291873265948931}], 
        PointBox[{19.2, 0.09194536895821612}], 
        PointBox[{19.3, 0.0947544867966465}], 
        PointBox[{19.4, 0.09535286954726226}], 
        PointBox[{19.5, 0.09255951259469138}], 
        PointBox[{19.6, 0.09554296858877019}], 
        PointBox[{19.7, 0.0969220591349483}], 
        PointBox[{19.8, 0.09699221121755858}], 
        PointBox[{19.9, 0.09533951022413613}], 
        PointBox[{20., 0.09883245263284801}], 
        PointBox[{20.1, 0.09634688724517518}], 
        PointBox[{20.2, 0.09451368600214163}], 
        PointBox[{20.3, 0.09669274426803805}], 
        PointBox[{20.4, 0.09865499686369873}], 
        PointBox[{20.5, 0.09523824004103337}], 
        PointBox[{20.6, 0.0977621655130065}], 
        PointBox[{20.7, 0.09932393859146603}], 
        PointBox[{20.8, 0.10049005843513091`}], 
        PointBox[{20.9, 0.09814000486777127}], 
        PointBox[{21., 0.10147851403551626`}], 
        PointBox[{21.1, 0.10010165312628644`}], 
        PointBox[{21.2, 0.09757906082721039}], 
        PointBox[{21.3, 0.09900976338839321}], 
        PointBox[{21.4, 0.10180539426353115`}], 
        PointBox[{21.5, 0.09865807540219906}], 
        PointBox[{21.6, 0.10014490469584003`}], 
        PointBox[{21.7, 0.10219563190359321`}], 
        PointBox[{21.8, 0.10413181094292628`}], 
        PointBox[{21.9, 0.10178531251470244`}], 
        PointBox[{22., 0.10422942318782658`}], 
        PointBox[{22.1, 0.10423912210582405`}], 
        PointBox[{22.2, 0.10123555968383881`}], 
        PointBox[{22.3, 0.10191061697767127`}], 
        PointBox[{22.4, 0.10503201855419617`}], 
        PointBox[{22.5, 0.10281596270384967`}], 
        PointBox[{22.6, 0.10294976682570732`}], 
        PointBox[{22.7, 0.10562477002988818`}], 
        PointBox[{22.8, 0.10807251553910129`}], 
        PointBox[{22.9, 0.1062590913320368}], 
        PointBox[{23., 0.10745441040854341`}], 
        PointBox[{23.1, 0.10885206117802732`}], 
        PointBox[{23.2, 0.10559543728301185`}], 
        PointBox[{23.3, 0.105578305478903}], 
        PointBox[{23.4, 0.10865893032819514`}], 
        PointBox[{23.5, 0.10765641939527204`}], 
        PointBox[{23.6, 0.10645215501430157`}], 
        PointBox[{23.7, 0.10967741590970469`}], 
        PointBox[{23.8, 0.11256196649508513`}], 
        PointBox[{23.9, 0.11157621615235126`}], 
        PointBox[{24., 0.11156195556281916`}], 
        PointBox[{24.1, 0.11409332135307411`}], 
        PointBox[{24.2, 0.11079713690492896`}], 
        PointBox[{24.3, 0.11019700909870919`}], 
        PointBox[{24.4, 0.11303435578077965`}], 
        PointBox[{24.5, 0.11318356078261883`}], 
        PointBox[{24.6, 0.11091828411309494`}], 
        PointBox[{24.7, 0.11451623257005132`}], 
        PointBox[{24.8, 0.11792111095671982`}], 
        PointBox[{24.9, 0.11783654715781061`}], 
        PointBox[{25., 0.1169090572826024}], 
        PointBox[{25.1, 0.12019256764925329`}], 
        PointBox[{25.2, 0.11700665348624294`}], 
        PointBox[{25.3, 0.11596517722165818`}], 
        PointBox[{25.4, 0.11849809723016962`}], 
        PointBox[{25.5, 0.11952887542998858`}], 
        PointBox[{25.6, 0.11658581943755278`}], 
        PointBox[{25.7, 0.12041499922822643`}], 
        PointBox[{25.8, 0.1245094943655794}], 
        PointBox[{25.9, 0.12521601414749975`}], 
        PointBox[{26., 0.12375072317120349`}], 
        PointBox[{26.1, 0.1274392176985268}], 
        PointBox[{26.2, 0.1243983429697193}], 
        PointBox[{26.3, 0.12308409930270969`}], 
        PointBox[{26.4, 0.12535944621264455`}], 
        PointBox[{26.5, 0.12693180106524712`}], 
        PointBox[{26.6, 0.12364975460406069`}], 
        PointBox[{26.7, 0.12771659531748816`}], 
        PointBox[{26.8, 0.13267247524663353`}], 
        PointBox[{26.9, 0.13388653061084613`}], 
        PointBox[{27., 0.13221539433972634`}], 
        PointBox[{27.1, 0.13609933130327923`}], 
        PointBox[{27.2, 0.1330919458624631}], 
        PointBox[{27.3, 0.13170688338850742`}], 
        PointBox[{27.4, 0.13384541305758743`}], 
        PointBox[{27.5, 0.1356224902058518}], 
        PointBox[{27.6, 0.1322355457691046}], 
        PointBox[{27.7, 0.13676144922905917`}], 
        PointBox[{27.8, 0.142592234608302}], 
        PointBox[{27.9, 0.14383992263389295`}], 
        PointBox[{28., 0.14223482561876252`}], 
        PointBox[{28.1, 0.14621427949595356`}], 
        PointBox[{28.2, 0.14301538142736195`}], 
        PointBox[{28.3, 0.14180771354333002`}], 
        PointBox[{28.4, 0.14397193489017776`}], 
        PointBox[{28.5, 0.14559795282835444`}], 
        PointBox[{28.6, 0.1423438443760928}], 
        PointBox[{28.7, 0.14775082532142633`}], 
        PointBox[{28.8, 0.1539475593584834}], 
        PointBox[{28.9, 0.15463731482145357`}], 
        PointBox[{29., 0.15342838551248553`}], 
        PointBox[{29.1, 0.15728300389384037`}], 
        PointBox[{29.2, 0.15372595015617205`}], 
        PointBox[{29.3, 0.15299329814797763`}], 
        PointBox[{29.4, 0.15533618748517783`}], 
        PointBox[{29.5, 0.1563170321514319}], 
        PointBox[{29.6, 0.15378414650480995`}], 
        PointBox[{29.7, 0.16037837300546792`}], 
        PointBox[{29.8, 0.16560950236887864`}], 
        PointBox[{29.9, 0.1653027242361004}], 
        PointBox[{30., 0.16511891623475597`}], 
        PointBox[{30.1, 0.16805869338056717`}], 
        PointBox[{30.2, 0.16438316386741852`}], 
        PointBox[{30.3, 0.16441437038425277`}], 
        PointBox[{30.4, 0.16699503649133082`}], 
        PointBox[{30.5, 0.16654324882727126`}], 
        PointBox[{30.6, 0.16612787384998418`}], 
        PointBox[{30.7, 0.17302552253473216`}], 
        PointBox[{30.8, 0.17600930465525755`}], 
        PointBox[{30.9, 0.1747171603047829}], 
        PointBox[{31., 0.17657162600225865`}], 
        PointBox[{31.1, 0.17706043080503076`}], 
        PointBox[{31.2, 0.17408940688594599`}], 
        PointBox[{31.3, 0.17504203431403706`}], 
        PointBox[{31.4, 0.1776575329101965}], 
        PointBox[{31.5, 0.17502302547997117`}], 
        PointBox[{31.6, 0.178340639914941}], 
        PointBox[{31.7, 0.1833488501385588}], 
        PointBox[{31.8, 0.1840406574280192}], 
        PointBox[{31.9, 0.18239892567896263`}], 
        PointBox[{32., 0.1866274906200377}], 
        PointBox[{32.1, 0.1837456368624112}], 
        PointBox[{32.2, 0.18233057224135135`}], 
        PointBox[{32.3, 0.1841202434250862}], 
        PointBox[{32.4, 0.18601893729190683`}], 
        PointBox[{32.5, 0.18236263393150037`}], 
        PointBox[{32.6, 0.18824552617404905`}], 
        PointBox[{32.7, 0.1904103945962602}], 
        PointBox[{32.8, 0.18948907482103566`}], 
        PointBox[{32.9, 0.18899176167689039`}], 
        PointBox[{33., 0.1929962589492625}], 
        PointBox[{33.1, 0.18871249164009607`}], 
        PointBox[{33.2, 0.1890105894097454}], 
        PointBox[{33.3, 0.19125849723115818`}], 
        PointBox[{33.4, 0.190904864483343}], 
        PointBox[{33.5, 0.19016940439361785`}], 
        PointBox[{33.6, 0.19456596093743395`}], 
        PointBox[{33.7, 0.19448828643723154`}], 
        PointBox[{33.8, 0.19288229954656486`}], 
        PointBox[{33.9, 0.19550234626203306`}], 
        PointBox[{34., 0.19514444558890598`}], 
        PointBox[{34.1, 0.19264479260800424`}], 
        PointBox[{34.2, 0.19415831952371027`}], 
        PointBox[{34.3, 0.19606894565161825`}], 
        PointBox[{34.4, 0.19266539805821215`}], 
        PointBox[{34.5, 0.19618161303664322`}], 
        PointBox[{34.6, 0.19761857863185112`}], 
        PointBox[{34.7, 0.1962320988316074}], 
        PointBox[{34.8, 0.19532088134179426`}], 
        PointBox[{34.9, 0.20014114022366575`}], 
        PointBox[{35., 0.19567728373359297`}], 
        PointBox[{35.1, 0.19570714131824665`}], 
        PointBox[{35.2, 0.19766428258254407`}], 
        PointBox[{35.3, 0.19783280121321714`}], 
        PointBox[{35.4, 0.19483019057348602`}], 
        PointBox[{35.5, 0.19894563701334497`}], 
        PointBox[{35.6, 0.19812408589019645`}], 
        PointBox[{35.7, 0.19639985861914833`}], 
        PointBox[{35.8, 0.19805389981219493`}], 
        PointBox[{35.9, 0.19959706182874654`}], 
        PointBox[{36., 0.19618081806311302`}], 
        PointBox[{36.1, 0.19765614555617428`}], 
        PointBox[{36.2, 0.19913079324242333`}], 
        PointBox[{36.3, 0.1962486670505658}], 
        PointBox[{36.4, 0.1972544652385931}], 
        PointBox[{36.5, 0.19862101952284297`}], 
        PointBox[{36.6, 0.19676238448013436`}], 
        PointBox[{36.7, 0.1958172305188416}], 
        PointBox[{36.8, 0.20032481000079003`}], 
        PointBox[{36.9, 0.19656228425306785`}], 
        PointBox[{37., 0.19635451479277496`}], 
        PointBox[{37.1, 0.1980247576845346}], 
        PointBox[{37.2, 0.19787144210402616`}], 
        PointBox[{37.3, 0.19336647585231018`}], 
        PointBox[{37.4, 0.19715657900314476`}], 
        PointBox[{37.5, 0.19592441858169257`}], 
        PointBox[{37.6, 0.19406781705982382`}], 
        PointBox[{37.7, 0.1951569109872582}], 
        PointBox[{37.8, 0.19819183200460985`}], 
        PointBox[{37.9, 0.19389930621805532`}], 
        PointBox[{38., 0.19535810658871963`}], 
        PointBox[{38.1, 0.19619228098375133`}], 
        PointBox[{38.2, 0.1933221792510956}], 
        PointBox[{38.3, 0.19151770309208835`}], 
        PointBox[{38.4, 0.19363808683594264`}], 
        PointBox[{38.5, 0.191411469674974}], 
        PointBox[{38.6, 0.19038873107531992`}], 
        PointBox[{38.7, 0.19396945580796854`}], 
        PointBox[{38.8, 0.1919771074165544}], 
        PointBox[{38.9, 0.19097706345433674`}], 
        PointBox[{39., 0.19238041047618523`}], 
        PointBox[{39.1, 0.1914335867446399}], 
        PointBox[{39.2, 0.18583078449131998`}], 
        PointBox[{39.3, 0.18833560963796178`}], 
        PointBox[{39.4, 0.18743400898198384`}], 
        PointBox[{39.5, 0.18531578558230014`}], 
        PointBox[{39.6, 0.1857728117132423}], 
        PointBox[{39.7, 0.18983538319740825`}], 
        PointBox[{39.8, 0.18521470397398462`}], 
        PointBox[{39.9, 0.18648493731348845`}], 
        PointBox[{40., 0.18671088266107083`}], 
        PointBox[{40.1, 0.18313649295695994`}], 
        PointBox[{40.2, 0.17788827649412922`}], 
        PointBox[{40.3, 0.1814791151442417}], 
        PointBox[{40.4, 0.1791040694615091}], 
        PointBox[{40.5, 0.17765218160194468`}], 
        PointBox[{40.6, 0.17980222760540276`}], 
        PointBox[{40.7, 0.18130557661424027`}], 
        PointBox[{40.8, 0.17797072661366886`}], 
        PointBox[{40.9, 0.1795996574782609}], 
        PointBox[{41., 0.1778508557807809}], 
        PointBox[{41.1, 0.17165381109527825`}], 
        PointBox[{41.2, 0.16993487521923706`}], 
        PointBox[{41.3, 0.17169395409492658`}], 
        PointBox[{41.4, 0.16901619343189409`}], 
        PointBox[{41.5, 0.16844146993099432`}], 
        PointBox[{41.6, 0.1717839344969229}], 
        PointBox[{41.7, 0.1702088725071113}], 
        PointBox[{41.8, 0.16922949425659167`}], 
        PointBox[{41.9, 0.17017989799807878`}], 
        PointBox[{42., 0.16605637996651046`}], 
        PointBox[{42.1, 0.15906876629377378`}], 
        PointBox[{42.2, 0.16039349393364385`}], 
        PointBox[{42.3, 0.16030976323308496`}], 
        PointBox[{42.4, 0.15777189409606424`}], 
        PointBox[{42.5, 0.158023222902541}], 
        PointBox[{42.6, 0.1616865625888383}], 
        PointBox[{42.7, 0.1584125546527307}], 
        PointBox[{42.8, 0.15896368318625756`}], 
        PointBox[{42.9, 0.15894999288884437`}], 
        PointBox[{43., 0.15314227369558767`}], 
        PointBox[{43.1, 0.14705537273545524`}], 
        PointBox[{43.2, 0.14977663368403132`}], 
        PointBox[{43.3, 0.14868917548937918`}], 
        PointBox[{43.4, 0.1463416531502556}], 
        PointBox[{43.5, 0.14718361550012968`}], 
        PointBox[{43.6, 0.1506417854332803}], 
        PointBox[{43.7, 0.1468479966179674}], 
        PointBox[{43.8, 0.1480868671168224}], 
        PointBox[{43.9, 0.14735518505518755`}], 
        PointBox[{44., 0.14132369576808348`}], 
        PointBox[{44.1, 0.13628636879248354`}], 
        PointBox[{44.2, 0.13942481887424818`}], 
        PointBox[{44.3, 0.13797778741891056`}], 
        PointBox[{44.4, 0.1357077901223479}], 
        PointBox[{44.5, 0.13684369597547855`}], 
        PointBox[{44.6, 0.14006954025828325`}], 
        PointBox[{44.7, 0.1362566894177357}], 
        PointBox[{44.8, 0.13769806163000398`}], 
        PointBox[{44.9, 0.13677981398901715`}], 
        PointBox[{45., 0.1314278889826257}], 
        PointBox[{45.1, 0.12704412494802925`}], 
        PointBox[{45.2, 0.1301741913930764}], 
        PointBox[{45.3, 0.12880340141590732`}], 
        PointBox[{45.4, 0.12645656637280142`}], 
        PointBox[{45.5, 0.1276164540939887}], 
        PointBox[{45.6, 0.13078290484490565`}], 
        PointBox[{45.7, 0.12714680591686803`}], 
        PointBox[{45.8, 0.12846318958663372`}], 
        PointBox[{45.9, 0.12787422047364522`}], 
        PointBox[{46., 0.12339509319386904`}], 
        PointBox[{46.1, 0.11938055992309957`}], 
        PointBox[{46.2, 0.12222237495417221`}], 
        PointBox[{46.3, 0.12129264135101112`}], 
        PointBox[{46.4, 0.11873861261308434`}], 
        PointBox[{46.5, 0.11970103328604159`}], 
        PointBox[{46.6, 0.12293763560408898`}], 
        PointBox[{46.7, 0.11968595325515144`}], 
        PointBox[{46.8, 0.12054313879928866`}], 
        PointBox[{46.9, 0.12062924671129205`}], 
        PointBox[{47., 0.11691136254212771`}], 
        PointBox[{47.1, 0.11319204229710798`}], 
        PointBox[{47.2, 0.11541931287606036`}], 
        PointBox[{47.3, 0.11527739827130064`}], 
        PointBox[{47.4, 0.1124519466024654}], 
        PointBox[{47.5, 0.11303366429388856`}], 
        PointBox[{47.6, 0.1163433547804075}], 
        PointBox[{47.7, 0.1137924029390025}], 
        PointBox[{47.8, 0.11382290733810413`}], 
        PointBox[{47.9, 0.11474499238840784`}], 
        PointBox[{48., 0.11162305869996157`}], 
        PointBox[{48.1, 0.10828781624937225`}], 
        PointBox[{48.2, 0.10953145470208568`}], 
        PointBox[{48.3, 0.11046238113530535`}], 
        PointBox[{48.4, 0.10740109801687933`}], 
        PointBox[{48.5, 0.10745016630375978`}], 
        PointBox[{48.6, 0.11071786863950035`}], 
        PointBox[{48.7, 0.10923217811634847`}], 
        PointBox[{48.8, 0.10812753952244651`}], 
        PointBox[{48.9, 0.10985824794612921`}], 
        PointBox[{49., 0.10723086689397746`}], 
        PointBox[{49.1, 0.1044297638931942}], 
        PointBox[{49.2, 0.10440140508913227`}], 
        PointBox[{49.3, 0.10650750906187671`}], 
        PointBox[{49.4, 0.10338061014592817`}], 
        PointBox[{49.5, 0.10277735969071113`}], 
        PointBox[{49.6, 0.10581386788584209`}], 
        PointBox[{49.7, 0.10566031884749241`}], 
        PointBox[{49.8, 0.10333499903664356`}], 
        PointBox[{49.9, 0.10563037539809154`}], 
        PointBox[{50., 0.10353774668704001`}], 
        PointBox[{50.1, 0.1013503238332086}], 
        PointBox[{50.2, 0.09999258122250851}], 
        PointBox[{50.3, 0.10305731994949163`}], 
        PointBox[{50.4, 0.10019555191430982`}], 
        PointBox[{50.5, 0.09886297130715743}], 
        PointBox[{50.6, 0.10145341264791344`}], 
        PointBox[{50.7, 0.10267111626868305`}], 
        PointBox[{50.8, 0.09940633938892958}], 
        PointBox[{50.9, 0.101787830783366}], 
        PointBox[{51., 0.10044788826043033`}], 
        PointBox[{51.1, 0.09877069928484687}], 
        PointBox[{51.2, 0.0963405761624671}], 
        PointBox[{51.3, 0.09977367463990454}], 
        PointBox[{51.4, 0.09765598121368968}], 
        PointBox[{51.5, 0.09558359093089998}], 
        PointBox[{51.6, 0.09752233662312944}], 
        PointBox[{51.7, 0.09988014455252417}], 
        PointBox[{51.8, 0.09634637922948186}], 
        PointBox[{51.9, 0.09814720232984589}], 
        PointBox[{52., 0.09787025523931997}], 
        PointBox[{52.1, 0.09642406244135193}], 
        PointBox[{52.2, 0.09345134300662931}], 
        PointBox[{52.3, 0.09639976659262488}], 
        PointBox[{52.4, 0.09555679088014385}], 
        PointBox[{52.5, 0.09283577529297465}], 
        PointBox[{52.6, 0.09394951769347648}], 
        PointBox[{52.7, 0.09701511844634919}], 
        PointBox[{52.8, 0.09410166409744114}], 
        PointBox[{52.9, 0.09463177105148779}], 
        PointBox[{53., 0.09558810820327195}], 
        PointBox[{53.1, 0.09409515779859388}], 
        PointBox[{53.2, 0.09121890561967565}], 
        PointBox[{53.3, 0.09285188734259359}], 
        PointBox[{53.4, 0.09365482351049004}], 
        PointBox[{53.5, 0.09052894684116633}], 
        PointBox[{53.6, 0.09068821216566895}], 
        PointBox[{53.7, 0.09394926813204041}], 
        PointBox[{53.8, 0.09244414125167794}], 
        PointBox[{53.9, 0.09128092464715695}], 
        PointBox[{54., 0.0932804373551566}], 
        PointBox[{54.1, 0.09169569996326478}], 
        PointBox[{54.2, 0.08941620168907745}], 
        PointBox[{54.3, 0.08927035129166701}], 
        PointBox[{54.4, 0.09165320944880459}], 
        PointBox[{54.5, 0.08856664994239742}], 
        PointBox[{54.6, 0.08770293765255868}], 
        PointBox[{54.7, 0.0906740529591375}], 
        PointBox[{54.8, 0.09094955831973468}], 
        PointBox[{54.9, 0.0882398742019891}], 
        PointBox[{55., 0.09067716948434933}], 
        PointBox[{55.1, 0.0893485467092379}], 
        PointBox[{55.2, 0.08774308639604828}], 
        PointBox[{55.3, 0.0859392096183351}], 
        PointBox[{55.4, 0.08922900299757396}], 
        PointBox[{55.5, 0.08682767504488971}], 
        PointBox[{55.6, 0.08496153836085998}], 
        PointBox[{55.7, 0.0872424953372868}], 
        PointBox[{55.8, 0.0891391693678545}], 
        PointBox[{55.9, 0.08569510599086518}], 
        PointBox[{56., 0.08765662410194622}], 
        PointBox[{56.1, 0.08724583128776131}], 
        PointBox[{56.2, 0.08588978953067052}], 
        PointBox[{56.3, 0.08308734309840911}], 
        PointBox[{56.4, 0.08613039283187707}], 
        PointBox[{56.5, 0.08513454621725723}], 
        PointBox[{56.6, 0.08242976694730066}], 
        PointBox[{56.7, 0.08372219272128402}], 
        PointBox[{56.8, 0.0866735310719336}], 
        PointBox[{56.9, 0.08371467600135526}], 
        PointBox[{57., 0.08425581691394955}], 
        PointBox[{57.1, 0.08521380114781558}], 
        PointBox[{57.2, 0.08361791447581385}], 
        PointBox[{57.3, 0.08071344184625852}], 
        PointBox[{57.4, 0.08233674375541616}], 
        PointBox[{57.5, 0.08322207730414449}], 
        PointBox[{57.6, 0.0800628319126768}], 
        PointBox[{57.7, 0.08017202842792175}], 
        PointBox[{57.8, 0.08344917308182356}], 
        PointBox[{57.9, 0.08206097206392042}], 
        PointBox[{58., 0.08066460999383435}], 
        PointBox[{58.1, 0.08274302519712344}], 
        PointBox[{58.2, 0.08092195845677305}], 
        PointBox[{58.3, 0.0785683155882514}], 
        PointBox[{58.4, 0.07814992788640943}], 
        PointBox[{58.5, 0.08073194130347935}], 
        PointBox[{58.6, 0.07778377032837885}], 
        PointBox[{58.7, 0.07663669730546979}], 
        PointBox[{58.8, 0.0795485049906852}], 
        PointBox[{58.9, 0.0801802145282917}], 
        PointBox[{59., 0.07719734689047594}], 
        PointBox[{59.1, 0.07948050627429397}], 
        PointBox[{59.2, 0.07817687757776574}], 
        PointBox[{59.3, 0.07626795654123228}], 
        PointBox[{59.4, 0.07405205870468037}], 
        PointBox[{59.5, 0.0772919121176103}], 
        PointBox[{59.6, 0.07544575537970519}], 
        PointBox[{59.7, 0.07314842587441545}], 
        PointBox[{59.8, 0.07513920264187392}], 
        PointBox[{59.9, 0.07747717951711654}], 
        PointBox[{60., 0.07414613001384325}], 
        PointBox[{60.1, 0.07539913203026467}], 
        PointBox[{60.2, 0.07556581193818777}], 
        PointBox[{60.3, 0.07344050640815455}], 
        PointBox[{60.4, 0.07036744682288956}], 
        PointBox[{60.5, 0.07272889618525812}], 
        PointBox[{60.6, 0.07278261370622276}], 
        PointBox[{60.7, 0.06972325874403738}], 
        PointBox[{60.8, 0.07040165993599119}], 
        PointBox[{60.9, 0.07362859216867176}], 
        PointBox[{61., 0.07148093440850396}], 
        PointBox[{61.1, 0.07074503319203337}], 
        PointBox[{61.2, 0.07243980939293121}], 
        PointBox[{61.3, 0.06997217675913983}], 
        PointBox[{61.4, 0.06703116334429635}], 
        PointBox[{61.5, 0.06730884605903384}], 
        PointBox[{61.6, 0.06938389243527354}], 
        PointBox[{61.7, 0.06633385225706895}], 
        PointBox[{61.8, 0.06550567905136967}], 
        PointBox[{61.9, 0.06866547879090648}], 
        PointBox[{62., 0.0686614085264066}], 
        PointBox[{62.1, 0.06598443327084866}], 
        PointBox[{62.2, 0.06818321518195673}], 
        PointBox[{62.3, 0.0663515301423727}], 
        PointBox[{62.4, 0.06365409510686142}], 
        PointBox[{62.5, 0.06170165634933455}], 
        PointBox[{62.6, 0.06479394948281055}], 
        PointBox[{62.7, 0.06284888581039463}], 
        PointBox[{62.8, 0.060608264205603155`}], 
        PointBox[{62.9, 0.06285177878292222}], 
        PointBox[{63., 0.0649154108971739}], 
        PointBox[{63.1, 0.061609984061689764`}], 
        PointBox[{63.2, 0.06277998127757448}], 
        PointBox[{63.3, 0.06284011496289511}], 
        PointBox[{63.4, 0.05977862828794857}], 
        PointBox[{63.5, 0.05653511876256828}], 
        PointBox[{63.6, 0.05882184722497388}], 
        PointBox[{63.7, 0.05895084788890547}], 
        PointBox[{63.8, 0.05584206587870404}], 
        PointBox[{63.9, 0.0565421382636203}], 
        PointBox[{64., 0.05977155487702772}], 
        PointBox[{64.1, 0.05768486515710444}], 
        PointBox[{64.2, 0.05668031833937489}], 
        PointBox[{64.3, 0.05845440891272943}], 
        PointBox[{64.4, 0.0553561277585817}], 
        PointBox[{64.5, 0.05192804511727354}], 
        PointBox[{64.6, 0.05189968261177637}], 
        PointBox[{64.7, 0.05412866093619606}], 
        PointBox[{64.8, 0.0512488364227258}], 
        PointBox[{64.9, 0.050118071291620214`}], 
        PointBox[{65., 0.05328851827037285}], 
        PointBox[{65.1, 0.053561385199628664`}], 
        PointBox[{65.2, 0.05064346926397187}], 
        PointBox[{65.3, 0.05259396515644629}], 
        PointBox[{65.4, 0.05108626859226954}], 
        PointBox[{65.5, 0.04747541016753011}], 
        PointBox[{65.6, 0.04501734196035177}], 
        PointBox[{65.7, 0.047915207516278265`}], 
        PointBox[{65.8, 0.04665163437872911}], 
        PointBox[{65.9, 0.043962453736608}], 
        PointBox[{66., 0.04591161189848914}], 
        PointBox[{66.1, 0.04834982215314046}], 
        PointBox[{66.2, 0.045322474962364134`}], 
        PointBox[{66.3, 0.04560391834310797}], 
        PointBox[{66.4, 0.046534857521596217`}], 
        PointBox[{66.5, 0.04270737495796501}], 
        PointBox[{66.6, 0.03904607187517325}], 
        PointBox[{66.7, 0.040405730419269176`}], 
        PointBox[{66.8, 0.04156120082362167}], 
        PointBox[{66.9, 0.038387420843117574`}], 
        PointBox[{67., 0.03828269696129295}], 
        PointBox[{67.1, 0.04167285542163052}], 
        PointBox[{67.2, 0.040566063790936024`}], 
        PointBox[{67.3, 0.0384344161256214}], 
        PointBox[{67.4, 0.04050305855805394}], 
        PointBox[{67.5, 0.03798189513780412}], 
        PointBox[{67.6, 0.03408308404434937}], 
        PointBox[{67.7, 0.03262520369647726}], 
        PointBox[{67.8, 0.035370614095010494`}], 
        PointBox[{67.9, 0.033437606451015796`}], 
        PointBox[{68., 0.0311734584247989}], 
        PointBox[{68.1, 0.03387876682574828}], 
        PointBox[{68.2, 0.03541998426776225}], 
        PointBox[{68.3, 0.03225865846564985}], 
        PointBox[{68.4, 0.033161742980793815`}], 
        PointBox[{68.5, 0.03349102439036607}], 
        PointBox[{68.6, 0.029537495877266777`}], 
        PointBox[{68.7, 0.026141019126811185`}], 
        PointBox[{68.8, 0.028018287435139337`}], 
        PointBox[{68.9, 0.028690469467796617`}], 
        PointBox[{69., 0.02543790043619585}], 
        PointBox[{69.1, 0.02588992498260445}], 
        PointBox[{69.2, 0.029160310048633703`}], 
        PointBox[{69.3, 0.027545124016435406`}], 
        PointBox[{69.4, 0.025798499504849016`}], 
        PointBox[{69.5, 0.027872380998603577`}], 
        PointBox[{69.6, 0.025277905631746873`}], 
        PointBox[{69.7, 0.021951047351833817`}], 
        PointBox[{69.8, 0.02083504192947627}], 
        PointBox[{69.9, 0.023521551605335346`}], 
        PointBox[{70., 0.02168185573515057}], 
        PointBox[{70.1, 0.019294637373654257`}], 
        PointBox[{70.2, 0.022127747959140964`}], 
        PointBox[{70.3, 0.023528397647203766`}], 
        PointBox[{70.4, 0.020496458802104312`}], 
        PointBox[{70.5, 0.021342354544196435`}], 
        PointBox[{70.6, 0.021945122298521698`}], 
        PointBox[{70.7, 0.01960075810965779}], 
        PointBox[{70.8, 0.016793632352785644`}], 
        PointBox[{70.9, 0.018285866500472675`}], 
        PointBox[{71., 0.019675645373601777`}], 
        PointBox[{71.1, 0.01650532401388829}], 
        PointBox[{71.2, 0.016172030301582242`}], 
        PointBox[{71.3, 0.019542861741841104`}], 
        PointBox[{71.4, 0.018689887298283435`}], 
        PointBox[{71.5, 0.01644775686652602}], 
        PointBox[{71.6, 0.01869379461129195}], 
        PointBox[{71.7, 0.018382967614663993`}], 
        PointBox[{71.8, 0.0177418104609042}], 
        PointBox[{71.9, 0.01597123701599522}], 
        PointBox[{72., 0.018791477196251054`}], 
        PointBox[{72.1, 0.018383438009450945`}], 
        PointBox[{72.2, 0.015107496487070035`}], 
        PointBox[{72.3, 0.016772184316938676`}], 
        PointBox[{72.4, 0.019310258546792275`}], 
        PointBox[{72.5, 0.016986753217601392`}], 
        PointBox[{72.6, 0.016689407889828336`}], 
        PointBox[{72.7, 0.019139405988861984`}], 
        PointBox[{72.8, 0.0210360922647534}], 
        PointBox[{72.9, 0.019462438842130836`}], 
        PointBox[{73., 0.019699658832035196`}], 
        PointBox[{73.1, 0.02235340490618227}], 
        PointBox[{73.2, 0.019992663011081917`}], 
        PointBox[{73.3, 0.017992379542872167`}], 
        PointBox[{73.4, 0.021048001020488365`}], 
        PointBox[{73.5, 0.0218412867075927}], 
        PointBox[{73.6, 0.01911922435769594}], 
        PointBox[{73.7, 0.02123146588515128}], 
        PointBox[{73.8, 0.024338257864060655`}], 
        PointBox[{73.9, 0.025915697608875295`}], 
        PointBox[{74., 0.02390614912348772}], 
        PointBox[{74.1, 0.02644555600472959}], 
        PointBox[{74.2, 0.027033591529380376`}], 
        PointBox[{74.3, 0.02361639123644377}], 
        PointBox[{74.4, 0.024214919511859837`}], 
        PointBox[{74.5, 0.02726758973665892}], 
        PointBox[{74.6, 0.025661076054610196`}], 
        PointBox[{74.7, 0.024734374906390716`}], 
        PointBox[{74.8, 0.028319593370301276`}], 
        PointBox[{74.9, 0.032047372756553026`}], 
        PointBox[{75., 0.03082235996845724}], 
        PointBox[{75.1, 0.030825997432783674`}], 
        PointBox[{75.2, 0.033715141980009994`}], 
        PointBox[{75.3, 0.03135702703117088}], 
        PointBox[{75.4, 0.02931910137705993}], 
        PointBox[{75.5, 0.03215548246476783}], 
        PointBox[{75.6, 0.033230364531283765`}], 
        PointBox[{75.7, 0.03046894937529003}], 
        PointBox[{75.8, 0.032858341299851594`}], 
        PointBox[{75.9, 0.03683807742189174}], 
        PointBox[{76., 0.038373709751384176`}], 
        PointBox[{76.1, 0.036461039101553}], 
        PointBox[{76.2, 0.039243697457549916`}], 
        PointBox[{76.3, 0.03935743522517402}], 
        PointBox[{76.4, 0.03602560522156387}], 
        PointBox[{76.5, 0.03697411248616554}], 
        PointBox[{76.6, 0.03990326884221292}], 
        PointBox[{76.7, 0.03795441012501008}], 
        PointBox[{76.8, 0.037597170625457275`}], 
        PointBox[{76.9, 0.04137807962626296}], 
        PointBox[{77., 0.044966239584369086`}], 
        PointBox[{77.1, 0.043375049675798645`}], 
        PointBox[{77.2, 0.044012501714175915`}], 
        PointBox[{77.3, 0.0465125872787335}], 
        PointBox[{77.4, 0.043537289922624275`}], 
        PointBox[{77.5, 0.042293436000476796`}], 
        PointBox[{77.6, 0.045333722955575556`}], 
        PointBox[{77.7, 0.04571630204066677}], 
        PointBox[{77.8, 0.043142837544028825`}], 
        PointBox[{77.9, 0.04623186815722593}], 
        PointBox[{78., 0.04997839124163064}], 
        PointBox[{78.1, 0.05054124218064889}], 
        PointBox[{78.2, 0.04902538763130371}], 
        PointBox[{78.3, 0.05225176744293681}], 
        PointBox[{78.4, 0.0510590930034812}], 
        PointBox[{78.5, 0.04823260151560351}], 
        PointBox[{78.6, 0.05002500500213332}], 
        PointBox[{78.7, 0.05245053107807207}], 
        PointBox[{78.8, 0.04972146438995206}], 
        PointBox[{78.9, 0.05075406137166016}], 
        PointBox[{79., 0.054170938715782775`}], 
        PointBox[{79.1, 0.05687260433931156}], 
        PointBox[{79.2, 0.0548049278569757}], 
        PointBox[{79.3, 0.05667025460516207}], 
        PointBox[{79.4, 0.05791191450143753}], 
        PointBox[{79.5, 0.05455834132707253}], 
        PointBox[{79.6, 0.05455435269204969}], 
        PointBox[{79.7, 0.05773249484699596}], 
        PointBox[{79.8, 0.05671942326470816}], 
        PointBox[{79.9, 0.055205816058169176`}], 
        PointBox[{80., 0.058601436357550406`}], 
        PointBox[{80.1, 0.06177675275319526}], 
        PointBox[{80.2, 0.060938439006593396`}], 
        PointBox[{80.3, 0.06052855428111834}], 
        PointBox[{80.4, 0.06356773028063038}], 
        PointBox[{80.5, 0.06091073388333638}], 
        PointBox[{80.6, 0.05921328731330784}], 
        PointBox[{80.7, 0.06188463507144417}], 
        PointBox[{80.8, 0.0631071756847215}], 
        PointBox[{80.9, 0.06009470262766773}], 
        PointBox[{81., 0.06270276703624815}], 
        PointBox[{81.1, 0.06546052685355087}], 
        PointBox[{81.2, 0.06664257988047609}], 
        PointBox[{81.3, 0.06465687054592549}], 
        PointBox[{81.4, 0.0677955693118255}], 
        PointBox[{81.5, 0.06691426368953311}], 
        PointBox[{81.6, 0.0640286320279905}], 
        PointBox[{81.7, 0.06544521563107351}], 
        PointBox[{81.8, 0.06820062272989842}], 
        PointBox[{81.9, 0.0655359663640012}], 
        PointBox[{82., 0.06619518985012293}], 
        PointBox[{82.1, 0.06896479867774395}], 
        PointBox[{82.2, 0.0713360346721771}], 
        PointBox[{82.3, 0.06927162823739567}], 
        PointBox[{82.4, 0.07085902737925777}], 
        PointBox[{82.5, 0.0722084919767984}], 
        PointBox[{82.6, 0.06889734828685981}], 
        PointBox[{82.7, 0.06881207183978975}], 
        PointBox[{82.8, 0.07198256391185838}], 
        PointBox[{82.9, 0.07107482288282052}], 
        PointBox[{83., 0.06945261902513165}], 
        PointBox[{83.1, 0.07255547482614445}], 
        PointBox[{83.2, 0.07483829170793202}], 
        PointBox[{83.3, 0.07399270111434063}], 
        PointBox[{83.4, 0.07346296006981469}], 
        PointBox[{83.5, 0.07648750817527247}], 
        PointBox[{83.6, 0.07367319069140152}], 
        PointBox[{83.7, 0.07218020288624402}], 
        PointBox[{83.8, 0.07485134326952145}], 
        PointBox[{83.9, 0.07600119884953464}], 
        PointBox[{84., 0.07292788984018078}], 
        PointBox[{84.1, 0.07562825046956478}], 
        PointBox[{84.2, 0.07753048807185517}], 
        PointBox[{84.3, 0.0783140190910079}], 
        PointBox[{84.4, 0.07629695176785752}], 
        PointBox[{84.5, 0.07961077557615025}], 
        PointBox[{84.6, 0.07819839525976505}], 
        PointBox[{84.7, 0.0756105310272872}], 
        PointBox[{84.8, 0.07725505310236393}], 
        PointBox[{84.9, 0.07986546161805659}], 
        PointBox[{85., 0.07683906658300013}], 
        PointBox[{85.1, 0.07808150044460092}], 
        PointBox[{85.2, 0.08017522763407207}], 
        PointBox[{85.3, 0.08189928874497225}], 
        PointBox[{85.4, 0.07959375546988867}], 
        PointBox[{85.5, 0.08174994553192456}], 
        PointBox[{85.6, 0.08230178189962788}], 
        PointBox[{85.7, 0.07910161646290723}], 
        PointBox[{85.8, 0.07951637479908584}], 
        PointBox[{85.9, 0.08268506830495978}], 
        PointBox[{86., 0.08101630398032472}], 
        PointBox[{86.1, 0.08022245207022484}], 
        PointBox[{86.2, 0.08293680352927667}], 
        PointBox[{86.3, 0.08466241183913598}], 
        PointBox[{86.4, 0.0831585358620713}], 
        PointBox[{86.5, 0.08341204694540559}], 
        PointBox[{86.6, 0.0858111310059369}], 
        PointBox[{86.7, 0.08263049329420946}], 
        PointBox[{86.8, 0.08182457743502966}], 
        PointBox[{86.9, 0.08478273188867012}], 
        PointBox[{87., 0.08500981970102577}], 
        PointBox[{87.1, 0.08244652913178721}], 
        PointBox[{87.2, 0.0854024248162639}], 
        PointBox[{87.3, 0.08681830071102907}], 
        PointBox[{87.4, 0.0866656514266774}], 
        PointBox[{87.5, 0.0852070589484365}], 
        PointBox[{87.6, 0.08860100706870133}], 
        PointBox[{87.7, 0.08616137490505114}], 
        PointBox[{87.8, 0.0842796665591172}], 
        PointBox[{87.9, 0.08653637861819294}], 
        PointBox[{88., 0.08841666202042868}], 
        PointBox[{88.1, 0.08507383910818231}], 
        PointBox[{88.2, 0.08742133453595205}], 
        PointBox[{88.3, 0.08885109903369678}], 
        PointBox[{88.4, 0.08987227139067876}], 
        PointBox[{88.5, 0.08751835431227194}], 
        PointBox[{88.6, 0.09068711878529187}], 
        PointBox[{88.7, 0.0896465316632278}], 
        PointBox[{88.8, 0.08693868754753843}], 
        PointBox[{88.9, 0.08825136154497443}], 
        PointBox[{89., 0.09112649948240864}], 
        PointBox[{89.1, 0.08822151805706673}], 
        PointBox[{89.2, 0.08915981283450337}], 
        PointBox[{89.3, 0.09112355495560172}], 
        PointBox[{89.4, 0.09268179265656949}], 
        PointBox[{89.5, 0.09039304088554073}], 
        PointBox[{89.6, 0.09230735760949767}], 
        PointBox[{89.7, 0.09302628697150192}], 
        PointBox[{89.8, 0.08984110147720542}], 
        PointBox[{89.9, 0.09013798199450358}], 
        PointBox[{90., 0.09331297624951161}], 
        PointBox[{90.1, 0.09175420642281987}], 
        PointBox[{90.2, 0.09090649463150889}], 
        PointBox[{90.3, 0.09356442295663024}], 
        PointBox[{90.4, 0.09515004049696202}], 
        PointBox[{90.5, 0.09367729460066009}], 
        PointBox[{90.6, 0.0938971398624542}], 
        PointBox[{90.7, 0.09624421807662795}], 
        PointBox[{90.8, 0.09302212906030517}], 
        PointBox[{90.9, 0.09233902524952732}], 
        PointBox[{91., 0.09528493567409367}], 
        PointBox[{91.1, 0.09539503167097561}], 
        PointBox[{91.2, 0.09296994775467524}], 
        PointBox[{91.3, 0.09598963632334451}], 
        PointBox[{91.4, 0.09748446270082198}], 
        PointBox[{91.5, 0.09720406473992435}], 
        PointBox[{91.6, 0.0959232997095016}], 
        PointBox[{91.7, 0.09928315679045904}], 
        PointBox[{91.8, 0.09652031356379286}], 
        PointBox[{91.9, 0.09496067148014808}], 
        PointBox[{92., 0.09735729887439865}], 
        PointBox[{92.1, 0.09893263291870794}], 
        PointBox[{92.2, 0.09561566762020635}], 
        PointBox[{92.3, 0.0984056562745932}], 
        PointBox[{92.4, 0.09999639723442488}], 
        PointBox[{92.5, 0.1008945943788111}], 
        PointBox[{92.6, 0.09870912358954904}], 
        PointBox[{92.7, 0.10221921579225525`}], 
        PointBox[{92.8, 0.10038385143512277`}], 
        PointBox[{92.9, 0.09809895127043132}], 
        PointBox[{93., 0.0997995303634353}], 
        PointBox[{93.1, 0.1023600000450565}], 
        PointBox[{93.2, 0.09901078589737265}], 
        PointBox[{93.3, 0.10098649699588054`}], 
        PointBox[{93.4, 0.1029643814241732}], 
        PointBox[{93.5, 0.10478564391722216`}], 
        PointBox[{93.6, 0.1023827415128006}], 
        PointBox[{93.7, 0.10526316305219975`}], 
        PointBox[{93.8, 0.10468080738276421`}], 
        PointBox[{93.9, 0.1018565100339746}], 
        PointBox[{94., 0.10283569857585148`}], 
        PointBox[{94.1, 0.10587301465608859`}], 
        PointBox[{94.2, 0.10320489492603056`}], 
        PointBox[{94.3, 0.10398405956659586`}], 
        PointBox[{94.4, 0.1065399650296711}], 
        PointBox[{94.5, 0.10902517954052017`}], 
        PointBox[{94.6, 0.1069622854329606}], 
        PointBox[{94.7, 0.10875976122836714`}], 
        PointBox[{94.8, 0.10951549291735613`}], 
        PointBox[{94.9, 0.10635367804685213`}], 
        PointBox[{95., 0.10666653370938406`}], 
        PointBox[{95.1, 0.10978820456945347`}], 
        PointBox[{95.2, 0.10818000732406802`}], 
        PointBox[{95.3, 0.10767855098346386`}], 
        PointBox[{95.4, 0.1108219699532714}], 
        PointBox[{95.5, 0.11386037101115852`}], 
        PointBox[{95.6, 0.11247251265726758`}], 
        PointBox[{95.7, 0.11311447658637913`}], 
        PointBox[{95.8, 0.11504831531799574`}], 
        PointBox[{95.9, 0.11173817015801064`}], 
        PointBox[{96., 0.11149179538318647`}], 
        PointBox[{96.1, 0.11446490859570517`}], 
        PointBox[{96.2, 0.11394633241471841`}], 
        PointBox[{96.3, 0.11234982472685529`}], 
        PointBox[{96.4, 0.11597651641076027`}], 
        PointBox[{96.5, 0.11961314338719883`}], 
        PointBox[{96.6, 0.11900662753060422`}], 
        PointBox[{96.7, 0.11870910266712185`}], 
        PointBox[{96.8, 0.12150466255615297`}], 
        PointBox[{96.9, 0.11818145172288638`}], 
        PointBox[{97., 0.1175204948367923}], 
        PointBox[{97.1, 0.12025850552617076`}], 
        PointBox[{97.2, 0.1206150908008898}], 
        PointBox[{97.3, 0.11825878742521398`}], 
        PointBox[{97.4, 0.12227524722022826`}], 
        PointBox[{97.5, 0.12664352453186717`}], 
        PointBox[{97.6, 0.1267201257344041}], 
        PointBox[{97.7, 0.1258327818209837}], 
        PointBox[{97.8, 0.12915086673881343`}], 
        PointBox[{97.9, 0.1258541736782133}], 
        PointBox[{98., 0.12495647490079259`}], 
        PointBox[{98.1, 0.12748635488243049`}], 
        PointBox[{98.2, 0.12838548088618065`}], 
        PointBox[{98.3, 0.12562676956526958`}], 
        PointBox[{98.4, 0.1300639693296262}], 
        PointBox[{98.5, 0.1352667826671726}], 
        PointBox[{98.6, 0.13573694706631714`}], 
        PointBox[{98.7, 0.13462531831316624`}], 
        PointBox[{98.8, 0.13818977304093966`}], 
        PointBox[{98.9, 0.13484941730506908`}], 
        PointBox[{99., 0.1339306391356068}], 
        PointBox[{99.1, 0.13635650887085132`}], 
        PointBox[{99.2, 0.1374151012576022}], 
        PointBox[{99.3, 0.13460025679934517`}], 
        PointBox[{99.4, 0.13967971276003083`}], 
        PointBox[{99.5, 0.1455537616962485}], 
        PointBox[{99.6, 0.14595566261351864`}], 
        PointBox[{99.7, 0.1449944553531933}], 
        PointBox[{99.8, 0.14853427409383851`}], 
        PointBox[{99.9, 0.1450343838613386}], 
        PointBox[{100., 0.14435465598688157`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 0.2}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 180.}], 
        PointBox[{0.1, 198.59222752746794`}], 
        PointBox[{0.2, 196.5090021985358}], 
        PointBox[{0.3, 193.3206137301961}], 
        PointBox[{0.4, 203.2683221384529}], 
        PointBox[{0.5, 202.50462739632633`}], 
        PointBox[{0.6, 191.05341406774315`}], 
        PointBox[{0.7, 196.19558661650203`}], 
        PointBox[{0.8, 203.68206124175862`}], 
        PointBox[{0.9, 196.43806106193588`}], 
        PointBox[{1., 203.69410133867774`}], 
        PointBox[{1.1, 223.3238708220148}], 
        PointBox[{1.2, 231.6773716601227}], 
        PointBox[{1.3, 225.17809031395103`}], 
        PointBox[{1.4, 228.3888725124967}], 
        PointBox[{1.5, 235.73293309354966`}], 
        PointBox[{1.6, 228.9655678798728}], 
        PointBox[{1.7, 223.6824546005447}], 
        PointBox[{1.8, 231.30765153474857`}], 
        PointBox[{1.9, 232.433528685358}], 
        PointBox[{2., 228.10686528804075`}], 
        PointBox[{2.1, 241.57262233678094`}], 
        PointBox[{2.2, 253.1554757556623}], 
        PointBox[{2.3, 253.17355142008358`}], 
        PointBox[{2.4, 249.2479012153719}], 
        PointBox[{2.5, 255.8980820420107}], 
        PointBox[{2.6, 257.0361515427694}], 
        PointBox[{2.7, 249.35337146210466`}], 
        PointBox[{2.8, 250.71120822831398`}], 
        PointBox[{2.9, 256.68791514639435`}], 
        PointBox[{3., 252.45380844802855`}], 
        PointBox[{3.1, 256.2755750316751}], 
        PointBox[{3.2, 267.77468714884793`}], 
        PointBox[{3.3, 272.9617084983198}], 
        PointBox[{3.4, 268.8212179030581}], 
        PointBox[{3.5, 270.6919353432913}], 
        PointBox[{3.6, 275.5507995313967}], 
        PointBox[{3.7, 271.2880744092339}], 
        PointBox[{3.8, 267.70761155093544`}], 
        PointBox[{3.9, 272.5268246777708}], 
        PointBox[{4., 273.28164535563224`}], 
        PointBox[{4.1, 270.6601155719348}], 
        PointBox[{4.2, 279.63327087351274`}], 
        PointBox[{4.3, 286.87685258227174`}], 
        PointBox[{4.4, 286.46369691199266`}], 
        PointBox[{4.5, 284.1399543111751}], 
        PointBox[{4.6, 289.0253930659503}], 
        PointBox[{4.7, 288.8334404436294}], 
        PointBox[{4.8, 283.94110871174354`}], 
        PointBox[{4.9, 285.26571720100725`}], 
        PointBox[{5., 289.14377125299575`}], 
        PointBox[{5.1, 285.8457215914822}], 
        PointBox[{5.2, 289.89269362939194`}], 
        PointBox[{5.3, 297.8789944684857}], 
        PointBox[{5.4, 300.9913787657158}], 
        PointBox[{5.5, 297.8188127570164}], 
        PointBox[{5.6, 300.23508023310546`}], 
        PointBox[{5.7, 302.8858026116196}], 
        PointBox[{5.8, 299.1961141261543}], 
        PointBox[{5.9, 297.4765041177589}], PointBox[{6., 301.3426237213108}],
         PointBox[{6.1, 300.7026981297421}], 
        PointBox[{6.2, 300.1218466667371}], 
        PointBox[{6.3, 307.56132734751475`}], 
        PointBox[{6.4, 312.72437669269937`}], 
        PointBox[{6.5, 311.4886421229023}], 
        PointBox[{6.6, 310.8114434437964}], 
        PointBox[{6.7, 314.5774481479071}], 
        PointBox[{6.8, 313.0696555198516}], 
        PointBox[{6.9, 309.86215498874174`}], 
        PointBox[{7., 311.8500209380973}], 
        PointBox[{7.1, 313.97317603685036`}], 
        PointBox[{7.2, 311.40731533405494`}], 
        PointBox[{7.3, 316.43953282328243`}], 
        PointBox[{7.4, 322.6710674427037}], 
        PointBox[{7.5, 324.11526241812817`}], 
        PointBox[{7.6, 321.73469711469295`}], 
        PointBox[{7.7, 324.8090335034472}], 
        PointBox[{7.8, 325.4937629048179}], 
        PointBox[{7.9, 322.2544810167326}], PointBox[{8., 322.0515281404592}],
         PointBox[{8.1, 325.2734300555996}], 
        PointBox[{8.2, 323.39784790737787`}], 
        PointBox[{8.3, 325.07357446120966`}], 
        PointBox[{8.4, 331.6377492521135}], 
        PointBox[{8.5, 335.1982548103554}], 
        PointBox[{8.6, 333.21809271257825`}], 
        PointBox[{8.7, 334.31191400232575`}], 
        PointBox[{8.8, 336.63270654259907`}], 
        PointBox[{8.9, 334.2989515739666}], 
        PointBox[{9., 332.51292973512034`}], 
        PointBox[{9.1, 335.1417820621097}], 
        PointBox[{9.2, 335.3128786896791}], 
        PointBox[{9.3, 334.3248027010841}], 
        PointBox[{9.4, 340.0531661983764}], 
        PointBox[{9.5, 344.94817387691427`}], 
        PointBox[{9.6, 344.7192541945043}], 
        PointBox[{9.7, 343.7367096733436}], 
        PointBox[{9.8, 346.72612554322023`}], 
        PointBox[{9.9, 345.75705139735885`}], 
        PointBox[{10., 343.24055727228335`}], 
        PointBox[{10.1, 344.42150881752667`}], 
        PointBox[{10.2, 346.41996217670766`}], 
        PointBox[{10.3, 344.339753353641}], 
        PointBox[{10.4, 348.1373335740604}], 
        PointBox[{10.5, 353.787314983798}], 
        PointBox[{10.6, 355.55080388099515`}], 
        PointBox[{10.7, 353.55329140829224`}], 
        PointBox[{10.8, 356.03854427011015`}], 
        PointBox[{10.9, 356.5353394434904}], 
        PointBox[{11., 354.0230248616355}], 
        PointBox[{11.1, 353.71292388015934`}], 
        PointBox[{11.2, 356.4141304273349}], 
        PointBox[{11.3, 354.85221830718285`}], 
        PointBox[{11.4, 356.302996402512}], 
        PointBox[{11.5, 2.064359589507168}], 
        PointBox[{11.6, 5.436167196649245}], 
        PointBox[{11.7, 3.8258708557111727`}], 
        PointBox[{11.8, 4.880018678872486}], 
        PointBox[{11.9, 6.631847568981457}], 
        PointBox[{12., 4.647637007167175}], 
        PointBox[{12.1, 3.236891507239363}], 
        PointBox[{12.2, 5.518976284679042}], 
        PointBox[{12.3, 5.443168644975302}], 
        PointBox[{12.4, 4.9024641954549555`}], 
        PointBox[{12.5, 10.006923155932895`}], 
        PointBox[{12.6, 14.469790009506054`}], 
        PointBox[{12.7, 14.190301437594538`}], 
        PointBox[{12.8, 13.611196230591078`}], 
        PointBox[{12.9, 16.09161978294251}], 
        PointBox[{13., 14.971198295203884`}], 
        PointBox[{13.1, 12.96021379490472}], 
        PointBox[{13.2, 14.202757289884405`}], 
        PointBox[{13.3, 15.646930175659532`}], 
        PointBox[{13.4, 13.984775380820645`}], 
        PointBox[{13.5, 17.772566254170904`}], 
        PointBox[{13.6, 22.868633442564736`}], 
        PointBox[{13.7, 24.1802799130627}], 
        PointBox[{13.8, 22.56039790727916}], 
        PointBox[{13.9, 24.99526169505304}], 
        PointBox[{14., 24.914256931389065`}], 
        PointBox[{14.1, 22.753247834114816`}], 
        PointBox[{14.2, 22.848231461439067`}], 
        PointBox[{14.3, 25.14765961768479}], 
        PointBox[{14.4, 23.449516074125015`}], 
        PointBox[{14.5, 25.561368140194094`}], 
        PointBox[{14.6, 30.836972622681134`}], 
        PointBox[{14.7, 33.54687426028954}], 
        PointBox[{14.8, 31.865485524031357`}], 
        PointBox[{14.9, 33.471051343308424`}], 
        PointBox[{15., 34.438560544353436`}], 
        PointBox[{15.1, 32.48428958927089}], 
        PointBox[{15.2, 31.631170162766985`}], 
        PointBox[{15.3, 33.938209262169316`}], 
        PointBox[{15.4, 33.11136354014757}], 
        PointBox[{15.5, 33.55873149637832}], 
        PointBox[{15.6, 38.536831692386556`}], 
        PointBox[{15.7, 42.28038687171273}], 
        PointBox[{15.8, 41.38306142052545}], 
        PointBox[{15.9, 41.7066371812066}], PointBox[{16., 43.5312375545795}],
         PointBox[{16.1, 42.052242604479545`}], 
        PointBox[{16.2, 40.56218897837673}], 
        PointBox[{16.3, 42.25483192620995}], 
        PointBox[{16.4, 42.701340396331666`}], 
        PointBox[{16.5, 41.83229648323203}], 
        PointBox[{16.6, 46.07932405716417}], 
        PointBox[{16.7, 50.48721283029609}], 
        PointBox[{16.8, 50.79949837306693}], 
        PointBox[{16.9, 49.92379419511592}], 
        PointBox[{17., 52.19780863277708}], 
        PointBox[{17.1, 51.385114883229505`}], 
        PointBox[{17.2, 49.568183428314356`}], 
        PointBox[{17.3, 50.38154164916571}], 
        PointBox[{17.4, 51.933393977849114`}], 
        PointBox[{17.5, 50.36818298276413}], 
        PointBox[{17.6, 53.54775314636896}], 
        PointBox[{17.7, 58.29681251883334}], 
        PointBox[{17.8, 59.8441868139919}], 
        PointBox[{17.9, 58.304523304003496`}], 
        PointBox[{18., 60.467279275229934`}], 
        PointBox[{18.1, 60.43267374604051}], 
        PointBox[{18.2, 58.55349607009302}], 
        PointBox[{18.3, 58.5050085182007}], 
        PointBox[{18.4, 60.6286989739684}], 
        PointBox[{18.5, 59.101321771142636`}], 
        PointBox[{18.6, 61.02920115349855}], 
        PointBox[{18.7, 65.82381584983219}], 
        PointBox[{18.8, 68.39906045838626}], 
        PointBox[{18.9, 66.89021851184563}], 
        PointBox[{19., 68.39942748021254}], 
        PointBox[{19.1, 69.15822837084471}], 
        PointBox[{19.2, 67.42694507660761}], 
        PointBox[{19.3, 66.68657996610652}], 
        PointBox[{19.4, 68.78946726565155}], 
        PointBox[{19.5, 67.91229980835745}], 
        PointBox[{19.6, 68.58696782195904}], 
        PointBox[{19.7, 73.15616065817696}], 
        PointBox[{19.8, 76.46753087836458}], 
        PointBox[{19.9, 75.55031783872455}], 
        PointBox[{20., 76.08465539315328}], 
        PointBox[{20.1, 77.53317010578667}], 
        PointBox[{20.2, 76.10822593932994}], 
        PointBox[{20.3, 74.89371401644411}], 
        PointBox[{20.4, 76.55083254575636}], 
        PointBox[{20.5, 76.62697778201127}], 
        PointBox[{20.6, 76.23136306887511}], 
        PointBox[{20.7, 80.34447233991114}], 
        PointBox[{20.8, 84.10869979095581}], 
        PointBox[{20.9, 84.05703715077047}], 
        PointBox[{21., 83.6247697296965}], 
        PointBox[{21.1, 85.53599109895742}], 
        PointBox[{21.2, 84.52614079149583}], 
        PointBox[{21.3, 83.04416294421789}], 
        PointBox[{21.4, 84.06702140571188}], 
        PointBox[{21.5, 85.05118899427353}], 
        PointBox[{21.6, 83.9255081875682}], 
        PointBox[{21.7, 87.40417946628168}], 
        PointBox[{21.8, 91.38552788467408}], 
        PointBox[{21.9, 92.20505470842987}], 
        PointBox[{22., 91.08971998798171}], 
        PointBox[{22.1, 93.14991176795672}], 
        PointBox[{22.2, 92.61341977061738}], 
        PointBox[{22.3, 91.03335319511972}], 
        PointBox[{22.4, 91.42538622723852}], 
        PointBox[{22.5, 93.02865440927373}], 
        PointBox[{22.6, 91.59126922419347}], 
        PointBox[{22.7, 94.33041705602648}], 
        PointBox[{22.8, 98.34154410454093}], 
        PointBox[{22.9, 99.86524326581598}], 
        PointBox[{23., 98.46678583846663}], 
        PointBox[{23.1, 100.35911625646558`}], 
        PointBox[{23.2, 100.29975707843147`}], 
        PointBox[{23.3, 98.74482984225432}], 
        PointBox[{23.4, 98.62054682270774}], 
        PointBox[{23.5, 100.48028054983108`}], 
        PointBox[{23.6, 99.10988661515371}], 
        PointBox[{23.7, 101.09654035447664`}], 
        PointBox[{23.8, 104.9849492884356}], 
        PointBox[{23.9, 106.97144882788243`}], 
        PointBox[{24., 105.63688868112261`}], 
        PointBox[{24.1, 107.13826848250037`}], 
        PointBox[{24.2, 107.50421112416359`}], 
        PointBox[{24.3, 106.05112007384402`}], 
        PointBox[{24.4, 105.56528430183863`}], 
        PointBox[{24.5, 107.38737359545694`}], 
        PointBox[{24.6, 106.3230327369889}], 
        PointBox[{24.7, 107.63720860966853`}], 
        PointBox[{24.8, 111.27475207477077`}], 
        PointBox[{24.9, 113.47123162602799`}], 
        PointBox[{25., 112.39358296634202`}], 
        PointBox[{25.1, 113.4330248250509}], 
        PointBox[{25.2, 114.12383666811584`}], 
        PointBox[{25.3, 112.8051984874206}], 
        PointBox[{25.4, 112.10886546158515`}], 
        PointBox[{25.5, 113.7341292191266}], 
        PointBox[{25.6, 113.03827510931256`}], 
        PointBox[{25.7, 113.83479676528509`}], 
        PointBox[{25.8, 117.10640217301776`}], 
        PointBox[{25.9, 119.28218770163474`}], 
        PointBox[{26., 118.48529622082172`}], 
        PointBox[{26.1, 119.13884293167975`}], 
        PointBox[{26.2, 120.02031650607012`}], 
        PointBox[{26.3, 118.83017958768768`}], 
        PointBox[{26.4, 118.05205913771502`}], 
        PointBox[{26.5, 119.45187763804525`}], 
        PointBox[{26.6, 119.03587104873674`}], 
        PointBox[{26.7, 119.51485431858396`}], 
        PointBox[{26.8, 122.2977084524687}], 
        PointBox[{26.9, 124.26234391914139`}], 
        PointBox[{27., 123.6461199718212}], 
        PointBox[{27.1, 124.08989918496539`}], 
        PointBox[{27.2, 125.0095892462075}], 
        PointBox[{27.3, 123.91419597152435`}], 
        PointBox[{27.4, 123.15656918309654`}], 
        PointBox[{27.5, 124.39354462915983`}], 
        PointBox[{27.6, 124.07220935353466`}], 
        PointBox[{27.7, 124.4422152424226}], 
        PointBox[{27.8, 126.59054891070994`}], 
        PointBox[{27.9, 128.21394435436093`}], 
        PointBox[{28., 127.61681065548679`}], 
        PointBox[{28.1, 128.08078938810021`}], 
        PointBox[{28.2, 128.86933369650012`}], 
        PointBox[{28.3, 127.82817457018194`}], 
        PointBox[{28.4, 127.1755290246564}], 
        PointBox[{28.5, 128.35569902628174`}], 
        PointBox[{28.6, 127.89588558889476`}], 
        PointBox[{28.7, 128.30588727222369`}], 
        PointBox[{28.8, 129.71756921128994`}], 
        PointBox[{28.9, 130.9408322220951}], 
        PointBox[{29., 130.20409551558168`}], 
        PointBox[{29.1, 130.93882727825476`}], 
        PointBox[{29.2, 131.40153093976232`}], 
        PointBox[{29.3, 130.3987979466419}], 
        PointBox[{29.4, 129.93101359539605`}], 
        PointBox[{29.5, 131.14700107195358`}], 
        PointBox[{29.6, 130.3325245957181}], 
        PointBox[{29.7, 130.72226804446942`}], 
        PointBox[{29.8, 131.5612437062582}], 
        PointBox[{29.9, 132.36311339415244`}], 
        PointBox[{30., 131.41481370371324`}], 
        PointBox[{30.1, 132.60100999408618`}], 
        PointBox[{30.2, 132.55754802120887`}], 
        PointBox[{30.3, 131.63087709646658`}], 
        PointBox[{30.4, 131.43959697344937`}], 
        PointBox[{30.5, 132.6591073159383}], 
        PointBox[{30.6, 131.4484488566003}], 
        PointBox[{30.7, 131.60847407465667`}], 
        PointBox[{30.8, 132.25650241928213`}], 
        PointBox[{30.9, 132.58783813988376`}], 
        PointBox[{31., 131.6174697964759}], 
        PointBox[{31.1, 133.1071826426894}], 
        PointBox[{31.2, 132.5384545839189}], 
        PointBox[{31.3, 131.77850070106683`}], 
        PointBox[{31.4, 131.97044812725076`}], 
        PointBox[{31.5, 132.82272761023555`}], 
        PointBox[{31.6, 131.46288580290482`}], 
        PointBox[{31.7, 131.53732898288035`}], 
        PointBox[{31.8, 132.08124237223586`}], 
        PointBox[{31.9, 131.84799679309876`}], 
        PointBox[{32., 131.48917771244683`}], 
        PointBox[{32.1, 132.58690007794374`}], 
        PointBox[{32.2, 131.73203824272235`}], 
        PointBox[{32.3, 131.25308962728494`}], 
        PointBox[{32.4, 131.90850327813547`}], 
        PointBox[{32.5, 131.6720402809635}], 
        PointBox[{32.6, 130.624668161868}], 
        PointBox[{32.7, 130.98916806239106`}], 
        PointBox[{32.8, 131.27153823805602`}], 
        PointBox[{32.9, 130.46758273302777`}], 
        PointBox[{33., 131.3147631025273}], 
        PointBox[{33.1, 131.33871268765182`}], 
        PointBox[{33.2, 130.54023065759884`}], 
        PointBox[{33.3, 130.45234705854628`}], 
        PointBox[{33.4, 131.39339217569835`}], 
        PointBox[{33.5, 129.86671234895218`}], 
        PointBox[{33.6, 129.68569568819333`}], 
        PointBox[{33.7, 130.11190519850166`}], 
        PointBox[{33.8, 129.95576103934985`}], 
        PointBox[{33.9, 129.0900849785577}], 
        PointBox[{34., 130.547691843507}], 
        PointBox[{34.1, 129.76462860882833`}], 
        PointBox[{34.2, 129.26619359051858`}], 
        PointBox[{34.3, 129.6411087227142}], 
        PointBox[{34.4, 129.95627698455172`}], 
        PointBox[{34.5, 128.25298879233145`}], 
        PointBox[{34.6, 128.75117320118343`}], 
        PointBox[{34.7, 128.9274617378178}], 
        PointBox[{34.8, 128.2481882241948}], 
        PointBox[{34.9, 128.4637120588812}], 
        PointBox[{35., 129.0188537896184}], 
        PointBox[{35.1, 128.1846330550703}], 
        PointBox[{35.2, 128.09364714241045`}], 
        PointBox[{35.3, 128.81806694890486`}], 
        PointBox[{35.4, 127.49221227993154`}], 
        PointBox[{35.5, 127.18835081878615`}], 
        PointBox[{35.6, 127.66853133163238`}], 
        PointBox[{35.7, 127.43638648204175`}], 
        PointBox[{35.8, 126.51873776579166`}], 
        PointBox[{35.9, 127.91640747114324`}], 
        PointBox[{36., 127.23312155000204`}], 
        PointBox[{36.1, 126.77150252093088`}], 
        PointBox[{36.2, 127.0864639524517}], 
        PointBox[{36.3, 127.45571614288392`}], 
        PointBox[{36.4, 125.54978449479049`}], 
        PointBox[{36.5, 126.24277861642383`}], 
        PointBox[{36.6, 126.3677197054971}], 
        PointBox[{36.7, 125.70046325622798`}], 
        PointBox[{36.8, 125.50847702044945`}], 
        PointBox[{36.9, 126.48403633052044`}], 
        PointBox[{37., 125.60074863937507`}], 
        PointBox[{37.1, 125.58293866691228`}], 
        PointBox[{37.2, 126.13240705232427`}], 
        PointBox[{37.3, 125.07436630164443`}], 
        PointBox[{37.4, 124.55703752660409`}], 
        PointBox[{37.5, 125.16116189977708`}], 
        PointBox[{37.6, 124.86465016598756`}], 
        PointBox[{37.7, 123.97520953037504`}], 
        PointBox[{37.8, 125.11215590550356`}], 
        PointBox[{37.9, 124.6934648441113}], 
        PointBox[{38., 124.2643943454307}], 
        PointBox[{38.1, 124.59198838612944`}], 
        PointBox[{38.2, 124.84027830922032`}], 
        PointBox[{38.3, 122.99926342843654`}], 
        PointBox[{38.4, 123.78170481522386`}], 
        PointBox[{38.5, 123.93564753849995`}], 
        PointBox[{38.6, 123.27182292126858`}], 
        PointBox[{38.7, 122.77154506679229`}], 
        PointBox[{38.8, 124.12065278722771`}], 
        PointBox[{38.9, 123.16380506065488`}], 
        PointBox[{39., 123.24403888838073`}], 
        PointBox[{39.1, 123.68728412860503`}], 
        PointBox[{39.2, 123.0844205777157}], 
        PointBox[{39.3, 122.10300633049033`}], 
        PointBox[{39.4, 122.98372675104005`}], 
        PointBox[{39.5, 122.69909071945494`}], 
        PointBox[{39.6, 121.83443984670811`}], 
        PointBox[{39.7, 122.36965568665858`}], 
        PointBox[{39.8, 122.66863975555938`}], 
        PointBox[{39.9, 122.10504139353287`}], 
        PointBox[{40., 122.54771253931867`}], 
        PointBox[{40.1, 122.76988986940393`}], 
        PointBox[{40.2, 121.54548160865302`}], 
        PointBox[{40.3, 121.86788797908054`}], 
        PointBox[{40.4, 122.3268504786723}], 
        PointBox[{40.5, 121.70241460918949`}], 
        PointBox[{40.6, 120.92935568949554`}], 
        PointBox[{40.7, 122.303501781363}], 
        PointBox[{40.8, 121.58993797656194`}], 
        PointBox[{40.9, 121.62447226224009`}], 
        PointBox[{41., 122.2538263873503}], 
        PointBox[{41.1, 122.36006812088097`}], 
        PointBox[{41.2, 121.04954078105216`}], 
        PointBox[{41.3, 122.13606020064933`}], 
        PointBox[{41.4, 122.16403572271284`}], 
        PointBox[{41.5, 121.31203248364925`}], 
        PointBox[{41.6, 120.93428613090843`}], 
        PointBox[{41.7, 122.37283538868789`}], 
        PointBox[{41.8, 121.35340971612402`}], 
        PointBox[{41.9, 121.9105031509122}], 
        PointBox[{42., 122.6615514276052}], 
        PointBox[{42.1, 123.04478964594871`}], 
        PointBox[{42.2, 121.9516613648459}], 
        PointBox[{42.3, 123.21898281615631`}], 
        PointBox[{42.4, 122.9213363835544}], 
        PointBox[{42.5, 121.9430277993686}], 
        PointBox[{42.6, 122.07221284245348`}], 
        PointBox[{42.7, 123.14578843671768`}], 
        PointBox[{42.8, 122.23465272906711`}], 
        PointBox[{42.9, 123.23642276510753`}], 
        PointBox[{43., 124.37013491997538`}], 
        PointBox[{43.1, 124.94850322743001`}], 
        PointBox[{43.2, 124.1972925396676}], 
        PointBox[{43.3, 125.45918274584704`}], 
        PointBox[{43.4, 124.93807707468937`}], 
        PointBox[{43.5, 123.89516621099443`}], 
        PointBox[{43.6, 124.42240269906355`}], 
        PointBox[{43.7, 125.16552646464044`}], 
        PointBox[{43.8, 124.40589105646401`}], 
        PointBox[{43.9, 125.81356563092677`}], 
        PointBox[{44., 127.63774606802616`}], 
        PointBox[{44.1, 128.2271356676468}], 
        PointBox[{44.2, 127.68589797824758`}], 
        PointBox[{44.3, 128.97783048992997`}], 
        PointBox[{44.4, 128.32180858772352`}], 
        PointBox[{44.5, 127.2232320206912}], 
        PointBox[{44.6, 127.95739595059325`}], 
        PointBox[{44.7, 128.589649258251}], 
        PointBox[{44.8, 127.86285596590707`}], 
        PointBox[{44.9, 129.62710159245574`}], 
        PointBox[{45., 132.1438058142243}], 
        PointBox[{45.1, 132.79598571106894`}], 
        PointBox[{45.2, 132.24632260566113`}], 
        PointBox[{45.3, 133.66098593019666`}], 
        PointBox[{45.4, 132.9573329149018}], 
        PointBox[{45.5, 131.77614626078847`}], 
        PointBox[{45.6, 132.5352733077435}], 
        PointBox[{45.7, 133.29134612900083`}], 
        PointBox[{45.8, 132.44469890251492`}], 
        PointBox[{45.9, 134.45607692900072`}], 
        PointBox[{46., 137.52427227241398`}], 
        PointBox[{46.1, 138.42306147763875`}], 
        PointBox[{46.2, 137.67086902666918`}], 
        PointBox[{46.3, 139.27690985535696`}], 
        PointBox[{46.4, 138.62629883294272`}], 
        PointBox[{46.5, 137.33079743138887`}], 
        PointBox[{46.6, 137.9539883957969}], 
        PointBox[{46.7, 139.0226433673761}], 
        PointBox[{46.8, 137.94547296814332`}], 
        PointBox[{46.9, 140.02961158541376`}], 
        PointBox[{47., 143.50880540404162`}], 
        PointBox[{47.1, 144.85418308506038`}], 
        PointBox[{47.2, 143.79039198023878`}], 
        PointBox[{47.3, 145.57817209905113`}], 
        PointBox[{47.4, 145.10416330679342`}], 
        PointBox[{47.5, 143.68279160000517`}], 
        PointBox[{47.6, 144.0291424879108}], 
        PointBox[{47.7, 145.50949766471658`}], 
        PointBox[{47.8, 144.19901663134172`}], 
        PointBox[{47.9, 146.13451828040235`}], 
        PointBox[{48., 149.89947510153365`}], 
        PointBox[{48.1, 151.85616870745525`}], 
        PointBox[{48.2, 150.50925487840482`}], 
        PointBox[{48.3, 152.3486312979671}], 
        PointBox[{48.4, 152.19796949033034`}], 
        PointBox[{48.5, 150.67402976135628`}], 
        PointBox[{48.6, 150.63481363486514`}], 
        PointBox[{48.7, 152.48901663091632`}], 
        PointBox[{48.8, 151.0998855103414}], 
        PointBox[{48.9, 152.63818078312983`}], 
        PointBox[{49., 156.5599946176563}], 
        PointBox[{49.1, 159.2247424835156}], 
        PointBox[{49.2, 157.79294798083845`}], 
        PointBox[{49.3, 159.4207185611757}], 
        PointBox[{49.4, 159.7479201808729}], 
        PointBox[{49.5, 158.1868493127902}], 
        PointBox[{49.6, 157.69854363737437`}], 
        PointBox[{49.7, 159.73912527275888`}], 
        PointBox[{49.8, 158.58238027209086`}], 
        PointBox[{49.9, 159.4782828625688}], 
        PointBox[{50., 163.4088937031459}], 
        PointBox[{50.1, 166.79018354416868`}], 
        PointBox[{50.2, 165.61771098210957`}], 
        PointBox[{50.3, 166.68831279014947`}], 
        PointBox[{50.4, 167.6174423842462}], 
        PointBox[{50.5, 166.1305584409864}], 
        PointBox[{50.6, 165.1831206861488}], 
        PointBox[{50.7, 167.11800078382183`}], 
        PointBox[{50.8, 166.57888289846957`}], 
        PointBox[{50.9, 166.6471227216381}], 
        PointBox[{51., 170.40725401491235`}], 
        PointBox[{51.1, 174.42232496098381`}], 
        PointBox[{51.2, 173.91280737778246`}], 
        PointBox[{51.3, 174.12450872736926`}], 
        PointBox[{51.4, 175.68459745382032`}], 
        PointBox[{51.5, 174.42980165073416`}], 
        PointBox[{51.6, 173.0671754958147}], 
        PointBox[{51.7, 174.58869792109607`}], 
        PointBox[{51.8, 174.97138816770735`}], 
        PointBox[{51.9, 174.17737548719282`}], 
        PointBox[{52., 177.54208208745973`}], 
        PointBox[{52.1, 182.03177258723227`}], 
        PointBox[{52.2, 182.5340422868049}], 
        PointBox[{52.3, 181.79482459621815`}], 
        PointBox[{52.4, 183.8388552073623}], 
        PointBox[{52.5, 183.0143255051716}], 
        PointBox[{52.6, 181.3316850927416}], 
        PointBox[{52.7, 182.20161475140057`}], 
        PointBox[{52.8, 183.565337914654}], 
        PointBox[{52.9, 182.12663240007208`}], 
        PointBox[{53., 184.82065940724996`}], 
        PointBox[{53.1, 189.5702840308904}], 
        PointBox[{53.2, 191.2927589597748}], 
        PointBox[{53.3, 189.84094185012864`}], 
        PointBox[{53.4, 191.99068537456944`}], 
        PointBox[{53.5, 191.81331087926512`}], 
        PointBox[{53.6, 189.95514984635682`}], 
        PointBox[{53.7, 190.05100488061527`}], 
        PointBox[{53.8, 192.13250494812894`}], 
        PointBox[{53.9, 190.5554758295154}], 
        PointBox[{54., 192.28486805446929`}], 
        PointBox[{54.1, 197.03665399709948`}], 
        PointBox[{54.2, 200.01005596919052`}], 
        PointBox[{54.3, 198.40498393356305`}], 
        PointBox[{54.4, 200.09316892189602`}], 
        PointBox[{54.5, 200.74690364069727`}], 
        PointBox[{54.6, 198.90982857485062`}], 
        PointBox[{54.7, 198.22655302974152`}], 
        PointBox[{54.8, 200.51707941757667`}], 
        PointBox[{54.9, 199.48168877083916`}], 
        PointBox[{55., 200.01389389418574`}], 
        PointBox[{55.1, 204.48185980595636`}], 
        PointBox[{55.2, 208.5561238618666}], 
        PointBox[{55.3, 207.51826017015685`}], 
        PointBox[{55.4, 208.18483905462608`}], 
        PointBox[{55.5, 209.72550447464985`}], 
        PointBox[{55.6, 208.16101560205325`}], 
        PointBox[{55.7, 206.79194893234703`}], 
        PointBox[{55.8, 208.72695752965814`}], 
        PointBox[{55.9, 208.81433575365176`}], 
        PointBox[{56., 208.11723391014183`}], 
        PointBox[{56.1, 211.98932479799228`}], 
        PointBox[{56.2, 216.85573407043347`}], 
        PointBox[{56.3, 217.0345324024838}], 
        PointBox[{56.4, 216.42645771681822`}], 
        PointBox[{56.5, 218.65242347087596`}], 
        PointBox[{56.6, 217.66201781289575`}], 
        PointBox[{56.7, 215.78098337157434`}], 
        PointBox[{56.8, 216.9216505117836}], 
        PointBox[{56.9, 218.31062367657546`}], 
        PointBox[{57., 216.7228381491092}], 
        PointBox[{57.1, 219.63998929107544`}], 
        PointBox[{57.2, 224.8834278342494}], 
        PointBox[{57.3, 226.68056314332253`}], 
        PointBox[{57.4, 225.08842270753723`}], 
        PointBox[{57.5, 227.44637488806018`}], 
        PointBox[{57.6, 227.34588833235117`}], 
        PointBox[{57.7, 225.20323454686456`}], 
        PointBox[{57.8, 225.31929460502127`}], 
        PointBox[{57.9, 227.65195002500232`}], 
        PointBox[{58., 225.94659942711368`}], 
        PointBox[{58.1, 227.53497209394865`}], 
        PointBox[{58.2, 232.6858275510095}], 
        PointBox[{58.3, 236.17869414984355`}], 
        PointBox[{58.4, 234.42938324750787`}], 
        PointBox[{58.5, 236.0942460617557}], 
        PointBox[{58.6, 237.1168337628422}], 
        PointBox[{58.7, 235.04937181923705`}], 
        PointBox[{58.8, 234.1145645538436}], 
        PointBox[{58.9, 236.64797085851774`}], 
        PointBox[{59., 235.81121779529798`}], 
        PointBox[{59.1, 235.825248773512}], 
        PointBox[{59.2, 240.4268642767799}], 
        PointBox[{59.3, 245.32608734154294`}], 
        PointBox[{59.4, 244.49955203329074`}], 
        PointBox[{59.5, 244.73317803369315`}], 
        PointBox[{59.6, 246.84810424081314`}], 
        PointBox[{59.7, 245.28802337794434`}], 
        PointBox[{59.8, 243.4462751265651}], 
        PointBox[{59.9, 245.38398809618695`}], 
        PointBox[{60., 246.11968108716587`}], 
        PointBox[{60.1, 244.7085053521683}], 
        PointBox[{60.2, 248.31483656380004`}], 
        PointBox[{60.3, 254.00512343940437`}], 
        PointBox[{60.4, 255.03665459609596`}], 
        PointBox[{60.5, 253.70865538097408`}], 
        PointBox[{60.6, 256.40424961400583`}], 
        PointBox[{60.7, 255.85017755887034`}], 
        PointBox[{60.8, 253.40341507814557`}], 
        PointBox[{60.9, 254.16337674530473`}], 
        PointBox[{61., 256.4327731579391}], 
        PointBox[{61.1, 254.4062257356753}], 
        PointBox[{61.2, 256.5059524547057}], 
        PointBox[{61.3, 262.22358483654824`}], 
        PointBox[{61.4, 265.58756360110215`}], 
        PointBox[{61.5, 263.49251520565105`}], 
        PointBox[{61.6, 265.7217231689858}], 
        PointBox[{61.7, 266.6061490634028}], 
        PointBox[{61.8, 264.03871966159306`}], 
        PointBox[{61.9, 263.34817556628644`}], 
        PointBox[{62., 266.33468739658986`}], 
        PointBox[{62.1, 265.0545720516768}], 
        PointBox[{62.2, 265.2065446964616}], 
        PointBox[{62.3, 270.2754622868448}], 
        PointBox[{62.4, 275.7128829070936}], 
        PointBox[{62.5, 274.3848502208965}], 
        PointBox[{62.6, 274.9591196225035}], 
        PointBox[{62.7, 277.35360536240216`}], 
        PointBox[{62.8, 275.3625003886398}], 
        PointBox[{62.9, 273.2606785850125}], 
        PointBox[{63., 275.7967653672114}], 
        PointBox[{63.1, 276.4647688815903}], 
        PointBox[{63.2, 274.7437902209206}], 
        PointBox[{63.3, 278.60392679329846`}], 
        PointBox[{63.4, 285.1063971140325}], 
        PointBox[{63.5, 286.18935330211235`}], 
        PointBox[{63.6, 284.6447553988945}], 
        PointBox[{63.7, 287.86908399705277`}], 
        PointBox[{63.8, 287.30549377859745`}], 
        PointBox[{63.9, 284.1741615049573}], 
        PointBox[{64., 285.2282032422707}], 
        PointBox[{64.1, 288.0036480153041}], 
        PointBox[{64.2, 285.5402427433256}], 
        PointBox[{64.3, 287.43947682274273`}], 
        PointBox[{64.4, 293.79887850184986`}], 
        PointBox[{64.5, 298.22900652860903`}], 
        PointBox[{64.6, 295.6093340557365}], 
        PointBox[{64.7, 298.0930223669639}], 
        PointBox[{64.8, 299.6593078177371}], 
        PointBox[{64.9, 296.337826735025}], 
        PointBox[{65., 295.26090885617816`}], 
        PointBox[{65.1, 299.04097549159235`}], 
        PointBox[{65.2, 297.88855295906876`}], 
        PointBox[{65.3, 297.148147589556}], 
        PointBox[{65.4, 302.56144579873813`}], 
        PointBox[{65.5, 309.69901031857285`}], 
        PointBox[{65.6, 308.5116215855239}], 
        PointBox[{65.7, 308.4612138012727}], 
        PointBox[{65.8, 312.0789642086343}], 
        PointBox[{65.9, 309.94537774804195`}], 
        PointBox[{66., 306.61373173289667`}], 
        PointBox[{66.1, 309.6271392860596}], 
        PointBox[{66.2, 311.450123593208}], 
        PointBox[{66.3, 308.4726345905437}], 
        PointBox[{66.4, 312.07919377946723`}], 
        PointBox[{66.5, 320.10553229870396`}], 
        PointBox[{66.6, 323.17432589925636`}], 
        PointBox[{66.7, 320.2105966580491}], 
        PointBox[{66.8, 324.3210892617115}], 
        PointBox[{66.9, 324.9944162377418}], 
        PointBox[{67., 320.15844258071667`}], 
        PointBox[{67.1, 320.6203176285491}], 
        PointBox[{67.2, 325.21229878301716`}], 
        PointBox[{67.3, 322.4381216907158}], 
        PointBox[{67.4, 322.76402759272946`}], 
        PointBox[{67.5, 330.22156246809186`}], 
        PointBox[{67.6, 338.4563632023538}], 
        PointBox[{67.7, 335.28595414209707`}], 
        PointBox[{67.8, 336.8660900220157}], 
        PointBox[{67.9, 341.1394423095275}], 
        PointBox[{68., 337.0224054836968}], 
        PointBox[{68.1, 333.5331606636622}], 
        PointBox[{68.2, 338.6805993790142}], 
        PointBox[{68.3, 339.61364066313405`}], 
        PointBox[{68.4, 335.98994781628153`}], 
        PointBox[{68.5, 341.7681337124199}], 
        PointBox[{68.6, 353.0785662786994}], 
        PointBox[{68.7, 355.3188480381027}], 
        PointBox[{68.8, 351.8892107808059}], 
        PointBox[{68.9, 358.0485410518129}], 
        PointBox[{69., 358.2709767828259}], 
        PointBox[{69.1, 350.9083712044727}], 
        PointBox[{69.2, 353.07821608763686`}], 
        PointBox[{69.3, 359.0633131818279}], 
        PointBox[{69.4, 354.54385695821895`}], 
        PointBox[{69.5, 355.7680275752664}], 
        PointBox[{69.6, 7.578113113870174}], 
        PointBox[{69.7, 19.498062763239137`}], 
        PointBox[{69.8, 14.322011574672391`}], 
        PointBox[{69.9, 16.881615574048677`}], 
        PointBox[{70., 23.63979504908477}], 
        PointBox[{70.1, 17.149286991887863`}], 
        PointBox[{70.2, 11.95278306953286}], 
        PointBox[{70.3, 19.767335770113878`}], 
        PointBox[{70.4, 21.366289519713284`}], 
        PointBox[{70.5, 15.671499628294804`}], 
        PointBox[{70.6, 25.17124386707269}], 
        PointBox[{70.7, 44.34391546757328}], 
        PointBox[{70.8, 49.010752844626595`}], 
        PointBox[{70.9, 42.695545360800274`}], 
        PointBox[{71., 51.149458400441674`}], 
        PointBox[{71.1, 54.41024196863606}], 
        PointBox[{71.2, 42.58141613551959}], 
        PointBox[{71.3, 43.979854429753615`}], 
        PointBox[{71.4, 53.46240725041435}], 
        PointBox[{71.5, 48.546222957252084`}], 
        PointBox[{71.6, 48.6409256669379}], 
        PointBox[{71.7, 68.28744113655456}], 
        PointBox[{71.8, 85.69845165523341}], 
        PointBox[{71.9, 81.58367396607571}], 
        PointBox[{72., 80.35751360624153}], 
        PointBox[{72.1, 90.48096144202538}], 
        PointBox[{72.2, 87.43530796392054}], 
        PointBox[{72.3, 76.81713060553845}], 
        PointBox[{72.4, 83.66614880094701}], 
        PointBox[{72.5, 89.88743550989838}], 
        PointBox[{72.6, 82.1670911019606}], 
        PointBox[{72.7, 92.02744718580254}], 
        PointBox[{72.8, 112.01922842584437`}], 
        PointBox[{72.9, 119.0441502927585}], 
        PointBox[{73., 112.03783120206963`}], 
        PointBox[{73.1, 116.81943647588433`}], 
        PointBox[{73.2, 123.49700323933007`}], 
        PointBox[{73.3, 115.2286911986805}], 
        PointBox[{73.4, 111.358716972634}], 
        PointBox[{73.5, 119.67432981360763`}], 
        PointBox[{73.6, 119.26289525741477`}], 
        PointBox[{73.7, 116.1497591549836}], 
        PointBox[{73.8, 131.0166531755609}], 
        PointBox[{73.9, 142.28105849145234`}], 
        PointBox[{74., 141.05572308435518`}], 
        PointBox[{74.1, 137.93025511947982`}], 
        PointBox[{74.2, 145.107609002116}], 
        PointBox[{74.3, 145.12735318954577`}], 
        PointBox[{74.4, 137.29402083555726`}], 
        PointBox[{74.5, 139.7968328278866}], 
        PointBox[{74.6, 145.4130755401381}], 
        PointBox[{74.7, 140.54341099926057`}], 
        PointBox[{74.8, 146.01248375110188`}], 
        PointBox[{74.9, 157.56467903040308`}], 
        PointBox[{75., 162.0502650851489}], 
        PointBox[{75.1, 157.53284814647594`}], 
        PointBox[{75.2, 160.33198572478113`}], 
        PointBox[{75.3, 164.79442217820156`}], 
        PointBox[{75.4, 159.7999407939275}], 
        PointBox[{75.5, 156.86060792146174`}], 
        PointBox[{75.6, 162.13390556164686`}], 
        PointBox[{75.7, 162.01134588121323`}], 
        PointBox[{75.8, 160.12849199908888`}], 
        PointBox[{75.9, 169.7000179337725}], 
        PointBox[{76., 176.65567761847365`}], 
        PointBox[{76.1, 175.49680928971034`}], 
        PointBox[{76.2, 173.7384968304038}], 
        PointBox[{76.3, 178.81731917678698`}], 
        PointBox[{76.4, 177.94242004222122`}], 
        PointBox[{76.5, 173.08935617317098`}], 
        PointBox[{76.6, 175.0671511955082}], 
        PointBox[{76.7, 178.59708176092326`}], 
        PointBox[{76.8, 175.0915747707326}], 
        PointBox[{76.9, 180.1090546436051}], 
        PointBox[{77., 187.96082063655163`}], 
        PointBox[{77.1, 190.50758462759399`}], 
        PointBox[{77.2, 187.24802886984742`}], 
        PointBox[{77.3, 190.2256703651414}], 
        PointBox[{77.4, 192.44594321884097`}], 
        PointBox[{77.5, 188.4450382125505}], 
        PointBox[{77.6, 187.19852187660572`}], 
        PointBox[{77.7, 191.23501660318755`}], 
        PointBox[{77.8, 190.0053818718016}], 
        PointBox[{77.9, 190.1385986600243}], 
        PointBox[{78., 197.7746225134319}], 
        PointBox[{78.1, 202.6181073314913}], 
        PointBox[{78.2, 200.907883155998}], 
        PointBox[{78.3, 200.76682618829696`}], 
        PointBox[{78.4, 204.43815848164365`}], 
        PointBox[{78.5, 202.4988169074789}], 
        PointBox[{78.6, 199.47324991495262`}], 
        PointBox[{78.7, 201.86968204082237`}], 
        PointBox[{78.8, 203.55275872091906`}], 
        PointBox[{78.9, 201.15368773043565`}], 
        PointBox[{79., 206.74626956100684`}], 
        PointBox[{79.1, 212.78205041313564`}], 
        PointBox[{79.2, 213.72503549258698`}], 
        PointBox[{79.3, 211.52089571811186`}], 
        PointBox[{79.4, 214.84150869475312`}], 
        PointBox[{79.5, 215.11896235498511`}], 
        PointBox[{79.6, 211.81896446799513`}], 
        PointBox[{79.7, 212.01226929323926`}], 
        PointBox[{79.8, 215.1525212869169}], 
        PointBox[{79.9, 212.99253971947365`}], 
        PointBox[{80., 215.31360633026637`}], 
        PointBox[{80.1, 221.85761095863356`}], 
        PointBox[{80.2, 225.05047831902255`}], 
        PointBox[{80.3, 222.85929903196168`}], 
        PointBox[{80.4, 224.3932461591375}], 
        PointBox[{80.5, 226.4362453541381}], 
        PointBox[{80.6, 223.88736540089135`}], 
        PointBox[{80.7, 222.36019426792507`}], 
        PointBox[{80.8, 225.19042044116372`}], 
        PointBox[{80.9, 224.92158151532195`}], 
        PointBox[{81., 224.36784540156793`}], 
        PointBox[{81.1, 230.33442194658306`}], 
        PointBox[{81.2, 234.9884321443473}], 
        PointBox[{81.3, 234.35874702134424`}], 
        PointBox[{81.4, 233.74673918135142`}], 
        PointBox[{81.5, 236.6756546939639}], 
        PointBox[{81.6, 235.41282120484158`}], 
        PointBox[{81.7, 232.99671278854672`}], 
        PointBox[{81.8, 234.48978734040165`}], 
        PointBox[{81.9, 236.17904465400932`}], 
        PointBox[{82., 234.19486082522383`}], 
        PointBox[{82.1, 238.43640628914198`}], 
        PointBox[{82.2, 243.9464729257965}], 
        PointBox[{82.3, 245.3115934941317}], 
        PointBox[{82.4, 243.4169675019478}], 
        PointBox[{82.5, 246.08878614268588`}], 
        PointBox[{82.6, 246.27835470555425`}], 
        PointBox[{82.7, 243.73239658569958`}], 
        PointBox[{82.8, 243.7113172881862}], 
        PointBox[{82.9, 246.35534443588}], 
        PointBox[{83., 244.58087345291935`}], 
        PointBox[{83.1, 246.5196170472195}], 
        PointBox[{83.2, 252.28978948224056`}], 
        PointBox[{83.3, 255.34845729229133`}], 
        PointBox[{83.4, 253.56262787260727`}], 
        PointBox[{83.5, 254.96655201791305`}], 
        PointBox[{83.6, 256.46799283168036`}], 
        PointBox[{83.7, 254.3485837800199}], 
        PointBox[{83.8, 253.14136133686247`}], 
        PointBox[{83.9, 255.57427300043057`}], 
        PointBox[{84., 255.13932398357528`}], 
        PointBox[{84.1, 254.98098391205576`}], 
        PointBox[{84.2, 260.2657933728643}], 
        PointBox[{84.3, 264.5070250598489}], 
        PointBox[{84.4, 263.8942740998545}], 
        PointBox[{84.5, 263.65307677292515`}], 
        PointBox[{84.6, 266.016646555221}], 
        PointBox[{84.7, 264.6887414545787}], 
        PointBox[{84.8, 262.7835971650463}], 
        PointBox[{84.9, 264.273369225089}], 
        PointBox[{85., 265.4094193552443}], 
        PointBox[{85.1, 263.9187196668788}], 
        PointBox[{85.2, 268.0320953983134}], 
        PointBox[{85.3, 272.9917021167648}], 
        PointBox[{85.4, 273.9431268608141}], 
        PointBox[{85.5, 272.48829995949745`}], 
        PointBox[{85.6, 274.9949533790317}], 
        PointBox[{85.7, 274.6642015060921}], 
        PointBox[{85.8, 272.5192046666597}], 
        PointBox[{85.9, 272.86581309592964`}], 
        PointBox[{86., 275.03173259604347`}], 
        PointBox[{86.1, 273.2569302813052}], 
        PointBox[{86.2, 275.7693289928996}], 
        PointBox[{86.3, 281.0109724435779}], 
        PointBox[{86.4, 283.406216935659}], 
        PointBox[{86.5, 281.66120105327377`}], 
        PointBox[{86.6, 283.5152484707216}], 
        PointBox[{86.7, 284.23062432061124`}], 
        PointBox[{86.8, 282.2148208797057}], 
        PointBox[{86.9, 281.5667984682897}], 
        PointBox[{87., 283.9268912887509}], 
        PointBox[{87.1, 282.83280564778676`}], 
        PointBox[{87.2, 283.67198487323697`}], 
        PointBox[{87.3, 288.73311254021297`}], 
        PointBox[{87.4, 292.2306278878077}], 
        PointBox[{87.5, 291.0905646119726}], 
        PointBox[{87.6, 291.74484751438024`}], 
        PointBox[{87.7, 293.37009128100607`}], 
        PointBox[{87.8, 291.762533882442}], 
        PointBox[{87.9, 290.41345359096135`}], 
        PointBox[{88., 292.28494635999067`}], 
        PointBox[{88.1, 292.4006338146313}], 
        PointBox[{88.2, 291.82970107682786`}], 
        PointBox[{88.3, 296.27652853883995`}], 
        PointBox[{88.4, 300.505541596462}], 
        PointBox[{88.5, 300.4897540283227}], 
        PointBox[{88.6, 299.89424949072475`}], 
        PointBox[{88.7, 302.0833162035308}], 
        PointBox[{88.8, 301.0854860423626}], 
        PointBox[{88.9, 299.3446957186074}], 
        PointBox[{89., 300.3868280979052}], 
        PointBox[{89.1, 301.67647121876274`}], 
        PointBox[{89.2, 300.2410254023432}], 
        PointBox[{89.3, 303.72151689510315`}], 
        PointBox[{89.4, 308.35673502320316`}], 
        PointBox[{89.5, 309.56919422244164`}], 
        PointBox[{89.6, 308.1546312524153}], 
        PointBox[{89.7, 310.3910700087329}], 
        PointBox[{89.8, 310.1293890872903}], 
        PointBox[{89.9, 308.2660096891274}], 
        PointBox[{90., 308.4416105350521}], 
        PointBox[{90.1, 310.44953775565625`}], 
        PointBox[{90.2, 308.85163164012715`}], 
        PointBox[{90.3, 311.1467592925006}], 
        PointBox[{90.4, 315.900457924437}], 
        PointBox[{90.5, 318.1751326905254}], 
        PointBox[{90.6, 316.6036700350701}], 
        PointBox[{90.7, 318.34049566963597`}], 
        PointBox[{90.8, 318.85458346365505`}], 
        PointBox[{90.9, 317.08316764851014`}], 
        PointBox[{91., 316.53325655682136`}], 
        PointBox[{91.1, 318.67432120548654`}], 
        PointBox[{91.2, 317.55702625749296`}], 
        PointBox[{91.3, 318.61793915526897`}], 
        PointBox[{91.4, 323.22737719165326`}], 
        PointBox[{91.5, 326.28605061586717`}], 
        PointBox[{91.6, 325.1516935871819}], 
        PointBox[{91.7, 326.0066775012529}], 
        PointBox[{91.8, 327.2296418661579}], 
        PointBox[{91.9, 325.7115884313586}], 
        PointBox[{92., 324.64406766176705`}], 
        PointBox[{92.1, 326.4523735938867}], 
        PointBox[{92.2, 326.20016384305967`}], 
        PointBox[{92.3, 326.1531433141671}], 
        PointBox[{92.4, 330.39298599653563`}], 
        PointBox[{92.5, 333.94822784471336`}], 
        PointBox[{92.6, 333.5902699602481}], 
        PointBox[{92.7, 333.47853615847924`}], 
        PointBox[{92.8, 335.2289772541863}], 
        PointBox[{92.9, 334.07540864181084`}], 
        PointBox[{93., 332.696784784893}], 
        PointBox[{93.1, 333.93058627023555`}], 
        PointBox[{93.2, 334.5933446417315}], 
        PointBox[{93.3, 333.7196156139534}], 
        PointBox[{93.4, 337.4144528529607}], 
        PointBox[{93.5, 341.21952050795744`}], 
        PointBox[{93.6, 341.7009847852484}], 
        PointBox[{93.7, 340.822766485329}], 
        PointBox[{93.8, 342.82960683894464`}], 
        PointBox[{93.9, 342.10175797934033`}], 
        PointBox[{94., 340.58500811646195`}], 
        PointBox[{94.1, 341.20550368162304`}], 
        PointBox[{94.2, 342.5680692026906}], 
        PointBox[{94.3, 341.2417956708993}], 
        PointBox[{94.4, 344.2813045800394}], 
        PointBox[{94.5, 348.1392589481843}], 
        PointBox[{94.6, 349.3299009821176}], 
        PointBox[{94.7, 348.03737618998304`}], 
        PointBox[{94.8, 350.00687947088}], PointBox[{94.9, 349.713772516918}],
         PointBox[{95., 348.18696899536917`}], 
        PointBox[{95.1, 348.2837294694223}], 
        PointBox[{95.2, 350.01725241595346`}], 
        PointBox[{95.3, 348.60276326346}], 
        PointBox[{95.4, 350.9607403844294}], 
        PointBox[{95.5, 354.71093440766646`}], 
        PointBox[{95.6, 356.3851136659903}], 
        PointBox[{95.7, 355.01935035161165`}], 
        PointBox[{95.8, 356.72448781875585`}], 
        PointBox[{95.9, 356.8221805592287}], 
        PointBox[{96., 355.3671344763679}], 
        PointBox[{96.1, 355.08494229202483`}], 
        PointBox[{96.2, 356.8925743112088}], 
        PointBox[{96.3, 355.6445967387566}], 
        PointBox[{96.4, 357.38336864639047`}], 
        PointBox[{96.5, 0.8860437177143239}], 
        PointBox[{96.6, 2.7950299864345864`}], 
        PointBox[{96.7, 1.5724256737125446`}], 
        PointBox[{96.8, 2.9168452025615403`}], 
        PointBox[{96.9, 3.312705003031355}], 
        PointBox[{97., 1.968150385882163}], 
        PointBox[{97.1, 1.4582034202235656`}], 
        PointBox[{97.2, 3.1565966158317593`}], 
        PointBox[{97.3, 2.1699279036727286`}], 
        PointBox[{97.4, 3.427146597094159}], 
        PointBox[{97.5, 6.548055522964045}], 
        PointBox[{97.6, 8.459326091829041}], 
        PointBox[{97.7, 7.439697442537079}], 
        PointBox[{97.8, 8.469433512800022}], 
        PointBox[{97.9, 9.032882220420195}], 
        PointBox[{98., 7.8013813463010715`}], 
        PointBox[{98.1, 7.197883923273128}], 
        PointBox[{98.2, 8.728675849332781}], 
        PointBox[{98.3, 7.948794590847932}], 
        PointBox[{98.4, 8.907038676504335}], 
        PointBox[{98.5, 11.501363545526747`}], 
        PointBox[{98.6, 13.22367113508694}], 
        PointBox[{98.7, 12.34185664719758}], 
        PointBox[{98.8, 13.211191273314995`}], 
        PointBox[{98.9, 13.784730780111907`}], 
        PointBox[{99., 12.64574947357262}], 
        PointBox[{99.1, 12.060595579620061`}], 
        PointBox[{99.2, 13.45774867735489}], 
        PointBox[{99.3, 12.727360710208748`}], 
        PointBox[{99.4, 13.56080976620238}], 
        PointBox[{99.5, 15.486048921530656`}], 
        PointBox[{99.6, 16.887397735493735`}], 
        PointBox[{99.7, 16.015924103994482`}], 
        PointBox[{99.8, 16.938795740071466`}], 
        PointBox[{99.9, 17.34373548636915}], 
        PointBox[{100., 16.275905136946335`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 360}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
        40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {0, -180}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 180.}], 
        PointBox[{0.1, 163.4003307194546}], 
        PointBox[{0.2, 167.0095820010872}], 
        PointBox[{0.3, 171.69840314211655`}], 
        PointBox[{0.4, 163.3300581072229}], 
        PointBox[{0.5, 165.74792884088652`}], 
        PointBox[{0.6, 178.87090774545362`}], 
        PointBox[{0.7, 175.34898565963243`}], 
        PointBox[{0.8, 169.3957704473159}], 
        PointBox[{0.9, 178.12668328675966`}], 
        PointBox[{1., 172.55921138082908`}], 
        PointBox[{1.1, 155.1196583352828}], 
        PointBox[{1.2, 148.4183947472888}], 
        PointBox[{1.3, 156.3926549093943}], 
        PointBox[{1.4, 154.7057496415307}], 
        PointBox[{1.5, 148.96978135191637`}], 
        PointBox[{1.6, 157.39501447251268`}], 
        PointBox[{1.7, 164.3165563950813}], 
        PointBox[{1.8, 158.25199596035714`}], 
        PointBox[{1.9, 158.6075218298945}], 
        PointBox[{2., 164.45449594413367`}], 
        PointBox[{2.1, 153.01059369634868`}], 
        PointBox[{2.2, 143.34905469278465`}], 
        PointBox[{2.3, 144.81218725290546`}], 
        PointBox[{2.4, 150.20143035419983`}], 
        PointBox[{2.5, 145.09189509804105`}], 
        PointBox[{2.6, 145.56732144786974`}], 
        PointBox[{2.7, 154.87909320591007`}], 
        PointBox[{2.8, 155.0952332448187}], 
        PointBox[{2.9, 150.6031085366767}], PointBox[{3., 156.2831484740102}],
         PointBox[{3.1, 154.15125254876216`}], 
        PointBox[{3.2, 144.79657909435218`}], 
        PointBox[{3.3, 141.17688551647052`}], 
        PointBox[{3.4, 146.72854822299087`}], 
        PointBox[{3.5, 146.31911678185156`}], 
        PointBox[{3.6, 143.00354838093517`}], 
        PointBox[{3.7, 148.85720946412584`}], 
        PointBox[{3.8, 154.00464378404195`}], 
        PointBox[{3.9, 150.67029164895212`}], 
        PointBox[{4., 151.32464118729467`}], 
        PointBox[{4.1, 155.42125518802823`}], 
        PointBox[{4.2, 148.47518612837712`}], 
        PointBox[{4.3, 143.02509312363236`}], 
        PointBox[{4.4, 144.82646186592092`}], 
        PointBox[{4.5, 148.5301600566504}], 
        PointBox[{4.6, 145.10026124535761`}], 
        PointBox[{4.7, 146.81896796027422`}], 
        PointBox[{4.8, 153.24798623992228`}], 
        PointBox[{4.9, 153.39850256666887`}], 
        PointBox[{5., 150.9053701681869}], PointBox[{5.1, 155.5671284782793}],
         PointBox[{5.2, 153.20468381348746`}], 
        PointBox[{5.3, 147.2614816968753}], 
        PointBox[{5.4, 145.58301917737754`}], 
        PointBox[{5.5, 150.06309938544655`}], 
        PointBox[{5.6, 149.00708476363798`}], 
        PointBox[{5.7, 147.79799126188254`}], 
        PointBox[{5.8, 152.9713084566065}], 
        PointBox[{5.9, 156.1415064890639}], 
        PointBox[{6., 153.63840817573782`}], 
        PointBox[{6.1, 155.57633849207377`}], 
        PointBox[{6.2, 157.57359510593415`}], 
        PointBox[{6.3, 152.1509709435004}], 
        PointBox[{6.4, 148.59124850609714`}], 
        PointBox[{6.5, 151.08736735107868`}], 
        PointBox[{6.6, 153.03138589331957`}], 
        PointBox[{6.7, 150.60888867341328`}], 
        PointBox[{6.8, 153.52759307758515`}], 
        PointBox[{6.9, 158.14457445326389`}], 
        PointBox[{7., 157.49467330337575`}], 
        PointBox[{7.1, 156.62284927333712`}], 
        PointBox[{7.2, 160.452767590662}], 
        PointBox[{7.3, 157.13190416353973`}], 
        PointBox[{7.4, 152.76211266845894`}], 
        PointBox[{7.5, 152.5843065304589}], 
        PointBox[{7.6, 156.14823276111474`}], 
        PointBox[{7.7, 154.3158060258247}], 
        PointBox[{7.8, 154.9544222384966}], 
        PointBox[{7.9, 159.5467008409023}], 
        PointBox[{8., 161.05551409632426`}], 
        PointBox[{8.1, 159.04745691977132`}], 
        PointBox[{8.2, 162.09501510679638`}], 
        PointBox[{8.3, 161.80952317978608`}], 
        PointBox[{8.4, 157.21117878171117`}], 
        PointBox[{8.5, 155.01714785644162`}], 
        PointBox[{8.6, 158.11709591404815`}], 
        PointBox[{8.7, 158.16857836782674`}], 
        PointBox[{8.8, 157.07455813067645`}], 
        PointBox[{8.9, 160.6921110452049}], PointBox[{9., 163.7427960417599}],
         PointBox[{9.1, 162.294958313174}], 
        PointBox[{9.2, 163.23201371925097`}], 
        PointBox[{9.3, 165.40454904460148`}], 
        PointBox[{9.4, 161.46276872149338`}], 
        PointBox[{9.5, 158.148610920367}], PointBox[{9.6, 159.4696310240506}],
         PointBox[{9.7, 161.51166368878785`}], 
        PointBox[{9.8, 159.65044697784288`}], 
        PointBox[{9.9, 161.82464930189963`}], 
        PointBox[{10., 165.55570275204627`}], 
        PointBox[{10.1, 165.52382595720155`}], 
        PointBox[{10.2, 164.58523869743476`}], 
        PointBox[{10.3, 167.72634673531957`}], 
        PointBox[{10.4, 165.38834715334633`}], 
        PointBox[{10.5, 161.5347855602131}], 
        PointBox[{10.6, 160.8958977086122}], 
        PointBox[{10.7, 163.88213884823472`}], 
        PointBox[{10.8, 162.43152363868376`}], 
        PointBox[{10.9, 163.05511392825701`}], 
        PointBox[{11., 166.72448750989406`}], 
        PointBox[{11.1, 168.1494515825325}], 
        PointBox[{11.2, 166.47060799733754`}], 
        PointBox[{11.3, 169.01287144075468`}], 
        PointBox[{11.4, 168.74553528943852`}], 
        PointBox[{11.5, 164.80993013795796`}], 
        PointBox[{11.6, 162.68321815040235`}], 
        PointBox[{11.7, 165.23312658379018`}], 
        PointBox[{11.8, 165.13015372974405`}], 
        PointBox[{11.9, 164.41160220510756`}], 
        PointBox[{12., 167.48974276975787`}], 
        PointBox[{12.1, 169.9772028223888}], 
        PointBox[{12.2, 168.68746910435948`}], 
        PointBox[{12.3, 169.68591622784152`}], 
        PointBox[{12.4, 171.2320853793426}], 
        PointBox[{12.5, 167.76243344270006`}], 
        PointBox[{12.6, 164.75033429972973`}], 
        PointBox[{12.7, 165.95271859338573`}], 
        PointBox[{12.8, 167.41180628968868`}], 
        PointBox[{12.9, 165.8791444415474}], 
        PointBox[{13., 168.02604145845726`}], 
        PointBox[{13.1, 171.07114261191964`}], 
        PointBox[{13.2, 170.79444119125765`}], 
        PointBox[{13.3, 170.2292512119111}], 
        PointBox[{13.4, 172.7852356062358}], 
        PointBox[{13.5, 170.33766596413443`}], 
        PointBox[{13.6, 166.88913677172968`}], 
        PointBox[{13.7, 166.53175052007828`}], 
        PointBox[{13.8, 168.97351109809097`}], 
        PointBox[{13.9, 167.40649256830693`}], 
        PointBox[{14., 168.44332479314835`}], 
        PointBox[{14.1, 171.5916718598619}], 
        PointBox[{14.2, 172.436003736344}], 
        PointBox[{14.3, 170.98237363255248`}], 
        PointBox[{14.4, 173.49978881012066`}], 
        PointBox[{14.5, 172.4683559896439}], 
        PointBox[{14.6, 168.90046663432986`}], 
        PointBox[{14.7, 167.24077435304935`}], 
        PointBox[{14.8, 169.7012790341123}], 
        PointBox[{14.9, 168.89197775757566`}], 
        PointBox[{15., 168.80755816373494`}], 
        PointBox[{15.1, 171.69839800631053`}], 
        PointBox[{15.2, 173.46154795466828`}], 
        PointBox[{15.3, 171.97441366933526`}], 
        PointBox[{15.4, 173.5658915257045}], 
        PointBox[{15.5, 174.01722856725428`}], 
        PointBox[{15.6, 170.6334244873069}], 
        PointBox[{15.7, 168.1030464415071}], 
        PointBox[{15.8, 169.75684523352902`}], 
        PointBox[{15.9, 170.16686199775359`}], 
        PointBox[{16., 169.15186959189668`}], 
        PointBox[{16.1, 171.51252077016943`}], 
        PointBox[{16.2, 173.87908443698325`}], 
        PointBox[{16.3, 172.98400543070056`}], 
        PointBox[{16.4, 173.25875985633502`}], 
        PointBox[{16.5, 174.90555355490687`}], 
        PointBox[{16.6, 172.02100345847612`}], 
        PointBox[{16.7, 169.0149690399685}], 
        PointBox[{16.8, 169.46414770191404`}], 
        PointBox[{16.9, 171.0187356778988}], 
        PointBox[{17., 169.4817908565783}], 
        PointBox[{17.1, 171.1166809148308}], 
        PointBox[{17.2, 173.7713660949812}], 
        PointBox[{17.3, 173.7325981677368}], 
        PointBox[{17.4, 172.86560394954904`}], 
        PointBox[{17.5, 175.12421206059298`}], 
        PointBox[{17.6, 173.0517017676175}], 
        PointBox[{17.7, 169.83735669435373`}], 
        PointBox[{17.8, 169.09246061901285`}], 
        PointBox[{17.9, 171.26283469776718`}], 
        PointBox[{18., 169.76691981019576`}], 
        PointBox[{18.1, 170.55907512693557`}], 
        PointBox[{18.2, 173.23110774854467`}], 
        PointBox[{18.3, 174.02696815986565`}], 
        PointBox[{18.4, 172.5556998297252}], 
        PointBox[{18.5, 174.71139389238488`}], 
        PointBox[{18.6, 173.67588753343625`}], 
        PointBox[{18.7, 170.434073600778}], 
        PointBox[{18.8, 168.74330671525604`}], 
        PointBox[{18.9, 170.84099708325994`}], 
        PointBox[{19., 169.93081060907934`}], 
        PointBox[{19.1, 169.85902836642344`}], 
        PointBox[{19.2, 172.33093132477916`}], 
        PointBox[{19.3, 173.78425690805125`}], 
        PointBox[{19.4, 172.30182031598088`}], 
        PointBox[{19.5, 173.75024887155087`}], 
        PointBox[{19.6, 173.8050304067965}], 
        PointBox[{19.7, 170.6884027244978}], 
        PointBox[{19.8, 168.37789557902033`}], 
        PointBox[{19.9, 169.8490014289182}], 
        PointBox[{20., 169.84666839661622`}], 
        PointBox[{20.1, 169.00804285785307`}], 
        PointBox[{20.2, 171.1124364875741}], 
        PointBox[{20.3, 172.9957902380229}], 
        PointBox[{20.4, 171.92326822793075`}], 
        PointBox[{20.5, 172.36238434940788`}], 
        PointBox[{20.6, 173.36228301132542`}], 
        PointBox[{20.7, 170.51861086285498`}], 
        PointBox[{20.8, 167.8797806389539}], 
        PointBox[{20.9, 168.457737585828}], 
        PointBox[{21., 169.35252746605875`}], 
        PointBox[{21.1, 167.96662854076385`}], 
        PointBox[{21.2, 169.58374003585777`}], 
        PointBox[{21.3, 171.6783438167422}], 
        PointBox[{21.4, 171.1953323688158}], 
        PointBox[{21.5, 170.66644623098728`}], 
        PointBox[{21.6, 172.2917118629939}], 
        PointBox[{21.7, 169.8654549472394}], 
        PointBox[{21.8, 167.1023860887617}], 
        PointBox[{21.9, 166.78687140700458`}], 
        PointBox[{22., 168.2884646363418}], 
        PointBox[{22.1, 166.65982864891157`}], 
        PointBox[{22.2, 167.7175081387395}], 
        PointBox[{22.3, 169.83883313588012`}], 
        PointBox[{22.4, 169.92765623979722`}], 
        PointBox[{22.5, 168.7108378531666}], 
        PointBox[{22.6, 170.54872301958676`}], 
        PointBox[{22.7, 168.64823704543232`}], 
        PointBox[{22.8, 165.88528060540375`}], 
        PointBox[{22.9, 164.8418994747608}], 
        PointBox[{23., 166.5379568022745}], 
        PointBox[{23.1, 164.97098044625636`}], 
        PointBox[{23.2, 165.44784513575541`}], 
        PointBox[{23.3, 167.45352719433868`}], 
        PointBox[{23.4, 167.97974420348692`}], 
        PointBox[{23.5, 166.42271911827265`}], 
        PointBox[{23.6, 168.0878506525296}], 
        PointBox[{23.7, 166.7428238244429}], 
        PointBox[{23.8, 164.06002854045073`}], 
        PointBox[{23.9, 162.51441914470342`}], 
        PointBox[{24., 164.03851792851856`}], 
        PointBox[{24.1, 162.73817380577748`}], 
        PointBox[{24.2, 162.66332027342287`}], 
        PointBox[{24.3, 164.45197209345133`}], 
        PointBox[{24.4, 165.2341917943413}], 
        PointBox[{24.5, 163.6080908420954}], 
        PointBox[{24.6, 164.8437866492095}], 
        PointBox[{24.7, 163.98688640602268`}], 
        PointBox[{24.8, 161.4465323375116}], 
        PointBox[{24.9, 159.61345828304547`}], 
        PointBox[{25., 160.74353065667674`}], 
        PointBox[{25.1, 159.7544455473908}], 
        PointBox[{25.2, 159.19887447165456`}], 
        PointBox[{25.3, 160.70590821265432`}], 
        PointBox[{25.4, 161.55822198373426`}], 
        PointBox[{25.5, 159.98909874318997`}], 
        PointBox[{25.6, 160.70441973055495`}], 
        PointBox[{25.7, 160.18244285780384`}], 
        PointBox[{25.8, 157.84212870076226`}], 
        PointBox[{25.9, 155.88558745776027`}], 
        PointBox[{26., 156.55604114982998`}], 
        PointBox[{26.1, 155.7651071066648}], 
        PointBox[{26.2, 154.82507017231183`}], 
        PointBox[{26.3, 156.0151755556035}], 
        PointBox[{26.4, 156.76379285806615`}], 
        PointBox[{26.5, 155.23468378052348`}], 
        PointBox[{26.6, 155.47833045513835`}], 
        PointBox[{26.7, 155.081975101406}], 
        PointBox[{26.8, 153.00172222984475`}], 
        PointBox[{26.9, 151.01606414470007`}], 
        PointBox[{27., 151.27131873218968`}], 
        PointBox[{27.1, 150.45377617686972`}], 
        PointBox[{27.2, 149.2346046287057}], 
        PointBox[{27.3, 150.08999865938313`}], 
        PointBox[{27.4, 150.57615333874855`}], 
        PointBox[{27.5, 148.96578355914608`}], 
        PointBox[{27.6, 148.87228033185966`}], 
        PointBox[{27.7, 148.3792358619794}], 
        PointBox[{27.8, 146.60724810307875`}], 
        PointBox[{27.9, 144.60896761114054`}], 
        PointBox[{28., 144.54650872156344`}], 
        PointBox[{28.1, 143.41629640717292`}], 
        PointBox[{28.2, 142.035073359526}], 
        PointBox[{28.3, 142.53755490116237`}], 
        PointBox[{28.4, 142.6118573697895}], 
        PointBox[{28.5, 140.7460677981726}], 
        PointBox[{28.6, 140.49439854506272`}], 
        PointBox[{28.7, 139.74667841614792`}], 
        PointBox[{28.8, 138.22116757560434`}], 
        PointBox[{28.9, 136.1722054362217}], 
        PointBox[{29., 135.89560380547482`}], 
        PointBox[{29.1, 134.15148755731934`}], 
        PointBox[{29.2, 132.7576342256325}], 
        PointBox[{29.3, 132.86780566331072`}], 
        PointBox[{29.4, 132.388240189739}], 
        PointBox[{29.5, 130.1103260292184}], 
        PointBox[{29.6, 129.87955575882734`}], 
        PointBox[{29.7, 128.90810985404823`}], 
        PointBox[{29.8, 127.27755661232004`}], 
        PointBox[{29.9, 125.1655386775783}], 
        PointBox[{30., 124.72644163247605`}], 
        PointBox[{30.1, 122.16449811718849`}], 
        PointBox[{30.2, 120.91825206194335`}], 
        PointBox[{30.3, 120.56495546929727`}], 
        PointBox[{30.4, 119.40023126010783`}], 
        PointBox[{30.5, 116.70833021200451`}], 
        PointBox[{30.6, 116.56007984688404`}], 
        PointBox[{30.7, 115.41889478251687`}], 
        PointBox[{30.8, 113.27844618715972`}], 
        PointBox[{30.9, 111.20168797921724`}], 
        PointBox[{31., 110.43757973984248`}], 
        PointBox[{31.1, 107.2288498848975}], 
        PointBox[{31.2, 106.16227369261469`}], 
        PointBox[{31.3, 105.25633541619027`}], 
        PointBox[{31.4, 103.29852726375611`}], 
        PointBox[{31.5, 100.58992548504102`}], 
        PointBox[{31.6, 100.37399183911111`}], 
        PointBox[{31.7, 98.6863867930224}], 
        PointBox[{31.8, 96.12589732385095}], 
        PointBox[{31.9, 94.28431059916693}], 
        PointBox[{32., 92.61650757074676}], 
        PointBox[{32.1, 89.52310769538963}], 
        PointBox[{32.2, 88.43112751961235}], 
        PointBox[{32.3, 86.8911998508811}], 
        PointBox[{32.4, 84.09867311805283}], 
        PointBox[{32.5, 82.20634357953895}], 
        PointBox[{32.6, 81.42257318073462}], 
        PointBox[{32.7, 78.85199407437176}], 
        PointBox[{32.8, 76.23023533844025}], 
        PointBox[{32.9, 74.7476324044037}], 
        PointBox[{33., 71.64302311424035}], 
        PointBox[{33.1, 69.42127052374781}], 
        PointBox[{33.2, 68.00226977849888}], 
        PointBox[{33.3, 65.76953245429831}], 
        PointBox[{33.4, 62.39989730835077}], 
        PointBox[{33.5, 61.713683875877905`}], 
        PointBox[{33.6, 59.6193390606968}], 
        PointBox[{33.7, 56.66696662244067}], 
        PointBox[{33.8, 54.31958896564538}], 
        PointBox[{33.9, 52.774160011056665`}], 
        PointBox[{34., 48.90446976969906}], 
        PointBox[{34.1, 47.32800523651531}], 
        PointBox[{34.2, 45.38335986773018}], 
        PointBox[{34.3, 42.450363227795606`}], 
        PointBox[{34.4, 39.56580258669783}], 
        PointBox[{34.5, 38.963683801594016`}], 
        PointBox[{34.6, 35.83860366558656}], 
        PointBox[{34.7, 33.015222000860376`}], 
        PointBox[{34.8, 31.141507292213646`}], 
        PointBox[{34.9, 28.427709903378855`}], 
        PointBox[{35., 25.388030766072916`}], 
        PointBox[{35.1, 23.72010902749389}], 
        PointBox[{35.2, 21.196739700641047`}], 
        PointBox[{35.3, 17.768705869111727`}], 
        PointBox[{35.4, 16.611110091187584`}], 
        PointBox[{35.5, 14.33902213615147}], 
        PointBox[{35.6, 11.134820961775404`}], 
        PointBox[{35.7, 8.723785571746703}], 
        PointBox[{35.8, 7.10702935612062}], 
        PointBox[{35.9, 3.160478257392242}], 
        PointBox[{36., 1.3258435816424026`}], 
        PointBox[{36.1, -0.8225168994322303}], 
        PointBox[{36.2, -3.8491200320968346`}], 
        PointBox[{36.3, -6.900784923567699}], 
        PointBox[{36.4, -7.420850225946197}], 
        PointBox[{36.5, -10.832140171391075`}], 
        PointBox[{36.6, -13.627331440726266`}], 
        PointBox[{36.7, -15.518162610511354`}], 
        PointBox[{36.8, -17.823235165029473`}], 
        PointBox[{36.9, -21.32690751820701}], 
        PointBox[{37., -22.98840684566676}], 
        PointBox[{37.1, -25.623521953024465`}], 
        PointBox[{37.2, -28.866841278206266`}], 
        PointBox[{37.3, -30.230746911242022`}], 
        PointBox[{37.4, -32.25204515007499}], 
        PointBox[{37.5, -35.49228792057693}], 
        PointBox[{37.6, -37.72236160776811}], 
        PointBox[{37.7, -39.256886411021696`}], 
        PointBox[{37.8, -42.84019419353717}], 
        PointBox[{37.9, -44.8705458987024}], 
        PointBox[{38., -46.9709481720929}], 
        PointBox[{38.1, -49.89247595976485}], 
        PointBox[{38.2, -52.612940966297174`}], 
        PointBox[{38.3, -52.9881539662274}], 
        PointBox[{38.4, -56.27805801145951}], 
        PointBox[{38.5, -58.86484830423797}], 
        PointBox[{38.6, -60.521710771732614`}], 
        PointBox[{38.7, -62.28643228485453}], 
        PointBox[{38.8, -65.96594451659257}], 
        PointBox[{38.9, -67.3494791371777}], 
        PointBox[{39., -69.85074846052885}], 
        PointBox[{39.1, -72.67113227135269}], 
        PointBox[{39.2, -74.08155919718774}], 
        PointBox[{39.3, -75.26568955899711}], 
        PointBox[{39.4, -78.42060411084822}], 
        PointBox[{39.5, -80.29094361836178}], 
        PointBox[{39.6, -81.49185064906851}], 
        PointBox[{39.7, -84.10745619829686}], 
        PointBox[{39.8, -86.53596532477968}], 
        PointBox[{39.9, -88.14316088632404}], 
        PointBox[{40., -90.76152438379359}], 
        PointBox[{40.1, -92.89555285092501}], 
        PointBox[{40.2, -93.31422126290636}], 
        PointBox[{40.3, -95.61693311063573}], 
        PointBox[{40.4, -98.00722709398542}], 
        PointBox[{40.5, -99.20283684808237}], 
        PointBox[{40.6, -100.1970095842189}], 
        PointBox[{40.7, -103.40807215202585`}], 
        PointBox[{40.8, -104.55453625259906`}], 
        PointBox[{40.9, -106.48447667663277`}], 
        PointBox[{41., -108.86468353385135`}], 
        PointBox[{41.1, -110.20843046954542`}], 
        PointBox[{41.2, -110.33324124048886`}], 
        PointBox[{41.3, -113.05837621034516`}], 
        PointBox[{41.4, -114.61841894773534`}], 
        PointBox[{41.5, -115.20935679243121`}], 
        PointBox[{41.6, -116.26265476598564`}], 
        PointBox[{41.7, -119.22026885066225`}], 
        PointBox[{41.8, -119.73399591419002`}], 
        PointBox[{41.9, -121.79775042609253`}], 
        PointBox[{42., -123.67560484038404`}], 
        PointBox[{42.1, -124.7599089755713}], 
        PointBox[{42.2, -124.83366647439834`}], 
        PointBox[{42.3, -127.3344009962675}], 
        PointBox[{42.4, -128.15359016186267`}], 
        PointBox[{42.5, -128.22548365027978`}], 
        PointBox[{42.6, -129.42697685864914`}], 
        PointBox[{42.7, -131.65778000529826`}], 
        PointBox[{42.8, -131.91297754335028`}], 
        PointBox[{42.9, -133.95760035726198`}], 
        PointBox[{43., -135.50536746408397`}], 
        PointBox[{43.1, -136.47558115506763`}], 
        PointBox[{43.2, -136.56237734608294`}], 
        PointBox[{43.3, -138.66296601193244`}], 
        PointBox[{43.4, -138.8687089530431}], 
        PointBox[{43.5, -138.50356102196383`}], 
        PointBox[{43.6, -139.75181487182272`}], 
        PointBox[{43.7, -141.29506495590977`}], 
        PointBox[{43.8, -141.33629494900742`}], 
        PointBox[{43.9, -143.32237150282526`}], 
        PointBox[{44., -144.97348500806402`}], 
        PointBox[{44.1, -145.73364980455517`}], 
        PointBox[{44.2, -145.7175588307291}], 
        PointBox[{44.3, -147.508052888541}], 
        PointBox[{44.4, -147.24465197350582`}], 
        PointBox[{44.5, -146.50044250723658`}], 
        PointBox[{44.6, -147.64181174140322`}], 
        PointBox[{44.7, -148.75896745220962`}], 
        PointBox[{44.8, -148.51085408695508`}], 
        PointBox[{44.9, -150.46225205729934`}], 
        PointBox[{45., -152.4059475905451}], 
        PointBox[{45.1, -153.02183972261264`}], 
        PointBox[{45.2, -152.73348446522868`}], 
        PointBox[{45.3, -154.3750552022757}], 
        PointBox[{45.4, -153.79578654149736`}], 
        PointBox[{45.5, -152.70506457908778`}], 
        PointBox[{45.6, -153.6092046182348}], 
        PointBox[{45.7, -154.59077894418442`}], 
        PointBox[{45.8, -153.9627491874562}], 
        PointBox[{45.9, -155.87796552037253`}], 
        PointBox[{46., -158.10379105766333`}], 
        PointBox[{46.1, -158.76950117795786`}], 
        PointBox[{46.2, -158.06724439041864`}], 
        PointBox[{46.3, -159.69179149468255`}], 
        PointBox[{46.4, -158.95818857479026`}], 
        PointBox[{46.5, -157.54469670823892`}], 
        PointBox[{46.6, -158.10090235398093`}], 
        PointBox[{46.7, -159.18786542332236`}], 
        PointBox[{46.8, -158.1285703082467}], 
        PointBox[{46.9, -159.93513864659326`}], 
        PointBox[{47., -162.38386016910226`}], 
        PointBox[{47.1, -163.30854416956572`}], 
        PointBox[{47.2, -162.12729026636225`}], 
        PointBox[{47.3, -163.77590697984851`}], 
        PointBox[{47.4, -163.0614408104375}], 
        PointBox[{47.5, -161.3592836001626}], 
        PointBox[{47.6, -161.46841251818842`}], 
        PointBox[{47.7, -162.80158695984574`}], 
        PointBox[{47.8, -161.3551976806848}], 
        PointBox[{47.9, -162.907849785508}], 
        PointBox[{48., -165.5183062333308}], 
        PointBox[{48.1, -166.8674871333642}], 
        PointBox[{48.2, -165.268185813562}], 
        PointBox[{48.3, -166.84849884704454`}], 
        PointBox[{48.4, -166.33886607697787`}], 
        PointBox[{48.5, -164.40707436476805`}], 
        PointBox[{48.6, -163.99335696652997`}], 
        PointBox[{48.7, -165.56523974523589`}], 
        PointBox[{48.8, -163.92011124330747`}], 
        PointBox[{48.9, -165.0174192181221}], 
        PointBox[{49., -167.72698230180686`}], 
        PointBox[{49.1, -169.58772120032518`}], 
        PointBox[{49.2, -167.78975796575105`}], 
        PointBox[{49.3, -169.06509312304843`}], 
        PointBox[{49.4, -168.94451976078562`}], 
        PointBox[{49.5, -166.87598796698876`}], 
        PointBox[{49.6, -165.90119868826878`}], 
        PointBox[{49.7, -167.54543752996688`}], 
        PointBox[{49.8, -166.0355840806369}], 
        PointBox[{49.9, -166.45532193811232`}], 
        PointBox[{50., -169.18743926366733`}], 
        PointBox[{50.1, -171.5532812632664}], 
        PointBox[{50.2, -169.91070892839343`}], 
        PointBox[{50.3, -170.55318100243312`}], 
        PointBox[{50.4, -170.96809454388858`}], 
        PointBox[{50.5, -168.8953800015879}], 
        PointBox[{50.6, -167.36903910747787`}], 
        PointBox[{50.7, -168.8081538328115}], 
        PointBox[{50.8, -167.8337493787476}], 
        PointBox[{50.9, -167.39717691449914`}], 
        PointBox[{51., -170.0371987535691}], 
        PointBox[{51.1, -172.8202938611721}], 
        PointBox[{51.2, -171.73436863705865`}], 
        PointBox[{51.3, -171.4532051960923}], 
        PointBox[{51.4, -172.44880139666202`}], 
        PointBox[{51.5, -170.54647326779377`}], 
        PointBox[{51.6, -168.527798101808}], 
        PointBox[{51.7, -169.46476768131834`}], 
        PointBox[{51.8, -169.33880276763375`}], 
        PointBox[{51.9, -168.00900485701277`}], 
        PointBox[{52., -170.3693755849672}], 
        PointBox[{52.1, -173.437880163081}], 
        PointBox[{52.2, -173.24055037288053`}], 
        PointBox[{52.3, -171.94935698767222`}], 
        PointBox[{52.4, -173.38915670349525`}], 
        PointBox[{52.5, -171.86865265000233`}], 
        PointBox[{52.6, -169.4648844578187}], 
        PointBox[{52.7, -169.66985227350233`}], 
        PointBox[{52.8, -170.4554420960776}], 
        PointBox[{52.9, -168.44422358881275`}], 
        PointBox[{53., -170.24858660087193`}], 
        PointBox[{53.1, -173.4619005710265}], 
        PointBox[{53.2, -174.3277148775669}], 
        PointBox[{53.3, -172.26541293381888`}], 
        PointBox[{53.4, -173.77650868255296`}], 
        PointBox[{53.5, -172.8652698149017}], 
        PointBox[{53.6, -170.23058016995492`}], 
        PointBox[{53.7, -169.58820808994642`}], 
        PointBox[{53.8, -171.0223102619566}], 
        PointBox[{53.9, -168.82993393539073`}], 
        PointBox[{54., -169.75452422292437`}], 
        PointBox[{54.1, -172.96727390147134`}], 
        PointBox[{54.2, -174.87760356679064`}], 
        PointBox[{54.3, -172.5972878009634}], 
        PointBox[{54.4, -173.61295774504106`}], 
        PointBox[{54.5, -173.50287528953777`}], 
        PointBox[{54.6, -170.84167851240636`}], 
        PointBox[{54.7, -169.35319198530487`}], 
        PointBox[{54.8, -170.92516580248775`}], 
        PointBox[{54.9, -169.22584397473838`}], 
        PointBox[{55., -168.99862915666017`}], 
        PointBox[{55.1, -172.04211846069666`}], 
        PointBox[{55.2, -174.8020962715018}], 
        PointBox[{55.3, -173.00778689717845`}], 
        PointBox[{55.4, -172.96494943086145`}], 
        PointBox[{55.5, -173.71698265497253`}], 
        PointBox[{55.6, -171.2873543157184}], 
        PointBox[{55.7, -169.05160925386735`}], 
        PointBox[{55.8, -170.1947500495662}], 
        PointBox[{55.9, -169.56350561406725`}], 
        PointBox[{56., -168.11611919062852`}], 
        PointBox[{56.1, -170.74681730981683`}], 
        PointBox[{56.2, -174.0566899456535}], 
        PointBox[{56.3, -173.36523239163216`}], 
        PointBox[{56.4, -172.0047467364784}], 
        PointBox[{56.5, -173.4188251207961}], 
        PointBox[{56.6, -171.5278228261741}], 
        PointBox[{56.7, -168.72346053714136`}], 
        PointBox[{56.8, -168.9979179721122}], 
        PointBox[{56.9, -169.60615441706614`}], 
        PointBox[{57., -167.24863062227087`}], 
        PointBox[{57.1, -169.09470380398125`}], 
        PointBox[{57.2, -172.64140370016685`}], 
        PointBox[{57.3, -173.398665579909}], 
        PointBox[{57.4, -171.00104251001903`}], 
        PointBox[{57.5, -172.52121425047517`}], 
        PointBox[{57.6, -171.48925050788966`}], 
        PointBox[{57.7, -168.3709030220416}], 
        PointBox[{57.8, -167.54695357038145`}], 
        PointBox[{57.9, -169.02810532479634`}], 
        PointBox[{58., -166.51252430096793`}], 
        PointBox[{58.1, -167.13718406363478`}], 
        PointBox[{58.2, -170.61936484369653`}], 
        PointBox[{58.3, -172.8258894114042}], 
        PointBox[{58.4, -170.20030256955943`}], 
        PointBox[{58.5, -170.99488450790523`}], 
        PointBox[{58.6, -171.0582643068119}], 
        PointBox[{58.7, -167.96679243007384`}], 
        PointBox[{58.8, -166.02008453270537`}], 
        PointBox[{58.9, -167.6227298122758}], 
        PointBox[{59., -165.91947193491796`}], 
        PointBox[{59.1, -165.01079891056725`}], 
        PointBox[{59.2, -168.12279982654582`}], 
        PointBox[{59.3, -171.43917210281506`}], 
        PointBox[{59.4, -169.63268631245592`}], 
        PointBox[{59.5, -168.95382493476063`}], 
        PointBox[{59.6, -170.08259070563508`}], 
        PointBox[{59.7, -167.45442232792993`}], 
        PointBox[{59.8, -164.5319943609793}], 
        PointBox[{59.9, -165.4535528879569}], 
        PointBox[{60., -165.25320020935033`}], 
        PointBox[{60.1, -162.90945228535566`}], 
        PointBox[{60.2, -165.23926740065508`}], 
        PointBox[{60.3, -169.12511589391943`}], 
        PointBox[{60.4, -169.01310342978832`}], 
        PointBox[{60.5, -166.71729529472213`}], 
        PointBox[{60.6, -168.39703464925697`}], 
        PointBox[{60.7, -166.7352701671989}], 
        PointBox[{60.8, -163.1431984744413}], 
        PointBox[{60.9, -162.79930189422157`}], 
        PointBox[{61., -164.05072848901182`}], 
        PointBox[{61.1, -161.04687698363705`}], 
        PointBox[{61.2, -162.00774755813472`}], 
        PointBox[{61.3, -165.90662741085544`}], 
        PointBox[{61.4, -167.8693466173354}], 
        PointBox[{61.5, -164.73067761936545`}], 
        PointBox[{61.6, -165.90765575375553`}], 
        PointBox[{61.7, -165.64901697728783`}], 
        PointBox[{61.8, -161.87710581124702`}], 
        PointBox[{61.9, -159.99668923070567`}], 
        PointBox[{62., -161.87277962773078`}], 
        PointBox[{62.1, -159.5475105175501}], 
        PointBox[{62.2, -158.60682880531385`}], 
        PointBox[{62.3, -162.0495251437169}], 
        PointBox[{62.4, -165.75633821666997`}], 
        PointBox[{62.5, -163.2710049744419}], 
        PointBox[{62.6, -162.74659315448662`}], 
        PointBox[{62.7, -163.96545161347603`}], 
        PointBox[{62.8, -160.71784265399037`}], 
        PointBox[{62.9, -157.3456838327038}], 
        PointBox[{63., -158.67277981403458`}], 
        PointBox[{63.1, -158.2117714761771}], 
        PointBox[{63.2, -155.37900647125207`}], 
        PointBox[{63.3, -157.8409525420284}], 
        PointBox[{63.4, -162.390257181185}], 
        PointBox[{63.5, -162.12872207999317`}], 
        PointBox[{63.6, -159.42475295188342`}], 
        PointBox[{63.7, -161.44074521162838`}], 
        PointBox[{63.8, -159.57740429308615`}], 
        PointBox[{63.9, -155.10419064712914`}], 
        PointBox[{64., -154.85139661674475`}], 
        PointBox[{64.1, -156.40247406646085`}], 
        PointBox[{64.2, -152.76849131283234`}], 
        PointBox[{64.3, -153.39080027015007`}], 
        PointBox[{64.4, -157.8498937084005}], 
        PointBox[{64.5, -160.63346677182562`}], 
        PointBox[{64.6, -156.76891807046923`}], 
        PointBox[{64.7, -158.00768069807964`}], 
        PointBox[{64.8, -158.24024238026323`}], 
        PointBox[{64.9, -153.5175321307761}], 
        PointBox[{65., -151.04378555499716`}], 
        PointBox[{65.1, -153.49796422515647`}], 
        PointBox[{65.2, -151.0939773173377}], 
        PointBox[{65.3, -149.09624183813867`}], 
        PointBox[{65.4, -152.86023805241712`}], 
        PointBox[{65.5, -158.02160770635965`}], 
        PointBox[{65.6, -155.45164371847204`}], 
        PointBox[{65.7, -154.11168534162425`}], 
        PointBox[{65.8, -156.3695255149214}], 
        PointBox[{65.9, -152.79053382491838`}], 
        PointBox[{66., -147.98612480388692`}], 
        PointBox[{66.1, -149.57405336930242`}], 
        PointBox[{66.2, -150.0531300594812}], 
        PointBox[{66.3, -145.77826817088499`}], 
        PointBox[{66.4, -147.9299523388545}], 
        PointBox[{66.5, -153.89163520577858`}], 
        PointBox[{66.6, -155.33445466851117`}], 
        PointBox[{66.7, -151.02027556315443`}], 
        PointBox[{66.8, -153.74876325796504`}], 
        PointBox[{66.9, -152.94916315145383`}], 
        PointBox[{67., -146.58349215690396`}], 
        PointBox[{67.1, -145.53172220943088`}], 
        PointBox[{67.2, -148.684159969358}], 
        PointBox[{67.3, -144.54322112382215`}], 
        PointBox[{67.4, -143.4783765747561}], 
        PointBox[{67.5, -149.08918575738062`}], 
        PointBox[{67.6, -155.35220795238274`}], 
        PointBox[{67.7, -150.73172277703998`}], 
        PointBox[{67.8, -150.90670980182767`}], 
        PointBox[{67.9, -153.69509886435117`}], 
        PointBox[{68., -148.0139035434986}], 
        PointBox[{68.1, -142.9426325571403}], 
        PointBox[{68.2, -146.56071765180968`}], 
        PointBox[{68.3, -146.0464710673623}], 
        PointBox[{68.4, -141.0180636272853}], 
        PointBox[{68.5, -145.19873215984262`}], 
        PointBox[{68.6, -154.3579655108042}], 
        PointBox[{68.7, -154.95783714480785`}], 
        PointBox[{68.8, -150.09008697100944`}], 
        PointBox[{68.9, -154.76366864453303`}], 
        PointBox[{69., -153.4111146731957}], 
        PointBox[{69.1, -144.423723851025}], 
        PointBox[{69.2, -144.99045383191697`}], 
        PointBox[{69.3, -149.44806063352735`}], 
        PointBox[{69.4, -143.47502355006145`}], 
        PointBox[{69.5, -143.2098385396166}], 
        PointBox[{69.6, -153.0430482922966}], 
        PointBox[{69.7, -163.00139299946022`}], 
        PointBox[{69.8, -156.3231217696084}], 
        PointBox[{69.9, -157.40070027380716`}], 
        PointBox[{70., -162.59433266588894`}], 
        PointBox[{70.1, -154.46478466444387`}], 
        PointBox[{70.2, -147.61605489850626`}], 
        PointBox[{70.3, -153.83315048798977`}], 
        PointBox[{70.4, -153.918937185088}], 
        PointBox[{70.5, -146.75136354839924`}], 
        PointBox[{70.6, -154.56080724014464`}], 
        PointBox[{70.7, -171.54688007058576`}], 
        PointBox[{70.8, -174.5666505512345}], 
        PointBox[{70.9, -166.76731568357354`}], 
        PointBox[{71., -173.6826186270191}], 
        PointBox[{71.1, -175.31831060724653`}], 
        PointBox[{71.2, -161.81819798849028`}], 
        PointBox[{71.3, -161.569142582528}], 
        PointBox[{71.4, -169.48186280445225`}], 
        PointBox[{71.5, -163.07128208757058`}], 
        PointBox[{71.6, -161.626181642554}], 
        PointBox[{71.7, -179.22459628837532`}], 
        PointBox[{71.8, 165.2962877492173}], 
        PointBox[{71.9, 170.92476354935206`}], 
        PointBox[{72., 173.65645603319717`}], 
        PointBox[{72.1, 165.1203059935724}], 
        PointBox[{72.2, 169.8247240748242}], 
        PointBox[{72.3, -177.88705423660576`}], 
        PointBox[{72.4, 176.87742433516541`}], 
        PointBox[{72.5, 172.1826516511719}], 
        PointBox[{72.6, -178.6074904330817}], 
        PointBox[{72.7, 173.26642087315122`}], 
        PointBox[{72.8, 155.45293155961554`}], 
        PointBox[{72.9, 150.04582289179962`}], 
        PointBox[{73., 158.5290115120879}], 
        PointBox[{73.1, 155.2806781241743}], 
        PointBox[{73.2, 150.22004602810193`}], 
        PointBox[{73.3, 160.1497213774128}], 
        PointBox[{73.4, 165.6553869278723}], 
        PointBox[{73.5, 158.89483449001273`}], 
        PointBox[{73.6, 160.78609093176055`}], 
        PointBox[{73.7, 165.43958264884714`}], 
        PointBox[{73.8, 152.64793502854445`}], 
        PointBox[{73.9, 143.2459251840628}], 
        PointBox[{74., 145.94531791730697`}], 
        PointBox[{74.1, 150.5433392338091}], 
        PointBox[{74.2, 144.9181752557779}], 
        PointBox[{74.3, 146.5201822426825}], 
        PointBox[{74.4, 155.9844283725106}], 
        PointBox[{74.5, 155.05251163607318`}], 
        PointBox[{74.6, 150.9182420470679}], 
        PointBox[{74.7, 157.24156071504694`}], 
        PointBox[{74.8, 153.51626863620186`}], 
        PointBox[{74.9, 144.08657533711084`}], 
        PointBox[{75., 141.1407840366519}], 
        PointBox[{75.1, 147.07509328251763`}], 
        PointBox[{75.2, 145.74970374794793`}], 
        PointBox[{75.3, 142.84249890343926`}], 
        PointBox[{75.4, 149.4344231305513}], 
        PointBox[{75.5, 153.94112622110697`}], 
        PointBox[{75.6, 150.15052823642327`}], 
        PointBox[{75.7, 151.68497878757626`}], 
        PointBox[{75.8, 155.0702080712217}], 
        PointBox[{75.9, 147.57171781751094`}], 
        PointBox[{76., 142.354356418291}], 
        PointBox[{76.1, 144.89886273370212`}], 
        PointBox[{76.2, 148.04873803597002`}], 
        PointBox[{76.3, 144.4393719445652}], 
        PointBox[{76.4, 146.8514771378468}], 
        PointBox[{76.5, 153.24537371603947`}], 
        PointBox[{76.6, 152.74221122741437`}], 
        PointBox[{76.7, 150.59798775929085`}], 
        PointBox[{76.8, 155.48011970990774`}], 
        PointBox[{76.9, 152.2092337576396}], 
        PointBox[{77., 146.36452668248967`}], 
        PointBox[{77.1, 145.2315990830175}], 
        PointBox[{77.2, 149.80715479741048`}], 
        PointBox[{77.3, 148.20388324845408`}], 
        PointBox[{77.4, 147.4385990242081}], 
        PointBox[{77.5, 152.9308259741374}], 
        PointBox[{77.6, 155.62985419017787`}], 
        PointBox[{77.7, 152.9565798620315}], 
        PointBox[{77.8, 155.49078894716513`}], 
        PointBox[{77.9, 156.8107181290543}], 
        PointBox[{78., 151.22011009289417`}], 
        PointBox[{78.1, 147.93257984966476`}], 
        PointBox[{78.2, 150.90475407517806`}], 
        PointBox[{78.3, 152.32543335954688`}], 
        PointBox[{78.4, 150.012312383471}], 
        PointBox[{78.5, 153.37320562372042`}], 
        PointBox[{78.6, 157.81276801234344`}], 
        PointBox[{78.7, 156.75488845061773`}], 
        PointBox[{78.8, 156.3265841374523}], 
        PointBox[{78.9, 160.0084992767661}], 
        PointBox[{79., 156.192563301498}], 
        PointBox[{79.1, 151.9673718954873}], 
        PointBox[{79.2, 152.27875825693627`}], 
        PointBox[{79.3, 155.67617474596045`}], 
        PointBox[{79.4, 153.61181383802614`}], 
        PointBox[{79.5, 154.67042596809188`}], 
        PointBox[{79.6, 159.33026841618994`}], 
        PointBox[{79.7, 160.44445678941702`}], 
        PointBox[{79.8, 158.51953982119448`}], 
        PointBox[{79.9, 161.86148340466025`}], 
        PointBox[{80., 160.98042796966183`}], 
        PointBox[{80.1, 156.39990617970034`}], 
        PointBox[{80.2, 154.53895965812262`}], 
        PointBox[{80.3, 157.8546026929762}], 
        PointBox[{80.4, 157.4785102075257}], 
        PointBox[{80.5, 156.67591305979295`}], 
        PointBox[{80.6, 160.51726622050046`}], 
        PointBox[{80.7, 163.31204080860334`}], 
        PointBox[{80.8, 161.6631310069206}], 
        PointBox[{80.9, 163.0454263085703}], 
        PointBox[{81., 164.81113601353718`}], 
        PointBox[{81.1, 160.6815673362944}], 
        PointBox[{81.2, 157.5529719586848}], 
        PointBox[{81.3, 159.27015810220473`}], 
        PointBox[{81.4, 160.951421774349}], 
        PointBox[{81.5, 159.16390853939083`}], 
        PointBox[{81.6, 161.6418780119493}], 
        PointBox[{81.7, 165.2767621976309}], 
        PointBox[{81.8, 164.93265654342395`}], 
        PointBox[{81.9, 164.3054428410469}], 
        PointBox[{82., 167.3650065417969}], 
        PointBox[{82.1, 164.64555712916626`}], 
        PointBox[{82.2, 160.8918516367412}], 
        PointBox[{82.3, 160.6314105850397}], 
        PointBox[{82.4, 163.5208267171838}], 
        PointBox[{82.5, 161.89509268343681`}], 
        PointBox[{82.6, 162.8366224453639}], 
        PointBox[{82.7, 166.54484084242722`}], 
        PointBox[{82.8, 167.68085276772035`}], 
        PointBox[{82.9, 166.05880740365683`}], 
        PointBox[{83., 168.82097493700712`}], 
        PointBox[{83.1, 168.10889096310711`}], 
        PointBox[{83.2, 164.17210674081434`}], 
        PointBox[{83.3, 162.3171984313958}], 
        PointBox[{83.4, 165.04298166814988`}], 
        PointBox[{83.5, 164.5990127512414}], 
        PointBox[{83.6, 164.1414226386405}], 
        PointBox[{83.7, 167.360592757439}], 
        PointBox[{83.8, 169.64488193479337`}], 
        PointBox[{83.9, 168.20198171422817`}], 
        PointBox[{84., 169.56246877512604`}], 
        PointBox[{84.1, 170.75048460984544`}], 
        PointBox[{84.2, 167.1500940147016}], 
        PointBox[{84.3, 164.3021827950579}], 
        PointBox[{84.4, 165.82935573588475`}], 
        PointBox[{84.5, 166.9562338081596}], 
        PointBox[{84.6, 165.549984689751}], 
        PointBox[{84.7, 167.91062597221753`}], 
        PointBox[{84.8, 170.8506352878976}], 
        PointBox[{84.9, 170.32327429839643`}], 
        PointBox[{85., 170.06572462307668`}], 
        PointBox[{85.1, 172.46252823878604`}], 
        PointBox[{85.2, 169.74948197487538`}], 
        PointBox[{85.3, 166.39212376627984`}], 
        PointBox[{85.4, 166.37296588218305`}], 
        PointBox[{85.5, 168.65181166858383`}], 
        PointBox[{85.6, 167.02054008018604`}], 
        PointBox[{85.7, 168.31347729375557`}], 
        PointBox[{85.8, 171.44675360104884`}], 
        PointBox[{85.9, 172.03541738959757`}], 
        PointBox[{86., 170.7117500484601}], 
        PointBox[{86.1, 173.31087555381237`}], 
        PointBox[{86.2, 171.9243755490752}], 
        PointBox[{86.3, 168.38297798235726`}], 
        PointBox[{86.4, 166.99768178027443`}], 
        PointBox[{86.5, 169.51915867339267`}], 
        PointBox[{86.6, 168.46616775428993`}], 
        PointBox[{86.7, 168.63993082498928`}], 
        PointBox[{86.8, 171.5932953326119}], 
        PointBox[{86.9, 173.14702009113535`}], 
        PointBox[{87., 171.60073149963864`}], 
        PointBox[{87.1, 173.4598275242315}], 
        PointBox[{87.2, 173.5468866157462}], 
        PointBox[{87.3, 170.1127147196239}], 
        PointBox[{87.4, 167.7701277448432}], 
        PointBox[{87.5, 169.65713544520986`}], 
        PointBox[{87.6, 169.73817408963077`}], 
        PointBox[{87.7, 168.92768021905067`}], 
        PointBox[{87.8, 171.41781805649953`}], 
        PointBox[{87.9, 173.63884551001684`}], 
        PointBox[{88., 172.556796193021}], 
        PointBox[{88.1, 173.15904557853355`}], 
        PointBox[{88.2, 174.52192286052014`}], 
        PointBox[{88.3, 171.4935987703211}], 
        PointBox[{88.4, 168.60407948657667`}], 
        PointBox[{88.5, 169.36171743850718`}], 
        PointBox[{88.6, 170.63448001037614`}], 
        PointBox[{88.7, 169.18590636833687`}], 
        PointBox[{88.8, 171.00659760830604`}], 
        PointBox[{88.9, 173.58022180039552`}], 
        PointBox[{89., 173.30310263815045`}], 
        PointBox[{89.1, 172.691465462216}], 
        PointBox[{89.2, 174.82550697062834`}], 
        PointBox[{89.3, 172.507873615039}], 
        PointBox[{89.4, 169.36353931957274`}], 
        PointBox[{89.5, 168.91974415232835`}], 
        PointBox[{89.6, 170.95959530605614`}], 
        PointBox[{89.7, 169.3907932079528}], 
        PointBox[{89.8, 170.4101320405971}], 
        PointBox[{89.9, 173.06084227603424`}], 
        PointBox[{90., 173.62181016453542`}], 
        PointBox[{90.1, 172.25588008361956`}], 
        PointBox[{90.2, 174.4809983617015}], 
        PointBox[{90.3, 173.12035698525142`}], 
        PointBox[{90.4, 169.9084572053107}], 
        PointBox[{90.5, 168.46661267330637`}], 
        PointBox[{90.6, 170.61639682952227`}], 
        PointBox[{90.7, 169.47603120173153`}], 
        PointBox[{90.8, 169.64809086130117`}], 
        PointBox[{90.9, 172.1537312288565}], 
        PointBox[{91., 173.40454588695866`}], 
        PointBox[{91.1, 171.8700246679582}], 
        PointBox[{91.2, 173.55258871523984`}], 
        PointBox[{91.3, 173.247691692457}], 
        PointBox[{91.4, 170.1137905027863}], 
        PointBox[{91.5, 167.98607785601052`}], 
        PointBox[{91.6, 169.6566905027139}], 
        PointBox[{91.7, 169.32723277022887`}], 
        PointBox[{91.8, 168.71157891541952`}], 
        PointBox[{91.9, 170.9014380885783}], 
        PointBox[{92., 172.62420016375836`}], 
        PointBox[{92.1, 171.38315982051427`}], 
        PointBox[{92.2, 172.14000880184176`}], 
        PointBox[{92.3, 172.80480105809693`}], 
        PointBox[{92.4, 169.88252740789903`}], 
        PointBox[{92.5, 167.3706656882423}], 
        PointBox[{92.6, 168.22727427547215`}], 
        PointBox[{92.7, 168.79062472791702`}], 
        PointBox[{92.8, 167.56009546673158`}], 
        PointBox[{92.9, 169.31143752648495`}], 
        PointBox[{93., 171.28689472511178`}], 
        PointBox[{93.1, 170.5720645651454}], 
        PointBox[{93.2, 170.34888625290478`}], 
        PointBox[{93.3, 171.7251634409913}], 
        PointBox[{93.4, 169.14219046950166`}], 
        PointBox[{93.5, 166.47247734782286`}], 
        PointBox[{93.6, 166.4541196016071}], 
        PointBox[{93.7, 167.70234551977774`}], 
        PointBox[{93.8, 166.1174515375751}], 
        PointBox[{93.9, 167.35437702259514`}], 
        PointBox[{94., 169.39350933187234`}], 
        PointBox[{94.1, 169.22897917903902`}], 
        PointBox[{94.2, 168.2311827069061}], 
        PointBox[{94.3, 169.95213230604713`}], 
        PointBox[{94.4, 167.8100559567829}], 
        PointBox[{94.5, 165.1259441266302}], 
        PointBox[{94.6, 164.35780060628895`}], 
        PointBox[{94.7, 165.9250366915221}], 
        PointBox[{94.8, 164.26547532105178`}], 
        PointBox[{94.9, 164.96018883955549`}], 
        PointBox[{95., 166.91450864821672`}], 
        PointBox[{95.1, 167.18972516941722`}], 
        PointBox[{95.2, 165.72998428546998`}], 
        PointBox[{95.3, 167.4252917018166}], 
        PointBox[{95.4, 165.76079165266128`}], 
        PointBox[{95.5, 163.15325501751795`}], 
        PointBox[{95.6, 161.842060342693}], 
        PointBox[{95.7, 163.36597901800997`}], 
        PointBox[{95.8, 161.83890198217705`}], 
        PointBox[{95.9, 162.01110705919564`}], 
        PointBox[{96., 163.772506670226}], 
        PointBox[{96.1, 164.3144711420464}], 
        PointBox[{96.2, 162.66510429359914`}], 
        PointBox[{96.3, 164.06208320824953`}], 
        PointBox[{96.4, 162.8240653879766}], 
        PointBox[{96.5, 160.36193984826969`}], 
        PointBox[{96.6, 158.7160141835193}], 
        PointBox[{96.7, 159.94873839787033`}], 
        PointBox[{96.8, 158.62207008479163`}], 
        PointBox[{96.9, 158.3328739454737}], 
        PointBox[{97., 159.8283840281656}], 
        PointBox[{97.1, 160.44867526835878`}], 
        PointBox[{97.2, 158.7578023502574}], 
        PointBox[{97.3, 159.73216331732692`}], 
        PointBox[{97.4, 158.78627138835145`}], 
        PointBox[{97.5, 156.53334452169656`}], 
        PointBox[{97.6, 154.71753574554168`}], 
        PointBox[{97.7, 155.55535897279333`}], 
        PointBox[{97.8, 154.3437872317736}], 
        PointBox[{97.9, 153.68345304141985`}], 
        PointBox[{98., 154.86654806751176`}], 
        PointBox[{98.1, 155.38298428582493`}], 
        PointBox[{98.2, 153.66096594354894`}], 
        PointBox[{98.3, 154.22611552960007`}], 
        PointBox[{98.4, 153.38472887266835`}], 
        PointBox[{98.5, 151.4006443284743}], 
        PointBox[{98.6, 149.5123393771355}], 
        PointBox[{98.7, 149.96390674891882`}], 
        PointBox[{98.8, 148.6628304989281}], 
        PointBox[{98.9, 147.73979876947124`}], 
        PointBox[{99., 148.5768258688331}], 
        PointBox[{99.1, 148.81817333716026`}], 
        PointBox[{99.2, 146.97005502929096`}], 
        PointBox[{99.3, 147.23295783529466`}], 
        PointBox[{99.4, 146.31348379465635`}], 
        PointBox[{99.5, 144.6123737537855}], 
        PointBox[{99.6, 142.6790133942559}], 
        PointBox[{99.7, 142.8101643195987}], 
        PointBox[{99.8, 141.1499200255348}], 
        PointBox[{99.9, 140.09049231544486`}], 
        PointBox[{100., 140.5429149765696}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {-180, 180}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \
\\\"input\\\" -> \\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-328., 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.880463340997671*^9, 3.880464078032713*^9, 
  3.880464219678196*^9, 3.880612976910411*^9, 3.8806131090428143`*^9, 
  3.8806555269404993`*^9, 3.880702747544702*^9, 3.880703463235106*^9, 
  3.890982087385673*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"fd5893c2-499f-455b-a59b-4ba696c0e532"]
}, Open  ]],

Cell["\<\
Produce the four labelled plots for the case of 2:1 resonance inner \
circulation.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, {3.880614064638723*^9, 
   3.880614102948683*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d0b4f081-8440-4538-b565-cf5a5cbd8be9"],

Cell[BoxData[
 RowBox[{"FourPlot", "[", 
  RowBox[{"0.001", ",", " ", "init5", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.880458339369193*^9, 3.880458339758844*^9}, 
   3.880702901072493*^9, 3.880702985188464*^9},
 CellLabel->"In[52]:=",ExpressionUUID->"aa977c13-4415-4d09-8074-ca4939d4f52b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcE", "=", "gc"}]], "Input",
 CellChangeTimes->{{3.880458350639888*^9, 3.880458353317975*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"7f39cc15-6eda-404e-aff4-0ecc53df8fa0"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJw9m3dcze///yMRsoXKKBpKe2nQebR3nX1OZsouMyKF0Nsq+21kZoUkIyuk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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0.6000000000000013},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0.6, 
           FormBox["0.6`", TraditionalForm]}, {0.62, 
           FormBox["0.62`", TraditionalForm]}, {0.64, 
           FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0.6, 0.65}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Prolog->{
        Dashing[{Small, Small}], 
        LineBox[{{0, 0.629961}, {100, 0.629961}}]},
      Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
     ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJw9mndcze///wtJZEaJKFpoLy06j/Y6jXNOZ2SkjFIqo4yMJGSFlhHpXUpL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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {0.1, 
           FormBox["0.1`", TraditionalForm]}, {0.2, 
           FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 0.2}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -159.99}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJxVm3k4VX3Y/VUIqZQkjaaQCJnnheOYDs58DhVCKBpMlUZSmlRKkwalQZMG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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}, {360, 
           FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 360.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJxVm3dYze//xw+hkJQyopQmSpK0xLlJ8amkoVKKdrbILpyMUBnJyjxIyUjK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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[CurlyPhi]\
\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{-180, 
           FormBox[
            RowBox[{"-", "180"}], TraditionalForm]}, {0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {-180., 180.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -383.19}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-438.99, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.880458354278678*^9, 3.8804633535093117`*^9, 
  3.8804640792523613`*^9, 3.880464220863752*^9, 3.880612978436286*^9, 
  3.880613110382905*^9, 3.88065552797738*^9, 3.880702748621338*^9, 
  3.880702880849525*^9, 3.880702911474237*^9, 3.880702994759207*^9, 
  3.8807034643355494`*^9, 3.890982088482634*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"69a4dd33-2f56-48b8-a81f-692ea8f7b997"]
}, Open  ]],

Cell["\<\
Produce the x-y plot for the case of 2:1 resonance inner circulation.  This \
is Fig.8.17e.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, {3.88046337138177*^9, 
   3.880463373916685*^9}, {3.880614109098806*^9, 3.880614116043968*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4866f574-20cf-4170-a51a-7f534acd8406"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xyE", "=", "xyplot"}]], "Input",
 CellChangeTimes->{{3.8804583579762783`*^9, 3.880458362693686*^9}, {
  3.880702886702837*^9, 3.8807028880818253`*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"43fb6112-cba6-4599-878e-419d1df537b5"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVV3c81f8XtkdWRJQGRRoiSiX0vsU3FJEUmYWoSEKKZFTSIkpJkZFRooiM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     "]]}, {{}, {}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-4., 4.}, {-4., 4.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Prolog->{
    Thickness[0.002], 
    LineBox[{{0, -4}, {0, 4}}], 
    LineBox[{{-4, 0}, {4, 0}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.880655528032187*^9, 3.8807027486808643`*^9, {3.880702889600572*^9, 
   3.880702916340584*^9}, 3.880702999636381*^9, 3.88070346440256*^9, 
   3.890982088543338*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"6433becd-994c-498f-b6e4-91cfa392f7cb"]
}, Open  ]],

Cell["\<\
Produce the four unlabelled plots for the case of 2:1 resonance outer \
circulation.  This is Fig.8.16f.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, 3.880462891878394*^9, {
   3.880614128433856*^9, 3.880614143794026*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fed2aeec-0c77-4623-85ce-bf7cf6c3666f"],

Cell[BoxData[
 RowBox[{"FourPlotNoLabel", "[", 
  RowBox[{"0.001", ",", " ", "init6", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.88046267960392*^9, 3.880462680234071*^9}, {
  3.880463182008906*^9, 3.880463182578125*^9}, {3.880463259858301*^9, 
  3.880463260503047*^9}, {3.880463330912463*^9, 3.8804633314215603`*^9}, {
  3.8804634048323383`*^9, 3.880463405476356*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"3c473291-d757-4aed-9f94-6612fe8f2f93"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcNLF", "=", "gcNL"}]], "Input",
 CellChangeTimes->{{3.880463026210558*^9, 3.88046302986303*^9}, {
  3.880463083413727*^9, 3.880463090373127*^9}, {3.880463186522532*^9, 
  3.880463187214306*^9}, {3.880463263263054*^9, 3.880463264012458*^9}, {
  3.8804633381433487`*^9, 3.8804633387719584`*^9}, {3.880463407921545*^9, 
  3.880463408581562*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"5cb59276-b5f7-454a-9eb2-4d747b0ddc10"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
       {Dashing[{Small, Small}], LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.610592}], 
        PointBox[{0.1, 0.6125389993455937}], 
        PointBox[{0.2, 0.6139550788236566}], 
        PointBox[{0.3, 0.6150123269288509}], 
        PointBox[{0.4, 0.617103824886392}], 
        PointBox[{0.5, 0.6187989247449442}], 
        PointBox[{0.6, 0.6154377945321506}], 
        PointBox[{0.7, 0.6140540236547561}], 
        PointBox[{0.8, 0.6131242459516499}], 
        PointBox[{0.9, 0.6115623564717139}], 
        PointBox[{1., 0.6115251976302931}], 
        PointBox[{1.1, 0.6140585588996277}], 
        PointBox[{1.2, 0.615199187641102}], 
        PointBox[{1.3, 0.6164726200271676}], 
        PointBox[{1.4, 0.6190038255542829}], 
        PointBox[{1.5, 0.6170676588575594}], 
        PointBox[{1.6, 0.6145343304997509}], 
        PointBox[{1.7, 0.6136802310539865}], 
        PointBox[{1.8, 0.6129017420365447}], 
        PointBox[{1.9, 0.6116539609457533}], 
        PointBox[{2., 0.6139521250526869}], 
        PointBox[{2.1, 0.615789282922376}], 
        PointBox[{2.2, 0.6167903824046534}], 
        PointBox[{2.3, 0.6183424960713789}], 
        PointBox[{2.4, 0.6196857987564537}], 
        PointBox[{2.5, 0.6157878285001183}], 
        PointBox[{2.6, 0.6144567892710601}], 
        PointBox[{2.7, 0.614048370622393}], 
        PointBox[{2.8, 0.6136677422954637}], 
        PointBox[{2.9, 0.6132424376581082}], 
        PointBox[{3., 0.6165426378735465}], 
        PointBox[{3.1, 0.6177307079712592}], 
        PointBox[{3.2, 0.6187058864403464}], 
        PointBox[{3.3, 0.6203484859896197}], 
        PointBox[{3.4, 0.618851735101862}], 
        PointBox[{3.5, 0.6157013220655945}], 
        PointBox[{3.6, 0.6152545415655523}], 
        PointBox[{3.7, 0.6154340745558392}], 
        PointBox[{3.8, 0.6149793745799592}], 
        PointBox[{3.9, 0.6166021737568605}], 
        PointBox[{4., 0.619085288241464}], 
        PointBox[{4.1, 0.6199253078072509}], 
        PointBox[{4.2, 0.6209016088268712}], 
        PointBox[{4.3, 0.6219782466896115}], 
        PointBox[{4.4, 0.618363611594125}], 
        PointBox[{4.5, 0.6167031082578741}], 
        PointBox[{4.6, 0.617016874662271}], PointBox[{4.7, 0.61793668402}], 
        PointBox[{4.8, 0.6167842450570538}], 
        PointBox[{4.9, 0.6201037226659422}], 
        PointBox[{5., 0.6216896936052938}], 
        PointBox[{5.1, 0.6223520108304182}], 
        PointBox[{5.2, 0.6232548262686061}], 
        PointBox[{5.3, 0.6230572961395411}], 
        PointBox[{5.4, 0.6190925054198521}], 
        PointBox[{5.5, 0.6185708159450891}], 
        PointBox[{5.6, 0.6197264108912399}], 
        PointBox[{5.7, 0.6203918120423081}], 
        PointBox[{5.8, 0.619702227746976}], 
        PointBox[{5.9, 0.6232449839199719}], 
        PointBox[{6., 0.6243115673539309}], 
        PointBox[{6.1, 0.6248583783024309}], 
        PointBox[{6.2, 0.6255550164608555}], 
        PointBox[{6.3, 0.6240856119792233}], 
        PointBox[{6.4, 0.62069287287043}], 
        PointBox[{6.5, 0.6209625997833219}], 
        PointBox[{6.6, 0.6229009030826673}], 
        PointBox[{6.7, 0.6222194233641075}], 
        PointBox[{6.8, 0.6227033767315933}], 
        PointBox[{6.9, 0.6259366109294627}], 
        PointBox[{7., 0.6267381259005411}], 
        PointBox[{7.1, 0.6271801740439014}], 
        PointBox[{7.2, 0.6275912753064341}], 
        PointBox[{7.3, 0.6253706259225179}], 
        PointBox[{7.4, 0.6225699362767642}], 
        PointBox[{7.5, 0.6233953486663911}], 
        PointBox[{7.6, 0.6256000153281509}], 
        PointBox[{7.7, 0.6238814370146264}], 
        PointBox[{7.8, 0.6251016527559936}], 
        PointBox[{7.9, 0.6280798387830282}], 
        PointBox[{8., 0.6287491952553041}], 
        PointBox[{8.1, 0.6290869163426817}], 
        PointBox[{8.2, 0.629240953682147}], 
        PointBox[{8.3, 0.6267400680499516}], 
        PointBox[{8.4, 0.6242644082092877}], 
        PointBox[{8.5, 0.6254383107589859}], 
        PointBox[{8.6, 0.6273962047380517}], 
        PointBox[{8.7, 0.6252680898059365}], 
        PointBox[{8.8, 0.6267491555023199}], 
        PointBox[{8.9, 0.6296386049402879}], 
        PointBox[{9., 0.6302501484104256}], 
        PointBox[{9.1, 0.6304911716695587}], 
        PointBox[{9.2, 0.6304704386438991}], 
        PointBox[{9.3, 0.6279596857612562}], 
        PointBox[{9.4, 0.6255611941623894}], 
        PointBox[{9.5, 0.6268985315038891}], 
        PointBox[{9.6, 0.6285054127726699}], 
        PointBox[{9.7, 0.6262672303796093}], 
        PointBox[{9.8, 0.627726741370056}], 
        PointBox[{9.9, 0.6306548505160936}], 
        PointBox[{10., 0.6312587528531822}], 
        PointBox[{10.1, 0.6314155052394171}], 
        PointBox[{10.2, 0.6312953525547257}], 
        PointBox[{10.3, 0.6289122017662375}], 
        PointBox[{10.4, 0.6264260160986707}], 
        PointBox[{10.5, 0.627787561203083}], 
        PointBox[{10.6, 0.6291523687744136}], 
        PointBox[{10.7, 0.6268744071913317}], 
        PointBox[{10.8, 0.6281602724108628}], 
        PointBox[{10.9, 0.6311970082918738}], 
        PointBox[{11., 0.6318307482258785}], 
        PointBox[{11.1, 0.6319144366776346}], 
        PointBox[{11.2, 0.6317410407101777}], 
        PointBox[{11.3, 0.6295502573497699}], 
        PointBox[{11.4, 0.626893741306247}], 
        PointBox[{11.5, 0.6281931648109742}], 
        PointBox[{11.6, 0.6294248905934163}], 
        PointBox[{11.7, 0.6271128750399843}], 
        PointBox[{11.8, 0.6281558156292035}], 
        PointBox[{11.9, 0.6313240830854016}], 
        PointBox[{12., 0.6320122523270909}], 
        PointBox[{12.1, 0.6320276872859566}], 
        PointBox[{12.2, 0.6318208664268434}], 
        PointBox[{12.3, 0.629838970358772}], 
        PointBox[{12.4, 0.6269944114955714}], 
        PointBox[{12.5, 0.6281987059654173}], 
        PointBox[{12.6, 0.6293260470024187}], 
        PointBox[{12.7, 0.6269848787543562}], 
        PointBox[{12.8, 0.627783455377996}], 
        PointBox[{12.9, 0.6310748657811034}], 
        PointBox[{13., 0.6318211056884544}], 
        PointBox[{13.1, 0.6317646565696882}], 
        PointBox[{13.2, 0.6315261242218454}], 
        PointBox[{13.3, 0.629728989243674}], 
        PointBox[{13.4, 0.6267220897001446}], 
        PointBox[{13.5, 0.6278560502983505}], 
        PointBox[{13.6, 0.6288045652215322}], 
        PointBox[{13.7, 0.6264576459344414}], 
        PointBox[{13.8, 0.6270748452651863}], 
        PointBox[{13.9, 0.6304720231507083}], 
        PointBox[{14., 0.6312443498311319}], 
        PointBox[{14.1, 0.6311021354509421}], 
        PointBox[{14.2, 0.6308217262852628}], 
        PointBox[{14.3, 0.6291524792905674}], 
        PointBox[{14.4, 0.6260276839644638}], 
        PointBox[{14.5, 0.6271860314284842}], 
        PointBox[{14.6, 0.6277604404491381}], 
        PointBox[{14.7, 0.6254726211931098}], 
        PointBox[{14.8, 0.6260306170408432}], 
        PointBox[{14.9, 0.6295313008822073}], 
        PointBox[{15., 0.6302417907553189}], 
        PointBox[{15.1, 0.6299910615333055}], 
        PointBox[{15.2, 0.6296521299825136}], 
        PointBox[{15.3, 0.6280168453872602}], 
        PointBox[{15.4, 0.624833923282965}], 
        PointBox[{15.5, 0.6261795318229592}], 
        PointBox[{15.6, 0.6260649113463377}], 
        PointBox[{15.7, 0.6239840838340875}], 
        PointBox[{15.8, 0.624671105186547}], 
        PointBox[{15.9, 0.6282778647219647}], 
        PointBox[{16., 0.6287645253319014}], 
        PointBox[{16.1, 0.6283802261038203}], 
        PointBox[{16.2, 0.6279626271064821}], 
        PointBox[{16.3, 0.6262214495112927}], 
        PointBox[{16.4, 0.6230957123365991}], 
        PointBox[{16.5, 0.6247588929467123}], 
        PointBox[{16.6, 0.6236818343791152}], 
        PointBox[{16.7, 0.6220458599244116}], 
        PointBox[{16.8, 0.6231265260061891}], 
        PointBox[{16.9, 0.6267596484113421}], 
        PointBox[{17., 0.6268043026466292}], 
        PointBox[{17.1, 0.6262765506430413}], 
        PointBox[{17.2, 0.6257501451871283}], 
        PointBox[{17.3, 0.6236933538282613}], 
        PointBox[{17.4, 0.6209479003526289}], 
        PointBox[{17.5, 0.6226043040667102}], 
        PointBox[{17.6, 0.6208827179923494}], 
        PointBox[{17.7, 0.6199124659599969}], 
        PointBox[{17.8, 0.62174640011062}], 
        PointBox[{17.9, 0.6250209999554347}], 
        PointBox[{18., 0.6244699051888546}], 
        PointBox[{18.1, 0.6238190959193609}], 
        PointBox[{18.2, 0.6231267385920326}], 
        PointBox[{18.3, 0.6204642088174936}], 
        PointBox[{18.4, 0.618861496306806}], 
        PointBox[{18.5, 0.619544105292779}], 
        PointBox[{18.6, 0.6182367155001902}], 
        PointBox[{18.7, 0.6180436807977691}], 
        PointBox[{18.8, 0.6210131103061044}], 
        PointBox[{18.9, 0.6230510192735427}], 
        PointBox[{19., 0.6220007026148322}], 
        PointBox[{19.1, 0.6212621475891896}], 
        PointBox[{19.2, 0.6202690853455993}], 
        PointBox[{19.3, 0.6168692746323675}], 
        PointBox[{19.4, 0.617079450969987}], 
        PointBox[{19.5, 0.6166872261209535}], 
        PointBox[{19.6, 0.6162468623198135}], 
        PointBox[{19.7, 0.6169522415878262}], 
        PointBox[{19.8, 0.6209325314060165}], 
        PointBox[{19.9, 0.620889732866591}], 
        PointBox[{20., 0.619648509836758}], 
        PointBox[{20.1, 0.6188245180206159}], 
        PointBox[{20.2, 0.6172484590122923}], 
        PointBox[{20.3, 0.6140200128491785}], 
        PointBox[{20.4, 0.614976433964512}], 
        PointBox[{20.5, 0.6148864772609741}], 
        PointBox[{20.6, 0.6151465900856314}], 
        PointBox[{20.7, 0.6170657035410109}], 
        PointBox[{20.8, 0.6204452838139812}], 
        PointBox[{20.9, 0.6187442701810092}], 
        PointBox[{21., 0.6175541022015351}], 
        PointBox[{21.1, 0.6165672803827597}], 
        PointBox[{21.2, 0.6140462550526805}], 
        PointBox[{21.3, 0.6128823453996083}], 
        PointBox[{21.4, 0.6136465162734319}], 
        PointBox[{21.5, 0.6141148699267448}], 
        PointBox[{21.6, 0.6150106723562283}], 
        PointBox[{21.7, 0.6183676747576674}], 
        PointBox[{21.8, 0.6188521068384671}], 
        PointBox[{21.9, 0.6168348942736306}], 
        PointBox[{22., 0.6157489245810166}], 
        PointBox[{22.1, 0.6144163235601247}], 
        PointBox[{22.2, 0.6114467401540867}], 
        PointBox[{22.3, 0.6123385154895911}], 
        PointBox[{22.4, 0.6133840362311207}], 
        PointBox[{22.5, 0.6141817300319239}], 
        PointBox[{22.6, 0.6158992418992412}], 
        PointBox[{22.7, 0.619286948622408}], 
        PointBox[{22.8, 0.6168961797905068}], 
        PointBox[{22.9, 0.6152729211707432}], 
        PointBox[{23., 0.6142225109038315}], 
        PointBox[{23.1, 0.612334033222346}], 
        PointBox[{23.2, 0.6109031705669058}], 
        PointBox[{23.3, 0.6127579835167497}], 
        PointBox[{23.4, 0.6138485259436512}], 
        PointBox[{23.5, 0.6149622808976043}], 
        PointBox[{23.6, 0.6176883836107218}], 
        PointBox[{23.7, 0.6181157558636282}], 
        PointBox[{23.8, 0.6153071353233517}], 
        PointBox[{23.9, 0.6141101023632337}], 
        PointBox[{24., 0.6129939375500582}], 
        PointBox[{24.1, 0.6109177975206156}], 
        PointBox[{24.2, 0.6118718141866347}], 
        PointBox[{24.3, 0.6137913124069446}], 
        PointBox[{24.4, 0.6148380982808115}], 
        PointBox[{24.5, 0.6163916481280686}], 
        PointBox[{24.6, 0.6191680322598201}], 
        PointBox[{24.7, 0.6162166336631368}], 
        PointBox[{24.8, 0.6143103791178905}], 
        PointBox[{24.9, 0.6134170917947469}], 
        PointBox[{25., 0.6122432395693894}], 
        PointBox[{25.1, 0.6110269385239399}], 
        PointBox[{25.2, 0.6137609327718139}], 
        PointBox[{25.3, 0.615174113231973}], 
        PointBox[{25.4, 0.6162608916464557}], 
        PointBox[{25.5, 0.6183002867362175}], 
        PointBox[{25.6, 0.6185514332832426}], 
        PointBox[{25.7, 0.6150481347425568}], 
        PointBox[{25.8, 0.6139770931902935}], 
        PointBox[{25.9, 0.6133538703684379}], 
        PointBox[{26., 0.6124259967604442}], 
        PointBox[{26.1, 0.6131603140378115}], 
        PointBox[{26.2, 0.6158020904661414}], 
        PointBox[{26.3, 0.6168502153383579}], 
        PointBox[{26.4, 0.6180616720258345}], 
        PointBox[{26.5, 0.6200245768457869}], 
        PointBox[{26.6, 0.6170460593974095}], 
        PointBox[{26.7, 0.6148681511697484}], 
        PointBox[{26.8, 0.6144173408620507}], 
        PointBox[{26.9, 0.6142427550743695}], 
        PointBox[{27., 0.6132784654493211}], 
        PointBox[{27.1, 0.6162482051631102}], 
        PointBox[{27.2, 0.6179461665258228}], 
        PointBox[{27.3, 0.6188208542465604}], 
        PointBox[{27.4, 0.6201387231296824}], 
        PointBox[{27.5, 0.6205849878153622}], 
        PointBox[{27.6, 0.6165598492771919}], 
        PointBox[{27.7, 0.6156443470848676}], 
        PointBox[{27.8, 0.6158249307070315}], 
        PointBox[{27.9, 0.6161301025817938}], 
        PointBox[{28., 0.6157869880455654}], 
        PointBox[{28.1, 0.619218001259257}], 
        PointBox[{28.2, 0.620277831323489}], 
        PointBox[{28.3, 0.6210737003564437}], 
        PointBox[{28.4, 0.6222658708529528}], 
        PointBox[{28.5, 0.6204210352220182}], 
        PointBox[{28.6, 0.6173392491988292}], 
        PointBox[{28.7, 0.617347826036612}], 
        PointBox[{28.8, 0.6183576975583309}], 
        PointBox[{28.9, 0.6178637981196274}], 
        PointBox[{29., 0.6194003159348557}], 
        PointBox[{29.1, 0.6220586346809547}], 
        PointBox[{29.2, 0.6227880764229468}], 
        PointBox[{29.3, 0.6235106695231708}], 
        PointBox[{29.4, 0.6241920856311407}], 
        PointBox[{29.5, 0.6208557971914176}], 
        PointBox[{29.6, 0.6190386879776093}], 
        PointBox[{29.7, 0.6198523312080837}], 
        PointBox[{29.8, 0.6214486341148462}], 
        PointBox[{29.9, 0.6199288303238479}], 
        PointBox[{30., 0.6228105562670679}], 
        PointBox[{30.1, 0.6247604728041267}], 
        PointBox[{30.2, 0.6253108622016375}], 
        PointBox[{30.3, 0.6259154261982517}], 
        PointBox[{30.4, 0.6258798242388237}], 
        PointBox[{30.5, 0.6221194800204762}], 
        PointBox[{30.6, 0.6211932543687294}], 
        PointBox[{30.7, 0.6227506684460705}], 
        PointBox[{30.8, 0.6237898908831964}], 
        PointBox[{30.9, 0.6222832384618421}], 
        PointBox[{31., 0.625592387214073}], 
        PointBox[{31.1, 0.6271482685561228}], 
        PointBox[{31.2, 0.6275813268091157}], 
        PointBox[{31.3, 0.6280300628770286}], 
        PointBox[{31.4, 0.6274091806529773}], 
        PointBox[{31.5, 0.6237218941939875}], 
        PointBox[{31.6, 0.6233103274578444}], 
        PointBox[{31.7, 0.6254082963331472}], 
        PointBox[{31.8, 0.6253532845666555}], 
        PointBox[{31.9, 0.62430672222907}], 
        PointBox[{32., 0.6276661782673165}], 
        PointBox[{32.1, 0.6290565291415845}], 
        PointBox[{32.2, 0.6293998682963797}], 
        PointBox[{32.3, 0.6296937446622198}], 
        PointBox[{32.4, 0.6287569415142826}], 
        PointBox[{32.5, 0.6252163796809919}], 
        PointBox[{32.6, 0.6250386204423355}], 
        PointBox[{32.7, 0.6273900954147762}], 
        PointBox[{32.8, 0.6265074626924706}], 
        PointBox[{32.9, 0.6257536405163633}], 
        PointBox[{33., 0.6290686128558269}], 
        PointBox[{33.1, 0.6304391964163731}], 
        PointBox[{33.2, 0.6307108969498217}], 
        PointBox[{33.3, 0.6308782190882958}], 
        PointBox[{33.4, 0.6298422972843448}], 
        PointBox[{33.5, 0.6264005631406645}], 
        PointBox[{33.6, 0.6262505812031101}], 
        PointBox[{33.7, 0.6286636227909298}], 
        PointBox[{33.8, 0.6273260491187292}], 
        PointBox[{33.9, 0.6266404892996964}], 
        PointBox[{34., 0.6298854266163828}], 
        PointBox[{34.1, 0.6313348997164612}], 
        PointBox[{34.2, 0.6315501493334861}], 
        PointBox[{34.3, 0.6316211751783464}], 
        PointBox[{34.4, 0.6306142888161941}], 
        PointBox[{34.5, 0.6272339070617633}], 
        PointBox[{34.6, 0.6269673103119826}], 
        PointBox[{34.7, 0.629368759845037}], 
        PointBox[{34.8, 0.6278151447153622}], 
        PointBox[{34.9, 0.6270592237812758}], 
        PointBox[{35., 0.6302066715822955}], 
        PointBox[{35.1, 0.6318030104503108}], 
        PointBox[{35.2, 0.6319727760448961}], 
        PointBox[{35.3, 0.6319691777325998}], 
        PointBox[{35.4, 0.6310453797878506}], 
        PointBox[{35.5, 0.6277249140198731}], 
        PointBox[{35.6, 0.6272546616785643}], 
        PointBox[{35.7, 0.6296250287683801}], 
        PointBox[{35.8, 0.6279661395879962}], 
        PointBox[{35.9, 0.6270851298688833}], 
        PointBox[{36., 0.6301051739116938}], 
        PointBox[{36.1, 0.6318870702502195}], 
        PointBox[{36.2, 0.632013769968654}], 
        PointBox[{36.3, 0.6319444069998673}], 
        PointBox[{36.4, 0.6311116976245339}], 
        PointBox[{36.5, 0.6278660903690695}], 
        PointBox[{36.6, 0.627164939215427}], 
        PointBox[{36.7, 0.629493926391096}], 
        PointBox[{36.8, 0.6277447807046861}], 
        PointBox[{36.9, 0.6267504602595999}], 
        PointBox[{37., 0.6296340479018383}], 
        PointBox[{37.1, 0.6316039194076425}], 
        PointBox[{37.2, 0.6316772952951559}], 
        PointBox[{37.3, 0.6315420140366312}], 
        PointBox[{37.4, 0.6307780385848606}], 
        PointBox[{37.5, 0.6276109521991741}], 
        PointBox[{37.6, 0.6267173672306944}], 
        PointBox[{37.7, 0.628981159961672}], 
        PointBox[{37.8, 0.6270847917811578}], 
        PointBox[{37.9, 0.6260449641201801}], 
        PointBox[{38., 0.6288318123244663}], 
        PointBox[{38.1, 0.6309451310973002}], 
        PointBox[{38.2, 0.6309349896113761}], 
        PointBox[{38.3, 0.6307252360641499}], 
        PointBox[{38.4, 0.6299901787843657}], 
        PointBox[{38.5, 0.6268688209457922}], 
        PointBox[{38.6, 0.6259037690647885}], 
        PointBox[{38.7, 0.6280194837962081}], 
        PointBox[{38.8, 0.6259006259002178}], 
        PointBox[{38.9, 0.6249353925629171}], 
        PointBox[{39., 0.6277371344382137}], 
        PointBox[{39.1, 0.6298818567053595}], 
        PointBox[{39.2, 0.6297345061946062}], 
        PointBox[{39.3, 0.6294386709606657}], 
        PointBox[{39.4, 0.6286781940659459}], 
        PointBox[{39.5, 0.6255188897371072}], 
        PointBox[{39.6, 0.6247179371341978}], 
        PointBox[{39.7, 0.6264295972094236}], 
        PointBox[{39.8, 0.6241412524426769}], 
        PointBox[{39.9, 0.6234200909295928}], 
        PointBox[{40., 0.6264282110456575}], 
        PointBox[{40.1, 0.628383316398518}], 
        PointBox[{40.2, 0.6280315389609141}], 
        PointBox[{40.3, 0.6276392779085586}], 
        PointBox[{40.4, 0.6267770116092951}], 
        PointBox[{40.5, 0.6234572915270233}], 
        PointBox[{40.6, 0.6232148775111994}], 
        PointBox[{40.7, 0.6239913666759291}], 
        PointBox[{40.8, 0.6218976114493953}], 
        PointBox[{40.9, 0.621629372505358}], 
        PointBox[{41., 0.6250711463722428}], 
        PointBox[{41.1, 0.6264550068068246}], 
        PointBox[{41.2, 0.6258577018426664}], 
        PointBox[{41.3, 0.6253627141387285}], 
        PointBox[{41.4, 0.6242736131487278}], 
        PointBox[{41.5, 0.6207397490120048}], 
        PointBox[{41.6, 0.6214747001734267}], 
        PointBox[{41.7, 0.6209063558830664}], 
        PointBox[{41.8, 0.619499076966302}], 
        PointBox[{41.9, 0.6199311028545412}], 
        PointBox[{42., 0.623846451301645}], 
        PointBox[{42.1, 0.624193274306875}], 
        PointBox[{42.2, 0.6233877110238428}], 
        PointBox[{42.3, 0.6227774697023638}], 
        PointBox[{42.4, 0.621233069274277}], 
        PointBox[{42.5, 0.617860377126834}], 
        PointBox[{42.6, 0.6191303131200466}], 
        PointBox[{42.7, 0.6179884205093937}], 
        PointBox[{42.8, 0.617428582624354}], 
        PointBox[{42.9, 0.6189028342526781}], 
        PointBox[{43., 0.6226310276174021}], 
        PointBox[{43.1, 0.6218020339513622}], 
        PointBox[{43.2, 0.6208915352998196}], 
        PointBox[{43.3, 0.62011496601047}], 
        PointBox[{43.4, 0.6177533277250683}], 
        PointBox[{43.5, 0.6157903487662009}], 
        PointBox[{43.6, 0.6163556045760974}], 
        PointBox[{43.7, 0.615880840407474}], 
        PointBox[{43.8, 0.6161085534218239}], 
        PointBox[{43.9, 0.6190182703269816}], 
        PointBox[{44., 0.6210141436852347}], 
        PointBox[{44.1, 0.61951259861292}], 
        PointBox[{44.2, 0.6185775318502048}], 
        PointBox[{44.3, 0.6174869168274634}], 
        PointBox[{44.4, 0.6142078321487526}], 
        PointBox[{44.5, 0.614368111110336}], 
        PointBox[{44.6, 0.6145226902329386}], 
        PointBox[{44.7, 0.6147368705566124}], 
        PointBox[{44.8, 0.6158302268068897}], 
        PointBox[{44.9, 0.6197830175120449}], 
        PointBox[{45., 0.6190106218793233}], 
        PointBox[{45.1, 0.6174768035407295}], 
        PointBox[{45.2, 0.6165101798584292}], 
        PointBox[{45.3, 0.6148129665109795}], 
        PointBox[{45.4, 0.6120682123225619}], 
        PointBox[{45.5, 0.6131814839247226}], 
        PointBox[{45.6, 0.6137968830576677}], 
        PointBox[{45.7, 0.6145043533518736}], 
        PointBox[{45.8, 0.6167804947293296}], 
        PointBox[{45.9, 0.6194164684468482}], 
        PointBox[{46., 0.6170546248381632}], 
        PointBox[{46.1, 0.6157510452535828}], 
        PointBox[{46.2, 0.6146538366116493}], 
        PointBox[{46.3, 0.6121432336266436}], 
        PointBox[{46.4, 0.6116558228355345}], 
        PointBox[{46.5, 0.6130452759395135}], 
        PointBox[{46.6, 0.6139015844087758}], 
        PointBox[{46.7, 0.6151381361796012}], 
        PointBox[{46.8, 0.6185253276836945}], 
        PointBox[{46.9, 0.6176360548215131}], 
        PointBox[{47., 0.6154479739109198}], 
        PointBox[{47.1, 0.6143521763838051}], 
        PointBox[{47.2, 0.612967598130455}], 
        PointBox[{47.3, 0.6106585967109985}], 
        PointBox[{47.4, 0.612227814662504}], 
        PointBox[{47.5, 0.6136427483930591}], 
        PointBox[{47.6, 0.6146499574994009}], 
        PointBox[{47.7, 0.6166084835463759}], 
        PointBox[{47.8, 0.6190145217862063}], 
        PointBox[{47.9, 0.6158223333803353}], 
        PointBox[{48., 0.6143010217518329}], 
        PointBox[{48.1, 0.6133186682199182}], 
        PointBox[{48.2, 0.611645125359546}], 
        PointBox[{48.3, 0.6110777057249428}], 
        PointBox[{48.4, 0.6135401229219547}], 
        PointBox[{48.5, 0.6147159549886843}], 
        PointBox[{48.6, 0.6159454431640585}], 
        PointBox[{48.7, 0.6185525914439284}], 
        PointBox[{48.8, 0.617433446283495}], 
        PointBox[{48.9, 0.6146730745551321}], 
        PointBox[{49., 0.6136850717248828}], 
        PointBox[{49.1, 0.6127876909554493}], 
        PointBox[{49.2, 0.6113647099935547}], 
        PointBox[{49.3, 0.6131667395762387}], 
        PointBox[{49.4, 0.6151348160197756}], 
        PointBox[{49.5, 0.6161653817867646}], 
        PointBox[{49.6, 0.6177080637004296}], 
        PointBox[{49.7, 0.6195825212458136}], 
        PointBox[{49.8, 0.6158769639408805}], 
        PointBox[{49.9, 0.6143047483233716}], 
        PointBox[{50., 0.6137295663324025}], 
        PointBox[{50.1, 0.6131129749458696}], 
        PointBox[{50.2, 0.6124154426916655}], 
        PointBox[{50.3, 0.6156555428486153}], 
        PointBox[{50.4, 0.6169488953436383}], 
        PointBox[{50.5, 0.6179552016307832}], 
        PointBox[{50.6, 0.6197059378134586}], 
        PointBox[{50.7, 0.6188138040603929}], 
        PointBox[{50.8, 0.6154289897395974}], 
        PointBox[{50.9, 0.6147663265362907}], 
        PointBox[{51., 0.614683528872736}], 
        PointBox[{51.1, 0.6142590753098458}], 
        PointBox[{51.2, 0.6154825269537572}], 
        PointBox[{51.3, 0.6181075075624576}], 
        PointBox[{51.4, 0.6190163737035319}], 
        PointBox[{51.5, 0.6200481834415991}], 
        PointBox[{51.6, 0.6213860667896548}], 
        PointBox[{51.7, 0.6179799441237122}], 
        PointBox[{51.8, 0.6160904332179872}], 
        PointBox[{51.9, 0.6161622507646657}], 
        PointBox[{52., 0.616802110785002}], 
        PointBox[{52.1, 0.6157664267890165}], 
        PointBox[{52.2, 0.618963332510259}], 
        PointBox[{52.3, 0.620626703633638}], 
        PointBox[{52.4, 0.6213442477301259}], 
        PointBox[{52.5, 0.6223414063631807}], 
        PointBox[{52.6, 0.6223703917456299}], 
        PointBox[{52.7, 0.6183573732681292}], 
        PointBox[{52.8, 0.6176938956230537}], 
        PointBox[{52.9, 0.6185721032581029}], 
        PointBox[{53., 0.6192988234800872}], 
        PointBox[{53.1, 0.6186039997555784}], 
        PointBox[{53.2, 0.6221564232551536}], 
        PointBox[{53.3, 0.6232335440366594}], 
        PointBox[{53.4, 0.6238360404541133}], 
        PointBox[{53.5, 0.6246438780837551}], 
        PointBox[{53.6, 0.6231646910969689}], 
        PointBox[{53.7, 0.619781917125119}], 
        PointBox[{53.8, 0.6199872020469238}], 
        PointBox[{53.9, 0.6217168125031156}], 
        PointBox[{54., 0.621188479662491}], 
        PointBox[{54.1, 0.6218331619031224}], 
        PointBox[{54.2, 0.6249879234710685}], 
        PointBox[{54.3, 0.6257622804105264}], 
        PointBox[{54.4, 0.6262610708892261}], 
        PointBox[{54.5, 0.6267475148891682}], 
        PointBox[{54.6, 0.6243088316186705}], 
        PointBox[{54.7, 0.6216856780345364}], 
        PointBox[{54.8, 0.6225391946439828}], 
        PointBox[{54.9, 0.6246487590046209}], 
        PointBox[{55., 0.6229827164285902}], 
        PointBox[{55.1, 0.6245606299863274}], 
        PointBox[{55.2, 0.627349848504513}], 
        PointBox[{55.3, 0.6279661128770491}], 
        PointBox[{55.4, 0.6283550848652363}], 
        PointBox[{55.5, 0.628518990531239}], 
        PointBox[{55.6, 0.6256987446686634}], 
        PointBox[{55.7, 0.6235434923950756}], 
        PointBox[{55.8, 0.6248503819273065}], 
        PointBox[{55.9, 0.6266630952127251}], 
        PointBox[{56., 0.6245809338260956}], 
        PointBox[{56.1, 0.6265290341511804}], 
        PointBox[{56.2, 0.6291536145156854}], 
        PointBox[{56.3, 0.6296866089470525}], 
        PointBox[{56.4, 0.6299681814168895}], 
        PointBox[{56.5, 0.6299037692197621}], 
        PointBox[{56.6, 0.6270291799463781}], 
        PointBox[{56.7, 0.6250443317146884}], 
        PointBox[{56.8, 0.6266076493026875}], 
        PointBox[{56.9, 0.6279240113631466}], 
        PointBox[{57., 0.6257887771559472}], 
        PointBox[{57.1, 0.6277766543086342}], 
        PointBox[{57.2, 0.630403865373437}], 
        PointBox[{57.3, 0.6309002072156523}], 
        PointBox[{57.4, 0.6310868785813657}], 
        PointBox[{57.5, 0.6308967411994186}], 
        PointBox[{57.6, 0.6281229495843684}], 
        PointBox[{57.7, 0.6260956154771748}], 
        PointBox[{57.8, 0.6277537581391568}], 
        PointBox[{57.9, 0.6287068518479212}], 
        PointBox[{58., 0.6265738812508412}], 
        PointBox[{58.1, 0.6284240537321338}], 
        PointBox[{58.2, 0.6311596069650295}], 
        PointBox[{58.3, 0.6316536671745256}], 
        PointBox[{58.4, 0.6317597140936904}], 
        PointBox[{58.5, 0.6315123913013503}], 
        PointBox[{58.6, 0.6289161046830613}], 
        PointBox[{58.7, 0.6267191339148157}], 
        PointBox[{58.8, 0.6283664500998315}], 
        PointBox[{58.9, 0.6291224574848127}], 
        PointBox[{59., 0.6269681790195246}], 
        PointBox[{59.1, 0.628586702555568}], 
        PointBox[{59.2, 0.6314839657306799}], 
        PointBox[{59.3, 0.6320007069955113}], 
        PointBox[{59.4, 0.6320346733510166}], 
        PointBox[{59.5, 0.6317639612041278}], 
        PointBox[{59.6, 0.6293793228898729}], 
        PointBox[{59.7, 0.6269588745433138}], 
        PointBox[{59.8, 0.6285422153117635}], 
        PointBox[{59.9, 0.6291858495194222}], 
        PointBox[{60., 0.6269961813556494}], 
        PointBox[{60.1, 0.6283532588691444}], 
        PointBox[{60.2, 0.6314222612986087}], 
        PointBox[{60.3, 0.631971921721805}], 
        PointBox[{60.4, 0.6319354897885915}], 
        PointBox[{60.5, 0.6316488993901658}], 
        PointBox[{60.6, 0.6294735488393753}], 
        PointBox[{60.7, 0.6268334284109535}], 
        PointBox[{60.8, 0.628351671806388}], 
        PointBox[{60.9, 0.6288575638864476}], 
        PointBox[{61., 0.6266481568017025}], 
        PointBox[{61.1, 0.6277738432640688}], 
        PointBox[{61.2, 0.6309992235666336}], 
        PointBox[{61.3, 0.6315669897757342}], 
        PointBox[{61.4, 0.6314527064870898}], 
        PointBox[{61.5, 0.6311423235498614}], 
        PointBox[{61.6, 0.6291352244194556}], 
        PointBox[{61.7, 0.6263203858607261}], 
        PointBox[{61.8, 0.6278293946680583}], 
        PointBox[{61.9, 0.6280543092006133}], 
        PointBox[{62., 0.6258801008433404}], 
        PointBox[{62.1, 0.6268683286694834}], 
        PointBox[{62.2, 0.6302250114744063}], 
        PointBox[{62.3, 0.6307548683038736}], 
        PointBox[{62.4, 0.6305463936713167}], 
        PointBox[{62.5, 0.6301947525045596}], 
        PointBox[{62.6, 0.6282763165997758}], 
        PointBox[{62.7, 0.6253619394611523}], 
        PointBox[{62.8, 0.6269723483220724}], 
        PointBox[{62.9, 0.6266603417879486}], 
        PointBox[{63., 0.624637256238734}], 
        PointBox[{63.1, 0.625649279626297}], 
        PointBox[{63.2, 0.6291071148212569}], 
        PointBox[{63.3, 0.6294845357149798}], 
        PointBox[{63.4, 0.6291605436308683}], 
        PointBox[{63.5, 0.628745057183692}], 
        PointBox[{63.6, 0.6267890102215401}], 
        PointBox[{63.7, 0.6239026938516464}], 
        PointBox[{63.8, 0.6257113915558462}], 
        PointBox[{63.9, 0.6245958988324883}], 
        PointBox[{64., 0.6229176839114003}], 
        PointBox[{64.1, 0.6241930304357634}], 
        PointBox[{64.2, 0.627666357923974}], 
        PointBox[{64.3, 0.6277206846647658}], 
        PointBox[{64.4, 0.627266507583609}], 
        PointBox[{64.5, 0.6267560100190267}], 
        PointBox[{64.6, 0.6245736478013347}], 
        PointBox[{64.7, 0.6219932419828805}], 
        PointBox[{64.8, 0.6237844359356943}], 
        PointBox[{64.9, 0.6219885292893647}], 
        PointBox[{65., 0.6208763176678608}], 
        PointBox[{65.1, 0.6227467387236878}], 
        PointBox[{65.2, 0.6259393996732413}], 
        PointBox[{65.3, 0.6255141022499009}], 
        PointBox[{65.4, 0.6249358090189592}], 
        PointBox[{65.5, 0.6242766007688471}], 
        PointBox[{65.6, 0.6216071054069813}], 
        PointBox[{65.7, 0.6199499869036796}], 
        PointBox[{65.8, 0.6208872657140985}], 
        PointBox[{65.9, 0.6192834896788596}], 
        PointBox[{66., 0.6188939553282217}], 
        PointBox[{66.1, 0.6217397330745105}], 
        PointBox[{66.2, 0.623955118662238}], 
        PointBox[{66.3, 0.6230577218285981}], 
        PointBox[{66.4, 0.6223803219841196}], 
        PointBox[{66.5, 0.6214570009944114}], 
        PointBox[{66.6, 0.6181168544600256}], 
        PointBox[{66.7, 0.6181250741542826}], 
        PointBox[{66.8, 0.6177828574743928}], 
        PointBox[{66.9, 0.6170281746674704}], 
        PointBox[{67., 0.6174951937896496}], 
        PointBox[{67.1, 0.6213691964930147}], 
        PointBox[{67.2, 0.6217697224640725}], 
        PointBox[{67.3, 0.6206206493469792}], 
        PointBox[{67.4, 0.619852226452332}], 
        PointBox[{67.5, 0.6184170581764438}], 
        PointBox[{67.6, 0.61498153718204}], 
        PointBox[{67.7, 0.6159456316217025}], 
        PointBox[{67.8, 0.6155548589663005}], 
        PointBox[{67.9, 0.6155768389827833}], 
        PointBox[{68., 0.6171836208335415}], 
        PointBox[{68.1, 0.6209100327962591}], 
        PointBox[{68.2, 0.6195579966472263}], 
        PointBox[{68.3, 0.6183976267241461}], 
        PointBox[{68.4, 0.6174818527894069}], 
        PointBox[{68.5, 0.6151509455303593}], 
        PointBox[{68.6, 0.6134426727687585}], 
        PointBox[{68.7, 0.6141354801339435}], 
        PointBox[{68.8, 0.6143932651432273}], 
        PointBox[{68.9, 0.6150760372694883}], 
        PointBox[{69., 0.6181603577295407}], 
        PointBox[{69.1, 0.6194894536712409}], 
        PointBox[{69.2, 0.617535750334287}], 
        PointBox[{69.3, 0.6164551761170775}], 
        PointBox[{69.4, 0.6152291008899735}], 
        PointBox[{69.5, 0.6121338402174952}], 
        PointBox[{69.6, 0.6126097113314253}], 
        PointBox[{69.7, 0.6134682483382609}], 
        PointBox[{69.8, 0.6141385060542923}], 
        PointBox[{69.9, 0.6156133790243021}], 
        PointBox[{70., 0.6193203606234052}], 
        PointBox[{70.1, 0.6175252634986423}], 
        PointBox[{70.2, 0.6158303876827256}], 
        PointBox[{70.3, 0.6147860013184336}], 
        PointBox[{70.4, 0.6130017026100887}], 
        PointBox[{70.5, 0.6110155407742774}], 
        PointBox[{70.6, 0.6126087809771771}], 
        PointBox[{70.7, 0.6136489166998536}], 
        PointBox[{70.8, 0.6146526260316079}], 
        PointBox[{70.9, 0.6171826734676414}], 
        PointBox[{71., 0.6186113545922616}], 
        PointBox[{71.1, 0.6157815897283}], 
        PointBox[{71.2, 0.614494668113717}], 
        PointBox[{71.3, 0.613380918827894}], 
        PointBox[{71.4, 0.6111463769452028}], 
        PointBox[{71.5, 0.6114849746691764}], 
        PointBox[{71.6, 0.6133937595723568}], 
        PointBox[{71.7, 0.6144271490573987}], 
        PointBox[{71.8, 0.6158663769939087}], 
        PointBox[{71.9, 0.6189289650159348}], 
        PointBox[{72., 0.6166902493388003}], 
        PointBox[{72.1, 0.614565652095283}], 
        PointBox[{72.2, 0.613580900077012}], 
        PointBox[{72.3, 0.6123359435971505}], 
        PointBox[{72.4, 0.610756876387778}], 
        PointBox[{72.5, 0.6130991808687406}], 
        PointBox[{72.6, 0.6146070948281432}], 
        PointBox[{72.7, 0.6156813498121921}], 
        PointBox[{72.8, 0.6176715762108612}], 
        PointBox[{72.9, 0.6188198014805539}], 
        PointBox[{73., 0.6152356491899965}], 
        PointBox[{73.1, 0.613962530965086}], 
        PointBox[{73.2, 0.6132071122816357}], 
        PointBox[{73.3, 0.6120719750272924}], 
        PointBox[{73.4, 0.61226123056458}], 
        PointBox[{73.5, 0.6150175417284626}], 
        PointBox[{73.6, 0.6161388393257524}], 
        PointBox[{73.7, 0.6173466453053821}], 
        PointBox[{73.8, 0.619535211897296}], 
        PointBox[{73.9, 0.617222772028172}], 
        PointBox[{74., 0.6147140810042628}], 
        PointBox[{74.1, 0.6140645980418648}], 
        PointBox[{74.2, 0.6136419632488921}], 
        PointBox[{74.3, 0.6126476198283964}], 
        PointBox[{74.4, 0.6151687331880923}], 
        PointBox[{74.5, 0.6170453463154697}], 
        PointBox[{74.6, 0.6179723294964281}], 
        PointBox[{74.7, 0.6193379401457076}], 
        PointBox[{74.8, 0.620325919438914}], 
        PointBox[{74.9, 0.6163214309866969}], 
        PointBox[{75., 0.6151295950115833}], 
        PointBox[{75.1, 0.615049307874316}], 
        PointBox[{75.2, 0.615170200650018}], 
        PointBox[{75.3, 0.6146254407606663}], 
        PointBox[{75.4, 0.618088389256925}], 
        PointBox[{75.5, 0.6192542684543008}], 
        PointBox[{75.6, 0.6201028343600647}], 
        PointBox[{75.7, 0.6214405555948475}], 
        PointBox[{75.8, 0.6200102440305183}], 
        PointBox[{75.9, 0.6167081893957426}], 
        PointBox[{76., 0.6164788162728491}], 
        PointBox[{76.1, 0.6171466476400788}], 
        PointBox[{76.2, 0.6168752307309104}], 
        PointBox[{76.3, 0.6181408711403711}], 
        PointBox[{76.4, 0.6208885268444879}], 
        PointBox[{76.5, 0.6216781476844374}], 
        PointBox[{76.6, 0.6224709162465859}], 
        PointBox[{76.7, 0.6233453910191521}], 
        PointBox[{76.8, 0.6200769352512105}], 
        PointBox[{76.9, 0.6181403038001596}], 
        PointBox[{77., 0.6187259554155522}], 
        PointBox[{77.1, 0.6201389766977683}], 
        PointBox[{77.2, 0.6188033832373844}], 
        PointBox[{77.3, 0.6216927900234218}], 
        PointBox[{77.4, 0.6236238621045302}], 
        PointBox[{77.5, 0.6242154891141425}], 
        PointBox[{77.6, 0.6249058877569635}], 
        PointBox[{77.7, 0.6249624009837605}], 
        PointBox[{77.8, 0.6211201977401026}], 
        PointBox[{77.9, 0.6202213585665391}], 
        PointBox[{78., 0.6216056669440565}], 
        PointBox[{78.1, 0.6227033483542116}], 
        PointBox[{78.2, 0.6212995212648692}], 
        PointBox[{78.3, 0.6247129467538841}], 
        PointBox[{78.4, 0.6261601271772967}], 
        PointBox[{78.5, 0.6266257836447934}], 
        PointBox[{78.6, 0.6271553073071241}], 
        PointBox[{78.7, 0.6264517162607837}], 
        PointBox[{78.8, 0.6227226885752241}], 
        PointBox[{78.9, 0.6224695121650081}], 
        PointBox[{79., 0.6245028404182634}], 
        PointBox[{79.1, 0.6244318001098588}], 
        PointBox[{79.2, 0.6236293982534681}], 
        PointBox[{79.3, 0.627074321526477}], 
        PointBox[{79.4, 0.6282920993768076}], 
        PointBox[{79.5, 0.6286593027216789}], 
        PointBox[{79.6, 0.6290093292805646}], 
        PointBox[{79.7, 0.6278552065609367}], 
        PointBox[{79.8, 0.6243494491541639}], 
        PointBox[{79.9, 0.6244474318066998}], 
        PointBox[{80., 0.6268015599973349}], 
        PointBox[{80.1, 0.6257506963820302}], 
        PointBox[{80.2, 0.6253820913501463}], 
        PointBox[{80.3, 0.6287676427530795}], 
        PointBox[{80.4, 0.6299114693690383}], 
        PointBox[{80.5, 0.6301958367249298}], 
        PointBox[{80.6, 0.6303937261770773}], 
        PointBox[{80.7, 0.629072512644911}], 
        PointBox[{80.8, 0.625698894979136}], 
        PointBox[{80.9, 0.625925792201191}], 
        PointBox[{81., 0.6283364758467332}], 
        PointBox[{81.1, 0.6267407278925176}], 
        PointBox[{81.2, 0.6265139592550035}], 
        PointBox[{81.3, 0.629852992414389}], 
        PointBox[{81.4, 0.6310239145654576}], 
        PointBox[{81.5, 0.6312395096327522}], 
        PointBox[{81.6, 0.6313255384989368}], 
        PointBox[{81.7, 0.6300151983709132}], 
        PointBox[{81.8, 0.6266832868874201}], 
        PointBox[{81.9, 0.6268743156834828}], 
        PointBox[{82., 0.6292459909156125}], 
        PointBox[{82.1, 0.6273947448970227}], 
        PointBox[{82.2, 0.6271168027167192}], 
        PointBox[{82.3, 0.6304153046940484}], 
        PointBox[{82.4, 0.6316856126823197}], 
        PointBox[{82.5, 0.6318442422983348}], 
        PointBox[{82.6, 0.6318486201180886}], 
        PointBox[{82.7, 0.6306376557382001}], 
        PointBox[{82.8, 0.6273092464428731}], 
        PointBox[{82.9, 0.6273540947609574}], 
        PointBox[{83., 0.6296785374278255}], 
        PointBox[{83.1, 0.6277119064071395}], 
        PointBox[{83.2, 0.6272899307497671}], 
        PointBox[{83.3, 0.6305304441708857}], 
        PointBox[{83.4, 0.6319491369407243}], 
        PointBox[{83.5, 0.6320567354881089}], 
        PointBox[{83.6, 0.6319968664363766}], 
        PointBox[{83.7, 0.6309112353086155}], 
        PointBox[{83.8, 0.6275897260122504}], 
        PointBox[{83.9, 0.6274333010441725}], 
        PointBox[{84., 0.629711346286019}], 
        PointBox[{84.1, 0.6276762456021547}], 
        PointBox[{84.2, 0.6270943503813089}], 
        PointBox[{84.3, 0.6302552250045033}], 
        PointBox[{84.4, 0.6318423110370558}], 
        PointBox[{84.5, 0.6318952916792765}], 
        PointBox[{84.6, 0.6317757418333257}], 
        PointBox[{84.7, 0.630802013582242}], 
        PointBox[{84.8, 0.6275051738196935}], 
        PointBox[{84.9, 0.6271536288739804}], 
        PointBox[{85., 0.6293605430400817}], 
        PointBox[{85.1, 0.6272419015996857}], 
        PointBox[{85.2, 0.6265454760795138}], 
        PointBox[{85.3, 0.6296306774030104}], 
        PointBox[{85.4, 0.6313660359597385}], 
        PointBox[{85.5, 0.6313464490983393}], 
        PointBox[{85.6, 0.6311622588772896}], 
        PointBox[{85.7, 0.6302617008115047}], 
        PointBox[{85.8, 0.6269899579502048}], 
        PointBox[{85.9, 0.6265244186021521}], 
        PointBox[{86., 0.628579463426529}], 
        PointBox[{86.1, 0.6263345064668896}], 
        PointBox[{86.2, 0.6256224913792209}], 
        PointBox[{86.3, 0.6286900128987656}], 
        PointBox[{86.4, 0.6304950016485723}], 
        PointBox[{86.5, 0.6303661302180714}], 
        PointBox[{86.6, 0.6301068635805223}], 
        PointBox[{86.7, 0.6292233440828793}], 
        PointBox[{86.8, 0.6259385076219228}], 
        PointBox[{86.9, 0.625540263812748}], 
        PointBox[{87., 0.6272331076361809}], 
        PointBox[{87.1, 0.6248817901060806}], 
        PointBox[{87.2, 0.6243046169302517}], 
        PointBox[{87.3, 0.6274845980557205}], 
        PointBox[{87.4, 0.62919084919656}], 
        PointBox[{87.5, 0.6289000399164365}], 
        PointBox[{87.6, 0.6285537198786704}], 
        PointBox[{87.7, 0.6276106870225716}], 
        PointBox[{87.8, 0.6242364066946432}], 
        PointBox[{87.9, 0.6242196586048068}], 
        PointBox[{88., 0.6251169339966535}], 
        PointBox[{88.1, 0.6228929396206392}], 
        PointBox[{88.2, 0.6226495922015173}], 
        PointBox[{88.3, 0.6261219723623576}], 
        PointBox[{88.4, 0.6274313700490047}], 
        PointBox[{88.5, 0.6269328784387518}], 
        PointBox[{88.6, 0.6264890422066559}], 
        PointBox[{88.7, 0.6253702620673743}], 
        PointBox[{88.8, 0.6218596238786571}], 
        PointBox[{88.9, 0.6226110322259991}], 
        PointBox[{89., 0.6222442154528738}], 
        PointBox[{89.1, 0.6205744545850175}], 
        PointBox[{89.2, 0.6209124015325251}], 
        PointBox[{89.3, 0.6247609243206684}], 
        PointBox[{89.4, 0.6252694138699221}], 
        PointBox[{89.5, 0.624567167212689}], 
        PointBox[{89.6, 0.6240126034200303}], 
        PointBox[{89.7, 0.6225184609972175}], 
        PointBox[{89.8, 0.6191036928858374}], 
        PointBox[{89.9, 0.6204747366139793}], 
        PointBox[{90., 0.6192064733321949}], 
        PointBox[{90.1, 0.6183514430860234}], 
        PointBox[{90.2, 0.6195992647203693}], 
        PointBox[{90.3, 0.623418085454173}], 
        PointBox[{90.4, 0.6228783952818246}], 
        PointBox[{90.5, 0.6220425339700306}], 
        PointBox[{90.6, 0.6213367003222439}], 
        PointBox[{90.7, 0.6191388904212283}], 
        PointBox[{90.8, 0.6167773961646527}], 
        PointBox[{90.9, 0.6175844660802923}], 
        PointBox[{91., 0.616746528987988}], 
        PointBox[{91.1, 0.61670057927348}], 
        PointBox[{91.2, 0.6192729499385603}], 
        PointBox[{91.3, 0.6218143530869367}], 
        PointBox[{91.4, 0.6205032403932654}], 
        PointBox[{91.5, 0.6196143250401548}], 
        PointBox[{91.6, 0.6186390074272169}], 
        PointBox[{91.7, 0.6154907089106344}], 
        PointBox[{91.8, 0.6152419836741493}], 
        PointBox[{91.9, 0.6152494571015492}], 
        PointBox[{92., 0.6151984615452772}], 
        PointBox[{92.1, 0.6159932789055955}], 
        PointBox[{92.2, 0.6198493012195188}], 
        PointBox[{92.3, 0.6198341559717818}], 
        PointBox[{92.4, 0.618336417058025}], 
        PointBox[{92.5, 0.6174114955014732}], 
        PointBox[{92.6, 0.6159059651237068}], 
        PointBox[{92.7, 0.612724102360111}], 
        PointBox[{92.8, 0.6136938068677457}], 
        PointBox[{92.9, 0.6140721629513696}], 
        PointBox[{93., 0.6145868725212187}], 
        PointBox[{93.1, 0.6164975766371876}], 
        PointBox[{93.2, 0.619837961076946}], 
        PointBox[{93.3, 0.6178003512197181}], 
        PointBox[{93.4, 0.6164637689149698}], 
        PointBox[{93.5, 0.6154273953528562}], 
        PointBox[{93.6, 0.6130739130146475}], 
        PointBox[{93.7, 0.6119100323145967}], 
        PointBox[{93.8, 0.6130878466050501}], 
        PointBox[{93.9, 0.6138333736562904}], 
        PointBox[{94., 0.6148744309904183}], 
        PointBox[{94.1, 0.6180940568741555}], 
        PointBox[{94.2, 0.6183133833423614}], 
        PointBox[{94.3, 0.6160404671210375}], 
        PointBox[{94.4, 0.6149037206450908}], 
        PointBox[{94.5, 0.6135994997388791}], 
        PointBox[{94.6, 0.6109411996131487}], 
        PointBox[{94.7, 0.6119976250894886}], 
        PointBox[{94.8, 0.6133780823120409}], 
        PointBox[{94.9, 0.6143125070673631}], 
        PointBox[{95., 0.6160535074801597}], 
        PointBox[{95.1, 0.619149308553331}], 
        PointBox[{95.2, 0.6163863429847721}], 
        PointBox[{95.3, 0.6146956269646935}], 
        PointBox[{95.4, 0.6136738875564844}], 
        PointBox[{95.5, 0.6119836196336238}], 
        PointBox[{95.6, 0.6107630739330111}], 
        PointBox[{95.7, 0.6130207965075809}], 
        PointBox[{95.8, 0.6142354907300149}], 
        PointBox[{95.9, 0.6153901065710161}], 
        PointBox[{96., 0.6179377755557289}], 
        PointBox[{96.1, 0.6179756064711064}], 
        PointBox[{96.2, 0.6149738888223032}], 
        PointBox[{96.3, 0.6138326930596065}], 
        PointBox[{96.4, 0.6128552644318297}], 
        PointBox[{96.5, 0.6111970179029708}], 
        PointBox[{96.6, 0.6123265452756138}], 
        PointBox[{96.7, 0.6144525378187324}], 
        PointBox[{96.8, 0.615512840251084}], 
        PointBox[{96.9, 0.6169931815744756}], 
        PointBox[{97., 0.6194035620448729}], 
        PointBox[{97.1, 0.6161811638072295}], 
        PointBox[{97.2, 0.6142901534851578}], 
        PointBox[{97.3, 0.6135511738622467}], 
        PointBox[{97.4, 0.6127166533394269}], 
        PointBox[{97.5, 0.6116702740009791}], 
        PointBox[{97.6, 0.6146811235203796}], 
        PointBox[{97.7, 0.6161260233536382}], 
        PointBox[{97.8, 0.6171526677512033}], 
        PointBox[{97.9, 0.6189517181773476}], 
        PointBox[{98., 0.6189697163184479}], 
        PointBox[{98.1, 0.6153137139545458}], 
        PointBox[{98.2, 0.6143865010435098}], 
        PointBox[{98.3, 0.6140544988210647}], 
        PointBox[{98.4, 0.6135643353718485}], 
        PointBox[{98.5, 0.6142056375872248}], 
        PointBox[{98.6, 0.6170484075998854}], 
        PointBox[{98.7, 0.6180506144131271}], 
        PointBox[{98.8, 0.6191191577923963}], 
        PointBox[{98.9, 0.6207506883788795}], 
        PointBox[{99., 0.6178222532781518}], 
        PointBox[{99.1, 0.6155617536941077}], 
        PointBox[{99.2, 0.6153614017705533}], 
        PointBox[{99.3, 0.6156582177598812}], 
        PointBox[{99.4, 0.6147571083426454}], 
        PointBox[{99.5, 0.6176284168456798}], 
        PointBox[{99.6, 0.6194661687778446}], 
        PointBox[{99.7, 0.6202484874690819}], 
        PointBox[{99.8, 0.6213311378381174}], 
        PointBox[{99.9, 0.6217758555052438}], 
        PointBox[{100., 0.617731007285496}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0.6, 0.65}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], 
        PointBox[{0, 0.19750000000000006`}], 
        PointBox[{0.1, 0.20155456748567904`}], 
        PointBox[{0.2, 0.20090651594250322`}], 
        PointBox[{0.3, 0.19908019719619066`}], 
        PointBox[{0.4, 0.19977832318423097`}], 
        PointBox[{0.5, 0.2031253120329808}], 
        PointBox[{0.6, 0.19872201322858168`}], 
        PointBox[{0.7, 0.2000081752191914}], 
        PointBox[{0.8, 0.20141438593212027`}], 
        PointBox[{0.9, 0.19926777711117152`}], 
        PointBox[{1., 0.19811412479023593`}], 
        PointBox[{1.1, 0.20036234848317458`}], 
        PointBox[{1.2, 0.19841163312038398`}], 
        PointBox[{1.3, 0.19721732980882656`}], 
        PointBox[{1.4, 0.20096089249287283`}], 
        PointBox[{1.5, 0.19869091033389863`}], 
        PointBox[{1.6, 0.1977050274599771}], 
        PointBox[{1.7, 0.1992951798805628}], 
        PointBox[{1.8, 0.19918254887938405`}], 
        PointBox[{1.9, 0.19428456025144544`}], 
        PointBox[{2., 0.1973480067848776}], 
        PointBox[{2.1, 0.1964226892373944}], 
        PointBox[{2.2, 0.19441851167853785`}], 
        PointBox[{2.3, 0.1949150448979892}], 
        PointBox[{2.4, 0.1989505195467981}], 
        PointBox[{2.5, 0.19418584145662965`}], 
        PointBox[{2.6, 0.19550057054362416`}], 
        PointBox[{2.7, 0.19616454389644458`}], 
        PointBox[{2.8, 0.19342812839634052`}], 
        PointBox[{2.9, 0.18958933817912116`}], 
        PointBox[{3., 0.19269831320026556`}], 
        PointBox[{3.1, 0.19038136147278403`}], 
        PointBox[{3.2, 0.18912552434238952`}], 
        PointBox[{3.3, 0.19188841923111957`}], 
        PointBox[{3.4, 0.19175123517332793`}], 
        PointBox[{3.5, 0.1896046423720966}], 
        PointBox[{3.6, 0.19105108895412598`}], 
        PointBox[{3.7, 0.18978643521999922`}], 
        PointBox[{3.8, 0.183998765037925}], 
        PointBox[{3.9, 0.18477954327494184`}], 
        PointBox[{4., 0.18482834994656264`}], 
        PointBox[{4.1, 0.18246697093603562`}], 
        PointBox[{4.2, 0.18245221433455291`}], 
        PointBox[{4.3, 0.18647079883531534`}], 
        PointBox[{4.4, 0.18262656425024926`}], 
        PointBox[{4.5, 0.18337020356723968`}], 
        PointBox[{4.6, 0.1836179596059109}], 
        PointBox[{4.7, 0.17958075446523314`}], 
        PointBox[{4.8, 0.17307684206882054`}], 
        PointBox[{4.9, 0.1766388815770932}], 
        PointBox[{5., 0.17464438477001176`}], 
        PointBox[{5.1, 0.1728011823442515}], 
        PointBox[{5.2, 0.174151601784906}], 
        PointBox[{5.3, 0.17723459661139523`}], 
        PointBox[{5.4, 0.1729289303876947}], 
        PointBox[{5.5, 0.17472123472734258`}], 
        PointBox[{5.6, 0.17302683259741883`}], 
        PointBox[{5.7, 0.16663080564848373`}], 
        PointBox[{5.8, 0.16243437997181473`}], 
        PointBox[{5.9, 0.16580527013285618`}], 
        PointBox[{6., 0.16306614742447803`}], 
        PointBox[{6.1, 0.16186396839548475`}], 
        PointBox[{6.2, 0.16427315172706855`}], 
        PointBox[{6.3, 0.16538400348346582`}], 
        PointBox[{6.4, 0.16233433932314317`}], 
        PointBox[{6.5, 0.16408233195952057`}], 
        PointBox[{6.6, 0.16037400688561632`}], 
        PointBox[{6.7, 0.15375997799282312`}], 
        PointBox[{6.8, 0.15196714537839506`}], 
        PointBox[{6.9, 0.15433666124687487`}], 
        PointBox[{7., 0.1514092401221702}], 
        PointBox[{7.1, 0.15073392559460577`}], 
        PointBox[{7.2, 0.15369734547368116`}], 
        PointBox[{7.3, 0.1533427601127046}], 
        PointBox[{7.4, 0.15143950894232783`}], 
        PointBox[{7.5, 0.15291485498077642`}], 
        PointBox[{7.6, 0.14818135179913614`}], 
        PointBox[{7.7, 0.14276186985913983`}], 
        PointBox[{7.8, 0.14229683393317488`}], 
        PointBox[{7.9, 0.1440446247174054}], 
        PointBox[{8., 0.14106234059305445`}], 
        PointBox[{8.1, 0.14069335901739416`}], 
        PointBox[{8.2, 0.14383428079283525`}], 
        PointBox[{8.3, 0.1428627965599429}], 
        PointBox[{8.4, 0.14148680361394936`}], 
        PointBox[{8.5, 0.14289819369922294`}], 
        PointBox[{8.6, 0.13848619102911214`}], 
        PointBox[{8.7, 0.1343344622517878}], 
        PointBox[{8.8, 0.1343086755424601}], 
        PointBox[{8.9, 0.13596419554569497`}], 
        PointBox[{9., 0.13292049141114998`}], 
        PointBox[{9.1, 0.13262952667483652`}], 
        PointBox[{9.2, 0.13576410979587566`}], 
        PointBox[{9.3, 0.13479937034021383`}], 
        PointBox[{9.4, 0.133424634941013}], 
        PointBox[{9.5, 0.13506625744024253`}], 
        PointBox[{9.6, 0.13172994795385956`}], 
        PointBox[{9.7, 0.12861190643103557`}], 
        PointBox[{9.8, 0.12847457824406938`}], 
        PointBox[{9.9, 0.1304224619564916}], 
        PointBox[{10., 0.12730340470845003`}], 
        PointBox[{10.1, 0.1269088042147929}], 
        PointBox[{10.2, 0.12994738417802934`}], 
        PointBox[{10.3, 0.12937818577887333`}], 
        PointBox[{10.4, 0.12765732464798055`}], 
        PointBox[{10.5, 0.12971775919844677`}], 
        PointBox[{10.6, 0.12767579337464355`}], 
        PointBox[{10.7, 0.12548428457235447`}], 
        PointBox[{10.8, 0.12493753662164414`}], 
        PointBox[{10.9, 0.1273816599583602}], 
        PointBox[{11., 0.12421240718282643`}], 
        PointBox[{11.1, 0.12359594478873569`}], 
        PointBox[{11.2, 0.12647392615215095`}], 
        PointBox[{11.3, 0.12650978702145427`}], 
        PointBox[{11.4, 0.12427431193069895`}], 
        PointBox[{11.5, 0.126798132139433}], 
        PointBox[{11.6, 0.12607053496257656`}], 
        PointBox[{11.7, 0.12480028360639041`}], 
        PointBox[{11.8, 0.12374454035945669`}], 
        PointBox[{11.9, 0.12671837383352524`}], 
        PointBox[{12., 0.12356089287669213`}], 
        PointBox[{12.1, 0.12267114999691771`}], 
        PointBox[{12.2, 0.12533818461370366`}], 
        PointBox[{12.3, 0.12603055708315342`}], 
        PointBox[{12.4, 0.12327954877922308`}], 
        PointBox[{12.5, 0.12621194088868504`}], 
        PointBox[{12.6, 0.12680526217236834`}], 
        PointBox[{12.7, 0.1264623363829413}], 
        PointBox[{12.8, 0.12496031718828526`}], 
        PointBox[{12.9, 0.12836620005823715`}], 
        PointBox[{13., 0.12528524592994514`}], 
        PointBox[{13.1, 0.1241354315632503}], 
        PointBox[{13.2, 0.12657319562857616`}], 
        PointBox[{13.3, 0.12783686939967123`}], 
        PointBox[{13.4, 0.12469359188584427`}], 
        PointBox[{13.5, 0.12796104211320397`}], 
        PointBox[{13.6, 0.12993260879582336`}], 
        PointBox[{13.7, 0.13045497826647365`}], 
        PointBox[{13.8, 0.12867353124233658`}], 
        PointBox[{13.9, 0.13236135012148426`}], 
        PointBox[{14., 0.1293706590412328}], 
        PointBox[{14.1, 0.1280371133823656}], 
        PointBox[{14.2, 0.13027776427468674`}], 
        PointBox[{14.3, 0.13193238300936785`}], 
        PointBox[{14.4, 0.1285657385745884}], 
        PointBox[{14.5, 0.13217052941127402`}], 
        PointBox[{14.6, 0.135628952319955}], 
        PointBox[{14.7, 0.13679942229249376`}], 
        PointBox[{14.8, 0.13493692777684216`}], 
        PointBox[{14.9, 0.13879000539266284`}], 
        PointBox[{15., 0.13580232177065127`}], 
        PointBox[{15.1, 0.13442533290318992`}], 
        PointBox[{15.2, 0.13655984924155554`}], 
        PointBox[{15.3, 0.13836336180102193`}], 
        PointBox[{15.4, 0.13493538624374077`}], 
        PointBox[{15.5, 0.1390462799884106}], 
        PointBox[{15.6, 0.1440315649644135}], 
        PointBox[{15.7, 0.14538930206040895`}], 
        PointBox[{15.8, 0.1436517156904993}], 
        PointBox[{15.9, 0.14759365604458302`}], 
        PointBox[{16., 0.1444199081665068}], 
        PointBox[{16.1, 0.1432124742416003}], 
        PointBox[{16.2, 0.1453795319059383}], 
        PointBox[{16.3, 0.1470208378270004}], 
        PointBox[{16.4, 0.14374538563723308`}], 
        PointBox[{16.5, 0.148747191686348}], 
        PointBox[{16.6, 0.1548091951281065}], 
        PointBox[{16.7, 0.1556868730547735}], 
        PointBox[{16.8, 0.15437262456259854`}], 
        PointBox[{16.9, 0.15819126423141824`}], 
        PointBox[{17., 0.1546773463743283}], 
        PointBox[{17.1, 0.15392400614326665`}], 
        PointBox[{17.2, 0.15627303116287553`}], 
        PointBox[{17.3, 0.15726929141681537`}], 
        PointBox[{17.4, 0.15471485657421852`}], 
        PointBox[{17.5, 0.16103050055072518`}], 
        PointBox[{17.6, 0.16665525129173664`}], 
        PointBox[{17.7, 0.16649690603122308`}], 
        PointBox[{17.8, 0.1662287762776428}], 
        PointBox[{17.9, 0.16914025082169998`}], 
        PointBox[{18., 0.16550922145378402`}], 
        PointBox[{18.1, 0.16550982475980244`}], 
        PointBox[{18.2, 0.16810882008346506`}], 
        PointBox[{18.3, 0.1676530320850301}], 
        PointBox[{18.4, 0.16722143437888126`}], 
        PointBox[{18.5, 0.17419413748965482`}], 
        PointBox[{18.6, 0.17758060336427095`}], 
        PointBox[{18.7, 0.17633520285248136`}], 
        PointBox[{18.8, 0.17817129336919518`}], 
        PointBox[{18.9, 0.17859762769392096`}], 
        PointBox[{19., 0.17567038908250016`}], 
        PointBox[{19.1, 0.1766048710208544}], 
        PointBox[{19.2, 0.1792580680782258}], 
        PointBox[{19.3, 0.1765572931066152}], 
        PointBox[{19.4, 0.17997862997306235`}], 
        PointBox[{19.5, 0.18521421001037058`}], 
        PointBox[{19.6, 0.1860924947164493}], 
        PointBox[{19.7, 0.18443021059177678`}], 
        PointBox[{19.8, 0.18870600058142276`}], 
        PointBox[{19.9, 0.1857181910416481}], 
        PointBox[{20., 0.18436545273160773`}], 
        PointBox[{20.1, 0.18616550117363162`}], 
        PointBox[{20.2, 0.18806586576166448`}], 
        PointBox[{20.3, 0.18442481814898065`}], 
        PointBox[{20.4, 0.19046531528999527`}], 
        PointBox[{20.5, 0.1927154083813147}], 
        PointBox[{20.6, 0.19183385761309582`}], 
        PointBox[{20.7, 0.19140788394836655`}], 
        PointBox[{20.8, 0.19524198284111527`}], 
        PointBox[{20.9, 0.19102042291936275`}], 
        PointBox[{21., 0.1913936646379956}], 
        PointBox[{21.1, 0.19366712227166857`}], 
        PointBox[{21.2, 0.19312193308067524`}], 
        PointBox[{21.3, 0.19278747815725678`}], 
        PointBox[{21.4, 0.19708051013732628`}], 
        PointBox[{21.5, 0.19699064744168562`}], 
        PointBox[{21.6, 0.19539218147202123`}], 
        PointBox[{21.7, 0.1983206535745417}], 
        PointBox[{21.8, 0.1974326631831065}], 
        PointBox[{21.9, 0.19520574371266883`}], 
        PointBox[{22., 0.19678225897654844`}], 
        PointBox[{22.1, 0.19864914337723757`}], 
        PointBox[{22.2, 0.1950348028856219}], 
        PointBox[{22.3, 0.19900152919793918`}], 
        PointBox[{22.4, 0.2002097424409477}], 
        PointBox[{22.5, 0.19879892862442855`}], 
        PointBox[{22.6, 0.19805091120201387`}], 
        PointBox[{22.7, 0.20280970064259568`}], 
        PointBox[{22.8, 0.19816925293730014`}], 
        PointBox[{22.9, 0.19844866932633498`}], 
        PointBox[{23., 0.2004175160076783}], 
        PointBox[{23.1, 0.2002832049065693}], 
        PointBox[{23.2, 0.19778066334717906`}], 
        PointBox[{23.3, 0.20167752244290177`}], 
        PointBox[{23.4, 0.20069359920511487`}], 
        PointBox[{23.5, 0.19901751135697357`}], 
        PointBox[{23.6, 0.2011849312511887}], 
        PointBox[{23.7, 0.20177250103549543`}], 
        PointBox[{23.8, 0.1989118700490223}], 
        PointBox[{23.9, 0.2004910098795919}], 
        PointBox[{24., 0.20184203411705354`}], 
        PointBox[{24.1, 0.19848348710812813`}], 
        PointBox[{24.2, 0.2003840016689513}], 
        PointBox[{24.3, 0.20118285139060713`}], 
        PointBox[{24.4, 0.1992937192312384}], 
        PointBox[{24.5, 0.1986118695145425}], 
        PointBox[{24.6, 0.2033365564798368}], 
        PointBox[{24.7, 0.19891430437961047`}], 
        PointBox[{24.8, 0.19921579719583118`}], 
        PointBox[{24.9, 0.20082127858702045`}], 
        PointBox[{25., 0.20026205050226423`}], 
        PointBox[{25.1, 0.19604402481613295`}], 
        PointBox[{25.2, 0.19989055990887747`}], 
        PointBox[{25.3, 0.1983319193344563}], 
        PointBox[{25.4, 0.19660618608276653`}], 
        PointBox[{25.5, 0.1983027761053009}], 
        PointBox[{25.6, 0.2001799980327151}], 
        PointBox[{25.7, 0.196602424226969}], 
        PointBox[{25.8, 0.19817816913331693`}], 
        PointBox[{25.9, 0.19873477404623632`}], 
        PointBox[{26., 0.1951735218926001}], 
        PointBox[{26.1, 0.19476840988359256`}], 
        PointBox[{26.2, 0.19593308955503308`}], 
        PointBox[{26.3, 0.19368804866298095`}], 
        PointBox[{26.4, 0.19301643688748102`}], 
        PointBox[{26.5, 0.19712147024311533`}], 
        PointBox[{26.6, 0.19380036029226141`}], 
        PointBox[{26.7, 0.19376027257780806`}], 
        PointBox[{26.8, 0.19492505338841093`}], 
        PointBox[{26.9, 0.19339228956230964`}], 
        PointBox[{27., 0.1875316737611147}], 
        PointBox[{27.1, 0.19097313518196637`}], 
        PointBox[{27.2, 0.18936241256450032`}], 
        PointBox[{27.3, 0.1874579799077812}], 
        PointBox[{27.4, 0.18851762299008978`}], 
        PointBox[{27.5, 0.1919231399223567}], 
        PointBox[{27.6, 0.1874249275927573}], 
        PointBox[{27.7, 0.18901035774141542`}], 
        PointBox[{27.8, 0.18864598718173822`}], 
        PointBox[{27.9, 0.18416651505569095`}], 
        PointBox[{28., 0.18033441490039667`}], 
        PointBox[{28.1, 0.1832421742669431}], 
        PointBox[{28.2, 0.18066531331063915`}], 
        PointBox[{28.3, 0.1796120812146263}], 
        PointBox[{28.4, 0.1824402987408776}], 
        PointBox[{28.5, 0.1822497997419004}], 
        PointBox[{28.6, 0.18021691460562336`}], 
        PointBox[{28.7, 0.18153791599450692`}], 
        PointBox[{28.8, 0.1787709163055313}], 
        PointBox[{28.9, 0.1719733078934021}], 
        PointBox[{29., 0.1723232187003224}], 
        PointBox[{29.1, 0.172749227749939}], 
        PointBox[{29.2, 0.17019837592035103`}], 
        PointBox[{29.3, 0.17016574000245244`}], 
        PointBox[{29.4, 0.17386934565415624`}], 
        PointBox[{29.5, 0.170794256969242}], 
        PointBox[{29.6, 0.17114564462795887`}], 
        PointBox[{29.7, 0.17130097631010682`}], 
        PointBox[{29.8, 0.16597108381973627`}], 
        PointBox[{29.9, 0.15941840684392855`}], 
        PointBox[{30., 0.1622265448643908}], 
        PointBox[{30.1, 0.16095954759288264`}], 
        PointBox[{30.2, 0.15872775433812453`}], 
        PointBox[{30.3, 0.15959447645760771`}], 
        PointBox[{30.4, 0.16310071635842815`}], 
        PointBox[{30.5, 0.1590367382791005}], 
        PointBox[{30.6, 0.16055408033423257`}], 
        PointBox[{30.7, 0.15938761878724925`}], 
        PointBox[{30.8, 0.1530656805621622}], 
        PointBox[{30.9, 0.14797534118525668`}], 
        PointBox[{31., 0.15152238230960433`}], 
        PointBox[{31.1, 0.14947986052451392`}], 
        PointBox[{31.2, 0.14753306985274534`}], 
        PointBox[{31.3, 0.14899498926945948`}], 
        PointBox[{31.4, 0.15193541321513368`}], 
        PointBox[{31.5, 0.1478579459865001}], 
        PointBox[{31.6, 0.14982747154838058`}], 
        PointBox[{31.7, 0.14782288328822252`}], 
        PointBox[{31.8, 0.14233570353084532`}], 
        PointBox[{31.9, 0.1383373567518215}], 
        PointBox[{32., 0.1419901349854418}], 
        PointBox[{32.1, 0.1396750076996668}], 
        PointBox[{32.2, 0.1378577370218321}], 
        PointBox[{32.3, 0.13959536380186974`}], 
        PointBox[{32.4, 0.1421768327325916}], 
        PointBox[{32.5, 0.13824648904565662`}], 
        PointBox[{32.6, 0.14040678214547367`}], 
        PointBox[{32.7, 0.13835127946773113`}], 
        PointBox[{32.8, 0.13437015949823367`}], 
        PointBox[{32.9, 0.1309353719913537}], 
        PointBox[{33., 0.13458096394168312`}], 
        PointBox[{33.1, 0.13227224697597242`}], 
        PointBox[{33.2, 0.13041670636422045`}], 
        PointBox[{33.3, 0.1321856851701902}], 
        PointBox[{33.4, 0.134720841354505}], 
        PointBox[{33.5, 0.13087358006311017`}], 
        PointBox[{33.6, 0.1331039964165806}], 
        PointBox[{33.7, 0.13161859165376494`}], 
        PointBox[{33.8, 0.12913648809700778`}], 
        PointBox[{33.9, 0.12595235569500432`}], 
        PointBox[{34., 0.129547860123832}], 
        PointBox[{34.1, 0.12745521484820715`}], 
        PointBox[{34.2, 0.12543302197363418`}], 
        PointBox[{34.3, 0.12706925095712296`}], 
        PointBox[{34.4, 0.12975510811271843`}], 
        PointBox[{34.5, 0.1259884471109877}], 
        PointBox[{34.6, 0.1281534358897646}], 
        PointBox[{34.7, 0.12755629441987315`}], 
        PointBox[{34.8, 0.1264440578140664}], 
        PointBox[{34.9, 0.12341560887405313`}], 
        PointBox[{35., 0.12684908370833808`}], 
        PointBox[{35.1, 0.12515757691697577`}], 
        PointBox[{35.2, 0.12289861288887025`}], 
        PointBox[{35.3, 0.12430169423472673`}], 
        PointBox[{35.4, 0.12718991272121966`}], 
        PointBox[{35.5, 0.12360784466875205`}], 
        PointBox[{35.6, 0.12554385695048934`}], 
        PointBox[{35.7, 0.1259505367754758}], 
        PointBox[{35.8, 0.12612687802212816`}], 
        PointBox[{35.9, 0.12330194796126621`}], 
        PointBox[{36., 0.1264230512480691}], 
        PointBox[{36.1, 0.12526914235810288`}], 
        PointBox[{36.2, 0.12276251841573506`}], 
        PointBox[{36.3, 0.12389142615515632`}], 
        PointBox[{36.4, 0.12693173923956205`}], 
        PointBox[{36.5, 0.12367466609948642`}], 
        PointBox[{36.6, 0.12525395282504415`}], 
        PointBox[{36.7, 0.12668844010979421`}], 
        PointBox[{36.8, 0.12812351236760924`}], 
        PointBox[{36.9, 0.12559598436795263`}], 
        PointBox[{37., 0.12830749324729898`}], 
        PointBox[{37.1, 0.12772677541196256`}], 
        PointBox[{37.2, 0.12500902282475385`}], 
        PointBox[{37.3, 0.12588330884233015`}], 
        PointBox[{37.4, 0.12898754133977627`}], 
        PointBox[{37.5, 0.1261305614755169}], 
        PointBox[{37.6, 0.12734394893244388`}], 
        PointBox[{37.7, 0.12981924676330853`}], 
        PointBox[{37.8, 0.13248321895820397`}], 
        PointBox[{37.9, 0.13030011870706668`}], 
        PointBox[{38., 0.13264392355509041`}], 
        PointBox[{38.1, 0.13252204125382214`}], 
        PointBox[{38.2, 0.1296637409142577}], 
        PointBox[{38.3, 0.13036875910648868`}], 
        PointBox[{38.4, 0.13346031747297124`}], 
        PointBox[{38.5, 0.13093095157435844`}], 
        PointBox[{38.6, 0.13195814243513582`}], 
        PointBox[{38.7, 0.1355539471013503}], 
        PointBox[{38.8, 0.139286395955174}], 
        PointBox[{38.9, 0.13738167728968134`}], 
        PointBox[{39., 0.13958513485592866`}], 
        PointBox[{39.1, 0.13962290787858941`}], 
        PointBox[{39.2, 0.13672719455008006`}], 
        PointBox[{39.3, 0.13741193014796504`}], 
        PointBox[{39.4, 0.1404495956752382}], 
        PointBox[{39.5, 0.1379923386789162}], 
        PointBox[{39.6, 0.13925701355214043`}], 
        PointBox[{39.7, 0.1441637875747048}], 
        PointBox[{39.8, 0.14841497092599862`}], 
        PointBox[{39.9, 0.14660767919158582`}], 
        PointBox[{40., 0.14908605825378304`}], 
        PointBox[{40.1, 0.1487673044851178}], 
        PointBox[{40.2, 0.14600567232287973`}], 
        PointBox[{40.3, 0.1468724871666044}], 
        PointBox[{40.4, 0.1498251887472252}], 
        PointBox[{40.5, 0.14703317026204588`}], 
        PointBox[{40.6, 0.14925811595827335`}], 
        PointBox[{40.7, 0.1555167836174165}], 
        PointBox[{40.8, 0.15918282567358527`}], 
        PointBox[{40.9, 0.1572943649739029}], 
        PointBox[{41., 0.16056661095834043`}], 
        PointBox[{41.1, 0.15917944165412923`}], 
        PointBox[{41.2, 0.15686220803955794`}], 
        PointBox[{41.3, 0.15812969752800995`}], 
        PointBox[{41.4, 0.16087358482058153`}], 
        PointBox[{41.5, 0.15741465576961375`}], 
        PointBox[{41.6, 0.16154912322018558`}], 
        PointBox[{41.7, 0.16816053052173024`}], 
        PointBox[{41.8, 0.17015138956649736`}], 
        PointBox[{41.9, 0.16829990226941305`}], 
        PointBox[{42., 0.17254440201981439`}], 
        PointBox[{42.1, 0.1695638214000533}], 
        PointBox[{42.2, 0.16813213934391943`}], 
        PointBox[{42.3, 0.1699544598615606}], 
        PointBox[{42.4, 0.17203573896923616`}], 
        PointBox[{42.5, 0.1684331837664705}], 
        PointBox[{42.6, 0.17479887631068386`}], 
        PointBox[{42.7, 0.1796029239807965}], 
        PointBox[{42.8, 0.1796840306645451}], 
        PointBox[{42.9, 0.1787138812450275}], 
        PointBox[{43., 0.1826999347265116}], 
        PointBox[{43.1, 0.17874540709832026`}], 
        PointBox[{43.2, 0.17854911955514371`}], 
        PointBox[{43.3, 0.18089004794365207`}], 
        PointBox[{43.4, 0.18120085375190473`}], 
        PointBox[{43.5, 0.17986561818878907`}], 
        PointBox[{43.6, 0.18623118634486763`}], 
        PointBox[{43.7, 0.18820353230282205`}], 
        PointBox[{43.8, 0.18691746073658297`}], 
        PointBox[{43.9, 0.18850479890186134`}], 
        PointBox[{44., 0.18936792514856504`}], 
        PointBox[{44.1, 0.1862985601787527}], 
        PointBox[{44.2, 0.18734052066416867`}], 
        PointBox[{44.3, 0.189783705646494}], 
        PointBox[{44.4, 0.18712822609721627`}], 
        PointBox[{44.5, 0.19039139347186412`}], 
        PointBox[{44.6, 0.19394934255367627`}], 
        PointBox[{44.7, 0.19373100994389494`}], 
        PointBox[{44.8, 0.19222657776907506`}], 
        PointBox[{44.9, 0.19676438984713468`}], 
        PointBox[{45., 0.1932887822308414}], 
        PointBox[{45.1, 0.19234006779716437`}], 
        PointBox[{45.2, 0.1942529023613562}], 
        PointBox[{45.3, 0.19565724195706832`}], 
        PointBox[{45.4, 0.19217490978502402`}], 
        PointBox[{45.5, 0.19746078838315392`}], 
        PointBox[{45.6, 0.1981892879437563}], 
        PointBox[{45.7, 0.19675527786313293`}], 
        PointBox[{45.8, 0.19705580115414742`}], 
        PointBox[{45.9, 0.20026461486619318`}], 
        PointBox[{46., 0.19611630605963026`}], 
        PointBox[{46.1, 0.19701096431292317`}], 
        PointBox[{46.2, 0.19910515449613067`}], 
        PointBox[{46.3, 0.19760683064441945`}], 
        PointBox[{46.4, 0.19793082778687413`}], 
        PointBox[{46.5, 0.2008355755138139}], 
        PointBox[{46.6, 0.199755483487782}], 
        PointBox[{46.7, 0.1982635249388989}], 
        PointBox[{46.8, 0.20211748173033797`}], 
        PointBox[{46.9, 0.19978442798939738`}], 
        PointBox[{47., 0.19843747619215782`}], 
        PointBox[{47.1, 0.20022284005378344`}], 
        PointBox[{47.2, 0.20136291818259075`}], 
        PointBox[{47.3, 0.1973646201481926}], 
        PointBox[{47.4, 0.20131570868251936`}], 
        PointBox[{47.5, 0.20124576246447495`}], 
        PointBox[{47.6, 0.19945498298102932`}], 
        PointBox[{47.7, 0.199545106616157}], 
        PointBox[{47.8, 0.20368852975476318`}], 
        PointBox[{47.9, 0.1989584967972892}], 
        PointBox[{48., 0.19994148158756114`}], 
        PointBox[{48.1, 0.20159319748370413`}], 
        PointBox[{48.2, 0.20020676140689284`}], 
        PointBox[{48.3, 0.19826993687896308`}], 
        PointBox[{48.4, 0.2012197887517432}], 
        PointBox[{48.5, 0.19949177531673}], 
        PointBox[{48.6, 0.19805304259671622`}], 
        PointBox[{48.7, 0.20123319246786964`}], 
        PointBox[{48.8, 0.200093029764353}], 
        PointBox[{48.9, 0.1983466000996931}], 
        PointBox[{49., 0.20000751230689523`}], 
        PointBox[{49.1, 0.2004397241012189}], 
        PointBox[{49.2, 0.1960604365033129}], 
        PointBox[{49.3, 0.19855261153837098`}], 
        PointBox[{49.4, 0.1982073079808246}], 
        PointBox[{49.5, 0.19615793015694288`}], 
        PointBox[{49.6, 0.1961975183557546}], 
        PointBox[{49.7, 0.2006362036156182}], 
        PointBox[{49.8, 0.19584883021081945`}], 
        PointBox[{49.9, 0.19686577004575617`}], 
        PointBox[{50., 0.19790367356967853`}], 
        PointBox[{50.1, 0.19595105344349278`}], 
        PointBox[{50.2, 0.19164755280231924`}], 
        PointBox[{50.3, 0.19514958875167188`}], 
        PointBox[{50.4, 0.1930200213957711}], 
        PointBox[{50.5, 0.19155780165035574`}], 
        PointBox[{50.6, 0.19392198352732187`}], 
        PointBox[{50.7, 0.19464711759751913`}], 
        PointBox[{50.8, 0.19186908868231684`}], 
        PointBox[{50.9, 0.1934252214478495}], 
        PointBox[{51., 0.19280970203351552`}], 
        PointBox[{51.1, 0.18774490487056184`}], 
        PointBox[{51.2, 0.18783080889230566`}], 
        PointBox[{51.3, 0.188351917059882}], 
        PointBox[{51.4, 0.1859766917685182}], 
        PointBox[{51.5, 0.18571168131523996`}], 
        PointBox[{51.6, 0.18973633039800297`}], 
        PointBox[{51.7, 0.18617172321005887`}], 
        PointBox[{51.8, 0.18659227682587837`}], 
        PointBox[{51.9, 0.1871816608269307}], 
        PointBox[{52., 0.1839684803575254}], 
        PointBox[{52.1, 0.1774320610183038}], 
        PointBox[{52.2, 0.18088163485302503`}], 
        PointBox[{52.3, 0.17904908970411534`}], 
        PointBox[{52.4, 0.1771515065874489}], 
        PointBox[{52.5, 0.1783519354696345}], 
        PointBox[{52.6, 0.18162941127235843`}], 
        PointBox[{52.7, 0.17722611281891834`}], 
        PointBox[{52.8, 0.17894544213061478`}], 
        PointBox[{52.9, 0.17766495192387194`}], 
        PointBox[{53., 0.17171119662192905`}], 
        PointBox[{53.1, 0.16732867952881378`}], 
        PointBox[{53.2, 0.17067547188289836`}], 
        PointBox[{53.3, 0.16797582140811138`}], 
        PointBox[{53.4, 0.16678250340814496`}], 
        PointBox[{53.5, 0.16922331149806946`}], 
        PointBox[{53.6, 0.17019744312023496`}], 
        PointBox[{53.7, 0.1672670638526678}], 
        PointBox[{53.8, 0.1689146798440348}], 
        PointBox[{53.9, 0.16539243613374974`}], 
        PointBox[{54., 0.15855044252163952`}], 
        PointBox[{54.1, 0.1570646742834542}], 
        PointBox[{54.2, 0.15908098566974024`}], 
        PointBox[{54.3, 0.15621026283712142`}], 
        PointBox[{54.4, 0.15566565353608394`}], 
        PointBox[{54.5, 0.15878486570711692`}], 
        PointBox[{54.6, 0.15787188606895186`}], 
        PointBox[{54.7, 0.15645177799472185`}], 
        PointBox[{54.8, 0.15762649915923926`}], 
        PointBox[{54.9, 0.15259837443867857`}], 
        PointBox[{55., 0.14670871640426725`}], 
        PointBox[{55.1, 0.1469616982878523}], 
        PointBox[{55.2, 0.14803466335420049`}], 
        PointBox[{55.3, 0.1451643760900656}], 
        PointBox[{55.4, 0.1450590786512186}], 
        PointBox[{55.5, 0.1483847313700294}], 
        PointBox[{55.6, 0.14658122832634243`}], 
        PointBox[{55.7, 0.14596561127061075`}], 
        PointBox[{55.8, 0.14684718715541858`}], 
        PointBox[{55.9, 0.14184035577342644`}], 
        PointBox[{56., 0.137192249129921}], 
        PointBox[{56.1, 0.1381280153258635}], 
        PointBox[{56.2, 0.1388834597445878}], 
        PointBox[{56.3, 0.13598677127658332`}], 
        PointBox[{56.4, 0.13607192555116393`}], 
        PointBox[{56.5, 0.13939396629117748`}], 
        PointBox[{56.6, 0.13742184609409902`}], 
        PointBox[{56.7, 0.13700405721353026`}], 
        PointBox[{56.8, 0.1379747383484669}], 
        PointBox[{56.9, 0.1340069525526488}], 
        PointBox[{57., 0.1303254643427426}], 
        PointBox[{57.1, 0.13129304401709205`}], 
        PointBox[{57.2, 0.13221151603436257`}], 
        PointBox[{57.3, 0.12922790573619536`}], 
        PointBox[{57.4, 0.12928974510911753`}], 
        PointBox[{57.5, 0.1325445388949297}], 
        PointBox[{57.6, 0.1308421718086312}], 
        PointBox[{57.7, 0.13020124968638774`}], 
        PointBox[{57.8, 0.13157828284387296`}], 
        PointBox[{57.9, 0.1289623798774362}], 
        PointBox[{58., 0.12608887247814068`}], 
        PointBox[{58.1, 0.12670391784451537`}], 
        PointBox[{58.2, 0.12809616992673215`}], 
        PointBox[{58.3, 0.12499840687924799`}], 
        PointBox[{58.4, 0.1248854545698692}], 
        PointBox[{58.5, 0.12803397086794707`}], 
        PointBox[{58.6, 0.12687576096326939`}], 
        PointBox[{58.7, 0.12574287374192583`}], 
        PointBox[{58.8, 0.1276808207912464}], 
        PointBox[{58.9, 0.12643273988817527`}], 
        PointBox[{59., 0.12435109586975346`}], 
        PointBox[{59.1, 0.12440984216923681`}], 
        PointBox[{59.2, 0.12642614120571816`}], 
        PointBox[{59.3, 0.12323510454278452`}], 
        PointBox[{59.4, 0.12286408995858829`}], 
        PointBox[{59.5, 0.12585831782488116`}], 
        PointBox[{59.6, 0.12538668907513903`}], 
        PointBox[{59.7, 0.12364540245067489`}], 
        PointBox[{59.8, 0.1261584078970839}], 
        PointBox[{59.9, 0.1262522262128119}], 
        PointBox[{60., 0.12499468611939236`}], 
        PointBox[{60.1, 0.12445977689241941`}], 
        PointBox[{60.2, 0.12709425437083813`}], 
        PointBox[{60.3, 0.12386359435110515`}], 
        PointBox[{60.4, 0.12321622731311432`}], 
        PointBox[{60.5, 0.12601615471324057`}], 
        PointBox[{60.6, 0.12623390801665738`}], 
        PointBox[{60.7, 0.12392028641474837`}], 
        PointBox[{60.8, 0.12694858058116712`}], 
        PointBox[{60.9, 0.1284081408785632}], 
        PointBox[{61., 0.12796833216961748`}], 
        PointBox[{61.1, 0.12694708634200755`}], 
        PointBox[{61.2, 0.13007804326690828`}], 
        PointBox[{61.3, 0.12685338315151573`}], 
        PointBox[{61.4, 0.1259764694410278}], 
        PointBox[{61.5, 0.12857737251371798`}], 
        PointBox[{61.6, 0.12935464196567695`}], 
        PointBox[{61.7, 0.12662259968112868`}], 
        PointBox[{61.8, 0.13011882226080282`}], 
        PointBox[{61.9, 0.13302554695031293`}], 
        PointBox[{62., 0.13328035921382234`}], 
        PointBox[{62.1, 0.1319788954477058}], 
        PointBox[{62.2, 0.1354335220879826}], 
        PointBox[{62.3, 0.1322058316956305}], 
        PointBox[{62.4, 0.13121143179953224`}], 
        PointBox[{62.5, 0.1336617655095008}], 
        PointBox[{62.6, 0.13476571487909306`}], 
        PointBox[{62.7, 0.13183276534347313`}], 
        PointBox[{62.8, 0.13585624035485994`}], 
        PointBox[{62.9, 0.14026820376879215`}], 
        PointBox[{63., 0.14090149348068534`}], 
        PointBox[{63.1, 0.13957802815050088`}], 
        PointBox[{63.2, 0.1431769631842278}], 
        PointBox[{63.3, 0.1398604073662897}], 
        PointBox[{63.4, 0.1389294320758731}], 
        PointBox[{63.5, 0.14133097773150372`}], 
        PointBox[{63.6, 0.14243841268755267`}], 
        PointBox[{63.7, 0.13959018853632504`}], 
        PointBox[{63.8, 0.1443889761332822}], 
        PointBox[{63.9, 0.15004298150852197`}], 
        PointBox[{64., 0.15052662062945119`}], 
        PointBox[{64.1, 0.1495152844722785}], 
        PointBox[{64.2, 0.1529926832247257}], 
        PointBox[{64.3, 0.14949246759496493`}], 
        PointBox[{64.4, 0.14887465840755706`}], 
        PointBox[{64.5, 0.15135847756842075`}], 
        PointBox[{64.6, 0.15200781296038154`}], 
        PointBox[{64.7, 0.14977001035758553`}], 
        PointBox[{64.8, 0.15574363361089963`}], 
        PointBox[{64.9, 0.1614995397728268}], 
        PointBox[{65., 0.16127219164895693`}], 
        PointBox[{65.1, 0.1611305271858598}], 
        PointBox[{65.2, 0.16384306849358224`}], 
        PointBox[{65.3, 0.16028521218022618`}], 
        PointBox[{65.4, 0.16026779279927014`}], 
        PointBox[{65.5, 0.16292328889139776`}], 
        PointBox[{65.6, 0.16240528264633977`}], 
        PointBox[{65.7, 0.1619086413188616}], 
        PointBox[{65.8, 0.168870472233585}], 
        PointBox[{65.9, 0.17289549582227154`}], 
        PointBox[{66., 0.17172527859559608`}], 
        PointBox[{66.1, 0.17336320225846877`}], 
        PointBox[{66.2, 0.1740248113691063}], 
        PointBox[{66.3, 0.17100464052457032`}], 
        PointBox[{66.4, 0.1718112844327615}], 
        PointBox[{66.5, 0.17453240782528287`}], 
        PointBox[{66.6, 0.17206819562250755`}], 
        PointBox[{66.7, 0.17494462089819343`}], 
        PointBox[{66.8, 0.18093386050398844`}], 
        PointBox[{66.9, 0.18244921409737525`}], 
        PointBox[{67., 0.18074413307074452`}], 
        PointBox[{67.1, 0.184705578754117}], 
        PointBox[{67.2, 0.18223822039129345`}], 
        PointBox[{67.3, 0.1805642399806351}], 
        PointBox[{67.4, 0.18222431754268859`}], 
        PointBox[{67.5, 0.18440219478091283`}], 
        PointBox[{67.6, 0.18066046371735872`}], 
        PointBox[{67.7, 0.18665170630136982`}], 
        PointBox[{67.8, 0.1897989489292857}], 
        PointBox[{67.9, 0.18932242895342108`}], 
        PointBox[{68., 0.18843000774078275`}], 
        PointBox[{68.1, 0.19269929458938131`}], 
        PointBox[{68.2, 0.18847704406546717`}], 
        PointBox[{68.3, 0.18847963261703687`}], 
        PointBox[{68.4, 0.19072790714165888`}], 
        PointBox[{68.5, 0.19088156328788497`}], 
        PointBox[{68.6, 0.18961496979454484`}], 
        PointBox[{68.7, 0.19474981018622414`}], 
        PointBox[{68.8, 0.19528737456078488`}], 
        PointBox[{68.9, 0.193763973426801}], 
        PointBox[{69., 0.19584369696363357`}], 
        PointBox[{69.1, 0.19617810045745612`}], 
        PointBox[{69.2, 0.19335657154073546`}], 
        PointBox[{69.3, 0.1946984891539715}], 
        PointBox[{69.4, 0.1968295043182642}], 
        PointBox[{69.5, 0.1937176770376222}], 
        PointBox[{69.6, 0.19709491067662022`}], 
        PointBox[{69.7, 0.19912890833973212`}], 
        PointBox[{69.8, 0.198033574872948}], 
        PointBox[{69.9, 0.1968695219516506}], 
        PointBox[{70., 0.2016903547471728}], 
        PointBox[{70.1, 0.19747312806877929`}], 
        PointBox[{70.2, 0.1972026862191047}], 
        PointBox[{70.3, 0.1991784732439856}], 
        PointBox[{70.4, 0.19976572339455295`}], 
        PointBox[{70.5, 0.19661783192845758`}], 
        PointBox[{70.6, 0.20104729559332923`}], 
        PointBox[{70.7, 0.20058601872261858`}], 
        PointBox[{70.8, 0.1988881840587607}], 
        PointBox[{70.9, 0.20018020260942582`}], 
        PointBox[{71., 0.20217454762486525`}], 
        PointBox[{71.1, 0.19854210901172126`}], 
        PointBox[{71.2, 0.1999081083908911}], 
        PointBox[{71.3, 0.20158979513034592`}], 
        PointBox[{71.4, 0.19900384100166946`}], 
        PointBox[{71.5, 0.1999873968437294}], 
        PointBox[{71.6, 0.20164544588847524`}], 
        PointBox[{71.7, 0.19992994320282553`}], 
        PointBox[{71.8, 0.1988410203388193}], 
        PointBox[{71.9, 0.20333010560081802`}], 
        PointBox[{72., 0.1996937694831786}], 
        PointBox[{72.1, 0.19933106227441807`}], 
        PointBox[{72.2, 0.20106862139034717`}], 
        PointBox[{72.3, 0.20121002457335269`}], 
        PointBox[{72.4, 0.1968759481451437}], 
        PointBox[{72.5, 0.20076328844907892`}], 
        PointBox[{72.6, 0.19967955204019314`}], 
        PointBox[{72.7, 0.19783250904257238`}], 
        PointBox[{72.8, 0.19883700717141012`}], 
        PointBox[{72.9, 0.20188987937262529`}], 
        PointBox[{73., 0.1976108107085843}], 
        PointBox[{73.1, 0.19904374791908316`}], 
        PointBox[{73.2, 0.20005406842621087`}], 
        PointBox[{73.3, 0.19736678149536446`}], 
        PointBox[{73.4, 0.195980005752273}], 
        PointBox[{73.5, 0.1979759491149351}], 
        PointBox[{73.6, 0.19582120412070733`}], 
        PointBox[{73.7, 0.19480133588912496`}], 
        PointBox[{73.8, 0.1985537049018948}], 
        PointBox[{73.9, 0.19616983121375342`}], 
        PointBox[{74., 0.19540519842720533`}], 
        PointBox[{74.1, 0.19682697249566566`}], 
        PointBox[{74.2, 0.19605600870239323`}], 
        PointBox[{74.3, 0.19060007010988508`}], 
        PointBox[{74.4, 0.19355744290803306`}], 
        PointBox[{74.5, 0.19242272701242427`}], 
        PointBox[{74.6, 0.19039644323636862`}], 
        PointBox[{74.7, 0.1910231124197284}], 
        PointBox[{74.8, 0.19495172374112424`}], 
        PointBox[{74.9, 0.19025194976267715`}], 
        PointBox[{75., 0.19166109726431266`}], 
        PointBox[{75.1, 0.19185333815658726`}], 
        PointBox[{75.2, 0.18831192077801964`}], 
        PointBox[{75.3, 0.18386610580459212`}], 
        PointBox[{75.4, 0.18714031541682644`}], 
        PointBox[{75.5, 0.18468666114277704`}], 
        PointBox[{75.6, 0.1834390654690365}], 
        PointBox[{75.7, 0.18600704569783147`}], 
        PointBox[{75.8, 0.1864268142661771}], 
        PointBox[{75.9, 0.18391971562866816`}], 
        PointBox[{76., 0.18537576921828178`}], 
        PointBox[{76.1, 0.18338717031726767`}], 
        PointBox[{76.2, 0.17703760711549466`}], 
        PointBox[{76.3, 0.17690957467389692`}], 
        PointBox[{76.4, 0.17757955401906753`}], 
        PointBox[{76.5, 0.1750427509240687}], 
        PointBox[{76.6, 0.17486559547517028`}], 
        PointBox[{76.7, 0.17859435389278963`}], 
        PointBox[{76.8, 0.17560950279113824`}], 
        PointBox[{76.9, 0.17581462127706415`}], 
        PointBox[{77., 0.17615357958638958`}], 
        PointBox[{77.1, 0.17143299139493917`}], 
        PointBox[{77.2, 0.1646458604111418}], 
        PointBox[{77.3, 0.16748352064131392`}], 
        PointBox[{77.4, 0.16615754817624262`}], 
        PointBox[{77.5, 0.1639764787932023}], 
        PointBox[{77.6, 0.16484108628499952`}], 
        PointBox[{77.7, 0.16839309039379124`}], 
        PointBox[{77.8, 0.1641999526616541}], 
        PointBox[{77.9, 0.16576025657545987`}], 
        PointBox[{78., 0.1645694120103874}], 
        PointBox[{78.1, 0.15817929231641925`}], 
        PointBox[{78.2, 0.15293390871420393`}], 
        PointBox[{78.3, 0.15658935816424754`}], 
        PointBox[{78.4, 0.15433642782719165`}], 
        PointBox[{78.5, 0.15254205265360357`}], 
        PointBox[{78.6, 0.15416419610665064`}], 
        PointBox[{78.7, 0.1568987421899299}], 
        PointBox[{78.8, 0.1528212114542135}], 
        PointBox[{78.9, 0.15484502073241818`}], 
        PointBox[{79., 0.15241989555524743`}], 
        PointBox[{79.1, 0.14642517130106752`}], 
        PointBox[{79.2, 0.14259200075077708`}], 
        PointBox[{79.3, 0.14623335258125747`}], 
        PointBox[{79.4, 0.14362370147480044`}], 
        PointBox[{79.5, 0.14207306544689904`}], 
        PointBox[{79.6, 0.14409758559268127`}], 
        PointBox[{79.7, 0.14620727148625995`}], 
        PointBox[{79.8, 0.14244383943912292`}], 
        PointBox[{79.9, 0.14465051979173646`}], 
        PointBox[{80., 0.14183353762694975`}], 
        PointBox[{80.1, 0.1372536552521969}], 
        PointBox[{80.2, 0.1341718674514672}], 
        PointBox[{80.3, 0.13775157673340993`}], 
        PointBox[{80.4, 0.13504627388279047`}], 
        PointBox[{80.5, 0.1335517212679816}], 
        PointBox[{80.6, 0.1356952400506675}], 
        PointBox[{80.7, 0.1376172212045529}], 
        PointBox[{80.8, 0.13397267029578053`}], 
        PointBox[{80.9, 0.1363221059303675}], 
        PointBox[{81., 0.13392609239586853`}], 
        PointBox[{81.1, 0.13084043221187908`}], 
        PointBox[{81.2, 0.12802189850817705`}], 
        PointBox[{81.3, 0.13164133068131742`}], 
        PointBox[{81.4, 0.12900474808187698`}], 
        PointBox[{81.5, 0.12740336444384748`}], 
        PointBox[{81.6, 0.1294760408628015}], 
        PointBox[{81.7, 0.13154366602880227`}], 
        PointBox[{81.8, 0.12785873502639616`}], 
        PointBox[{81.9, 0.1303122350477772}], 
        PointBox[{82., 0.12879126844936434`}], 
        PointBox[{82.1, 0.12705469635718722`}], 
        PointBox[{82.2, 0.12426459589638855`}], 
        PointBox[{82.3, 0.12793192233930603`}], 
        PointBox[{82.4, 0.12551852211883022`}], 
        PointBox[{82.5, 0.12370175754271123`}], 
        PointBox[{82.6, 0.12558260696372692`}], 
        PointBox[{82.7, 0.1279496886998004}], 
        PointBox[{82.8, 0.12421690984626187`}], 
        PointBox[{82.9, 0.12666691952641246`}], 
        PointBox[{83., 0.1261971354662088}], 
        PointBox[{83.1, 0.1257094561512724}], 
        PointBox[{83.2, 0.12291779104957104`}], 
        PointBox[{83.3, 0.1265267239420324}], 
        PointBox[{83.4, 0.12448438681680503`}], 
        PointBox[{83.5, 0.12240579145638872`}], 
        PointBox[{83.6, 0.12402725136833057`}], 
        PointBox[{83.7, 0.1266979739360762}], 
        PointBox[{83.8, 0.12303000056219951`}], 
        PointBox[{83.9, 0.1253355625199614}], 
        PointBox[{84., 0.12596775674263905`}], 
        PointBox[{84.1, 0.12668636195744207`}], 
        PointBox[{84.2, 0.12398154989431717`}], 
        PointBox[{84.3, 0.12738805143792786`}], 
        PointBox[{84.4, 0.12581407573732142`}], 
        PointBox[{84.5, 0.12348490935095431`}], 
        PointBox[{84.6, 0.1248345069596544}], 
        PointBox[{84.7, 0.12772229604894764`}], 
        PointBox[{84.8, 0.12425720344785905`}], 
        PointBox[{84.9, 0.12632740318387273`}], 
        PointBox[{85., 0.12808420466854772`}], 
        PointBox[{85.1, 0.1299771921254712}], 
        PointBox[{85.2, 0.12746789258939822`}], 
        PointBox[{85.3, 0.1305967078147018}], 
        PointBox[{85.4, 0.12947645049269213`}], 
        PointBox[{85.5, 0.12695521289838926`}], 
        PointBox[{85.6, 0.12808202575036337`}], 
        PointBox[{85.7, 0.1310738587943081}], 
        PointBox[{85.8, 0.12786637568843326`}], 
        PointBox[{85.9, 0.12975161704786387`}], 
        PointBox[{86., 0.13269566622396886`}], 
        PointBox[{86.1, 0.13565110304041947`}], 
        PointBox[{86.2, 0.13338140633553217`}], 
        PointBox[{86.3, 0.1363111551257937}], 
        PointBox[{86.4, 0.13546428698343246`}], 
        PointBox[{86.5, 0.13285120127128738`}], 
        PointBox[{86.6, 0.13386798849893583`}], 
        PointBox[{86.7, 0.13686709629411664`}], 
        PointBox[{86.8, 0.133815625116436}], 
        PointBox[{86.9, 0.13578320770361674`}], 
        PointBox[{87., 0.14006587279688903`}], 
        PointBox[{87.1, 0.14370966847610464`}], 
        PointBox[{87.2, 0.14161804594247324`}], 
        PointBox[{87.3, 0.14461645864164516`}], 
        PointBox[{87.4, 0.14365970094070366`}], 
        PointBox[{87.5, 0.14111107011383384`}], 
        PointBox[{87.6, 0.14218909356999213`}], 
        PointBox[{87.7, 0.1451172860619298}], 
        PointBox[{87.8, 0.14196070392418123`}], 
        PointBox[{87.9, 0.14454974990140407`}], 
        PointBox[{88., 0.15028608288446493`}], 
        PointBox[{88.1, 0.15378022211255268`}], 
        PointBox[{88.2, 0.1517526045470983}], 
        PointBox[{88.3, 0.15522113965158224`}], 
        PointBox[{88.4, 0.15358020487699936`}], 
        PointBox[{88.5, 0.15135254209512342`}], 
        PointBox[{88.6, 0.1526981526603215}], 
        PointBox[{88.7, 0.15542867572177993`}], 
        PointBox[{88.8, 0.15189670246645975`}], 
        PointBox[{88.9, 0.1559026834208314}], 
        PointBox[{89., 0.16251723854620453`}], 
        PointBox[{89.1, 0.16478558259252818`}], 
        PointBox[{89.2, 0.16286601456092847`}], 
        PointBox[{89.3, 0.16703672755699248`}], 
        PointBox[{89.4, 0.16418238300626106`}], 
        PointBox[{89.5, 0.16265471243314164`}], 
        PointBox[{89.6, 0.16444889012175856`}], 
        PointBox[{89.7, 0.16662520255360747`}], 
        PointBox[{89.8, 0.16298292084801527`}], 
        PointBox[{89.9, 0.16901231015049473`}], 
        PointBox[{90., 0.17460892611764836`}], 
        PointBox[{90.1, 0.17510441748288774`}], 
        PointBox[{90.2, 0.17388190198201314`}], 
        PointBox[{90.3, 0.17800378072084122`}], 
        PointBox[{90.4, 0.1741622870402964}], 
        PointBox[{90.5, 0.17370973742444004`}], 
        PointBox[{90.6, 0.17600020863206048`}], 
        PointBox[{90.7, 0.17673117560276588`}], 
        PointBox[{90.8, 0.1747454377722232}], 
        PointBox[{90.9, 0.18155918336013885`}], 
        PointBox[{91., 0.18446487796949476`}], 
        PointBox[{91.1, 0.18345082229143989`}], 
        PointBox[{91.2, 0.18434646991711442`}], 
        PointBox[{91.3, 0.18607460038748297`}], 
        PointBox[{91.4, 0.18268285059667855`}], 
        PointBox[{91.5, 0.1834350720942284}], 
        PointBox[{91.6, 0.18596349775939863`}], 
        PointBox[{91.7, 0.18398096696954086`}], 
        PointBox[{91.8, 0.18625703354970977`}], 
        PointBox[{91.9, 0.19086183338610954`}], 
        PointBox[{92., 0.1912907600905606}], 
        PointBox[{92.1, 0.18967615179933808`}], 
        PointBox[{92.2, 0.19368337561183688`}], 
        PointBox[{92.3, 0.1911294862871005}], 
        PointBox[{92.4, 0.1896009492759873}], 
        PointBox[{92.5, 0.1913345595520855}], 
        PointBox[{92.6, 0.1932233031227459}], 
        PointBox[{92.7, 0.18946489468573796`}], 
        PointBox[{92.8, 0.1949028240000729}], 
        PointBox[{92.9, 0.1964895317020652}], 
        PointBox[{93., 0.19535944862820837`}], 
        PointBox[{93.1, 0.19490207294827422`}], 
        PointBox[{93.2, 0.19903257272871297`}], 
        PointBox[{93.3, 0.19460883447105576`}], 
        PointBox[{93.4, 0.19504992358309636`}], 
        PointBox[{93.5, 0.19721481553398315`}], 
        PointBox[{93.6, 0.19669864477122362`}], 
        PointBox[{93.7, 0.1958496230131061}], 
        PointBox[{93.8, 0.19970667854223348`}], 
        PointBox[{93.9, 0.19913426792451364`}], 
        PointBox[{94., 0.19751978215970592`}], 
        PointBox[{94.1, 0.20041214787664796`}], 
        PointBox[{94.2, 0.19963939852885}], 
        PointBox[{94.3, 0.19742022681508917`}], 
        PointBox[{94.4, 0.19904877023578962`}], 
        PointBox[{94.5, 0.20067446031946587`}], 
        PointBox[{94.6, 0.19702105545972368`}], 
        PointBox[{94.7, 0.20049290342698933`}], 
        PointBox[{94.8, 0.20126149688501294`}], 
        PointBox[{94.9, 0.19961637519573855`}], 
        PointBox[{95., 0.19903046754991982`}], 
        PointBox[{95.1, 0.20378254381554967`}], 
        PointBox[{95.2, 0.1990523600289812}], 
        PointBox[{95.3, 0.19950844232852313`}], 
        PointBox[{95.4, 0.20134487893257083`}], 
        PointBox[{95.5, 0.20089855936538972`}], 
        PointBox[{95.6, 0.19802998749247877`}], 
        PointBox[{95.7, 0.20173380047106765`}], 
        PointBox[{95.8, 0.2003981690774932}], 
        PointBox[{95.9, 0.1987416150936976}], 
        PointBox[{96., 0.20100917207112293`}], 
        PointBox[{96.1, 0.20154697960062393`}], 
        PointBox[{96.2, 0.19875248061414316`}], 
        PointBox[{96.3, 0.20037053343716146`}], 
        PointBox[{96.4, 0.20136508402995446`}], 
        PointBox[{96.5, 0.19777342008729046`}], 
        PointBox[{96.6, 0.19928174512861868`}], 
        PointBox[{96.7, 0.199829886337786}], 
        PointBox[{96.8, 0.19779622394878432`}], 
        PointBox[{96.9, 0.1972754948572135}], 
        PointBox[{97., 0.20189091399751283`}], 
        PointBox[{97.1, 0.19750133413920504`}], 
        PointBox[{97.2, 0.19795221996244725`}], 
        PointBox[{97.3, 0.1993388691741916}], 
        PointBox[{97.4, 0.19829875506879677`}], 
        PointBox[{97.5, 0.19357208286085933`}], 
        PointBox[{97.6, 0.1973730402869033}], 
        PointBox[{97.7, 0.19559364493060316`}], 
        PointBox[{97.8, 0.1938923179068565}], 
        PointBox[{97.9, 0.19560102835845622`}], 
        PointBox[{98., 0.19762814144893798`}], 
        PointBox[{98.1, 0.19396097394819312`}], 
        PointBox[{98.2, 0.19555137749624946`}], 
        PointBox[{98.3, 0.19563054804178978`}], 
        PointBox[{98.4, 0.1915809051201797}], 
        PointBox[{98.5, 0.19051826592674256`}], 
        PointBox[{98.6, 0.19185639275418573`}], 
        PointBox[{98.7, 0.1894839883384756}], 
        PointBox[{98.8, 0.1888473435980965}], 
        PointBox[{98.9, 0.19269537545930052`}], 
        PointBox[{99., 0.1898511014434508}], 
        PointBox[{99.1, 0.1896376732964108}], 
        PointBox[{99.2, 0.19063191884928116`}], 
        PointBox[{99.3, 0.18841378185753735`}], 
        PointBox[{99.4, 0.18202703378779345`}], 
        PointBox[{99.5, 0.1850870541171185}], 
        PointBox[{99.6, 0.18363333344263988`}], 
        PointBox[{99.7, 0.18161325826160127`}], 
        PointBox[{99.8, 0.1824811086289345}], 
        PointBox[{99.9, 0.18615184120078968`}], 
        PointBox[{100., 0.18160538084540306`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 0.2}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
        PointBox[{0.1, 359.21781137132655`}], 
        PointBox[{0.2, 359.8024276455997}], 
        PointBox[{0.3, 359.63712260837957`}], 
        PointBox[{0.4, 358.7464296439937}], 
        PointBox[{0.5, 359.82609383675833`}], 
        PointBox[{0.6, 359.47090620914275`}], 
        PointBox[{0.7, 358.9377977671755}], 
        PointBox[{0.8, 359.17764964713575`}], 
        PointBox[{0.9, 359.64773967545034`}], 
        PointBox[{1., 357.727981951683}], PointBox[{1.1, 358.3755144427768}], 
        PointBox[{1.2, 358.5775342347513}], 
        PointBox[{1.3, 357.98968673086074`}], 
        PointBox[{1.4, 357.4622766951599}], 
        PointBox[{1.5, 358.76293530362227`}], 
        PointBox[{1.6, 357.83136496253474`}], 
        PointBox[{1.7, 357.7887457531664}], 
        PointBox[{1.8, 358.26043780010457`}], 
        PointBox[{1.9, 357.62319757391083`}], 
        PointBox[{2., 356.6802451557663}], 
        PointBox[{2.1, 357.43060831109887`}], 
        PointBox[{2.2, 357.18768317298793`}], 
        PointBox[{2.3, 356.3353297503363}], 
        PointBox[{2.4, 357.0591281789123}], 
        PointBox[{2.5, 357.07788693382537`}], 
        PointBox[{2.6, 356.56508834959754`}], 
        PointBox[{2.7, 356.89103614010077`}], 
        PointBox[{2.8, 357.154887175481}], 
        PointBox[{2.9, 355.54187015086353`}], 
        PointBox[{3., 356.1213252152849}], PointBox[{3.1, 356.4025470569756}],
         PointBox[{3.2, 355.79049915230644`}], 
        PointBox[{3.3, 355.1152880334188}], 
        PointBox[{3.4, 356.56321543820036`}], 
        PointBox[{3.5, 355.6472193291618}], 
        PointBox[{3.6, 355.7243693684022}], 
        PointBox[{3.7, 356.18747306022027`}], 
        PointBox[{3.8, 355.929545697189}], PointBox[{3.9, 354.6594395711025}],
         PointBox[{4., 355.7107051341758}], 
        PointBox[{4.1, 355.5210059014419}], 
        PointBox[{4.2, 354.6851710227223}], 
        PointBox[{4.3, 354.75861924508837`}], 
        PointBox[{4.4, 355.6222607901276}], 
        PointBox[{4.5, 354.8573508112386}], 
        PointBox[{4.6, 355.3944560815056}], 
        PointBox[{4.7, 355.75928452362245`}], 
        PointBox[{4.8, 355.2190229610484}], 
        PointBox[{4.9, 354.9356785471909}], PointBox[{5., 355.7184691900523}],
         PointBox[{5.1, 355.17235431735725`}], 
        PointBox[{5.2, 354.31276664009425`}], 
        PointBox[{5.3, 355.2648110307792}], 
        PointBox[{5.4, 355.13212875249917`}], 
        PointBox[{5.5, 354.93318836001936`}], 
        PointBox[{5.6, 355.8127695224405}], 
        PointBox[{5.7, 356.39428574151395`}], 
        PointBox[{5.8, 355.60742106640015`}], 
        PointBox[{5.9, 356.23032586959084`}], 
        PointBox[{6., 356.6440669500789}], 
        PointBox[{6.1, 355.84849648714135`}], 
        PointBox[{6.2, 355.14618117616027`}], 
        PointBox[{6.3, 356.588246811552}], 
        PointBox[{6.4, 355.82173544882426`}], 
        PointBox[{6.5, 356.17125478819446`}], 
        PointBox[{6.6, 357.4291104347298}], PointBox[{6.7, 358.714856818989}],
         PointBox[{6.8, 357.6637555175113}], 
        PointBox[{6.9, 358.7846126183302}], PointBox[{7., 358.9333086473461}],
         PointBox[{7.1, 357.9677475873575}], 
        PointBox[{7.2, 357.48419025609394`}], 
        PointBox[{7.3, 359.06222009321164`}], 
        PointBox[{7.4, 358.0389136348743}], 
        PointBox[{7.5, 358.83308995963665`}], 
        PointBox[{7.6, 0.6795405940831594}], 
        PointBox[{7.7, 2.5388364914736448`}], 
        PointBox[{7.8, 1.376777997481578}], 
        PointBox[{7.9, 2.727584837782603}], PointBox[{8., 2.739835158222333}],
         PointBox[{8.1, 1.655183691408477}], 
        PointBox[{8.2, 1.3250739233356368`}], 
        PointBox[{8.3, 2.9357117411613296`}], 
        PointBox[{8.4, 1.8156735655655882`}], 
        PointBox[{8.5, 2.9333492220850363`}], 
        PointBox[{8.6, 5.481414466474178}], 
        PointBox[{8.7, 7.648684946721344}], PointBox[{8.8, 6.44651305340044}],
         PointBox[{8.9, 7.899495268344854}], PointBox[{9., 7.89579174457779}],
         PointBox[{9.1, 6.723945829108461}], 
        PointBox[{9.2, 6.430588717283759}], 
        PointBox[{9.3, 8.091263047129283}], 
        PointBox[{9.4, 6.929338981556621}], 
        PointBox[{9.5, 8.221585339739121}], 
        PointBox[{9.6, 11.35717176312144}], 
        PointBox[{9.7, 13.728496377055196`}], 
        PointBox[{9.8, 12.5142106638594}], 
        PointBox[{9.9, 13.973136335269283`}], 
        PointBox[{10., 14.060332002256953`}], 
        PointBox[{10.1, 12.830000749068377`}], 
        PointBox[{10.2, 12.469841438808071`}], 
        PointBox[{10.3, 14.189909544693371`}], 
        PointBox[{10.4, 13.042621503715663`}], 
        PointBox[{10.5, 14.34312997779681}], 
        PointBox[{10.6, 17.861723454021945`}], 
        PointBox[{10.7, 20.411364880418784`}], 
        PointBox[{10.8, 19.23915866038339}], 
        PointBox[{10.9, 20.59383782637548}], 
        PointBox[{11., 20.85482321335284}], 
        PointBox[{11.1, 19.601310880883158`}], 
        PointBox[{11.2, 19.113702693906717`}], 
        PointBox[{11.3, 20.84958534881895}], 
        PointBox[{11.4, 19.805595300488733`}], 
        PointBox[{11.5, 20.965294328600187`}], 
        PointBox[{11.6, 24.666900739225714`}], 
        PointBox[{11.7, 27.346315263926027`}], 
        PointBox[{11.8, 26.297749315170343`}], 
        PointBox[{11.9, 27.438716466759995`}], 
        PointBox[{12., 27.917011946872407`}], 
        PointBox[{12.1, 26.680476987598304`}], 
        PointBox[{12.2, 26.054188034510318`}], 
        PointBox[{12.3, 27.72609187886264}], 
        PointBox[{12.4, 26.877573023649386`}], 
        PointBox[{12.5, 27.802682092485387`}], 
        PointBox[{12.6, 31.508255988918286`}], 
        PointBox[{12.7, 34.214867169566595`}], 
        PointBox[{12.8, 33.35643003832596}], 
        PointBox[{12.9, 34.218653134482935`}], 
        PointBox[{13., 34.90561789435937}], 
        PointBox[{13.1, 33.72037667059271}], 
        PointBox[{13.2, 32.98636593220634}], 
        PointBox[{13.3, 34.52244008716385}], 
        PointBox[{13.4, 33.91359212435967}], 
        PointBox[{13.5, 34.59068423738288}], 
        PointBox[{13.6, 38.12989140504941}], 
        PointBox[{13.7, 40.71546725386745}], 
        PointBox[{13.8, 40.052207985138956`}], 
        PointBox[{13.9, 40.65332398328228}], 
        PointBox[{14., 41.485938199580225`}], 
        PointBox[{14.1, 40.3681064184908}], 
        PointBox[{14.2, 39.58556530119437}], 
        PointBox[{14.3, 40.95871939369569}], 
        PointBox[{14.4, 40.54953555815857}], 
        PointBox[{14.5, 41.05051761433154}], 
        PointBox[{14.6, 44.23604613747651}], 
        PointBox[{14.7, 46.5359735648044}], 
        PointBox[{14.8, 45.995807424351455`}], 
        PointBox[{14.9, 46.44301654541912}], 
        PointBox[{15., 47.31135709816169}], 
        PointBox[{15.1, 46.253588828565704`}], 
        PointBox[{15.2, 45.494252469074645`}], 
        PointBox[{15.3, 46.73853150688514}], 
        PointBox[{15.4, 46.398143359445555`}], 
        PointBox[{15.5, 46.86005066706219}], 
        PointBox[{15.6, 49.46004431886519}], 
        PointBox[{15.7, 51.339391998136044`}], 
        PointBox[{15.8, 50.7901019154181}], 
        PointBox[{15.9, 51.26679282253099}], 
        PointBox[{16., 52.02006682849391}], 
        PointBox[{16.1, 51.001134499401424`}], 
        PointBox[{16.2, 50.340474921105944`}], 
        PointBox[{16.3, 51.536703807413694`}], 
        PointBox[{16.4, 51.06657495578808}], 
        PointBox[{16.5, 51.625087531779236`}], 
        PointBox[{16.6, 53.41089065228135}], 
        PointBox[{16.7, 54.80793400934958}], 
        PointBox[{16.8, 54.104493375491245`}], 
        PointBox[{16.9, 54.840817878496075`}], 
        PointBox[{17., 55.288620726632416`}], 
        PointBox[{17.1, 54.301051945466206`}], 
        PointBox[{17.2, 53.8205472860762}], 
        PointBox[{17.3, 55.049792086094065`}], 
        PointBox[{17.4, 54.24608137105365}], 
        PointBox[{17.5, 54.84078959611901}], 
        PointBox[{17.6, 55.86288078358799}], 
        PointBox[{17.7, 56.77311981313276}], 
        PointBox[{17.8, 55.84365085562225}], 
        PointBox[{17.9, 57.02084310640504}], 
        PointBox[{18., 56.977375455909225`}], 
        PointBox[{18.1, 56.06008435753647}], 
        PointBox[{18.2, 55.855027953762765`}], 
        PointBox[{18.3, 57.08542779292202}], 
        PointBox[{18.4, 55.91088942743291}], 
        PointBox[{18.5, 56.22930399540496}], 
        PointBox[{18.6, 56.93069371834512}], 
        PointBox[{18.7, 57.32523913466135}], 
        PointBox[{18.8, 56.36437304301668}], 
        PointBox[{18.9, 57.83649633836106}], 
        PointBox[{19., 57.27401208469706}], 
        PointBox[{19.1, 56.51931229605449}], 
        PointBox[{19.2, 56.70605296703875}], 
        PointBox[{19.3, 57.553227898497326`}], 
        PointBox[{19.4, 56.27798686526657}], 
        PointBox[{19.5, 56.38743089480005}], 
        PointBox[{19.6, 56.95554080704849}], 
        PointBox[{19.7, 56.746594405080636`}], 
        PointBox[{19.8, 56.42373982518918}], 
        PointBox[{19.9, 57.470196805057626`}], 
        PointBox[{20., 56.628096686534946`}], 
        PointBox[{20.1, 56.15582333898459}], 
        PointBox[{20.2, 56.82466986088719}], 
        PointBox[{20.3, 56.543101135341054`}], 
        PointBox[{20.4, 55.59484772049265}], 
        PointBox[{20.5, 55.95307355798599}], 
        PointBox[{20.6, 56.24489284588244}], 
        PointBox[{20.7, 55.43581087011611}], 
        PointBox[{20.8, 56.3466532453447}], 
        PointBox[{20.9, 56.29398866970785}], 
        PointBox[{21., 55.518730339584124`}], 
        PointBox[{21.1, 55.44852329531399}], 
        PointBox[{21.2, 56.39449610032007}], 
        PointBox[{21.3, 54.84222659112205}], 
        PointBox[{21.4, 54.72636482117434}], 
        PointBox[{21.5, 55.138528277944104`}], 
        PointBox[{21.6, 54.96752470595993}], 
        PointBox[{21.7, 54.15331560253005}], 
        PointBox[{21.8, 55.572140017714055`}], 
        PointBox[{21.9, 54.76631541015996}], 
        PointBox[{22., 54.301896932847804`}], 
        PointBox[{22.1, 54.713256398108236`}], 
        PointBox[{22.2, 54.90325767177173}], 
        PointBox[{22.3, 53.33373763862484}], 
        PointBox[{22.4, 53.836028629367604`}], 
        PointBox[{22.5, 53.983327865889066`}], 
        PointBox[{22.6, 53.26812842258202}], 
        PointBox[{22.7, 53.669247348765396`}], 
        PointBox[{22.8, 54.02407633286319}], 
        PointBox[{22.9, 53.23470953282856}], 
        PointBox[{23., 53.18839599211989}], 
        PointBox[{23.1, 53.93255662871941}], 
        PointBox[{23.2, 52.43437853768795}], 
        PointBox[{23.3, 52.34342532506809}], 
        PointBox[{23.4, 52.77414256036616}], 
        PointBox[{23.5, 52.494068424045466`}], 
        PointBox[{23.6, 51.614893349017336`}], 
        PointBox[{23.7, 53.057671554274414`}], 
        PointBox[{23.8, 52.270167886124625`}], 
        PointBox[{23.9, 51.88080541400691}], 
        PointBox[{24., 52.245514683145096`}], 
        PointBox[{24.1, 52.45205460010428}], 
        PointBox[{24.2, 50.70570516664276}], 
        PointBox[{24.3, 51.42044977617013}], 
        PointBox[{24.4, 51.47393786736316}], 
        PointBox[{24.5, 50.75350190975565}], 
        PointBox[{24.6, 50.82824943218841}], 
        PointBox[{24.7, 51.51270557136481}], 
        PointBox[{24.8, 50.70779672363142}], 
        PointBox[{24.9, 50.760598142875395`}], 
        PointBox[{25., 51.315365615293395`}], 
        PointBox[{25.1, 49.96641367927522}], 
        PointBox[{25.2, 49.83658869686818}], 
        PointBox[{25.3, 50.33353816283744}], 
        PointBox[{25.4, 49.959978690828514`}], 
        PointBox[{25.5, 49.09886803911884}], 
        PointBox[{25.6, 50.431601696787126`}], 
        PointBox[{25.7, 49.753731309798624`}], 
        PointBox[{25.8, 49.458542592505864`}], 
        PointBox[{25.9, 49.830830466159476`}], 
        PointBox[{26., 49.91013879783403}], 
        PointBox[{26.1, 48.18162312572547}], 
        PointBox[{26.2, 49.07379721116059}], 
        PointBox[{26.3, 49.097025947522354`}], 
        PointBox[{26.4, 48.37204076526248}], 
        PointBox[{26.5, 48.13412025955516}], 
        PointBox[{26.6, 49.218089005787306`}], 
        PointBox[{26.7, 48.340437780380284`}], 
        PointBox[{26.8, 48.53137413421765}], 
        PointBox[{26.9, 48.938660704656826`}], 
        PointBox[{27., 48.06058511301281}], 
        PointBox[{27.1, 47.54992799995783}], 
        PointBox[{27.2, 48.271550351718304`}], 
        PointBox[{27.3, 47.87048848240396}], 
        PointBox[{27.4, 47.01671745691563}], 
        PointBox[{27.5, 47.93692140674997}], 
        PointBox[{27.6, 47.75503354837267}], 
        PointBox[{27.7, 47.43548049629868}], 
        PointBox[{27.8, 47.9316045182227}], 
        PointBox[{27.9, 48.03745408750964}], 
        PointBox[{28., 46.683949978025105`}], 
        PointBox[{28.1, 47.432543169161264`}], 
        PointBox[{28.2, 47.66233496378106}], 
        PointBox[{28.3, 46.951971341398576`}], 
        PointBox[{28.4, 46.343505381887624`}], 
        PointBox[{28.5, 47.806826656474335`}], 
        PointBox[{28.6, 46.869845376369646`}], 
        PointBox[{28.7, 47.161840716118775`}], 
        PointBox[{28.8, 47.77145133569167}], 
        PointBox[{28.9, 47.880647236140206`}], 
        PointBox[{29., 46.67891037506644}], 
        PointBox[{29.1, 47.86513100877192}], 
        PointBox[{29.2, 47.6717044671845}], 
        PointBox[{29.3, 46.782240725189446`}], 
        PointBox[{29.4, 46.74048412754353}], 
        PointBox[{29.5, 47.86665462548455}], 
        PointBox[{29.6, 46.971126407008335`}], 
        PointBox[{29.7, 47.77519430187584}], 
        PointBox[{29.8, 48.563050636144645`}], 
        PointBox[{29.9, 48.877035464599224`}], 
        PointBox[{30., 48.16956558620497}], 
        PointBox[{30.1, 49.30124739863383}], 
        PointBox[{30.2, 48.80197833330081}], 
        PointBox[{30.3, 47.84930200754883}], 
        PointBox[{30.4, 48.39692792602911}], 
        PointBox[{30.5, 48.943504467823814`}], 
        PointBox[{30.6, 48.364667947172975`}], 
        PointBox[{30.7, 49.64463668317714}], 
        PointBox[{30.8, 51.101577877540635`}], 
        PointBox[{30.9, 51.331389177248184`}], 
        PointBox[{31., 51.109382769036834`}], 
        PointBox[{31.1, 52.12719904297426}], 
        PointBox[{31.2, 51.41805488283691}], 
        PointBox[{31.3, 50.46320524537864}], 
        PointBox[{31.4, 51.4031975809052}], 
        PointBox[{31.5, 51.55552080397773}], 
        PointBox[{31.6, 51.24159721335815}], 
        PointBox[{31.7, 53.02627438873094}], 
        PointBox[{31.8, 55.33172313459001}], 
        PointBox[{31.9, 55.3737214929115}], 
        PointBox[{32., 55.40810269363087}], 
        PointBox[{32.1, 56.40522762191881}], 
        PointBox[{32.2, 55.56261241359584}], 
        PointBox[{32.3, 54.6022346472784}], 
        PointBox[{32.4, 55.72499243542612}], 
        PointBox[{32.5, 55.73970221989393}], 
        PointBox[{32.6, 55.53792731213002}], 
        PointBox[{32.7, 57.82231651179373}], 
        PointBox[{32.8, 60.76706454039856}], 
        PointBox[{32.9, 60.761534589521936`}], 
        PointBox[{33., 60.81688060229109}], 
        PointBox[{33.1, 61.90423021220204}], 
        PointBox[{33.2, 60.99592979761058}], 
        PointBox[{33.3, 59.99448347864239}], 
        PointBox[{33.4, 61.14313514247659}], 
        PointBox[{33.5, 61.23178023693113}], 
        PointBox[{33.6, 60.97783924932844}], 
        PointBox[{33.7, 63.66092741304887}], 
        PointBox[{33.8, 67.00451314418163}], 
        PointBox[{33.9, 67.1146428881387}], 
        PointBox[{34., 67.00884117039665}], 
        PointBox[{34.1, 68.2654674850076}], 
        PointBox[{34.2, 67.35728186286963}], 
        PointBox[{34.3, 66.28592083455425}], 
        PointBox[{34.4, 67.33903252891312}], 
        PointBox[{34.5, 67.65592101769953}], 
        PointBox[{34.6, 67.2212446850437}], 
        PointBox[{34.7, 70.1415667358757}], 
        PointBox[{34.8, 73.70168584476397}], 
        PointBox[{34.9, 74.04248570563838}], 
        PointBox[{35., 73.66832031709002}], 
        PointBox[{35.1, 75.11839211063096}], 
        PointBox[{35.2, 74.27161772106325}], 
        PointBox[{35.3, 73.12685879600147}], 
        PointBox[{35.4, 73.99641546376772}], 
        PointBox[{35.5, 74.62308242458208}], 
        PointBox[{35.6, 73.94833317944244}], 
        PointBox[{35.7, 76.94018521139412}], 
        PointBox[{35.8, 80.55931746363983}], PointBox[{35.9, 81.172305462}], 
        PointBox[{36., 80.51189772381294}], 
        PointBox[{36.1, 82.12060120503924}], 
        PointBox[{36.2, 81.3804550493893}], 
        PointBox[{36.3, 80.1865357624101}], 
        PointBox[{36.4, 80.82875380564757}], 
        PointBox[{36.5, 81.75899811160853}], 
        PointBox[{36.6, 80.86398609633034}], 
        PointBox[{36.7, 83.79166187106642}], 
        PointBox[{36.8, 87.30497886245685}], 
        PointBox[{36.9, 88.14714982115962}], 
        PointBox[{37., 87.26273517372205}], 
        PointBox[{37.1, 88.95547463566908}], 
        PointBox[{37.2, 88.33609998265564}], 
        PointBox[{37.3, 87.13311091572338}], 
        PointBox[{37.4, 87.55947109836721}], 
        PointBox[{37.5, 88.71010017696612}], 
        PointBox[{37.6, 87.67039502573704}], 
        PointBox[{37.7, 90.44116947299528}], 
        PointBox[{37.8, 93.66319400183897}], 
        PointBox[{37.9, 94.6170588766822}], 
        PointBox[{38., 93.61297918002445}], 
        PointBox[{38.1, 95.31301011908266}], 
        PointBox[{38.2, 94.785490447124}], 
        PointBox[{38.3, 93.61758327344242}], 
        PointBox[{38.4, 93.89046811801174}], 
        PointBox[{38.5, 95.13621370502733}], 
        PointBox[{38.6, 94.0428343543939}], 
        PointBox[{38.7, 96.58975046023977}], 
        PointBox[{38.8, 99.32375324451269}], 
        PointBox[{38.9, 100.22774194234471`}], 
        PointBox[{39., 99.20893315807152}], 
        PointBox[{39.1, 100.8681239877638}], 
        PointBox[{39.2, 100.36014169076071`}], 
        PointBox[{39.3, 99.26690656192443}], 
        PointBox[{39.4, 99.48564874612985}], 
        PointBox[{39.5, 100.69128224550285`}], 
        PointBox[{39.6, 99.62689743256527}], 
        PointBox[{39.7, 101.83894518692739`}], 
        PointBox[{39.8, 103.9375457875182}], 
        PointBox[{39.9, 104.62333571930434`}], 
        PointBox[{40., 103.6907449693044}], 
        PointBox[{40.1, 105.27840535568427`}], 
        PointBox[{40.2, 104.69323603144431`}], 
        PointBox[{40.3, 103.71266187627121`}], 
        PointBox[{40.4, 103.9986609901965}], 
        PointBox[{40.5, 105.00891604232943`}], 
        PointBox[{40.6, 104.07573857780346`}], 
        PointBox[{40.7, 105.71267216076845`}], 
        PointBox[{40.8, 107.19446720754989`}], 
        PointBox[{40.9, 107.51259622227548`}], 
        PointBox[{41., 106.82619907382794`}], 
        PointBox[{41.1, 108.24593271291084`}], 
        PointBox[{41.2, 107.51087186525265`}], 
        PointBox[{41.3, 106.6910930028752}], 
        PointBox[{41.4, 107.17617844438932`}], 
        PointBox[{41.5, 107.74746652679563`}], 
        PointBox[{41.6, 107.09503651192108`}], 
        PointBox[{41.7, 107.95440748404093`}], 
        PointBox[{41.8, 108.98291742515944`}], 
        PointBox[{41.9, 108.80945817791363`}], 
        PointBox[{42., 108.68151306474194`}], 
        PointBox[{42.1, 109.65905254875506`}], 
        PointBox[{42.2, 108.79349058083508`}], 
        PointBox[{42.3, 108.20539560171086`}], 
        PointBox[{42.4, 109.0034977860049}], 
        PointBox[{42.5, 108.78525251813623`}], 
        PointBox[{42.6, 108.38956988915893`}], 
        PointBox[{42.7, 108.81651780599148`}], 
        PointBox[{42.8, 109.47136583577719`}], 
        PointBox[{42.9, 108.75767591430268`}], 
        PointBox[{43., 109.52890278606006`}], 
        PointBox[{43.1, 109.71627276062799`}], 
        PointBox[{43.2, 108.85412438936548`}], 
        PointBox[{43.3, 108.59643293616925`}], 
        PointBox[{43.4, 109.66665843440704`}], 
        PointBox[{43.5, 108.53195838857884`}], 
        PointBox[{43.6, 108.27951141953594`}], 
        PointBox[{43.7, 108.75578111365353`}], 
        PointBox[{43.8, 108.96016123052257`}], 
        PointBox[{43.9, 108.00448841435166`}], 
        PointBox[{44., 109.43933402633314`}], 
        PointBox[{44.1, 108.86077359123271`}], 
        PointBox[{44.2, 108.1837168964827}], 
        PointBox[{44.3, 108.37389239884106`}], 
        PointBox[{44.4, 109.13933735186026`}], 
        PointBox[{44.5, 107.55327463847797`}], 
        PointBox[{44.6, 107.69145338731374`}], 
        PointBox[{44.7, 108.08700924041312`}], 
        PointBox[{44.8, 107.70733743489177`}], 
        PointBox[{44.9, 107.4792189072565}], 
        PointBox[{45., 108.42568600717769`}], 
        PointBox[{45.1, 107.56621889098912`}], 
        PointBox[{45.2, 107.22692655343867`}], 
        PointBox[{45.3, 107.91448162324986`}], 
        PointBox[{45.4, 107.31597488737539`}], 
        PointBox[{45.5, 106.41655091582393`}], 
        PointBox[{45.6, 106.87727964837634`}], 
        PointBox[{45.7, 106.94888192916085`}], 
        PointBox[{45.8, 106.05266076336333`}], 
        PointBox[{45.9, 107.17472101858132`}], 
        PointBox[{46., 106.85722522437655`}], 
        PointBox[{46.1, 106.18438615475603`}], 
        PointBox[{46.2, 106.28109780016139`}], 
        PointBox[{46.3, 107.07188252624456`}], 
        PointBox[{46.4, 105.2115478452498}], 
        PointBox[{46.5, 105.49094625311193`}], 
        PointBox[{46.6, 105.80996678027878`}], 
        PointBox[{46.7, 105.39941665503076`}], 
        PointBox[{46.8, 104.80745428252675`}], 
        PointBox[{46.9, 106.088107173004}], 
        PointBox[{47., 105.19555788729738`}], 
        PointBox[{47.1, 104.9201967029376}], 
        PointBox[{47.2, 105.44796214857611`}], 
        PointBox[{47.3, 105.06985210831016`}], 
        PointBox[{47.4, 103.90273208001275`}], 
        PointBox[{47.5, 104.51298623197431`}], 
        PointBox[{47.6, 104.45802360780945`}], 
        PointBox[{47.7, 103.60831543867145`}], 
        PointBox[{47.8, 104.42358281411339`}], 
        PointBox[{47.9, 104.35265235458252`}], 
        PointBox[{48., 103.70718448581357`}], 
        PointBox[{48.1, 103.85458268521509`}], 
        PointBox[{48.2, 104.45679264544587`}], 
        PointBox[{48.3, 102.60390440990365`}], 
        PointBox[{48.4, 103.03418567115853`}], 
        PointBox[{48.5, 103.33672375188047`}], 
        PointBox[{48.6, 102.84678141898296`}], 
        PointBox[{48.7, 102.14667208188047`}], 
        PointBox[{48.8, 103.56272527782369`}], 
        PointBox[{48.9, 102.64299150445794`}], 
        PointBox[{49., 102.48073045672453`}], 
        PointBox[{49.1, 102.93282091104216`}], 
        PointBox[{49.2, 102.6014157841606}], 
        PointBox[{49.3, 101.31345564663657`}], 
        PointBox[{49.4, 102.10329993141653`}], 
        PointBox[{49.5, 101.96303992499047`}], 
        PointBox[{49.6, 101.14091679093045`}], 
        PointBox[{49.7, 101.60344036084757`}], 
        PointBox[{49.8, 101.90253840583381`}], 
        PointBox[{49.9, 101.26259618180723`}], 
        PointBox[{50., 101.50724244748419`}], 
        PointBox[{50.1, 101.88878007184913`}], 
        PointBox[{50.2, 100.32850901343772`}], 
        PointBox[{50.3, 100.66500259662592`}], 
        PointBox[{50.4, 101.04269561297178`}], 
        PointBox[{50.5, 100.50632750724758`}], 
        PointBox[{50.6, 99.7449272934613}], 
        PointBox[{50.7, 101.16886243012617`}], 
        PointBox[{50.8, 100.3304182604744}], 
        PointBox[{50.9, 100.27584868226143`}], 
        PointBox[{51., 100.7211249545217}], 
        PointBox[{51.1, 100.5331288103187}], 
        PointBox[{51.2, 99.10386551663092}], 
        PointBox[{51.3, 100.12629904708143`}], 
        PointBox[{51.4, 100.01647169192324`}], 
        PointBox[{51.5, 99.21427372175334}], 
        PointBox[{51.6, 99.145738596238}], 
        PointBox[{51.7, 100.13334039592647`}], 
        PointBox[{51.8, 99.30703689292818}], 
        PointBox[{51.9, 99.72992401418725}], 
        PointBox[{52., 100.08922100514675`}], 
        PointBox[{52.1, 99.45114120992137}], 
        PointBox[{52.2, 99.04743673268533}], 
        PointBox[{52.3, 99.83991437420099}], 
        PointBox[{52.4, 99.34682933531796}], 
        PointBox[{52.5, 98.48702920048977}], 
        PointBox[{52.6, 99.37638575892261}], 
        PointBox[{52.7, 99.29206308268938}], 
        PointBox[{52.8, 99.03325809237907}], 
        PointBox[{52.9, 99.78462392003522}], 
        PointBox[{53., 100.15482091417037`}], 
        PointBox[{53.1, 99.2563247026401}], 
        PointBox[{53.2, 99.8745406531599}], 
        PointBox[{53.3, 100.25504538799476`}], 
        PointBox[{53.4, 99.49238686147905}], 
        PointBox[{53.5, 98.80138300749744}], 
        PointBox[{53.6, 100.24327102802526`}], 
        PointBox[{53.7, 99.44313436269323}], 
        PointBox[{53.8, 99.77209672029699}], 
        PointBox[{53.9, 100.82424554593035`}], 
        PointBox[{54., 101.77000747378528`}], 
        PointBox[{54.1, 100.6480783012147}], 
        PointBox[{54.2, 101.81519892073112`}], 
        PointBox[{54.3, 101.87351549341338`}], 
        PointBox[{54.4, 100.93211203098723`}], 
        PointBox[{54.5, 100.52615108119257`}], 
        PointBox[{54.6, 102.05999251115401`}], 
        PointBox[{54.7, 101.00969275114369`}], 
        PointBox[{54.8, 101.83668850297141`}], 
        PointBox[{54.9, 103.40428951797479`}], 
        PointBox[{55., 104.90883216868617`}], 
        PointBox[{55.1, 103.7344740900715}], 
        PointBox[{55.2, 105.13301298623801`}], 
        PointBox[{55.3, 104.99387362039752`}], 
        PointBox[{55.4, 103.93284238783757`}], 
        PointBox[{55.5, 103.76769659538402`}], 
        PointBox[{55.6, 105.25450039490448`}], 
        PointBox[{55.7, 104.14014218039753`}], 
        PointBox[{55.8, 105.37267024696493`}], 
        PointBox[{55.9, 107.67627869978944`}], 
        PointBox[{56., 109.45028274218166`}], 
        PointBox[{56.1, 108.2768495951748}], 
        PointBox[{56.2, 109.79652907524681`}], 
        PointBox[{56.3, 109.57601415275423`}], 
        PointBox[{56.4, 108.42567904132713`}], 
        PointBox[{56.5, 108.37103113878311`}], 
        PointBox[{56.6, 109.86707832271131`}], 
        PointBox[{56.7, 108.70603978068414`}], 
        PointBox[{56.8, 110.22713687968326`}], 
        PointBox[{56.9, 113.2103004199229}], 
        PointBox[{57., 115.14242756199693`}], 
        PointBox[{57.1, 113.93665512235339`}], 
        PointBox[{57.2, 115.53023659669705`}], 
        PointBox[{57.3, 115.33446887704321`}], 
        PointBox[{57.4, 114.11304750137808`}], 
        PointBox[{57.5, 114.03605903522124`}], 
        PointBox[{57.6, 115.61845568446593`}], 
        PointBox[{57.7, 114.405277761652}], 
        PointBox[{57.8, 116.06188731117723`}], 
        PointBox[{57.9, 119.5183127480426}], 
        PointBox[{58., 121.62295691017648`}], 
        PointBox[{58.1, 120.37510904552421`}], 
        PointBox[{58.2, 121.97577615933372`}], 
        PointBox[{58.3, 121.89708447994613`}], 
        PointBox[{58.4, 120.62762051138976`}], 
        PointBox[{58.5, 120.43397140278358`}], 
        PointBox[{58.6, 122.11940000953638`}], 
        PointBox[{58.7, 120.89271265522987`}], 
        PointBox[{58.8, 122.52212362957994`}], 
        PointBox[{58.9, 126.23898861380505`}], 
        PointBox[{59., 128.5201905716442}], 
        PointBox[{59.1, 127.27876586880332`}], 
        PointBox[{59.2, 128.78780500704565`}], 
        PointBox[{59.3, 128.89235350163136`}], 
        PointBox[{59.4, 127.60843313433593`}], 
        PointBox[{59.5, 127.25543858822563`}], 
        PointBox[{59.6, 128.99156549964562`}], 
        PointBox[{59.7, 127.83433644450281`}], 
        PointBox[{59.8, 129.30407186022427`}], 
        PointBox[{59.9, 133.09264200875094`}], 
        PointBox[{60., 135.49211635231305`}], 
        PointBox[{60.1, 134.33834181525205`}], 
        PointBox[{60.2, 135.65808113607275`}], 
        PointBox[{60.3, 135.96981108799076`}], 
        PointBox[{60.4, 134.70915089279507`}], 
        PointBox[{60.5, 134.20529771628367`}], 
        PointBox[{60.6, 135.90501461781298`}], 
        PointBox[{60.7, 134.90034277235642`}], 
        PointBox[{60.8, 136.143074624489}], 
        PointBox[{60.9, 139.8267285813478}], 
        PointBox[{61., 142.22405861116664`}], 
        PointBox[{61.1, 141.2188106535552}], 
        PointBox[{61.2, 142.3022573871515}], 
        PointBox[{61.3, 142.7918102312361}], 
        PointBox[{61.4, 141.58403715355882`}], 
        PointBox[{61.5, 140.97735297980847`}], 
        PointBox[{61.6, 142.56897763108037`}], 
        PointBox[{61.7, 141.74516669320158`}], 
        PointBox[{61.8, 142.77711291915762`}], 
        PointBox[{61.9, 146.16915465078705`}], 
        PointBox[{62., 148.40643198659302`}], 
        PointBox[{62.1, 147.54598210646964`}], 
        PointBox[{62.2, 148.43237940558274`}], 
        PointBox[{62.3, 149.01597175151213`}], 
        PointBox[{62.4, 147.872950954899}], 
        PointBox[{62.5, 147.2356071555819}], 
        PointBox[{62.6, 148.69782873437157`}], 
        PointBox[{62.7, 147.99629311711163`}], 
        PointBox[{62.8, 148.91033368281936`}], 
        PointBox[{62.9, 151.79008780886193`}], 
        PointBox[{63., 153.71123294184056`}], 
        PointBox[{63.1, 152.9189386728959}], 
        PointBox[{63.2, 153.73727065780602`}], 
        PointBox[{63.3, 154.28266153853824`}], 
        PointBox[{63.4, 153.19931950845282`}], 
        PointBox[{63.5, 152.6134330161072}], 
        PointBox[{63.6, 153.9808288073602}], 
        PointBox[{63.7, 153.26092944131923`}], 
        PointBox[{63.8, 154.17459807173097`}], 
        PointBox[{63.9, 156.30635645426796`}], 
        PointBox[{64., 157.8018028370725}], 
        PointBox[{64.1, 156.96008285541453`}], 
        PointBox[{64.2, 157.90205331535628`}], 
        PointBox[{64.3, 158.23772434839276`}], 
        PointBox[{64.4, 157.20900425885952`}], 
        PointBox[{64.5, 156.76199402095426`}], 
        PointBox[{64.6, 158.09156704491218`}], 
        PointBox[{64.7, 157.18347575237976`}], 
        PointBox[{64.8, 158.0807278978661}], 
        PointBox[{64.9, 159.40209096577303`}], 
        PointBox[{65., 160.4232887063868}], 
        PointBox[{65.1, 159.4510135736924}], 
        PointBox[{65.2, 160.69076282266346`}], 
        PointBox[{65.3, 160.63970822592015`}], 
        PointBox[{65.4, 159.68888177755795`}], 
        PointBox[{65.5, 159.47811867543933`}], 
        PointBox[{65.6, 160.75669787172558`}], 
        PointBox[{65.7, 159.59858295166978`}], 
        PointBox[{65.8, 160.18971655350182`}], 
        PointBox[{65.9, 161.03214295443038`}], 
        PointBox[{66., 161.54297250618256`}], 
        PointBox[{66.1, 160.5568468337516}], 
        PointBox[{66.2, 162.03832540923986`}], 
        PointBox[{66.3, 161.52755194991107`}], 
        PointBox[{66.4, 160.7242657957064}], 
        PointBox[{66.5, 160.86431714894212`}], 
        PointBox[{66.6, 161.8125857688772}], 
        PointBox[{66.7, 160.60571059069568`}], 
        PointBox[{66.8, 160.79893838129277`}], 
        PointBox[{66.9, 161.45384876370136`}], 
        PointBox[{67., 161.3770637125011}], 
        PointBox[{67.1, 160.90322020609327`}], 
        PointBox[{67.2, 162.0805839520588}], 
        PointBox[{67.3, 161.2627340070817}], 
        PointBox[{67.4, 160.71261744062693`}], 
        PointBox[{67.5, 161.31057488564804`}], 
        PointBox[{67.6, 161.28450652341658`}], 
        PointBox[{67.7, 160.30600925570272`}], 
        PointBox[{67.8, 160.59997376915211`}], 
        PointBox[{67.9, 161.00428335674982`}], 
        PointBox[{68., 160.30152544724703`}], 
        PointBox[{68.1, 160.97981588916147`}], 
        PointBox[{68.2, 161.15986545727685`}], 
        PointBox[{68.3, 160.3394185590511}], 
        PointBox[{68.4, 160.16090721549816`}], 
        PointBox[{68.5, 161.12283265190845`}], 
        PointBox[{68.6, 159.81962799119822`}], 
        PointBox[{68.7, 159.49747170423822`}], 
        PointBox[{68.8, 159.9337927285088}], 
        PointBox[{68.9, 159.90936724887703`}], 
        PointBox[{69., 158.99237717123435`}], 
        PointBox[{69.1, 160.43757012504364`}], 
        PointBox[{69.2, 159.7382964180475}], 
        PointBox[{69.3, 159.17509302310867`}], 
        PointBox[{69.4, 159.47035839246095`}], 
        PointBox[{69.5, 159.98430971779328`}], 
        PointBox[{69.6, 158.2583114577892}], 
        PointBox[{69.7, 158.65023462792573`}], 
        PointBox[{69.8, 158.89741669970113`}], 
        PointBox[{69.9, 158.3153763755473}], 
        PointBox[{70., 158.36146109084876`}], 
        PointBox[{70.1, 159.05460862989835`}], 
        PointBox[{70.2, 158.20821905514384`}], 
        PointBox[{70.3, 158.04171609728667`}], 
        PointBox[{70.4, 158.7623098613138}], 
        PointBox[{70.5, 157.65831717717052`}], 
        PointBox[{70.6, 157.17008415454086`}], 
        PointBox[{70.7, 157.65639438050397`}], 
        PointBox[{70.8, 157.5080419889018}], 
        PointBox[{70.9, 156.5843775316895}], 
        PointBox[{71., 157.92187559010202`}], 
        PointBox[{71.1, 157.31537404341088`}], 
        PointBox[{71.2, 156.8016442029218}], 
        PointBox[{71.3, 157.06631706198482`}], 
        PointBox[{71.4, 157.56229625878575`}], 
        PointBox[{71.5, 155.64289074517444`}], 
        PointBox[{71.6, 156.25944509318649`}], 
        PointBox[{71.7, 156.42788403951886`}], 
        PointBox[{71.8, 155.81482056408052`}], 
        PointBox[{71.9, 155.55417353027957`}], 
        PointBox[{72., 156.56313119639506`}], 
        PointBox[{72.1, 155.68168751586876`}], 
        PointBox[{72.2, 155.61391377366655`}], 
        PointBox[{72.3, 156.17698795086793`}], 
        PointBox[{72.4, 155.20491378177812`}], 
        PointBox[{72.5, 154.6280275979418}], 
        PointBox[{72.6, 155.21587911856417`}], 
        PointBox[{72.7, 154.95906226336334`}], 
        PointBox[{72.8, 154.0738537494865}], 
        PointBox[{72.9, 155.2091616734291}], 
        PointBox[{73., 154.77603986157686`}], 
        PointBox[{73.1, 154.33243447393224`}], 
        PointBox[{73.2, 154.6350730496069}], 
        PointBox[{73.3, 154.94074601744904`}], 
        PointBox[{73.4, 153.08234464088451`}], 
        PointBox[{73.5, 153.84885321953604`}], 
        PointBox[{73.6, 153.99197634424016`}], 
        PointBox[{73.7, 153.34578480543655`}], 
        PointBox[{73.8, 152.88129833355967`}], 
        PointBox[{73.9, 154.16227261728991`}], 
        PointBox[{74., 153.22900758178736`}], 
        PointBox[{74.1, 153.293851671546}], 
        PointBox[{74.2, 153.7367815922313}], 
        PointBox[{74.3, 153.0491755704712}], 
        PointBox[{74.4, 152.20330705374312`}], 
        PointBox[{74.5, 152.99746160367565`}], 
        PointBox[{74.6, 152.69466946256057`}], 
        PointBox[{74.7, 151.84172658657093`}], 
        PointBox[{74.8, 152.54017800094553`}], 
        PointBox[{74.9, 152.6048473467434}], 
        PointBox[{75., 152.1378892315301}], 
        PointBox[{75.1, 152.5533359367048}], 
        PointBox[{75.2, 152.73528475542264`}], 
        PointBox[{75.3, 151.33225663408513`}], 
        PointBox[{75.4, 151.8932311686851}], 
        PointBox[{75.5, 152.2078260827307}], 
        PointBox[{75.6, 151.56192599189444`}], 
        PointBox[{75.7, 150.87544594358093`}], 
        PointBox[{75.8, 152.31819019746047`}], 
        PointBox[{75.9, 151.44034782964317`}], 
        PointBox[{76., 151.59376535230777`}], 
        PointBox[{76.1, 152.14455292476705`}], 
        PointBox[{76.2, 152.11235444288832`}], 
        PointBox[{76.3, 150.83609270332545`}], 
        PointBox[{76.4, 151.97483203137145`}], 
        PointBox[{76.5, 151.8333035258055}], 
        PointBox[{76.6, 150.9783926698767}], 
        PointBox[{76.7, 150.86562862366156`}], 
        PointBox[{76.8, 152.01727958785276`}], 
        PointBox[{76.9, 151.1164579183046}], 
        PointBox[{77., 151.78526407731562`}], 
        PointBox[{77.1, 152.39244619519457`}], 
        PointBox[{77.2, 152.46657690747915`}], 
        PointBox[{77.3, 151.77012064492695`}], 
        PointBox[{77.4, 152.8385075006112}], 
        PointBox[{77.5, 152.35838217071205`}], 
        PointBox[{77.6, 151.4330270869178}], 
        PointBox[{77.7, 152.0032225475931}], 
        PointBox[{77.8, 152.45799562474488`}], 
        PointBox[{77.9, 151.93554602241753`}], 
        PointBox[{78., 153.0572363433955}], 
        PointBox[{78.1, 154.1608573917049}], 
        PointBox[{78.2, 154.14158358928984`}], 
        PointBox[{78.3, 154.08054066122494`}], 
        PointBox[{78.4, 154.958048335828}], 
        PointBox[{78.5, 154.23997690103658`}], 
        PointBox[{78.6, 153.33714585345183`}], 
        PointBox[{78.7, 154.3913822221569}], 
        PointBox[{78.8, 154.31571060843046`}], 
        PointBox[{78.9, 154.16291593383409`}], 
        PointBox[{79., 155.7758515976181}], 
        PointBox[{79.1, 157.727602751343}], 
        PointBox[{79.2, 157.44989759262162`}], 
        PointBox[{79.3, 157.78250699136106`}], 
        PointBox[{79.4, 158.55732585865303`}], 
        PointBox[{79.5, 157.6774891973888}], 
        PointBox[{79.6, 156.81223865200627`}], 
        PointBox[{79.7, 158.11234602444767`}], 
        PointBox[{79.8, 157.78625313247912`}], 
        PointBox[{79.9, 157.86210238382324`}], 
        PointBox[{80., 160.0221887511411}], 
        PointBox[{80.1, 162.6683811690761}], 
        PointBox[{80.2, 162.25655050062917`}], 
        PointBox[{80.3, 162.723466917943}], 
        PointBox[{80.4, 163.52183410222776`}], 
        PointBox[{80.5, 162.54197899787698`}], 
        PointBox[{80.6, 161.67156231689407`}], 
        PointBox[{80.7, 163.05710218087293`}], 
        PointBox[{80.8, 162.70395516340326`}], 
        PointBox[{80.9, 162.83572672884765`}], 
        PointBox[{81., 165.49612746275918`}], 
        PointBox[{81.1, 168.58462866092626`}], 
        PointBox[{81.2, 168.20743551518146`}], 
        PointBox[{81.3, 168.60073078489677`}], 
        PointBox[{81.4, 169.53225951309582`}], 
        PointBox[{81.5, 168.51044566974736`}], 
        PointBox[{81.6, 167.5831289135428}], 
        PointBox[{81.7, 168.93839108175828`}], 
        PointBox[{81.8, 168.73077749576078`}], 
        PointBox[{81.9, 168.75464179109295`}], 
        PointBox[{82., 171.76936700149884`}], 
        PointBox[{82.1, 175.12067612331248`}], 
        PointBox[{82.2, 174.9161796949705}], 
        PointBox[{82.3, 175.08130401924808`}], 
        PointBox[{82.4, 176.21442190077929`}], 
        PointBox[{82.5, 175.208622931149}], 
        PointBox[{82.6, 174.19702992209162`}], 
        PointBox[{82.7, 175.4227218404559}], 
        PointBox[{82.8, 175.48791288462323`}], 
        PointBox[{82.9, 175.28622004258116`}], 
        PointBox[{83., 178.47947952919733`}], 
        PointBox[{83.1, 181.95396786585886`}], 
        PointBox[{83.2, 182.01063126147938`}], 
        PointBox[{83.3, 181.8630164496831}], 
        PointBox[{83.4, 183.2096946685658}], 
        PointBox[{83.5, 182.27192148534564`}], 
        PointBox[{83.6, 181.1811727714992}], 
        PointBox[{83.7, 182.20368028934416`}], 
        PointBox[{83.8, 182.6017407232065}], 
        PointBox[{83.9, 182.13150555331197`}], 
        PointBox[{84., 185.34321267245875`}], 
        PointBox[{84.1, 188.79600685773133`}], 
        PointBox[{84.2, 189.12991556798247`}], 
        PointBox[{84.3, 188.67159631838427`}], 
        PointBox[{84.4, 190.18770594800034`}], 
        PointBox[{84.5, 189.35104226763391`}], 
        PointBox[{84.6, 188.21399259283132`}], 
        PointBox[{84.7, 189.00519906647398`}], 
        PointBox[{84.8, 189.71001876571646`}], 
        PointBox[{84.9, 189.00669119493887`}], 
        PointBox[{85., 192.109256904504}], 
        PointBox[{85.1, 195.37264107390877`}], 
        PointBox[{85.2, 195.9172402607483}], 
        PointBox[{85.3, 195.2270825248405}], 
        PointBox[{85.4, 196.8340712133558}], 
        PointBox[{85.5, 196.09816917064632`}], 
        PointBox[{85.6, 194.96170958056564`}], 
        PointBox[{85.7, 195.54976944007296`}], 
        PointBox[{85.8, 196.4601459211577}], 
        PointBox[{85.9, 195.61359925139647`}], 
        PointBox[{86., 198.50559142471934`}], 
        PointBox[{86.1, 201.393093121782}], 
        PointBox[{86.2, 202.0139240974567}], 
        PointBox[{86.3, 201.212602486568}], 
        PointBox[{86.4, 202.82890631160254`}], 
        PointBox[{86.5, 202.15308193157716`}], 
        PointBox[{86.6, 201.06589240160167`}], 
        PointBox[{86.7, 201.52895450655438`}], 
        PointBox[{86.8, 202.4988376876732}], 
        PointBox[{86.9, 201.62160527575094`}], 
        PointBox[{87., 204.18349809006165`}], 
        PointBox[{87.1, 206.5267940411941}], 
        PointBox[{87.2, 207.05440040394305`}], 
        PointBox[{87.3, 206.27654099959048`}], 
        PointBox[{87.4, 207.83070478331206`}], 
        PointBox[{87.5, 207.14217141594833`}], 
        PointBox[{87.6, 206.15038322870902`}], 
        PointBox[{87.7, 206.6014469703644}], 
        PointBox[{87.8, 207.4569701238378}], 
        PointBox[{87.9, 206.67844033061306`}], 
        PointBox[{88., 208.69749327469813`}], 
        PointBox[{88.1, 210.43393252284162`}], 
        PointBox[{88.2, 210.69860532235214`}], 
        PointBox[{88.3, 210.11193261312806`}], 
        PointBox[{88.4, 211.50389518022803`}], 
        PointBox[{88.5, 210.73039289638973`}], 
        PointBox[{88.6, 209.88319124320734`}], 
        PointBox[{88.7, 210.45358747762748`}], 
        PointBox[{88.8, 210.96565880124172`}], 
        PointBox[{88.9, 210.4426444298664}], 
        PointBox[{89., 211.66973966093818`}], 
        PointBox[{89.1, 212.88960774345094`}], 
        PointBox[{89.2, 212.74384300857227`}], 
        PointBox[{89.3, 212.61338336866356`}], 
        PointBox[{89.4, 213.62963886394286`}], 
        PointBox[{89.5, 212.75632199163852`}], 
        PointBox[{89.6, 212.1178872830098}], 
        PointBox[{89.7, 212.9312529027863}], 
        PointBox[{89.8, 212.79254659911211`}], 
        PointBox[{89.9, 212.54820502931813`}], 
        PointBox[{90., 213.1241390794616}], 
        PointBox[{90.1, 213.92868931725877`}], 
        PointBox[{90.2, 213.28683918509546`}], 
        PointBox[{90.3, 213.93339822872133`}], 
        PointBox[{90.4, 214.266484831421}], 
        PointBox[{90.5, 213.37806297785764`}], 
        PointBox[{90.6, 213.03777151870938`}], 
        PointBox[{90.7, 214.11295806009335`}], 
        PointBox[{90.8, 213.1403675325349}], 
        PointBox[{90.9, 212.9561407191966}], 
        PointBox[{91., 213.44724813954045`}], 
        PointBox[{91.1, 213.80954029435907`}], 
        PointBox[{91.2, 212.8408461775766}], 
        PointBox[{91.3, 214.2135181703657}], 
        PointBox[{91.4, 213.7799758258911}], 
        PointBox[{91.5, 213.03165603675217`}], 
        PointBox[{91.6, 213.10413322189973`}], 
        PointBox[{91.7, 214.05138782478744`}], 
        PointBox[{91.8, 212.55062903250345`}], 
        PointBox[{91.9, 212.55716026869908`}], 
        PointBox[{92., 213.02134414648287`}], 
        PointBox[{92.1, 212.82039733938396`}], 
        PointBox[{92.2, 212.3088452472129}], 
        PointBox[{92.3, 213.49657146862248`}], 
        PointBox[{92.4, 212.65973901867798`}], 
        PointBox[{92.5, 212.2065504539487}], 
        PointBox[{92.6, 212.78221387591037`}], 
        PointBox[{92.7, 212.6179459960576}], 
        PointBox[{92.8, 211.45082920122002`}], 
        PointBox[{92.9, 211.85537153903206`}], 
        PointBox[{93., 212.05894160925556`}], 
        PointBox[{93.1, 211.26609658079622`}], 
        PointBox[{93.2, 212.07487853401148`}], 
        PointBox[{93.3, 212.07846954992388`}], 
        PointBox[{93.4, 211.31762806424416`}], 
        PointBox[{93.5, 211.276705222871}], 
        PointBox[{93.6, 212.15105769264645`}], 
        PointBox[{93.7, 210.52468137938683`}], 
        PointBox[{93.8, 210.49668051926722`}], 
        PointBox[{93.9, 210.89249160395605`}], 
        PointBox[{94., 210.64489688104788`}], 
        PointBox[{94.1, 209.830018342263}], 
        PointBox[{94.2, 211.2599257159131}], 
        PointBox[{94.3, 210.4286822478283}], 
        PointBox[{94.4, 210.01842353012006`}], 
        PointBox[{94.5, 210.43661807241273`}], 
        PointBox[{94.6, 210.5486891827193}], 
        PointBox[{94.7, 208.9717682054002}], 
        PointBox[{94.8, 209.56248594260836`}], 
        PointBox[{94.9, 209.64119546472918`}], 
        PointBox[{95., 208.8934779739066}], 
        PointBox[{95.1, 209.29299450308844`}], 
        PointBox[{95.2, 209.64307527700774`}], 
        PointBox[{95.3, 208.87632781081888`}], 
        PointBox[{95.4, 208.89380333395306`}], 
        PointBox[{95.5, 209.57065583423065`}], 
        PointBox[{95.6, 207.9966062674805}], 
        PointBox[{95.7, 208.03600956315069`}], 
        PointBox[{95.8, 208.45477820556647`}], 
        PointBox[{95.9, 208.10194535314682`}], 
        PointBox[{96., 207.25036223046223`}], 
        PointBox[{96.1, 208.6934165853014}], 
        PointBox[{96.2, 207.87706746189966`}], 
        PointBox[{96.3, 207.56029831474112`}], 
        PointBox[{96.4, 207.9465715285104}], 
        PointBox[{96.5, 208.01722792452026`}], 
        PointBox[{96.6, 206.34080507235015`}], 
        PointBox[{96.7, 207.13353172164645`}], 
        PointBox[{96.8, 207.12978038342416`}], 
        PointBox[{96.9, 206.38132484207787`}], 
        PointBox[{97., 206.46017412556347`}], 
        PointBox[{97.1, 207.15817117818278`}], 
        PointBox[{97.2, 206.37299278174117`}], 
        PointBox[{97.3, 206.50011912144402`}], 
        PointBox[{97.4, 206.98041211377384`}], 
        PointBox[{97.5, 205.65007779894665`}], 
        PointBox[{97.6, 205.57150876515223`}], 
        PointBox[{97.7, 206.0803905412753}], 
        PointBox[{97.8, 205.6556670218656}], 
        PointBox[{97.9, 204.81396871933023`}], 
        PointBox[{98., 206.11484250528483`}], 
        PointBox[{98.1, 205.4648933891639}], 
        PointBox[{98.2, 205.23591581903406`}], 
        PointBox[{98.3, 205.64099839014935`}], 
        PointBox[{98.4, 205.6365193114395}], 
        PointBox[{98.5, 204.00301271109092`}], 
        PointBox[{98.6, 204.95228991994753`}], 
        PointBox[{98.7, 204.96566674229643`}], 
        PointBox[{98.8, 204.22307660880296`}], 
        PointBox[{98.9, 203.92886586784067`}], 
        PointBox[{99., 205.11927153919254`}], 
        PointBox[{99.1, 204.2101743133103}], 
        PointBox[{99.2, 204.49193871927898`}], 
        PointBox[{99.3, 204.88898003995882`}], 
        PointBox[{99.4, 204.25759811515806`}], 
        PointBox[{99.5, 203.59328991879818`}], 
        PointBox[{99.6, 204.44414239994617`}], 
        PointBox[{99.7, 204.0398036601062}], 
        PointBox[{99.8, 203.17680785522919`}], 
        PointBox[{99.9, 203.89269698219982`}], 
        PointBox[{100., 203.99253974531428`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {0, 360}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
        40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.006], 
       LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {0, -180}}], 
       {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
        PointBox[{0.1, -1.8807459156163873`}], 
        PointBox[{0.2, -5.30704639258505}], 
        PointBox[{0.3, -7.896141271188071}], 
        PointBox[{0.4, -9.647811548602476}], 
        PointBox[{0.5, -13.373926932476252`}], 
        PointBox[{0.6, -15.650084802775723`}], 
        PointBox[{0.7, -17.826749314018855`}], 
        PointBox[{0.8, -20.873504445849562`}], 
        PointBox[{0.9, -24.126256634429637`}], 
        PointBox[{1., -24.69861900896143}], 
        PointBox[{1.1, -28.12562257581868}], 
        PointBox[{1.2, -31.062746341615366`}], 
        PointBox[{1.3, -33.09618186112061}], 
        PointBox[{1.4, -35.11781748867725}], 
        PointBox[{1.5, -39.01830859868119}], 
        PointBox[{1.6, -40.68977514559333}], 
        PointBox[{1.7, -43.35267965827961}], 
        PointBox[{1.8, -46.55512759241435}], 
        PointBox[{1.9, -48.37432900390388}], 
        PointBox[{2., -49.94975879048411}], 
        PointBox[{2.1, -53.35005412799728}], 
        PointBox[{2.2, -55.643128195808}], 
        PointBox[{2.3, -57.22614314724888}], 
        PointBox[{2.4, -60.39645848162377}], 
        PointBox[{2.5, -62.88865702530984}], 
        PointBox[{2.6, -64.90861548564658}], 
        PointBox[{2.7, -67.8158981115514}], 
        PointBox[{2.8, -70.50906339792368}], 
        PointBox[{2.9, -71.03470464724433}], 
        PointBox[{3., -74.0589910163319}], 
        PointBox[{3.1, -76.72403471033203}], 
        PointBox[{3.2, -78.38329257081796}], 
        PointBox[{3.3, -79.92103935769933}], 
        PointBox[{3.4, -83.65438753099897}], 
        PointBox[{3.5, -85.03150414383254}], 
        PointBox[{3.6, -87.46452002076057}], 
        PointBox[{3.7, -90.20058749276177}], 
        PointBox[{3.8, -91.80038630881427}], 
        PointBox[{3.9, -92.53422864868344}], 
        PointBox[{4., -95.74295489531596}], 
        PointBox[{4.1, -97.59184735700092}], 
        PointBox[{4.2, -98.70724256517315}], 
        PointBox[{4.3, -100.73429787604528`}], 
        PointBox[{4.4, -103.62558913069961`}], 
        PointBox[{4.5, -104.90686796568343`}], 
        PointBox[{4.6, -107.46977672334242`}], 
        PointBox[{4.7, -109.52386745826198`}], 
        PointBox[{4.8, -110.36535381225167`}], 
        PointBox[{4.9, -111.84758717511204`}], 
        PointBox[{5., -114.38599064765458`}], 
        PointBox[{5.1, -115.48029309377125`}], 
        PointBox[{5.2, -116.20646536268578`}], 
        PointBox[{5.3, -118.8000946408165}], 
        PointBox[{5.4, -120.35762846555053`}], 
        PointBox[{5.5, -121.86069111713005`}], 
        PointBox[{5.6, -124.25877925601617`}], 
        PointBox[{5.7, -125.74597575911184`}], 
        PointBox[{5.8, -126.08270468813407`}], 
        PointBox[{5.9, -128.10265410456577`}], 
        PointBox[{6., -129.83419562708787`}], 
        PointBox[{6.1, -130.26028129043198`}], 
        PointBox[{6.2, -130.75664461414726`}], 
        PointBox[{6.3, -133.4814616465119}], 
        PointBox[{6.4, -134.02757377816033`}], 
        PointBox[{6.5, -135.6574145022405}], 
        PointBox[{6.6, -137.78076653741573`}], 
        PointBox[{6.7, -139.3761798543528}], 
        PointBox[{6.8, -139.19438539412295`}], 
        PointBox[{6.9, -141.32389085671548`}], 
        PointBox[{7., -142.37978051672144`}], 
        PointBox[{7.1, -142.24309093678585`}], 
        PointBox[{7.2, -142.58974532521825`}], 
        PointBox[{7.3, -145.09134286502558`}], 
        PointBox[{7.4, -145.01251802590923`}], 
        PointBox[{7.5, -146.65606909517646`}], 
        PointBox[{7.6, -148.71124510822847`}], 
        PointBox[{7.7, -150.56657795968113`}], 
        PointBox[{7.8, -150.0063595858801}], 
        PointBox[{7.9, -152.03136229843494`}], 
        PointBox[{8., -152.61234568466443`}], 
        PointBox[{8.1, -152.03037165427668`}], 
        PointBox[{8.2, -152.21919669264844`}], 
        PointBox[{8.3, -154.4443456783847}], 
        PointBox[{8.4, -153.95604696909777`}], 
        PointBox[{8.5, -155.55469784901015`}], 
        PointBox[{8.6, -157.81003718264674`}], 
        PointBox[{8.7, -159.80482745383415`}], 
        PointBox[{8.8, -158.98292090283667`}], 
        PointBox[{8.9, -160.85927678643566`}], 
        PointBox[{9., -161.17508631488363`}], 
        PointBox[{9.1, -160.26325853823164`}], 
        PointBox[{9.2, -160.25331264639317`}], 
        PointBox[{9.3, -162.2938661981707}], 
        PointBox[{9.4, -161.52932506322122`}], 
        PointBox[{9.5, -163.03365741561083`}], 
        PointBox[{9.6, -165.56088452430413`}], 
        PointBox[{9.7, -167.64849894344025`}], 
        PointBox[{9.8, -166.65864679985316`}], 
        PointBox[{9.9, -168.3742571411085}], 
        PointBox[{10., -168.61757457534713`}], 
        PointBox[{10.1, -167.48592091177125`}], 
        PointBox[{10.2, -167.24982718164847`}], 
        PointBox[{10.3, -169.19112084555582`}], 
        PointBox[{10.4, -168.2864290465941}], 
        PointBox[{10.5, -169.63080686759258`}], 
        PointBox[{10.6, -172.36663847552518`}], 
        PointBox[{10.7, -174.5607301770906}], 
        PointBox[{10.8, -173.52293031301087`}], 
        PointBox[{10.9, -175.0425112820585}], 
        PointBox[{11., -175.37211411352473`}], 
        PointBox[{11.1, -174.12878069505496`}], 
        PointBox[{11.2, -173.67589039631002`}], 
        PointBox[{11.3, -175.5438447853976}], 
        PointBox[{11.4, -174.65974301727147`}], 
        PointBox[{11.5, -175.7804036077805}], 
        PointBox[{11.6, -178.62375065387278`}], 
        PointBox[{11.7, 179.07920676723188`}], 
        PointBox[{11.8, -179.97915524452947`}], 
        PointBox[{11.9, 178.74009857588135`}], 
        PointBox[{12., 178.2130363073229}], 
        PointBox[{12.1, 179.461850004609}], 
        PointBox[{12.2, -179.92219226936322`}], 
        PointBox[{12.3, 178.2985824309726}], 
        PointBox[{12.4, 179.0044495278962}], 
        PointBox[{12.5, 178.13231313622236`}], 
        PointBox[{12.6, 175.28598815823898`}], 
        PointBox[{12.7, 172.92946073563326`}], 
        PointBox[{12.8, 173.64570365621694`}], 
        PointBox[{12.9, 172.60536472161766`}], 
        PointBox[{13., 171.82533989558215`}], 
        PointBox[{13.1, 172.98140696442533`}], 
        PointBox[{13.2, 173.66511746048855`}], 
        PointBox[{13.3, 171.98216170734486`}], 
        PointBox[{13.4, 172.40213024379773`}], 
        PointBox[{13.5, 171.73400584262163`}], 
        PointBox[{13.6, 168.98993653140678`}], 
        PointBox[{13.7, 166.64154612484344`}], 
        PointBox[{13.8, 167.05909097805306`}], 
        PointBox[{13.9, 166.17554687482152`}], 
        PointBox[{14., 165.13990735338666`}], 
        PointBox[{14.1, 166.12028064021615`}], 
        PointBox[{14.2, 166.74384206761533`}], 
        PointBox[{14.3, 165.11459688453397`}], 
        PointBox[{14.4, 165.2218902302575}], 
        PointBox[{14.5, 164.63415635139427`}], 
        PointBox[{14.6, 162.10671599083798`}], 
        PointBox[{14.7, 159.82361447406402`}], 
        PointBox[{14.8, 159.93647233784213`}], 
        PointBox[{14.9, 159.02984553216265`}], 
        PointBox[{15., 157.77755252153656`}], 
        PointBox[{15.1, 158.5158366250762}], 
        PointBox[{15.2, 158.9302737768412}], 
        PointBox[{15.3, 157.24121090943663`}], 
        PointBox[{15.4, 157.09344101272472`}], 
        PointBox[{15.5, 156.40364596958534`}], 
        PointBox[{15.6, 154.2133006955246}], 
        PointBox[{15.7, 152.00160000277356`}], 
        PointBox[{15.8, 151.85622137773498`}], 
        PointBox[{15.9, 150.66404066462928`}], 
        PointBox[{16., 149.27052587967592`}], 
        PointBox[{16.1, 149.70734967756835`}], 
        PointBox[{16.2, 149.75133337549414`}], 
        PointBox[{16.3, 147.83261611091257`}], 
        PointBox[{16.4, 147.5516571123626}], 
        PointBox[{16.5, 146.59241903285692`}], 
        PointBox[{16.6, 144.7757475912622}], 
        PointBox[{16.7, 142.5792727374701}], 
        PointBox[{16.8, 142.24277196674848`}], 
        PointBox[{16.9, 140.4608346411078}], 
        PointBox[{17., 139.04769602573288`}], 
        PointBox[{17.1, 139.1125852985424}], 
        PointBox[{17.2, 138.6200771445474}], 
        PointBox[{17.3, 136.30388701955962`}], 
        PointBox[{17.4, 136.03230160427483`}], 
        PointBox[{17.5, 134.82882829602931`}], 
        PointBox[{17.6, 133.08632629457497`}], 
        PointBox[{17.7, 130.85807932985153`}], 
        PointBox[{17.8, 130.3618497034895}], 
        PointBox[{17.9, 127.76516812908449`}], 
        PointBox[{18., 126.47781009458413`}], 
        PointBox[{18.1, 126.07803731856075`}], 
        PointBox[{18.2, 124.89344085073208`}], 
        PointBox[{18.3, 122.1563635742059}], 
        PointBox[{18.4, 121.9297252008837}], 
        PointBox[{18.5, 120.62883385016175`}], 
        PointBox[{18.6, 118.43656655750601`}], 
        PointBox[{18.7, 116.25064204906084`}], 
        PointBox[{18.8, 115.41694082057256`}], 
        PointBox[{18.9, 112.16383008022422`}], 
        PointBox[{19., 111.03203771749213`}], 
        PointBox[{19.1, 110.06511163651703`}], 
        PointBox[{19.2, 108.05845546819364`}], 
        PointBox[{19.3, 105.29948079628048`}], 
        PointBox[{19.4, 104.94063187766915`}], 
        PointBox[{19.5, 103.19166407512603`}], 
        PointBox[{19.6, 100.54934566394877`}], 
        PointBox[{19.7, 98.60821972046688}], 
        PointBox[{19.8, 96.8231497504421}], 
        PointBox[{19.9, 93.70165660157181}], 
        PointBox[{20., 92.5189246168029}], 
        PointBox[{20.1, 90.89602464765449}], 
        PointBox[{20.2, 88.01328186462706}], 
        PointBox[{20.3, 86.09113747794436}], 
        PointBox[{20.4, 85.13666134680352}], 
        PointBox[{20.5, 82.49598160689129}], 
        PointBox[{20.6, 79.77681215630037}], 
        PointBox[{20.7, 78.20706830252311}], 
        PointBox[{20.8, 74.94209918435809}], 
        PointBox[{20.9, 72.70481029975417}], 
        PointBox[{21., 71.16865283045445}], 
        PointBox[{21.1, 68.82435776931015}], 
        PointBox[{21.2, 65.35586193258678}], 
        PointBox[{21.3, 64.61093071047435}], 
        PointBox[{21.4, 62.348604887847614`}], 
        PointBox[{21.5, 59.31095094149896}], 
        PointBox[{21.6, 56.8781998184586}], 
        PointBox[{21.7, 55.17860465441663}], 
        PointBox[{21.8, 51.24452380933326}], 
        PointBox[{21.9, 49.587110712654976`}], 
        PointBox[{22., 47.50228025518118}], 
        PointBox[{22.1, 44.426008698637816`}], 
        PointBox[{22.2, 41.57158800121033}], 
        PointBox[{22.3, 40.724440425741705`}], 
        PointBox[{22.4, 37.48253398666202}], 
        PointBox[{22.5, 34.583011487415206`}], 
        PointBox[{22.6, 32.64188153390205}], 
        PointBox[{22.7, 29.6303752272579}], 
        PointBox[{22.8, 26.686281210646484`}], 
        PointBox[{22.9, 24.859744212069927`}], 
        PointBox[{23., 22.17710840973814}], 
        PointBox[{23.1, 18.618452744107344`}], 
        PointBox[{23.2, 17.544207355233084`}], 
        PointBox[{23.3, 14.921675932579092`}], 
        PointBox[{23.4, 11.658626615058893`}], 
        PointBox[{23.5, 9.19163260019559}], 
        PointBox[{23.6, 7.4301211782803875`}], 
        PointBox[{23.7, 3.3252247157106467`}], 
        PointBox[{23.8, 1.482073034687346}], 
        PointBox[{23.9, -0.8583156394452089}], 
        PointBox[{24., -4.051679116430023}], 
        PointBox[{24.1, -7.031377726558276}], 
        PointBox[{24.2, -7.8402860869973665`}], 
        PointBox[{24.3, -11.390316686218284`}], 
        PointBox[{24.4, -14.2159862203589}], 
        PointBox[{24.5, -16.154434320480505`}], 
        PointBox[{24.6, -18.841407439813338`}], 
        PointBox[{24.7, -22.161707328643388`}], 
        PointBox[{24.8, -24.022873146503116`}], 
        PointBox[{24.9, -26.847703052008}], 
        PointBox[{25., -30.200884695768764`}], 
        PointBox[{25.1, -31.35194945006515}], 
        PointBox[{25.2, -33.9075715708168}], 
        PointBox[{25.3, -37.13893777326666}], 
        PointBox[{25.4, -39.38702996186112}], 
        PointBox[{25.5, -41.05054310463311}], 
        PointBox[{25.6, -44.94634623365346}], 
        PointBox[{25.7, -46.82737387466477}], 
        PointBox[{25.8, -49.18117201558562}], 
        PointBox[{25.9, -52.25318490173959}], 
        PointBox[{26., -54.86138960176686}], 
        PointBox[{26.1, -55.48231267851588}], 
        PointBox[{26.2, -58.987612919008825`}], 
        PointBox[{26.3, -61.52870734998942}], 
        PointBox[{26.4, -63.21274359450763}], 
        PointBox[{26.5, -65.34572438115356}], 
        PointBox[{26.6, -68.86430892859062}], 
        PointBox[{26.7, -70.44025494353264}], 
        PointBox[{26.8, -73.15473446677424}], 
        PointBox[{26.9, -76.0024796766993}], 
        PointBox[{27., -77.18586756048171}], 
        PointBox[{27.1, -78.97887874822118}], 
        PointBox[{27.2, -82.04804324168072}], 
        PointBox[{27.3, -83.87435788149014}], 
        PointBox[{27.4, -85.16805508299512}], 
        PointBox[{27.5, -88.27436827261408}], 
        PointBox[{27.6, -90.31285583803401}], 
        PointBox[{27.7, -92.2622071556325}], 
        PointBox[{27.8, -94.99474369303425}], 
        PointBox[{27.9, -96.98726495831943}], 
        PointBox[{28., -97.39716159074305}], 
        PointBox[{28.1, -100.21087403282218`}], 
        PointBox[{28.2, -102.42192793431241`}], 
        PointBox[{28.3, -103.58962398034419`}], 
        PointBox[{28.4, -104.82305191683918`}], 
        PointBox[{28.5, -108.21164679098365`}], 
        PointBox[{28.6, -109.21299421018557`}], 
        PointBox[{28.7, -111.46018385850039`}], 
        PointBox[{28.8, -113.7945190731225}], 
        PointBox[{28.9, -115.11514996533515`}], 
        PointBox[{29., -115.47164385307042`}], 
        PointBox[{29.1, -118.33833670365857`}], 
        PointBox[{29.2, -119.70761051921}], 
        PointBox[{29.3, -120.30430156134389`}], 
        PointBox[{29.4, -121.75874702579313`}], 
        PointBox[{29.5, -124.46757432738013`}], 
        PointBox[{29.6, -125.16263747739504`}], 
        PointBox[{29.7, -127.47292485450453`}], 
        PointBox[{29.8, -129.23761119575647`}], 
        PointBox[{29.9, -130.3400603888731}], 
        PointBox[{30., -130.8740557592937}], 
        PointBox[{30.1, -133.25665591039797`}], 
        PointBox[{30.2, -133.8934987391549}], 
        PointBox[{30.3, -134.02560012087997`}], 
        PointBox[{30.4, -135.7027782034238}], 
        PointBox[{30.5, -137.45357658206922`}], 
        PointBox[{30.6, -138.07481779199952`}], 
        PointBox[{30.7, -140.32464169191007`}], 
        PointBox[{30.8, -142.01298749065245`}], 
        PointBox[{30.9, -142.8027636559309}], 
        PointBox[{31., -143.47565434561693`}], 
        PointBox[{31.1, -145.34901071778222`}], 
        PointBox[{31.2, -145.39108639107872`}], 
        PointBox[{31.3, -145.15537258751283`}], 
        PointBox[{31.4, -146.87861461820648`}], 
        PointBox[{31.5, -147.88027909618177`}], 
        PointBox[{31.6, -148.39103781136873`}], 
        PointBox[{31.7, -150.61959220180142`}], 
        PointBox[{31.8, -152.66072342285042`}], 
        PointBox[{31.9, -153.06829054161062`}], 
        PointBox[{32., -153.69957252523818`}], 
        PointBox[{32.1, -155.23591447462604`}], 
        PointBox[{32.2, -154.83643143341033`}], 
        PointBox[{32.3, -154.29921263918732`}], 
        PointBox[{32.4, -155.91753608709405`}], 
        PointBox[{32.5, -156.4920551851792}], 
        PointBox[{32.6, -156.80677912912506`}], 
        PointBox[{32.7, -159.11377249914585`}], 
        PointBox[{32.8, -161.5175974778649}], 
        PointBox[{32.9, -161.70932205482313`}], 
        PointBox[{33., -162.14004015563842`}], 
        PointBox[{33.1, -163.54092216845675`}], 
        PointBox[{33.2, -162.85431315738242`}], 
        PointBox[{33.3, -162.060605529241}], 
        PointBox[{33.4, -163.4916583278973}], 
        PointBox[{33.5, -163.92998873564648`}], 
        PointBox[{33.6, -163.972014918083}], 
        PointBox[{33.7, -166.39590374206819`}], 
        PointBox[{33.8, -169.04462506504933`}], 
        PointBox[{33.9, -169.23014651714766`}], 
        PointBox[{34., -169.3553098426637}], 
        PointBox[{34.1, -170.78392358032943`}], 
        PointBox[{34.2, -169.95689080206284`}], 
        PointBox[{34.3, -168.95444722235334`}], 
        PointBox[{34.4, -170.15015057272103`}], 
        PointBox[{34.5, -170.68284634084557`}], 
        PointBox[{34.6, -170.40773079800783`}], 
        PointBox[{34.7, -172.91096581948295`}], 
        PointBox[{34.8, -175.69421058187072`}], 
        PointBox[{34.9, -176.04190569576895`}], 
        PointBox[{35., -175.82422018056604`}], 
        PointBox[{35.1, -177.37826088246584`}], 
        PointBox[{35.2, -176.54373014479643`}], 
        PointBox[{35.3, -175.39817584164848`}], 
        PointBox[{35.4, -176.338027677044}], 
        PointBox[{35.5, -177.11526892341863`}], 
        PointBox[{35.6, -176.53675782457867`}], 
        PointBox[{35.7, -179.04766278048191`}], 
        PointBox[{35.8, 178.13236200104438`}], 
        PointBox[{35.9, 177.52440259818104`}], 
        PointBox[{36., 178.03836521222547`}], 
        PointBox[{36.1, 176.32774633407462`}], 
        PointBox[{36.2, 177.0592011065237}], 
        PointBox[{36.3, 178.2592629195642}], 
        PointBox[{36.4, 177.55498232338869`}], 
        PointBox[{36.5, 176.47559836281653`}], 
        PointBox[{36.6, 177.27331760178276`}], 
        PointBox[{36.7, 174.8223174051709}], 
        PointBox[{36.8, 172.06279681876913`}], 
        PointBox[{36.9, 171.1742657630857}], 
        PointBox[{37., 171.85844579250988`}], 
        PointBox[{37.1, 170.0021773109911}], 
        PointBox[{37.2, 170.5524294990646}], 
        PointBox[{37.3, 171.70243207875683`}], 
        PointBox[{37.4, 171.15686597997774`}], 
        PointBox[{37.5, 169.79415912982586`}], 
        PointBox[{37.6, 170.67443921033555`}], 
        PointBox[{37.7, 168.32563249878513`}], 
        PointBox[{37.8, 165.72294460022022`}], 
        PointBox[{37.9, 164.5955685791596}], 
        PointBox[{38., 165.27727949347172`}], 
        PointBox[{38.1, 163.2854716711554}], 
        PointBox[{38.2, 163.61599339247914`}], 
        PointBox[{38.3, 164.60224582103547`}], 
        PointBox[{38.4, 164.08111819156693`}], 
        PointBox[{38.5, 162.48999962447851`}], 
        PointBox[{38.6, 163.2994272169817}], 
        PointBox[{38.7, 161.07704209627627`}], 
        PointBox[{38.8, 158.70341418803218`}], 
        PointBox[{38.9, 157.40765744307646`}], 
        PointBox[{39., 157.90584450176175`}], 
        PointBox[{39.1, 155.75361435111336`}], 
        PointBox[{39.2, 155.86269954754607`}], 
        PointBox[{39.3, 156.56749494575342`}], 
        PointBox[{39.4, 155.88956302543374`}], 
        PointBox[{39.5, 154.12577810834046`}], 
        PointBox[{39.6, 154.71807023576912`}], 
        PointBox[{39.7, 152.6773795396548}], 
        PointBox[{39.8, 150.51403413819207`}], 
        PointBox[{39.9, 149.11929769951166`}], 
        PointBox[{40., 149.25266114420447`}], 
        PointBox[{40.1, 146.89446773121017`}], 
        PointBox[{40.2, 146.80067331693135`}], 
        PointBox[{40.3, 147.10140764555763`}], 
        PointBox[{40.4, 146.05549162283933`}], 
        PointBox[{40.5, 144.1898893925645}], 
        PointBox[{40.6, 144.41055559212327`}], 
        PointBox[{40.7, 142.66779739115736`}], 
        PointBox[{40.8, 140.53145916953144`}], 
        PointBox[{40.9, 139.10657027910202`}], 
        PointBox[{41., 138.6461347168697}], 
        PointBox[{41.1, 136.11500303546927`}], 
        PointBox[{41.2, 135.82174634166222`}], 
        PointBox[{41.3, 135.59254529234022`}], 
        PointBox[{41.4, 133.96350812886521`}], 
        PointBox[{41.5, 132.17121281899745`}], 
        PointBox[{41.6, 131.8623931428956}], 
        PointBox[{41.7, 130.36485640884348`}], 
        PointBox[{41.8, 128.0379413856208}], 
        PointBox[{41.9, 126.68233177393267`}], 
        PointBox[{42., 125.28335433385655`}], 
        PointBox[{42.1, 122.8299760525806}], 
        PointBox[{42.2, 122.27923561758143`}], 
        PointBox[{42.3, 121.40256684583437`}], 
        PointBox[{42.4, 119.02703834620115`}], 
        PointBox[{42.5, 117.6467334581721}], 
        PointBox[{42.6, 116.8380900646298}], 
        PointBox[{42.7, 114.99297734647553`}], 
        PointBox[{42.8, 112.4906427543865}], 
        PointBox[{42.9, 111.30094710547564`}], 
        PointBox[{43., 108.64242833312528`}], 
        PointBox[{43.1, 106.64193208736833`}], 
        PointBox[{43.2, 105.70429340128248`}], 
        PointBox[{43.3, 104.08232653279265`}], 
        PointBox[{43.4, 101.01179123527982`}], 
        PointBox[{43.5, 100.26106208333294`}], 
        PointBox[{43.6, 98.87880984343428}], 
        PointBox[{43.7, 96.31125896270532}], 
        PointBox[{43.8, 93.87238892901223}], 
        PointBox[{43.9, 92.63903285454944}], 
        PointBox[{44., 89.02445900533712}], 
        PointBox[{44.1, 87.50223453460785}], 
        PointBox[{44.2, 86.0336686237315}], 
        PointBox[{44.3, 83.59032426154226}], 
        PointBox[{44.4, 80.48993600334506}], 
        PointBox[{44.5, 80.0415059944753}], 
        PointBox[{44.6, 77.65529521317876}], 
        PointBox[{44.7, 74.77861555831623}], 
        PointBox[{44.8, 72.69524037822339}], 
        PointBox[{44.9, 70.52324148302796}], 
        PointBox[{45., 67.20039911281492}], 
        PointBox[{45.1, 65.71308267342101}], 
        PointBox[{45.2, 63.61408707758892}], 
        PointBox[{45.3, 60.36999530940011}], 
        PointBox[{45.4, 58.48606984601429}], 
        PointBox[{45.5, 57.06655495754967}], 
        PointBox[{45.6, 53.956535960162}], 
        PointBox[{45.7, 51.22189747716402}], 
        PointBox[{45.8, 49.54802943550021}], 
        PointBox[{45.9, 45.87115423085197}], 
        PointBox[{46., 43.68753277344513}], 
        PointBox[{46.1, 41.80501950672624}], 
        PointBox[{46.2, 39.03960206210468}], 
        PointBox[{46.3, 35.50557441930869}], 
        PointBox[{46.4, 34.9056790666873}], 
        PointBox[{46.5, 31.920295481591893`}], 
        PointBox[{46.6, 28.811887127805676`}], 
        PointBox[{46.7, 26.514923210677807`}], 
        PointBox[{46.8, 24.489690889327903`}], 
        PointBox[{46.9, 20.577720177796436`}], 
        PointBox[{47., 18.8617914300994}], 
        PointBox[{47.1, 16.42154921324982}], 
        PointBox[{47.2, 13.0767594080462}], 
        PointBox[{47.3, 10.746672295339522`}], 
        PointBox[{47.4, 9.312753242687904}], 
        PointBox[{47.5, 5.857615150991478}], 
        PointBox[{47.6, 3.1340894542299793`}], 
        PointBox[{47.7, 1.3180930151502253`}], 
        PointBox[{47.8, -2.1470065115499892`}], 
        PointBox[{47.9, -4.711983270739438}], 
        PointBox[{48., -6.76446841465804}], 
        PointBox[{48.1, -9.716996443574317}], 
        PointBox[{48.2, -13.14614686560526}], 
        PointBox[{48.3, -13.818936235540605`}], 
        PointBox[{48.4, -17.03765001957072}], 
        PointBox[{48.5, -20.12579148995428}], 
        PointBox[{48.6, -22.310771503325668`}], 
        PointBox[{48.7, -24.197745653749735`}], 
        PointBox[{48.8, -28.245454552787123`}], 
        PointBox[{48.9, -29.948746684960497`}], 
        PointBox[{49., -32.5156404345762}], 
        PointBox[{49.1, -35.752264652910526`}], 
        PointBox[{49.2, -38.00331412545347}], 
        PointBox[{49.3, -39.24746358597622}], 
        PointBox[{49.4, -42.76194931772625}], 
        PointBox[{49.5, -45.2414525460772}], 
        PointBox[{49.6, -46.931346125471464`}], 
        PointBox[{49.7, -49.896547849952185`}], 
        PointBox[{49.8, -52.72881869986304}], 
        PointBox[{49.9, -54.67291999152803}], 
        PointBox[{50., -57.57422068570304}], 
        PointBox[{50.1, -60.52937251566618}], 
        PointBox[{50.2, -61.21207461877202}], 
        PointBox[{50.3, -64.07942682167777}], 
        PointBox[{50.4, -66.95646453401423}], 
        PointBox[{50.5, -68.80354670123052}], 
        PointBox[{50.6, -70.35367686448444}], 
        PointBox[{50.7, -74.15230543067446}], 
        PointBox[{50.8, -75.69457146539935}], 
        PointBox[{50.9, -78.09551171937346}], 
        PointBox[{51., -80.96380296344432}], 
        PointBox[{51.1, -82.84985072987911}], 
        PointBox[{51.2, -83.52159655137075}], 
        PointBox[{51.3, -86.84351391086966}], 
        PointBox[{51.4, -88.91889099876425}], 
        PointBox[{51.5, -90.20689976491849}], 
        PointBox[{51.6, -92.21761216261075}], 
        PointBox[{51.7, -95.35854916679818}], 
        PointBox[{51.8, -96.70444033351669}], 
        PointBox[{51.9, -99.31166072584165}], 
        PointBox[{52., -101.6080029712466}], 
        PointBox[{52.1, -102.53251936644665`}], 
        PointBox[{52.2, -104.04839404796803`}], 
        PointBox[{52.3, -106.76861978341913`}], 
        PointBox[{52.4, -108.08537423123198`}], 
        PointBox[{52.5, -108.9731699397089}], 
        PointBox[{52.6, -111.65969515807228`}], 
        PointBox[{52.7, -113.42020087200217`}], 
        PointBox[{52.8, -115.02777592820348`}], 
        PointBox[{52.9, -117.51192189422}], 
        PointBox[{53., -119.06752629816037`}], 
        PointBox[{53.1, -119.45068865078792`}], 
        PointBox[{53.2, -121.6437321662379}], 
        PointBox[{53.3, -123.52078229311155`}], 
        PointBox[{53.4, -124.15604762678413`}], 
        PointBox[{53.5, -124.83574416589545`}], 
        PointBox[{53.6, -127.73195884939923`}], 
        PointBox[{53.7, -128.41217461193446`}], 
        PointBox[{53.8, -130.20145369105012`}], 
        PointBox[{53.9, -132.35160011449625`}], 
        PointBox[{54., -133.82676348730456`}], 
        PointBox[{54.1, -133.7366851890838}], 
        PointBox[{54.2, -136.0778301908722}], 
        PointBox[{54.3, -137.20453056076803`}], 
        PointBox[{54.4, -137.25337669732107`}], 
        PointBox[{54.5, -137.839626130306}], 
        PointBox[{54.6, -140.45946606293728`}], 
        PointBox[{54.7, -140.51063095784775`}], 
        PointBox[{54.8, -142.3460338367222}], 
        PointBox[{54.9, -144.30516548646847`}], 
        PointBox[{55., -145.9800133025492}], 
        PointBox[{55.1, -145.54896976933378`}], 
        PointBox[{55.2, -147.7531253066918}], 
        PointBox[{55.3, -148.30965775337245`}], 
        PointBox[{55.4, -147.88155443655705`}], 
        PointBox[{55.5, -148.37042472988105`}], 
        PointBox[{55.6, -150.6061775171911}], 
        PointBox[{55.7, -150.2501595518188}], 
        PointBox[{55.8, -152.07352431994514`}], 
        PointBox[{55.9, -154.1900203284531}], 
        PointBox[{56., -155.94659687483363`}], 
        PointBox[{56.1, -155.26118825772573`}], 
        PointBox[{56.2, -157.29612553551124`}], 
        PointBox[{56.3, -157.48300574057794`}], 
        PointBox[{56.4, -156.68657801318477`}], 
        PointBox[{56.5, -157.01678816928325`}], 
        PointBox[{56.6, -158.99298935725528`}], 
        PointBox[{56.7, -158.3186212737637}], 
        PointBox[{56.8, -160.10531199698744`}], 
        PointBox[{56.9, -162.5260862148425}], 
        PointBox[{57., -164.31337291812815`}], 
        PointBox[{57.1, -163.40592886188824`}], 
        PointBox[{57.2, -165.31170319992816`}], 
        PointBox[{57.3, -165.32330617999105`}], 
        PointBox[{57.4, -164.25981632229377`}], 
        PointBox[{57.5, -164.37524678732007`}], 
        PointBox[{57.6, -166.24655662198347`}], 
        PointBox[{57.7, -165.32980707872048`}], 
        PointBox[{57.8, -167.03515942212107`}], 
        PointBox[{57.9, -169.7139026068544}], 
        PointBox[{58., -171.58308840236714`}], 
        PointBox[{58.1, -170.51297099643125`}], 
        PointBox[{58.2, -172.30258571041486`}], 
        PointBox[{58.3, -172.31114452505426`}], 
        PointBox[{58.4, -171.07980547408806`}], 
        PointBox[{58.5, -170.95853342564078`}], 
        PointBox[{58.6, -172.8144405234343}], 
        PointBox[{58.7, -171.77009135206754`}], 
        PointBox[{58.8, -173.32809431086207`}], 
        PointBox[{58.9, -176.16044253498694`}], 
        PointBox[{59., -178.15692513158865`}], 
        PointBox[{59.1, -177.03754712448426`}], 
        PointBox[{59.2, -178.68230390636745`}], 
        PointBox[{59.3, -178.8244809291864}], 
        PointBox[{59.4, -177.52710931986803`}], 
        PointBox[{59.5, -177.19296463322826`}], 
        PointBox[{59.6, -179.0472268524536}], 
        PointBox[{59.7, -178.02630339506868`}], 
        PointBox[{59.8, -179.38199981588696`}], 
        PointBox[{59.9, 177.7412635951332}], 
        PointBox[{60., 175.62356829582131`}], 
        PointBox[{60.1, 176.6486189658899}], 
        PointBox[{60.2, 175.1823117873646}], 
        PointBox[{60.3, 174.8178244493829}], 
        PointBox[{60.4, 176.07957706824527`}], 
        PointBox[{60.5, 176.55434693471034`}], 
        PointBox[{60.6, 174.7255407532066}], 
        PointBox[{60.7, 175.57648841338232`}], 
        PointBox[{60.8, 174.4286630054703}], 
        PointBox[{60.9, 171.61563745608873`}], 
        PointBox[{61., 169.42826571581827`}], 
        PointBox[{61.1, 170.23332353233855`}], 
        PointBox[{61.2, 168.92866885990952`}], 
        PointBox[{61.3, 168.30702942483913`}], 
        PointBox[{61.4, 169.43877420163335`}], 
        PointBox[{61.5, 169.94007731952297`}], 
        PointBox[{61.6, 168.14226797502488`}], 
        PointBox[{61.7, 168.73083828940435`}], 
        PointBox[{61.8, 167.7228580592273}], 
        PointBox[{61.9, 165.08719294118782`}], 
        PointBox[{62., 162.89627524070966`}], 
        PointBox[{62.1, 163.41279086903523`}], 
        PointBox[{62.2, 162.161683623126}], 
        PointBox[{62.3, 161.29848730764206`}], 
        PointBox[{62.4, 162.2180241014139}], 
        PointBox[{62.5, 162.60057285164658`}], 
        PointBox[{62.6, 160.7807759031566}], 
        PointBox[{62.7, 161.09632580416655`}], 
        PointBox[{62.8, 160.09063852447434`}], 
        PointBox[{62.9, 157.75193045919877`}], 
        PointBox[{63., 155.5983209217302}], 
        PointBox[{63.1, 155.82140352409624`}], 
        PointBox[{63.2, 154.41855696398852`}], 
        PointBox[{63.3, 153.37202257594618`}], 
        PointBox[{63.4, 154.0061111806208}], 
        PointBox[{63.5, 154.1050817843934}], 
        PointBox[{63.6, 152.1438867741963}], 
        PointBox[{63.7, 152.25259291843395`}], 
        PointBox[{63.8, 151.09669956279686`}], 
        PointBox[{63.9, 149.12569271838584`}], 
        PointBox[{64., 146.99784288997762`}], 
        PointBox[{64.1, 146.96234213677963`}], 
        PointBox[{64.2, 145.13794418128236`}], 
        PointBox[{64.3, 144.00529501105484`}], 
        PointBox[{64.4, 144.27721877998556`}], 
        PointBox[{64.5, 143.9174648774424}], 
        PointBox[{64.6, 141.6683089443104}], 
        PointBox[{64.7, 141.67123000033462`}], 
        PointBox[{64.8, 140.3456142052164}], 
        PointBox[{64.9, 138.57067615727283`}], 
        PointBox[{65., 136.43364159456542`}], 
        PointBox[{65.1, 136.159805197698}], 
        PointBox[{65.2, 133.6792339633903}], 
        PointBox[{65.3, 132.58004438879289`}], 
        PointBox[{65.4, 132.39774181699613`}], 
        PointBox[{65.5, 131.40652151550603`}], 
        PointBox[{65.6, 128.81019573229423`}], 
        PointBox[{65.7, 128.74019444632722`}], 
        PointBox[{65.8, 127.40303964257328`}], 
        PointBox[{65.9, 125.34388460207992`}], 
        PointBox[{66., 123.23287170551339`}], 
        PointBox[{66.1, 122.59217777222511`}], 
        PointBox[{66.2, 119.49769744035439`}], 
        PointBox[{66.3, 118.48498650426336`}], 
        PointBox[{66.4, 117.74652301397145`}], 
        PointBox[{66.5, 115.972008448196}], 
        PointBox[{66.6, 113.29083147873462`}], 
        PointBox[{66.7, 113.00722780144861`}], 
        PointBox[{66.8, 111.46348468219367`}], 
        PointBox[{66.9, 108.94025558634166`}], 
        PointBox[{67., 107.0155836827762}], 
        PointBox[{67.1, 105.51955149193236`}], 
        PointBox[{67.2, 102.4031928286131}], 
        PointBox[{67.3, 101.34361595009977`}], 
        PointBox[{67.4, 99.95704300261423}], 
        PointBox[{67.5, 97.3071565971768}], 
        PointBox[{67.6, 95.25991209984932}], 
        PointBox[{67.7, 94.50677004219324}], 
        PointBox[{67.8, 92.14590120720823}], 
        PointBox[{67.9, 89.44431796694698}], 
        PointBox[{68., 87.86730201850878}], 
        PointBox[{68.1, 84.93848533071287}], 
        PointBox[{68.2, 82.56998895537981}], 
        PointBox[{68.3, 81.19972731026792}], 
        PointBox[{68.4, 79.09275070661533}], 
        PointBox[{68.5, 75.72833321063808}], 
        PointBox[{68.6, 74.7973946008351}], 
        PointBox[{68.7, 72.93668362121389}], 
        PointBox[{68.8, 69.98563455809926}], 
        PointBox[{68.9, 67.47482997085172}], 
        PointBox[{69., 65.94015085769206}], 
        PointBox[{69.1, 62.045953121931234`}], 
        PointBox[{69.2, 60.360346410176135`}], 
        PointBox[{69.3, 58.46792736536736}], 
        PointBox[{69.4, 55.60196813901712}], 
        PointBox[{69.5, 52.473286865373666`}], 
        PointBox[{69.6, 51.873806935807806`}], 
        PointBox[{69.7, 48.84226013272564}], 
        PointBox[{69.8, 45.884382404809}], 
        PointBox[{69.9, 43.83392979305063}], 
        PointBox[{70., 41.21724462706334}], 
        PointBox[{70.1, 37.969697286847804`}], 
        PointBox[{70.2, 36.259570527327014`}], 
        PointBox[{70.3, 33.760755418101326`}], 
        PointBox[{70.4, 30.27192634002131}], 
        PointBox[{70.5, 28.78455419396778}], 
        PointBox[{70.6, 26.65898078790633}], 
        PointBox[{70.7, 23.357852097244177`}], 
        PointBox[{70.8, 20.754233262145135`}], 
        PointBox[{70.9, 19.035258163356048`}], 
        PointBox[{71., 15.048404064320493`}], 
        PointBox[{71.1, 13.044604718474147`}], 
        PointBox[{71.2, 10.863056412592414`}], 
        PointBox[{71.3, 7.794406676883227}], 
        PointBox[{71.4, 4.48960258027364}], 
        PointBox[{71.5, 3.8743364072433906`}], 
        PointBox[{71.6, 0.4274339640469407}], 
        PointBox[{71.7, -2.5453222750220448`}], 
        PointBox[{71.8, -4.627443425299134}], 
        PointBox[{71.9, -6.993270743645553}], 
        PointBox[{72., -10.654887734126532`}], 
        PointBox[{72.1, -12.435423296301451`}], 
        PointBox[{72.2, -15.14123760786606}], 
        PointBox[{72.3, -18.537946441392705`}], 
        PointBox[{72.4, -20.15879802199197}], 
        PointBox[{72.5, -22.254964417705196`}], 
        PointBox[{72.6, -25.63567097621126}], 
        PointBox[{72.7, -28.06703655529418}], 
        PointBox[{72.8, -29.763293268675625`}], 
        PointBox[{72.9, -33.498532460398565`}], 
        PointBox[{73., -35.66091906012298}], 
        PointBox[{73.1, -37.89540912720986}], 
        PointBox[{73.2, -40.952375649758324`}], 
        PointBox[{73.3, -43.922012816641654`}], 
        PointBox[{73.4, -44.4626219325437}], 
        PointBox[{73.5, -47.91691254358011}], 
        PointBox[{73.6, -50.67641231782909}], 
        PointBox[{73.7, -52.53331115926267}], 
        PointBox[{73.8, -54.51361938064656}], 
        PointBox[{73.9, -58.3012040412068}], 
        PointBox[{74., -59.88384357441828}], 
        PointBox[{74.1, -62.55230758908874}], 
        PointBox[{74.2, -65.57301853897661}], 
        PointBox[{74.3, -67.12088634724932}], 
        PointBox[{74.4, -68.65451708852925}], 
        PointBox[{74.5, -71.92602234841615}], 
        PointBox[{74.6, -73.98126468641567}], 
        PointBox[{74.7, -75.39556635695044}], 
        PointBox[{74.8, -78.38218927084381}], 
        PointBox[{74.9, -80.77329831834504}], 
        PointBox[{75., -82.68250959906436}], 
        PointBox[{75.1, -85.48409519274719}], 
        PointBox[{75.2, -87.80217039394483}], 
        PointBox[{75.3, -88.2919873933206}], 
        PointBox[{75.4, -91.06585687861661}], 
        PointBox[{75.5, -93.52673846071411}], 
        PointBox[{75.6, -94.91793754660466}], 
        PointBox[{75.7, -96.21982363003917}], 
        PointBox[{75.8, -99.72814082406694}], 
        PointBox[{75.9, -100.92909683265316`}], 
        PointBox[{76., -103.19915020436747`}], 
        PointBox[{76.1, -105.71177114547754`}], 
        PointBox[{76.2, -107.1489423108942}], 
        PointBox[{76.3, -107.58185914826754`}], 
        PointBox[{76.4, -110.58563677178608`}], 
        PointBox[{76.5, -112.19246416782698`}], 
        PointBox[{76.6, -113.00290553694504`}], 
        PointBox[{76.7, -114.55709084099362`}], 
        PointBox[{76.8, -117.4610362940075}], 
        PointBox[{76.9, -118.32265302251471`}], 
        PointBox[{77., -120.70286274545651`}], 
        PointBox[{77.1, -122.5854267191171}], 
        PointBox[{77.2, -123.64134400518378`}], 
        PointBox[{77.3, -124.36647678106965`}], 
        PointBox[{77.4, -126.87309137058037`}], 
        PointBox[{77.5, -127.71465358058776`}], 
        PointBox[{77.6, -128.0557297569976}], 
        PointBox[{77.7, -129.9355805048981}], 
        PointBox[{77.8, -131.7708946897692}], 
        PointBox[{77.9, -132.62958478224027`}], 
        PointBox[{78., -134.93277764485538`}], 
        PointBox[{78.1, -136.523594557264}], 
        PointBox[{78.2, -137.22982403618516`}], 
        PointBox[{78.3, -138.23159817470878`}], 
        PointBox[{78.4, -140.1268772133626}], 
        PointBox[{78.5, -140.3224910456047}], 
        PointBox[{78.6, -140.30115850685252`}], 
        PointBox[{78.7, -142.30440321544302`}], 
        PointBox[{78.8, -143.23608619104198`}], 
        PointBox[{78.9, -144.06668606877793`}], 
        PointBox[{79., -146.28887777977798`}], 
        PointBox[{79.1, -148.15923519124044`}], 
        PointBox[{79.2, -148.39439193333237`}], 
        PointBox[{79.3, -149.4573489944887}], 
        PointBox[{79.4, -150.8938676055477}], 
        PointBox[{79.5, -150.5826475576614}], 
        PointBox[{79.6, -150.2695504908188}], 
        PointBox[{79.7, -152.20018306381826`}], 
        PointBox[{79.8, -152.55808729171986`}], 
        PointBox[{79.9, -153.26672031890485`}], 
        PointBox[{80., -155.53748952739988`}], 
        PointBox[{80.1, -157.78518274049566`}], 
        PointBox[{80.2, -157.68918350283639`}], 
        PointBox[{80.3, -158.6255154031969}], 
        PointBox[{80.4, -159.8181866420564}], 
        PointBox[{80.5, -159.14602349288907`}], 
        PointBox[{80.6, -158.57553843306232`}], 
        PointBox[{80.7, -160.34303425114194`}], 
        PointBox[{80.8, -160.42648499566712`}], 
        PointBox[{80.9, -160.92492554386263`}], 
        PointBox[{81., -163.34046913644852`}], 
        PointBox[{81.1, -165.85627426900464`}], 
        PointBox[{81.2, -165.64280725571734`}], 
        PointBox[{81.3, -166.32487253240834`}], 
        PointBox[{81.4, -167.47149044313846`}], 
        PointBox[{81.5, -166.58047170160717`}], 
        PointBox[{81.6, -165.77963431684475`}], 
        PointBox[{81.7, -167.343373427575}], 
        PointBox[{81.8, -167.40402610455203`}], 
        PointBox[{81.9, -167.61844752040633`}], 
        PointBox[{82., -170.1743263703902}], 
        PointBox[{82.1, -172.8530968894338}], 
        PointBox[{82.2, -172.7156942852016}], 
        PointBox[{82.3, -173.063043161339}], 
        PointBox[{82.4, -174.31017260476074`}], 
        PointBox[{82.5, -173.3335451929015}], 
        PointBox[{82.6, -172.34689710173552`}], 
        PointBox[{82.7, -173.67760594074934`}], 
        PointBox[{82.8, -173.91488240085891`}], 
        PointBox[{82.9, -173.8074610700496}], 
        PointBox[{83., -176.4381852373408}], 
        PointBox[{83.1, -179.19465516002674`}], 
        PointBox[{83.2, -179.2787744826055}], 
        PointBox[{83.3, -179.2733935111828}], 
        PointBox[{83.4, 179.29827011829911`}], 
        PointBox[{83.5, -179.75879943971086`}], 
        PointBox[{83.6, -178.65714203593961`}], 
        PointBox[{83.7, -179.74599415189732`}], 
        PointBox[{83.8, 179.71458067748608`}], 
        PointBox[{83.9, -179.88138696129317`}], 
        PointBox[{84., 177.49315120450046`}], 
        PointBox[{84.1, 174.7447065959568}], 
        PointBox[{84.2, 174.36307709031098`}], 
        PointBox[{84.3, 174.65597114740376`}], 
        PointBox[{84.4, 173.02665744732076`}], 
        PointBox[{84.5, 173.83913881748595`}], 
        PointBox[{84.6, 174.95941207862052`}], 
        PointBox[{84.7, 174.0767352899711}], 
        PointBox[{84.8, 173.19821276589937`}], 
        PointBox[{84.9, 173.80222106915608`}], 
        PointBox[{85., 171.2512618161054}], 
        PointBox[{85.1, 168.6012163695923}], 
        PointBox[{85.2, 167.9206099770454}], 
        PointBox[{85.3, 168.35699661294348`}], 
        PointBox[{85.4, 166.54090572339192`}], 
        PointBox[{85.5, 167.15824678780336`}], 
        PointBox[{85.6, 168.1838487970963}], 
        PointBox[{85.7, 167.41119950560824`}], 
        PointBox[{85.8, 166.22841865345254`}], 
        PointBox[{85.9, 166.88279816408613`}], 
        PointBox[{86., 164.46055496495683`}], 
        PointBox[{86.1, 161.98823326011916`}], 
        PointBox[{86.2, 161.06182500846626`}], 
        PointBox[{86.3, 161.44929519235302`}], 
        PointBox[{86.4, 159.45851441318518`}], 
        PointBox[{86.5, 159.8506234882807}], 
        PointBox[{86.6, 160.65899606150197`}], 
        PointBox[{86.7, 159.84138887353765`}], 
        PointBox[{86.8, 158.42626132378064`}], 
        PointBox[{86.9, 158.95780246571667`}], 
        PointBox[{87., 156.73024289226305`}], 
        PointBox[{87.1, 154.45891210139234`}], 
        PointBox[{87.2, 153.36266043975047`}], 
        PointBox[{87.3, 153.487720227924}], 
        PointBox[{87.4, 151.31856615684228`}], 
        PointBox[{87.5, 151.48088437067054`}], 
        PointBox[{87.6, 151.94336433088029`}], 
        PointBox[{87.7, 150.88084091364}], 
        PointBox[{87.8, 149.32529695986887`}], 
        PointBox[{87.9, 149.54913026418217`}], 
        PointBox[{88., 147.62742020194128`}], 
        PointBox[{88.1, 145.4560800932377}], 
        PointBox[{88.2, 144.2690523814963}], 
        PointBox[{88.3, 143.88669063713314`}], 
        PointBox[{88.4, 141.56728576662135`}], 
        PointBox[{88.5, 141.49521190714586`}], 
        PointBox[{88.6, 141.47845456247887`}], 
        PointBox[{88.7, 139.95030226596282`}], 
        PointBox[{88.8, 138.4056787849695}], 
        PointBox[{88.9, 138.13820339856466`}], 
        PointBox[{89., 136.55689776365762`}], 
        PointBox[{89.1, 134.2919209318934}], 
        PointBox[{89.2, 133.1068188685167}], 
        PointBox[{89.3, 131.89814747429773`}], 
        PointBox[{89.4, 129.59603347042867`}], 
        PointBox[{89.5, 129.2469357302325}], 
        PointBox[{89.6, 128.62118852307322`}], 
        PointBox[{89.7, 126.43423693035584`}], 
        PointBox[{89.8, 125.16683945114346`}], 
        PointBox[{89.9, 124.39057820387825`}], 
        PointBox[{90., 122.72815136413556`}], 
        PointBox[{90.1, 120.29902138611214`}], 
        PointBox[{90.2, 119.21334570491308`}], 
        PointBox[{90.3, 116.8511804677837}], 
        PointBox[{90.4, 114.87558350268955`}], 
        PointBox[{90.5, 114.1470107461937}], 
        PointBox[{90.6, 112.79944117017294`}], 
        PointBox[{90.7, 109.91574208235397`}], 
        PointBox[{90.8, 109.15287723697838`}], 
        PointBox[{90.9, 107.9532506892574}], 
        PointBox[{91., 105.62015491099737`}], 
        PointBox[{91.1, 103.18524369761872`}], 
        PointBox[{91.2, 102.09985663510452`}], 
        PointBox[{91.3, 98.68365800337779}], 
        PointBox[{91.4, 97.15742091317225}], 
        PointBox[{91.5, 95.91776510428463}], 
        PointBox[{91.6, 93.7574034101417}], 
        PointBox[{91.7, 90.62233100742742}], 
        PointBox[{91.8, 90.19945628287678}], 
        PointBox[{91.9, 88.19773963406624}], 
        PointBox[{92., 85.39845347053779}], 
        PointBox[{92.1, 83.23590348425205}], 
        PointBox[{92.2, 81.44577101101459}], 
        PointBox[{92.3, 77.9755262935214}], 
        PointBox[{92.4, 76.57974801048113}], 
        PointBox[{92.5, 74.72202504995221}], 
        PointBox[{92.6, 71.7168380895746}], 
        PointBox[{92.7, 69.46431686678261}], 
        PointBox[{92.8, 68.47456188416982}], 
        PointBox[{92.9, 65.55314691986132}], 
        PointBox[{93., 62.75729537650477}], 
        PointBox[{93.1, 61.03146102394385}], 
        PointBox[{93.2, 57.7339701949968}], 
        PointBox[{93.3, 55.29363686568104}], 
        PointBox[{93.4, 53.58850080447155}], 
        PointBox[{93.5, 51.05463330200291}], 
        PointBox[{93.6, 47.50601939072658}], 
        PointBox[{93.7, 46.69944504686282}], 
        PointBox[{93.8, 44.155106783349765`}], 
        PointBox[{93.9, 41.01399583466991}], 
        PointBox[{94., 38.57196783783729}], 
        PointBox[{94.1, 36.795544711480034`}], 
        PointBox[{94.2, 32.76421397703234}], 
        PointBox[{94.3, 31.036486455399427`}], 
        PointBox[{94.4, 28.79220849617559}], 
        PointBox[{94.5, 25.608249785393127`}], 
        PointBox[{94.6, 22.760314045808627`}], 
        PointBox[{94.7, 21.81730656666332}], 
        PointBox[{94.8, 18.407094676600536`}], 
        PointBox[{94.9, 15.538804288735264`}], 
        PointBox[{95., 13.6043831743591}], 
        PointBox[{95.1, 10.564391966327094`}], 
        PointBox[{95.2, 7.582024077724782}], 
        PointBox[{95.3, 5.680270441400353}], 
        PointBox[{95.4, 2.881316838102066}], 
        PointBox[{95.5, -0.6395529195724521}], 
        PointBox[{95.6, -1.6373549974523485`}], 
        PointBox[{95.7, -4.433955323780538}], 
        PointBox[{95.8, -7.67743087427516}], 
        PointBox[{95.9, -10.048037380634923`}], 
        PointBox[{96., -11.81730697992316}], 
        PointBox[{96.1, -15.913289703777991`}], 
        PointBox[{96.2, -17.729202117800014`}], 
        PointBox[{96.3, -20.14669255905028}], 
        PointBox[{96.4, -23.349025669143884`}], 
        PointBox[{96.5, -26.126585392601555`}], 
        PointBox[{96.6, -26.97723120759474}], 
        PointBox[{96.7, -30.555187318561366`}], 
        PointBox[{96.8, -33.25155860003724}], 
        PointBox[{96.9, -35.09038121601043}], 
        PointBox[{97., -37.719662279312615`}], 
        PointBox[{97.1, -41.00451577290369}], 
        PointBox[{97.2, -42.83978754017153}], 
        PointBox[{97.3, -45.68082980236795}], 
        PointBox[{97.4, -48.857630915241316`}], 
        PointBox[{97.5, -49.89301888846967}], 
        PointBox[{97.6, -52.40538759138144}], 
        PointBox[{97.7, -55.527403560932726`}], 
        PointBox[{97.8, -57.598861933511216`}], 
        PointBox[{97.9, -59.165798586444}], 
        PointBox[{98., -62.92191396851558}], 
        PointBox[{98.1, -64.73308438679669}], 
        PointBox[{98.2, -67.04539537755772}], 
        PointBox[{98.3, -70.00769806551398}], 
        PointBox[{98.4, -72.31099940784043}], 
        PointBox[{98.5, -72.85972099681385}], 
        PointBox[{98.6, -76.24740817269776}], 
        PointBox[{98.7, -78.59719427861273}], 
        PointBox[{98.8, -80.08717252437782}], 
        PointBox[{98.9, -81.994784064329}], 
        PointBox[{99., -85.4613304255763}], 
        PointBox[{99.1, -86.84334898671659}], 
        PointBox[{99.2, -89.46157768722333}], 
        PointBox[{99.3, -92.04269238220877}], 
        PointBox[{99.4, -93.1825637549482}], 
        PointBox[{99.5, -94.582953938836}], 
        PointBox[{99.6, -97.54515927587636}], 
        PointBox[{99.7, -99.13144866116636}], 
        PointBox[{99.8, -100.18584812700283`}], 
        PointBox[{99.9, -102.85547130712075`}], 
        PointBox[{100., -104.95974599244073`}]}},
      AspectRatio->0.2,
      DisplayFunction->Identity,
      ImagePadding->{{0., 0.}, {0., 0.}},
      PlotRange->{{0, 100}, {-180, 180}},
      Prolog->InsetBox[
        FormBox[
        "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \
\\\"input\\\" -> \\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
        3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-328., 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.880463416312924*^9, 3.880464080852511*^9, 
  3.880464222577696*^9, 3.880612980420525*^9, 3.880613112164455*^9, 
  3.8806555293961363`*^9, 3.880702750136725*^9, 3.880703465862454*^9, 
  3.8909820896653357`*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"5d2a32d9-6057-4d6c-9654-30a19ed7b481"]
}, Open  ]],

Cell["\<\
Produce the four labelled plots for the case of 2:1 resonance outer \
circulation. \
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, 3.880462891878394*^9, {
   3.880614128433856*^9, 3.880614162859313*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b4351781-dcf7-4b5c-b716-49ee93d56f1a"],

Cell[BoxData[
 RowBox[{"FourPlot", "[", 
  RowBox[{"0.001", ",", " ", "init6", ",", "100", ",", "10"}], "]"}]], "Input",\

 CellChangeTimes->{{3.8804583794052553`*^9, 3.88045838067955*^9}},
 CellLabel->"In[57]:=",ExpressionUUID->"5c283a63-bbdd-4377-8d03-ca045824630e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gcF", "=", "gc"}]], "Input",
 CellChangeTimes->{{3.8804583857552233`*^9, 3.880458390429739*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"338d5c73-54ef-43bf-b902-6dad48a45bfe"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJw9W3c8lv3/lVUJSSRlZ2bvzbHXjXvft6bS3qWU6nnSfBpaVKhEimQlStGS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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0.6000000000000013},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0.6, 
           FormBox["0.6`", TraditionalForm]}, {0.62, 
           FormBox["0.62`", TraditionalForm]}, {0.64, 
           FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0.6, 0.65}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Prolog->{
        Dashing[{Small, Small}], 
        LineBox[{{0, 0.629961}, {100, 0.629961}}]},
      Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
     ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJw9m3dczW/YxxNC+llFymqotLS3Op/2rrPPycgukkSFECUZyc+IMqIySkZG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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {0.1, 
           FormBox["0.1`", TraditionalForm]}, {0.2, 
           FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 0.2}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -159.99}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.0055000000000000005`], Thickness[0.0075], PointBox[CompressedData["
1:eJxd13dczf/7P/Ak2WSVzERpSXuPR3ud6uxzGiqrZcsKKavwjmwyEpFsKbIi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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}, {360, 
           FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {0., 360.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.004583333333333334], Thickness[0.0075], PointBox[CompressedData["
1:eJxdm3k8lN/7/0chSaWkaB0qlK1kLcupkFBkbayDQiottEk17Zv2HUkqVFpV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         "]]}, {{}, {}}},
      AspectRatio->0.2,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
          TagBox[
           RotationBox[
           "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[CurlyPhi]\
\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
            BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm],
          None}, {
         FormBox[
          TagBox["\"Time (Jupiter Periods)\"", HoldForm], TraditionalForm], 
         None}},
      FrameStyle->Thickness[0.004],
      FrameTicks->{{{{-180, 
           FormBox[
            RowBox[{"-", "180"}], TraditionalForm]}, {0, 
           FormBox["0", TraditionalForm]}, {180, 
           FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{60., 12.}, {41., 8.}},
      LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
      Method->{
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}},
      PlotRange->{{0., 100.}, {-180., 180.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -383.19}, 
     ImageScaled[{0.5, 0.5}], {360, 106.6},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->Medium,
  PlotRange->{{0, 378.}, {-438.99, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.880458391178816*^9, 3.880463428332018*^9, 
  3.8804640823065557`*^9, 3.88046422401606*^9, 3.880612981823515*^9, 
  3.880613113745319*^9, 3.880655530445393*^9, 3.880702751214261*^9, 
  3.880703467025565*^9, 3.890982090765874*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"c6f22937-ad67-4edf-bd26-51bc9966e475"]
}, Open  ]],

Cell["\<\
Produce the x-y plot for the case of 2:1 resonance outer circulation.  This \
is Fig.8.17f.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, 3.880462891878394*^9, {
   3.8804634457063847`*^9, 3.880463448195674*^9}, {3.8806141679440327`*^9, 
   3.880614175563982*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"51a8064c-1c7e-419d-8061-149bcb6d200e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xyF", "=", "xyplot"}]], "Input",
 CellChangeTimes->{{3.880458394261064*^9, 3.8804583986052647`*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"eae9bc64-047b-465a-9433-fd8756052ed0"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwtmHlcTP/3x6emWRKFipAUbUrZo837TQsRbZQWREgKUdFCUmihUGm3JG2S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     "]]}, {{}, {}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-4., 4.}, {-4., 4.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Prolog->{
    Thickness[0.002], 
    LineBox[{{0, -4}, {0, 4}}], 
    LineBox[{{-4, 0}, {4, 0}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8804583992541428`*^9, 3.8804595504276857`*^9, 
  3.880463450765295*^9, 3.880464082405418*^9, 3.880464224083102*^9, 
  3.880612981889844*^9, 3.88061311384243*^9, 3.8806555305002728`*^9, 
  3.880702751272561*^9, 3.880703467094713*^9, 3.890982090825712*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"ca2b0b0e-2ebf-412a-be2d-3a3fb3066abc"]
}, Open  ]],

Cell["Combine the unlabelled plots.  This is Fig.8.16.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, 3.880462891878394*^9, {
   3.8804634457063847`*^9, 3.880463448195674*^9}, {3.8806141679440327`*^9, 
   3.8806142112342987`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"328808de-df78-4330-b013-1701a3f1498f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"gcNLA", ",", "gcNLB"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"gcNLC", ",", "gcNLD"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"gcNLE", ",", "gcNLF"}], "}"}]}], "}"}], ",", 
   RowBox[{"Spacings", "->", 
    RowBox[{"{", 
     RowBox[{"20", ",", "40"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8804638090529003`*^9, 3.880463821666258*^9}, {
  3.880463854651278*^9, 3.880463894414651*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"a678812e-c4e0-4f18-8a27-604403bbd698"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
            {Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.625277}], 
             PointBox[{0.1, 0.6259686355768492}], 
             PointBox[{0.2, 0.6273736511909047}], 
             PointBox[{0.3, 0.6286463214910968}], 
             PointBox[{0.4, 0.6305881194588028}], 
             PointBox[{0.5, 0.6324190644307863}], 
             PointBox[{0.6, 0.6304147131346407}], 
             PointBox[{0.7, 0.6285475652174198}], 
             PointBox[{0.8, 0.6272874038475243}], 
             PointBox[{0.9, 0.6258619053669047}], 
             PointBox[{1., 0.625274000481498}], 
             PointBox[{1.1, 0.6260750036549589}], 
             PointBox[{1.2, 0.627456974714097}], 
             PointBox[{1.3, 0.6287467855779384}], 
             PointBox[{1.4, 0.6307641985069974}], 
             PointBox[{1.5, 0.6323872052968448}], 
             PointBox[{1.6, 0.6302448297672972}], 
             PointBox[{1.7, 0.6284497330106544}], 
             PointBox[{1.8, 0.627198251028428}], 
             PointBox[{1.9, 0.6257555695049932}], 
             PointBox[{2., 0.6252665572741121}], 
             PointBox[{2.1, 0.6261797143744898}], 
             PointBox[{2.2, 0.6275378683660486}], 
             PointBox[{2.3, 0.6288493235641331}], 
             PointBox[{2.4, 0.6309420300812095}], 
             PointBox[{2.5, 0.6323242724624056}], 
             PointBox[{2.6, 0.6300786655850195}], 
             PointBox[{2.7, 0.6283525386810321}], 
             PointBox[{2.8, 0.627104873384124}], 
             PointBox[{2.9, 0.6256517346763191}], 
             PointBox[{3., 0.6252586493441133}], 
             PointBox[{3.1, 0.6262823952057137}], 
             PointBox[{3.2, 0.6276172264461802}], 
             PointBox[{3.3, 0.6289551892157544}], 
             PointBox[{3.4, 0.6311205713632864}], 
             PointBox[{3.5, 0.6322333976857769}], 
             PointBox[{3.6, 0.6299171703718282}], 
             PointBox[{3.7, 0.6282559029370294}], 
             PointBox[{3.8, 0.6270081079227489}], 
             PointBox[{3.9, 0.6255528896735832}], 
             PointBox[{4., 0.6252550491238453}], 
             PointBox[{4.1, 0.6263823418878793}], 
             PointBox[{4.2, 0.627695136711139}], 
             PointBox[{4.3, 0.6290644909467883}], 
             PointBox[{4.4, 0.6312973810482354}], 
             PointBox[{4.5, 0.6321160594767278}], 
             PointBox[{4.6, 0.6297598156542259}], 
             PointBox[{4.7, 0.6281592323828662}], 
             PointBox[{4.8, 0.6269074725759244}], 
             PointBox[{4.9, 0.62546100834877}], 
             PointBox[{5., 0.6252603426790695}], 
             PointBox[{5.1, 0.6264793900579759}], 
             PointBox[{5.2, 0.6277721464914303}], 
             PointBox[{5.3, 0.6291778467164263}], 
             PointBox[{5.4, 0.6314708978167086}], 
             PointBox[{5.5, 0.6319755724564486}], 
             PointBox[{5.6, 0.6296066730706238}], 
             PointBox[{5.7, 0.6280622173118305}], 
             PointBox[{5.8, 0.6268030197281277}], 
             PointBox[{5.9, 0.6253791685995661}], 
             PointBox[{6., 0.6252783534559848}], 
             PointBox[{6.1, 0.6265737407216837}], 
             PointBox[{6.2, 0.627849341579742}], 
             PointBox[{6.3, 0.6292958393107106}], 
             PointBox[{6.4, 0.6316375082443112}], 
             PointBox[{6.5, 0.6318160208457897}], 
             PointBox[{6.6, 0.6294580040805438}], 
             PointBox[{6.7, 0.6279648888546501}], 
             PointBox[{6.8, 0.6266940136962417}], 
             PointBox[{6.9, 0.625309742340656}], 
             PointBox[{7., 0.6253107080216136}], 
             PointBox[{7.1, 0.626665471984743}], 
             PointBox[{7.2, 0.6279267577208097}], 
             PointBox[{7.3, 0.6294200825255885}], 
             PointBox[{7.4, 0.6317948569939642}], 
             PointBox[{7.5, 0.6316410781141532}], 
             PointBox[{7.6, 0.6293139640502387}], 
             PointBox[{7.7, 0.6278671140756245}], 
             PointBox[{7.8, 0.6265815102326335}], 
             PointBox[{7.9, 0.6252546024409925}], 
             PointBox[{8., 0.6253578099044653}], 
             PointBox[{8.1, 0.6267549641394836}], 
             PointBox[{8.2, 0.6280054656921639}], 
             PointBox[{8.3, 0.6295509591517437}], 
             PointBox[{8.4, 0.631938219095616}], 
             PointBox[{8.5, 0.6314545676573985}], 
             PointBox[{8.6, 0.6291740074518709}], 
             PointBox[{8.7, 0.6277687427540464}], 
             PointBox[{8.8, 0.6264651995814693}], 
             PointBox[{8.9, 0.6252149266815534}], 
             PointBox[{9., 0.6254189723683116}], 
             PointBox[{9.1, 0.626842607954492}], 
             PointBox[{9.2, 0.628085928408874}], 
             PointBox[{9.3, 0.6296887590745461}], 
             PointBox[{9.4, 0.6320645317575988}], 
             PointBox[{9.5, 0.6312600936953636}], 
             PointBox[{9.6, 0.6290383151594051}], 
             PointBox[{9.7, 0.6276696714567026}], 
             PointBox[{9.8, 0.6263459776564863}], 
             PointBox[{9.9, 0.6251893325713853}], 
             PointBox[{10., 0.6254925890149102}], 
             PointBox[{10.1, 0.626928646045456}], 
             PointBox[{10.2, 0.6281689164716623}], 
             PointBox[{10.3, 0.629834289093246}], 
             PointBox[{10.4, 0.6321694090111833}], 
             PointBox[{10.5, 0.6310609957889173}], 
             PointBox[{10.6, 0.6289068536365496}], 
             PointBox[{10.7, 0.6275702147273109}], 
             PointBox[{10.8, 0.6262234395974359}], 
             PointBox[{10.9, 0.625175901143655}], 
             PointBox[{11., 0.6255767714851413}], 
             PointBox[{11.1, 0.6270137809657017}], 
             PointBox[{11.2, 0.6282550620835429}], 
             PointBox[{11.3, 0.6299875098161969}], 
             PointBox[{11.4, 0.6322483171414873}], 
             PointBox[{11.5, 0.630860339373956}], 
             PointBox[{11.6, 0.6287794812286063}], 
             PointBox[{11.7, 0.6274697935335826}], 
             PointBox[{11.8, 0.6260994269208858}], 
             PointBox[{11.9, 0.6251696726730801}], 
             PointBox[{12., 0.6256694471476292}], 
             PointBox[{12.1, 0.6270985085272257}], 
             PointBox[{12.2, 0.6283451819751166}], 
             PointBox[{12.3, 0.6301499722011702}], 
             PointBox[{12.4, 0.6322993713783158}], 
             PointBox[{12.5, 0.6306607060988447}], 
             PointBox[{12.6, 0.6286565426914302}], 
             PointBox[{12.7, 0.6273690151176777}], 
             PointBox[{12.8, 0.625974549968986}], 
             PointBox[{12.9, 0.6251653588678281}], 
             PointBox[{13., 0.6257685810625101}], 
             PointBox[{13.1, 0.6271829022987121}], 
             PointBox[{13.2, 0.6284393662062034}], 
             PointBox[{13.3, 0.6303193083152657}], 
             PointBox[{13.4, 0.6323192366571178}], 
             PointBox[{13.5, 0.630464454501701}], 
             PointBox[{13.6, 0.6285374056893103}], 
             PointBox[{13.7, 0.6272677632625103}], 
             PointBox[{13.8, 0.6258506491218634}], 
             PointBox[{13.9, 0.6251587224988588}], 
             PointBox[{14., 0.6258727627617396}], 
             PointBox[{14.1, 0.62726795863325}], 
             PointBox[{14.2, 0.6285391723575467}], 
             PointBox[{14.3, 0.6304967138520198}], 
             PointBox[{14.4, 0.6323070254650416}], 
             PointBox[{14.5, 0.6302730495769632}], 
             PointBox[{14.6, 0.6284226388346422}], 
             PointBox[{14.7, 0.6271656972750363}], 
             PointBox[{14.8, 0.625729213143763}], 
             PointBox[{14.9, 0.6251484927867732}], 
             PointBox[{15., 0.6259802072392873}], 
             PointBox[{15.1, 0.6273538122618584}], 
             PointBox[{15.2, 0.6286445086140849}], 
             PointBox[{15.3, 0.6306806793300203}], 
             PointBox[{15.4, 0.6322627786357484}], 
             PointBox[{15.5, 0.6300878529751109}], 
             PointBox[{15.6, 0.6283115533652035}], 
             PointBox[{15.7, 0.6270630886625642}], 
             PointBox[{15.8, 0.6256123614824746}], 
             PointBox[{15.9, 0.6251373105198229}], 
             PointBox[{16., 0.6260897646240345}], 
             PointBox[{16.1, 0.6274405979226908}], 
             PointBox[{16.2, 0.6287561157587417}], 
             PointBox[{16.3, 0.6308697955186632}], 
             PointBox[{16.4, 0.6321875135321108}], 
             PointBox[{16.5, 0.6299099517715178}], 
             PointBox[{16.6, 0.6282043431883877}], 
             PointBox[{16.7, 0.6269600875357854}], 
             PointBox[{16.8, 0.625502987921274}], 
             PointBox[{16.9, 0.6251303060579813}], 
             PointBox[{17., 0.6262006678348218}], 
             PointBox[{17.1, 0.6275292641010294}], 
             PointBox[{17.2, 0.6288739318055966}], 
             PointBox[{17.3, 0.6310616044169929}], 
             PointBox[{17.4, 0.6320839635928415}], 
             PointBox[{17.5, 0.6297401815868618}], 
             PointBox[{17.6, 0.6281009004891499}], 
             PointBox[{17.7, 0.6268565073997816}], 
             PointBox[{17.8, 0.6254037176191488}], 
             PointBox[{17.9, 0.6251330176350186}], 
             PointBox[{18., 0.6263120840618176}], 
             PointBox[{18.1, 0.62761973172378}], 
             PointBox[{18.2, 0.6289987847763239}], 
             PointBox[{18.3, 0.6312539885919216}], 
             PointBox[{18.4, 0.631955652525127}], 
             PointBox[{18.5, 0.6295786599515121}], 
             PointBox[{18.6, 0.6280012241974309}], 
             PointBox[{18.7, 0.6267522949674393}], 
             PointBox[{18.8, 0.6253176133601422}], 
             PointBox[{18.9, 0.6251509628284566}], 
             PointBox[{19., 0.6264233845836157}], 
             PointBox[{19.1, 0.6277123742414249}], 
             PointBox[{19.2, 0.6291314255446108}], 
             PointBox[{19.3, 0.6314429668861975}], 
             PointBox[{19.4, 0.6318066528444785}], 
             PointBox[{19.5, 0.6294257511543231}], 
             PointBox[{19.6, 0.627904919181402}], 
             PointBox[{19.7, 0.6266478128162255}], 
             PointBox[{19.8, 0.6252474279325356}], 
             PointBox[{19.9, 0.6251874391619241}], 
             PointBox[{20., 0.6265342833185197}], 
             PointBox[{20.1, 0.6278074248996299}], 
             PointBox[{20.2, 0.6292717904789623}], 
             PointBox[{20.3, 0.6316248825153564}], 
             PointBox[{20.4, 0.631641748191249}], 
             PointBox[{20.5, 0.629281293317855}], 
             PointBox[{20.6, 0.6278117323964516}], 
             PointBox[{20.7, 0.6265425598079263}], 
             PointBox[{20.8, 0.6251956162499229}], 
             PointBox[{20.9, 0.6252428406101335}], 
             PointBox[{21., 0.626644413180714}], 
             PointBox[{21.1, 0.627904916196575}], 
             PointBox[{21.2, 0.6294198389739062}], 
             PointBox[{21.3, 0.6317951138393799}], 
             PointBox[{21.4, 0.6314652871231166}], 
             PointBox[{21.5, 0.6291451143413948}], 
             PointBox[{21.6, 0.6277215822252494}], 
             PointBox[{21.7, 0.6264367687561441}], 
             PointBox[{21.8, 0.6251622427657583}], 
             PointBox[{21.9, 0.6253162054778026}], 
             PointBox[{22., 0.6267535529249795}], 
             PointBox[{22.1, 0.6280051695045364}], 
             PointBox[{22.2, 0.6295756876680865}], 
             PointBox[{22.3, 0.6319500834626514}], 
             PointBox[{22.4, 0.6312817059396447}], 
             PointBox[{22.5, 0.6290168222008018}], 
             PointBox[{22.6, 0.6276337111520325}], 
             PointBox[{22.7, 0.6263308584740874}], 
             PointBox[{22.8, 0.6251473071549289}], 
             PointBox[{22.9, 0.6254052925073794}], 
             PointBox[{23., 0.6268615544830349}], 
             PointBox[{23.1, 0.6281082163934578}], 
             PointBox[{23.2, 0.6297394483182991}], 
             PointBox[{23.3, 0.632083922844518}], 
             PointBox[{23.4, 0.6310947913075732}], 
             PointBox[{23.5, 0.6288962975347424}], 
             PointBox[{23.6, 0.6275482158520207}], 
             PointBox[{23.7, 0.6262247756130359}], 
             PointBox[{23.8, 0.6251474885174696}], 
             PointBox[{23.9, 0.6255073034259613}], 
             PointBox[{24., 0.6269685115549785}], 
             PointBox[{24.1, 0.6282141321792089}], 
             PointBox[{24.2, 0.6299109185013212}], 
             PointBox[{24.3, 0.6321938528897741}], 
             PointBox[{24.4, 0.6309081435843882}], 
             PointBox[{24.5, 0.6287828814830712}], 
             PointBox[{24.6, 0.6274647957367453}], 
             PointBox[{24.7, 0.6261193558096225}], 
             PointBox[{24.8, 0.6251579588222896}], 
             PointBox[{24.9, 0.6256189282105231}], 
             PointBox[{25., 0.6270741484358938}], 
             PointBox[{25.1, 0.6283231319211439}], 
             PointBox[{25.2, 0.6300897696775991}], 
             PointBox[{25.3, 0.6322751737317922}], 
             PointBox[{25.4, 0.6307240303751629}], 
             PointBox[{25.5, 0.6286759908462093}], 
             PointBox[{25.6, 0.6273825396366441}], 
             PointBox[{25.7, 0.6260144943196941}], 
             PointBox[{25.8, 0.6251717414279298}], 
             PointBox[{25.9, 0.6257370918917217}], 
             PointBox[{26., 0.6271783551823505}], 
             PointBox[{26.1, 0.6284349669895973}], 
             PointBox[{26.2, 0.6302744423124863}], 
             PointBox[{26.3, 0.6323261980836621}], 
             PointBox[{26.4, 0.6305444852103576}], 
             PointBox[{26.5, 0.6285748700923558}], 
             PointBox[{26.6, 0.6273015358408235}], 
             PointBox[{26.7, 0.6259113423804374}], 
             PointBox[{26.8, 0.6251851303064586}], 
             PointBox[{26.9, 0.6258593140768133}], 
             PointBox[{27., 0.6272811709759131}], 
             PointBox[{27.1, 0.6285497850152006}], 
             PointBox[{27.2, 0.6304647853516142}], 
             PointBox[{27.3, 0.6323451412004435}], 
             PointBox[{27.4, 0.6303709606773147}], 
             PointBox[{27.5, 0.6284789380827093}], 
             PointBox[{27.6, 0.6272201723114704}], 
             PointBox[{27.7, 0.6258107341796005}], 
             PointBox[{27.8, 0.625193958001334}], 
             PointBox[{27.9, 0.6259833413947833}], 
             PointBox[{28., 0.627382552397369}], 
             PointBox[{28.1, 0.6286676860485036}], 
             PointBox[{28.2, 0.6306593631956325}], 
             PointBox[{28.3, 0.6323315803857152}], 
             PointBox[{28.4, 0.6302042663063843}], 
             PointBox[{28.5, 0.6283875041409811}], 
             PointBox[{28.6, 0.6271395929559826}], 
             PointBox[{28.7, 0.625713859204983}], 
             PointBox[{28.8, 0.6251997078549709}], 
             PointBox[{28.9, 0.6261073929422083}], 
             PointBox[{29., 0.6274824729851642}], 
             PointBox[{29.1, 0.6287887524324549}], 
             PointBox[{29.2, 0.6308564759700133}], 
             PointBox[{29.3, 0.6322877419596127}], 
             PointBox[{29.4, 0.6300448580039396}], 
             PointBox[{29.5, 0.6282998241834433}], 
             PointBox[{29.6, 0.6270573618467157}], 
             PointBox[{29.7, 0.6256221296087536}], 
             PointBox[{29.8, 0.6252060883231673}], 
             PointBox[{29.9, 0.6262301143491222}], 
             PointBox[{30., 0.6275809369384284}], 
             PointBox[{30.1, 0.6289130343434469}], 
             PointBox[{30.2, 0.6310541864542025}], 
             PointBox[{30.3, 0.632214313987484}], 
             PointBox[{30.4, 0.6298928039558526}], 
             PointBox[{30.5, 0.6282153061702739}], 
             PointBox[{30.6, 0.6269747529567448}], 
             PointBox[{30.7, 0.625537561100585}], 
             PointBox[{30.8, 0.6252175436491388}], 
             PointBox[{30.9, 0.6263501646104851}], 
             PointBox[{31., 0.6276779746626598}], 
             PointBox[{31.1, 0.6290405328874806}], 
             PointBox[{31.2, 0.6312502019415567}], 
             PointBox[{31.3, 0.632115490923466}], 
             PointBox[{31.4, 0.6297479704325916}], 
             PointBox[{31.5, 0.6281333352130049}], 
             PointBox[{31.6, 0.6268898502269261}], 
             PointBox[{31.7, 0.6254619098979174}], 
             PointBox[{31.8, 0.6252388208611108}], 
             PointBox[{31.9, 0.6264668870672329}], 
             PointBox[{32., 0.6277736335980276}], 
             PointBox[{32.1, 0.6291714577787255}], 
             PointBox[{32.2, 0.6314417126267462}], 
             PointBox[{32.3, 0.6319938470082972}], 
             PointBox[{32.4, 0.6296097448517586}], 
             PointBox[{32.5, 0.6280528244201244}], 
             PointBox[{32.6, 0.6268030593774737}], 
             PointBox[{32.7, 0.6253966678380568}], 
             PointBox[{32.8, 0.6252730261533852}], 
             PointBox[{32.9, 0.6265797543320669}], 
             PointBox[{33., 0.6278680247922432}], 
             PointBox[{33.1, 0.6293059364451015}], 
             PointBox[{33.2, 0.6316256146531924}], 
             PointBox[{33.3, 0.6318537583620429}], 
             PointBox[{33.4, 0.6294778914999632}], 
             PointBox[{33.5, 0.6279733157849877}], 
             PointBox[{33.6, 0.626713048211822}], 
             PointBox[{33.7, 0.6253445985973126}], 
             PointBox[{33.8, 0.6253215313300619}], 
             PointBox[{33.9, 0.6266887112649715}], 
             PointBox[{34., 0.6279612838490402}], 
             PointBox[{34.1, 0.6294441511777721}], 
             PointBox[{34.2, 0.6317987882616894}], 
             PointBox[{34.3, 0.6316985877569511}], 
             PointBox[{34.4, 0.6293513957583867}], 
             PointBox[{34.5, 0.6278941838640454}], 
             PointBox[{34.6, 0.6266203727467936}], 
             PointBox[{34.7, 0.6253054939545251}], 
             PointBox[{34.8, 0.6253833146799669}], 
             PointBox[{34.9, 0.6267932028855605}], 
             PointBox[{35., 0.6280534935886081}], 
             PointBox[{35.1, 0.629586211835615}], 
             PointBox[{35.2, 0.6319571542867122}], 
             PointBox[{35.3, 0.6315322546818832}], 
             PointBox[{35.4, 0.6292298503871191}], 
             PointBox[{35.5, 0.6278148926016304}], 
             PointBox[{35.6, 0.6265238183693825}], 
             PointBox[{35.7, 0.6252801918210136}], 
             PointBox[{35.8, 0.6254572425692977}], 
             PointBox[{35.9, 0.6268932342095581}], 
             PointBox[{36., 0.6281449688636441}], 
             PointBox[{36.1, 0.629732417346695}], 
             PointBox[{36.2, 0.6320971992541154}], 
             PointBox[{36.3, 0.6313579027671532}], 
             PointBox[{36.4, 0.6291125205972528}], 
             PointBox[{36.5, 0.6277347269649088}], 
             PointBox[{36.6, 0.6264240152877877}], 
             PointBox[{36.7, 0.6252673202348611}], 
             PointBox[{36.8, 0.625541157647615}], 
             PointBox[{36.9, 0.626989220343891}], 
             PointBox[{37., 0.6282360589692755}], 
             PointBox[{37.1, 0.629882976496341}], 
             PointBox[{37.2, 0.6322156308205036}], 
             PointBox[{37.3, 0.631178553712583}], 
             PointBox[{37.4, 0.62899887288331}], 
             PointBox[{37.5, 0.627653267418638}], 
             PointBox[{37.6, 0.6263207781813807}], 
             PointBox[{37.7, 0.6252642446747129}], 
             PointBox[{37.8, 0.6256326951097695}], 
             PointBox[{37.9, 0.6270813118920682}], 
             PointBox[{38., 0.6283272737296953}], 
             PointBox[{38.1, 0.6300381015219804}], 
             PointBox[{38.2, 0.6323088461690796}], 
             PointBox[{38.3, 0.630996570903711}], 
             PointBox[{38.4, 0.6288882836762985}], 
             PointBox[{38.5, 0.6275698237857467}], 
             PointBox[{38.6, 0.6262140545506438}], 
             PointBox[{38.7, 0.6252662595260375}], 
             PointBox[{38.8, 0.6257296356144062}], 
             PointBox[{38.9, 0.6271700423469039}], 
             PointBox[{39., 0.6284189036158562}], 
             PointBox[{39.1, 0.6301976822011889}], 
             PointBox[{39.2, 0.6323739427602932}], 
             PointBox[{39.3, 0.6308139535786447}], 
             PointBox[{39.4, 0.6287800482535426}], 
             PointBox[{39.5, 0.6274843403427456}], 
             PointBox[{39.6, 0.6261044625105134}], 
             PointBox[{39.7, 0.6252693723162704}], 
             PointBox[{39.8, 0.6258298765287433}], 
             PointBox[{39.9, 0.6272553001213705}], 
             PointBox[{40., 0.6285114746885225}], 
             PointBox[{40.1, 0.6303618257947999}], 
             PointBox[{40.2, 0.6324093864034873}], 
             PointBox[{40.3, 0.6306322484890556}], 
             PointBox[{40.4, 0.628673854924566}], 
             PointBox[{40.5, 0.6273966865534492}], 
             PointBox[{40.6, 0.6259927891747602}], 
             PointBox[{40.7, 0.6252690550597316}], 
             PointBox[{40.8, 0.6259317552692534}], 
             PointBox[{40.9, 0.6273375714201653}], 
             PointBox[{41., 0.6286055463582995}], 
             PointBox[{41.1, 0.6305303702627363}], 
             PointBox[{41.2, 0.6324127290390402}], 
             PointBox[{41.3, 0.6304526744793307}], 
             PointBox[{41.4, 0.6285690266887345}], 
             PointBox[{41.5, 0.627305347735485}], 
             PointBox[{41.6, 0.6258798505745587}], 
             PointBox[{41.7, 0.6252626787938674}], 
             PointBox[{41.8, 0.62603395119248}], 
             PointBox[{41.9, 0.627417595488456}], 
             PointBox[{42., 0.6287016075818718}], 
             PointBox[{42.1, 0.6307024558268469}], 
             PointBox[{42.2, 0.6323843387901719}], 
             PointBox[{42.3, 0.6302761088376887}], 
             PointBox[{42.4, 0.6284653020623744}], 
             PointBox[{42.5, 0.6272112412686012}], 
             PointBox[{42.6, 0.6257672575799355}], 
             PointBox[{42.7, 0.625251725991091}], 
             PointBox[{42.8, 0.6261353400086823}], 
             PointBox[{42.9, 0.6274959591861565}], 
             PointBox[{43., 0.6288006010824109}], 
             PointBox[{43.1, 0.6308775621151368}], 
             PointBox[{43.2, 0.6323248354798295}], 
             PointBox[{43.3, 0.6301031057292874}], 
             PointBox[{43.4, 0.6283623719094718}], 
             PointBox[{43.5, 0.6271132079940116}], 
             PointBox[{43.6, 0.6256570255623439}], 
             PointBox[{43.7, 0.6252393295161293}], 
             PointBox[{43.8, 0.626235585231059}], 
             PointBox[{43.9, 0.6275728307076546}], 
             PointBox[{44., 0.6289030648327285}], 
             PointBox[{44.1, 0.6310543715988747}], 
             PointBox[{44.2, 0.6322358419277809}], 
             PointBox[{44.3, 0.629934712723784}], 
             PointBox[{44.4, 0.6282601124378251}], 
             PointBox[{44.5, 0.6270121552450123}], 
             PointBox[{44.6, 0.6255515149493769}], 
             PointBox[{44.7, 0.6252303985432834}], 
             PointBox[{44.8, 0.6263339734654039}], 
             PointBox[{44.9, 0.6276492922471715}], 
             PointBox[{45., 0.6290098850207153}], 
             PointBox[{45.1, 0.6312312231992101}], 
             PointBox[{45.2, 0.6321197568413043}], 
             PointBox[{45.3, 0.6297708360477868}], 
             PointBox[{45.4, 0.6281583231131491}], 
             PointBox[{45.5, 0.6269073950280031}], 
             PointBox[{45.6, 0.6254533923657883}], 
             PointBox[{45.7, 0.6252307019421374}], 
             PointBox[{45.8, 0.6264305756105687}], 
             PointBox[{45.9, 0.6277256581236014}], 
             PointBox[{46., 0.6291218861290704}], 
             PointBox[{46.1, 0.6314057818410698}], 
             PointBox[{46.2, 0.6319800533447513}], 
             PointBox[{46.3, 0.6296117477594104}], 
             PointBox[{46.4, 0.6280569732708143}], 
             PointBox[{46.5, 0.626799179399011}], 
             PointBox[{46.6, 0.6253656701672178}], 
             PointBox[{46.7, 0.6252436884248549}], 
             PointBox[{46.8, 0.6265252581360692}], 
             PointBox[{46.9, 0.6278028275737052}], 
             PointBox[{47., 0.6292398202469893}], 
             PointBox[{47.1, 0.6315753576926857}], 
             PointBox[{47.2, 0.6318203693547056}], 
             PointBox[{47.3, 0.6294580071906152}], 
             PointBox[{47.4, 0.6279559497537143}], 
             PointBox[{47.5, 0.6266877649155282}], 
             PointBox[{47.6, 0.6252911093595656}], 
             PointBox[{47.7, 0.6252723857168846}], 
             PointBox[{47.8, 0.6266184734917063}], 
             PointBox[{47.9, 0.6278813921185096}], 
             PointBox[{48., 0.6293645868570209}], 
             PointBox[{48.1, 0.6317364801740993}], 
             PointBox[{48.2, 0.6316447151872672}], 
             PointBox[{48.3, 0.6293094866091093}], 
             PointBox[{48.4, 0.6278553728826382}], 
             PointBox[{48.5, 0.626573829612991}], 
             PointBox[{48.6, 0.6252320893798513}], 
             PointBox[{48.7, 0.6253172790607122}], 
             PointBox[{48.8, 0.626710135856642}], 
             PointBox[{48.9, 0.6279616865388226}], 
             PointBox[{49., 0.6294966256645307}], 
             PointBox[{49.1, 0.6318851854001779}], 
             PointBox[{49.2, 0.6314570817183557}], 
             PointBox[{49.3, 0.6291660899648792}], 
             PointBox[{49.4, 0.6277548856654661}], 
             PointBox[{49.5, 0.6264555361003937}], 
             PointBox[{49.6, 0.6251894938526027}], 
             PointBox[{49.7, 0.6253776964279285}], 
             PointBox[{49.8, 0.6268006415081594}], 
             PointBox[{49.9, 0.628044786547352}], 
             PointBox[{50., 0.6296366208629351}], 
             PointBox[{50.1, 0.6320173651766751}], 
             PointBox[{50.2, 0.6312614561607177}], 
             PointBox[{50.3, 0.6290278635192506}], 
             PointBox[{50.4, 0.6276547230328519}], 
             PointBox[{50.5, 0.6263353788233007}], 
             PointBox[{50.6, 0.6251629571691038}], 
             PointBox[{50.7, 0.6254521860196024}], 
             PointBox[{50.8, 0.6268904560614669}], 
             PointBox[{50.9, 0.6281311186326227}], 
             PointBox[{51., 0.6297851481201718}], 
             PointBox[{51.1, 0.6321287382853035}], 
             PointBox[{51.2, 0.6310615579324252}], 
             PointBox[{51.3, 0.6288950624426297}], 
             PointBox[{51.4, 0.6275549576491679}], 
             PointBox[{51.5, 0.6262134026591756}], 
             PointBox[{51.6, 0.6251499436820572}], 
             PointBox[{51.7, 0.6255385964298734}], 
             PointBox[{51.8, 0.6269798632068595}], 
             PointBox[{51.9, 0.6282208215490171}], 
             PointBox[{52., 0.6299423694421203}], 
             PointBox[{52.1, 0.6322153919642782}], 
             PointBox[{52.2, 0.6308605071731482}], 
             PointBox[{52.3, 0.6287675391688112}], 
             PointBox[{52.4, 0.6274554125449351}], 
             PointBox[{52.5, 0.6260904349837787}], 
             PointBox[{52.6, 0.6251455459605065}], 
             PointBox[{52.7, 0.6256345950602422}], 
             PointBox[{52.8, 0.6270690799465841}], 
             PointBox[{52.9, 0.6283150095785687}], 
             PointBox[{53., 0.6301083205383798}], 
             PointBox[{53.1, 0.6322735320489146}], 
             PointBox[{53.2, 0.6306610424481338}], 
             PointBox[{53.3, 0.628645156905977}], 
             PointBox[{53.4, 0.6273561882796677}], 
             PointBox[{53.5, 0.6259677896408177}], 
             PointBox[{53.6, 0.6251444599410175}], 
             PointBox[{53.7, 0.6257382634097074}], 
             PointBox[{53.8, 0.6271586987902837}], 
             PointBox[{53.9, 0.6284142899110178}], 
             PointBox[{54., 0.6302828350348487}], 
             PointBox[{54.1, 0.6323014230861422}], 
             PointBox[{54.2, 0.6304657176083757}], 
             PointBox[{54.3, 0.6285277520136561}], 
             PointBox[{54.4, 0.627257332052563}], 
             PointBox[{54.5, 0.6258464794505367}], 
             PointBox[{54.6, 0.6251422055854434}], 
             PointBox[{54.7, 0.6258471114745995}], 
             PointBox[{54.8, 0.6272487848214213}], 
             PointBox[{54.9, 0.6285183518575831}], 
             PointBox[{55., 0.6304648657758885}], 
             PointBox[{55.1, 0.6322963049149041}], 
             PointBox[{55.2, 0.6302758039787899}], 
             PointBox[{55.3, 0.6284151109008057}], 
             PointBox[{55.4, 0.6271586597883865}], 
             PointBox[{55.5, 0.6257282972885373}], 
             PointBox[{55.6, 0.6251362384310791}], 
             PointBox[{55.7, 0.6259598369059354}], 
             PointBox[{55.8, 0.6273398418511601}], 
             PointBox[{55.9, 0.6286282539278039}], 
             PointBox[{56., 0.6306537427349317}], 
             PointBox[{56.1, 0.6322593570817396}], 
             PointBox[{56.2, 0.6300930607426155}], 
             PointBox[{56.3, 0.6283074114676068}], 
             PointBox[{56.4, 0.6270597732623368}], 
             PointBox[{56.5, 0.6256154197523911}], 
             PointBox[{56.6, 0.6251295579854625}], 
             PointBox[{56.7, 0.6260750949004319}], 
             PointBox[{56.8, 0.6274321455467042}], 
             PointBox[{56.9, 0.6287447614290214}], 
             PointBox[{57., 0.6308476440330374}], 
             PointBox[{57.1, 0.6321916726907697}], 
             PointBox[{57.2, 0.6299183889371638}], 
             PointBox[{57.3, 0.628204168867854}], 
             PointBox[{57.4, 0.6269613156890753}], 
             PointBox[{57.5, 0.6255100469074071}], 
             PointBox[{57.6, 0.6251265985815654}], 
             PointBox[{57.7, 0.6261913071457689}], 
             PointBox[{57.8, 0.6275257253734218}], 
             PointBox[{57.9, 0.6288669292235732}], 
             PointBox[{58., 0.6310443975039602}], 
             PointBox[{58.1, 0.6320952521526781}], 
             PointBox[{58.2, 0.6297521838470869}], 
             PointBox[{58.3, 0.6281052640149662}], 
             PointBox[{58.4, 0.6268627218541908}], 
             PointBox[{58.5, 0.6254152257633947}], 
             PointBox[{58.6, 0.6251332616277221}], 
             PointBox[{58.7, 0.6263078578725259}], 
             PointBox[{58.8, 0.6276208471692623}], 
             PointBox[{58.9, 0.6289962396121513}], 
             PointBox[{59., 0.6312411205475967}], 
             PointBox[{59.1, 0.6319739417079302}], 
             PointBox[{59.2, 0.6295949947754852}], 
             PointBox[{59.3, 0.6280103067597576}], 
             PointBox[{59.4, 0.626763898193568}], 
             PointBox[{59.5, 0.6253330680340581}], 
             PointBox[{59.6, 0.6251545612003034}], 
             PointBox[{59.7, 0.626423845832162}], 
             PointBox[{59.8, 0.6277176263614392}], 
             PointBox[{59.9, 0.6291319854850342}], 
             PointBox[{60., 0.6314344250719645}], 
             PointBox[{60.1, 0.63183191335584}], 
             PointBox[{60.2, 0.6294465188658606}], 
             PointBox[{60.3, 0.6279189913203116}], 
             PointBox[{60.4, 0.6266651802523441}], 
             PointBox[{60.5, 0.6252667631073807}], 
             PointBox[{60.6, 0.6251937769488503}], 
             PointBox[{60.7, 0.6265389489075306}], 
             PointBox[{60.8, 0.6278161914473495}], 
             PointBox[{60.9, 0.6292749766424149}], 
             PointBox[{61., 0.6316206376014678}], 
             PointBox[{61.1, 0.6316737615134603}], 
             PointBox[{61.2, 0.6293068116397788}], 
             PointBox[{61.3, 0.6278311403452154}], 
             PointBox[{61.4, 0.6265655814730624}], 
             PointBox[{61.5, 0.6252180743731299}], 
             PointBox[{61.6, 0.6252518922936363}], 
             PointBox[{61.7, 0.6266527704676409}], 
             PointBox[{61.8, 0.6279167993415645}], 
             PointBox[{61.9, 0.6294257304161828}], 
             PointBox[{62., 0.6317951996835367}], 
             PointBox[{62.1, 0.6315037052084107}], 
             PointBox[{62.2, 0.6291753321062122}], 
             PointBox[{62.3, 0.62774594674982}], 
             PointBox[{62.4, 0.6264652659931139}], 
             PointBox[{62.5, 0.6251866187924446}], 
             PointBox[{62.6, 0.625326780239378}], 
             PointBox[{62.7, 0.6267643586092904}], 
             PointBox[{62.8, 0.6280188341875392}], 
             PointBox[{62.9, 0.6295819876891767}], 
             PointBox[{63., 0.6319538508417114}], 
             PointBox[{63.1, 0.6313261143354633}], 
             PointBox[{63.2, 0.6290515796598269}], 
             PointBox[{63.3, 0.6276629171598386}], 
             PointBox[{63.4, 0.6263643769138015}], 
             PointBox[{63.5, 0.625174285329232}], 
             PointBox[{63.6, 0.6254169444783199}], 
             PointBox[{63.7, 0.6268744718455953}], 
             PointBox[{63.8, 0.6281231471875254}], 
             PointBox[{63.9, 0.6297456455677503}], 
             PointBox[{64., 0.6320922482727134}], 
             PointBox[{64.1, 0.6311445483823801}], 
             PointBox[{64.2, 0.6289349549702961}], 
             PointBox[{64.3, 0.6275817313554778}], 
             PointBox[{64.4, 0.6262631091401072}], 
             PointBox[{64.5, 0.6251753899169392}], 
             PointBox[{64.6, 0.6255188289101931}], 
             PointBox[{64.7, 0.6269821197978492}], 
             PointBox[{64.8, 0.6282289307960657}], 
             PointBox[{64.9, 0.6299157650098026}], 
             PointBox[{65., 0.6322061479310909}], 
             PointBox[{65.1, 0.6309622890831014}], 
             PointBox[{65.2, 0.6288249047996973}], 
             PointBox[{65.3, 0.627502062741373}], 
             PointBox[{65.4, 0.6261612448641952}], 
             PointBox[{65.5, 0.6251867236171011}], 
             PointBox[{65.6, 0.6256297820336693}], 
             PointBox[{65.7, 0.62708763418133}], 
             PointBox[{65.8, 0.6283368723703688}], 
             PointBox[{65.9, 0.6300920292906368}], 
             PointBox[{66., 0.6322925337965671}], 
             PointBox[{66.1, 0.6307819636615242}], 
             PointBox[{66.2, 0.628720901544353}], 
             PointBox[{66.3, 0.6274231691637495}], 
             PointBox[{66.4, 0.6260596638847505}], 
             PointBox[{66.5, 0.6252018165823151}], 
             PointBox[{66.6, 0.625746670640664}], 
             PointBox[{66.7, 0.6271911409921342}], 
             PointBox[{66.8, 0.6284470978384927}], 
             PointBox[{66.9, 0.6302738683310682}], 
             PointBox[{67., 0.6323490542530772}], 
             PointBox[{67.1, 0.63060577866424}], 
             PointBox[{67.2, 0.6286224328050106}], 
             PointBox[{67.3, 0.6273448915187231}], 
             PointBox[{67.4, 0.625959160708103}], 
             PointBox[{67.5, 0.625215694567481}], 
             PointBox[{67.6, 0.6258672809127922}], 
             PointBox[{67.7, 0.6272925996713488}], 
             PointBox[{67.8, 0.6285594014004173}], 
             PointBox[{67.9, 0.630460862489159}], 
             PointBox[{68., 0.6323735732661013}], 
             PointBox[{68.1, 0.630434289367667}], 
             PointBox[{68.2, 0.6285280796169604}], 
             PointBox[{68.3, 0.6272661161496641}], 
             PointBox[{68.4, 0.6258596268960289}], 
             PointBox[{68.5, 0.625225269233854}], 
             PointBox[{68.6, 0.6259885692824704}], 
             PointBox[{68.7, 0.6273913750230188}], 
             PointBox[{68.8, 0.6286738459373178}], 
             PointBox[{68.9, 0.6306506783112844}], 
             PointBox[{69., 0.6323658488065045}], 
             PointBox[{69.1, 0.6302683550741613}], 
             PointBox[{69.2, 0.6284371357719479}], 
             PointBox[{69.3, 0.6271859747142743}], 
             PointBox[{69.4, 0.625762441048767}], 
             PointBox[{69.5, 0.6252304495925021}], 
             PointBox[{69.6, 0.6261092436359652}], 
             PointBox[{69.7, 0.627487953143369}], 
             PointBox[{69.8, 0.6287901125162315}], 
             PointBox[{69.9, 0.6308429405566096}], 
             PointBox[{70., 0.6323273567104799}], 
             PointBox[{70.1, 0.6301090485738252}], 
             PointBox[{70.2, 0.6283495716929424}], 
             PointBox[{70.3, 0.6271048302260762}], 
             PointBox[{70.4, 0.6256693735658754}], 
             PointBox[{70.5, 0.6252341739524692}], 
             PointBox[{70.6, 0.6262282154973507}], 
             PointBox[{70.7, 0.6275826188156424}], 
             PointBox[{70.8, 0.6289093661339474}], 
             PointBox[{70.9, 0.631035811779917}], 
             PointBox[{71., 0.6322590675069644}], 
             PointBox[{71.1, 0.6299557515669834}], 
             PointBox[{71.2, 0.628263994937003}], 
             PointBox[{71.3, 0.6270217438386502}], 
             PointBox[{71.4, 0.6255815493469358}], 
             PointBox[{71.5, 0.6252415531655232}], 
             PointBox[{71.6, 0.6263440936454611}], 
             PointBox[{71.7, 0.6276751569100288}], 
             PointBox[{71.8, 0.629030980494339}], 
             PointBox[{71.9, 0.6312270523312682}], 
             PointBox[{72., 0.6321639778209136}], 
             PointBox[{72.1, 0.6298085960426809}], 
             PointBox[{72.2, 0.6281800245035092}], 
             PointBox[{72.3, 0.6269359110990558}], 
             PointBox[{72.4, 0.6255009080697694}], 
             PointBox[{72.5, 0.6252563771961219}], 
             PointBox[{72.6, 0.6264562499373505}], 
             PointBox[{72.7, 0.6277657187574284}], 
             PointBox[{72.8, 0.6291552435104566}], 
             PointBox[{72.9, 0.6314140012317511}], 
             PointBox[{73., 0.6320452293690266}], 
             PointBox[{73.1, 0.6296670682012698}], 
             PointBox[{73.2, 0.6280967183779814}], 
             PointBox[{73.3, 0.6268466468677913}], 
             PointBox[{73.4, 0.6254294998420454}], 
             PointBox[{73.5, 0.6252827760910623}], 
             PointBox[{73.6, 0.62656449834113}], 
             PointBox[{73.7, 0.6278548387574174}], 
             PointBox[{73.8, 0.6292831847335976}], 
             PointBox[{73.9, 0.6315947224525338}], 
             PointBox[{74., 0.6319066508043297}], 
             PointBox[{74.1, 0.6295309787030017}], 
             PointBox[{74.2, 0.6280141730849096}], 
             PointBox[{74.3, 0.6267541225047375}], 
             PointBox[{74.4, 0.625369274019317}], 
             PointBox[{74.5, 0.6253221916119966}], 
             PointBox[{74.6, 0.6266684959377312}], 
             PointBox[{74.7, 0.6279426629477582}], 
             PointBox[{74.8, 0.6294142786422485}], 
             PointBox[{74.9, 0.6317651127918122}], 
             PointBox[{75., 0.6317516315075276}], 
             PointBox[{75.1, 0.6293996767090269}], 
             PointBox[{75.2, 0.6279309703064265}], 
             PointBox[{75.3, 0.6266579847413299}], 
             PointBox[{75.4, 0.6253217540174428}], 
             PointBox[{75.5, 0.6253750131614677}], 
             PointBox[{75.6, 0.6267682756108779}], 
             PointBox[{75.7, 0.6280293801049174}], 
             PointBox[{75.8, 0.6295497580074735}], 
             PointBox[{75.9, 0.6319223440485449}], 
             PointBox[{76., 0.631584099436863}], 
             PointBox[{76.1, 0.6292729152195575}], 
             PointBox[{76.2, 0.627847536750531}], 
             PointBox[{76.3, 0.6265584467434923}], 
             PointBox[{76.4, 0.6252877497285801}], 
             PointBox[{76.5, 0.6254404903846223}], 
             PointBox[{76.6, 0.6268643389653361}], 
             PointBox[{76.7, 0.6281158757521951}], 
             PointBox[{76.8, 0.6296896472280773}], 
             PointBox[{76.9, 0.6320629241702396}], 
             PointBox[{77., 0.6314072015558978}], 
             PointBox[{77.1, 0.6291498878154871}], 
             PointBox[{77.2, 0.6277626404687076}], 
             PointBox[{77.3, 0.626454308511872}], 
             PointBox[{77.4, 0.625266382968329}], 
             PointBox[{77.5, 0.6255164902731436}], 
             PointBox[{77.6, 0.6269563323812944}], 
             PointBox[{77.7, 0.6282020553726341}], 
             PointBox[{77.8, 0.6298342395281944}], 
             PointBox[{77.9, 0.6321827216241692}], 
             PointBox[{78., 0.6312241678004362}], 
             PointBox[{78.1, 0.6290302096922418}], 
             PointBox[{78.2, 0.6276765104581228}], 
             PointBox[{78.3, 0.6263466530246877}], 
             PointBox[{78.4, 0.6252560412771496}], 
             PointBox[{78.5, 0.6256009810574681}], 
             PointBox[{78.6, 0.6270447859628991}], 
             PointBox[{78.7, 0.6282886883545105}], 
             PointBox[{78.8, 0.6299842618211589}], 
             PointBox[{78.9, 0.6322785712299237}], 
             PointBox[{79., 0.631037542908167}], 
             PointBox[{79.1, 0.6289135252861693}], 
             PointBox[{79.2, 0.6275883913574765}], 
             PointBox[{79.3, 0.6262349045003311}], 
             PointBox[{79.4, 0.6252522895530785}], 
             PointBox[{79.5, 0.6256920608275448}], 
             PointBox[{79.6, 0.6271301089714142}], 
             PointBox[{79.7, 0.6283764337217993}], 
             PointBox[{79.8, 0.6301391635863934}], 
             PointBox[{79.9, 0.6323477037583316}], 
             PointBox[{80., 0.6308493981042413}], 
             PointBox[{80.1, 0.628799287958849}], 
             PointBox[{80.2, 0.6274981662691156}], 
             PointBox[{80.3, 0.6261210614080192}], 
             PointBox[{80.4, 0.6252515234514122}], 
             PointBox[{80.5, 0.6257875547623808}], 
             PointBox[{80.6, 0.6272127369878295}], 
             PointBox[{80.7, 0.6284654581381739}], 
             PointBox[{80.8, 0.6302996352588817}], 
             PointBox[{80.9, 0.6323862371197548}], 
             PointBox[{81., 0.6306615761635831}], 
             PointBox[{81.1, 0.6286868717631054}], 
             PointBox[{81.2, 0.6274050784205537}], 
             PointBox[{81.3, 0.6260035600783177}], 
             PointBox[{81.4, 0.6252480770474017}], 
             PointBox[{81.5, 0.6258858698800032}], 
             PointBox[{81.6, 0.6272931456617714}], 
             PointBox[{81.7, 0.6285567529219107}], 
             PointBox[{81.8, 0.630465336157734}], 
             PointBox[{81.9, 0.6323947516753584}], 
             PointBox[{82., 0.6304759649095362}], 
             PointBox[{82.1, 0.6285765850982363}], 
             PointBox[{82.2, 0.627310009143674}], 
             PointBox[{82.3, 0.625885663217914}], 
             PointBox[{82.4, 0.6252406693921723}], 
             PointBox[{82.5, 0.6259860849622092}], 
             PointBox[{82.6, 0.6273722478789228}], 
             PointBox[{82.7, 0.6286509300563652}], 
             PointBox[{82.8, 0.6306362937010711}], 
             PointBox[{82.9, 0.632370976418707}], 
             PointBox[{83., 0.630293523068971}], 
             PointBox[{83.1, 0.6284680379562758}], 
             PointBox[{83.2, 0.6272120892393841}], 
             PointBox[{83.3, 0.6257683917613023}], 
             PointBox[{83.4, 0.6252278060870233}], 
             PointBox[{83.5, 0.6260865502140683}], 
             PointBox[{83.6, 0.62745001465485}], 
             PointBox[{83.7, 0.628748914469027}], 
             PointBox[{83.8, 0.630811155839414}], 
             PointBox[{83.9, 0.6323152543335193}], 
             PointBox[{84., 0.6301151708785787}], 
             PointBox[{84.1, 0.6283606914183918}], 
             PointBox[{84.2, 0.6271112917204208}], 
             PointBox[{84.3, 0.6256539376611816}], 
             PointBox[{84.4, 0.6252133070114959}], 
             PointBox[{84.5, 0.6261867983611337}], 
             PointBox[{84.6, 0.6275275495117261}], 
             PointBox[{84.7, 0.6288512387602029}], 
             PointBox[{84.8, 0.6309889648603644}], 
             PointBox[{84.9, 0.6322299684865086}], 
             PointBox[{85., 0.6299415022063583}], 
             PointBox[{85.1, 0.6282547043760007}], 
             PointBox[{85.2, 0.6270075387169616}], 
             PointBox[{85.3, 0.6255441884820238}], 
             PointBox[{85.4, 0.6252021334697159}], 
             PointBox[{85.5, 0.6262863408350269}], 
             PointBox[{85.6, 0.627604904679983}], 
             PointBox[{85.7, 0.6289586591870958}], 
             PointBox[{85.8, 0.63116816715813}], 
             PointBox[{85.9, 0.6321166794178142}], 
             PointBox[{86., 0.6297732699986635}], 
             PointBox[{86.1, 0.6281500093759559}], 
             PointBox[{86.2, 0.6269004647914596}], 
             PointBox[{86.3, 0.6254423531146395}], 
             PointBox[{86.4, 0.6251997584632862}], 
             PointBox[{86.5, 0.6263850378427918}], 
             PointBox[{86.6, 0.6276831718706594}], 
             PointBox[{86.7, 0.6290718051797489}], 
             PointBox[{86.8, 0.6313461591340819}], 
             PointBox[{86.9, 0.6319791463623049}], 
             PointBox[{87., 0.6296106131473543}], 
             PointBox[{87.1, 0.6280464038246182}], 
             PointBox[{87.2, 0.6267909851499942}], 
             PointBox[{87.3, 0.625351564979271}], 
             PointBox[{87.4, 0.6252109192445888}], 
             PointBox[{87.5, 0.6264824594766576}], 
             PointBox[{87.6, 0.6277626459458338}], 
             PointBox[{87.7, 0.6291918018112386}], 
             PointBox[{87.8, 0.631520183077752}], 
             PointBox[{87.9, 0.6318210321236379}], 
             PointBox[{88., 0.6294538772986349}], 
             PointBox[{88.1, 0.6279439551415659}], 
             PointBox[{88.2, 0.6266790196705138}], 
             PointBox[{88.3, 0.62527444263742}], 
             PointBox[{88.4, 0.6252383970529054}], 
             PointBox[{88.5, 0.626578976100028}], 
             PointBox[{88.6, 0.6278441122483992}], 
             PointBox[{88.7, 0.6293193205905613}], 
             PointBox[{88.8, 0.6316864147925034}], 
             PointBox[{88.9, 0.631646587400848}], 
             PointBox[{89., 0.6293032996598641}], 
             PointBox[{89.1, 0.6278425825036512}], 
             PointBox[{89.2, 0.6265639991237035}], 
             PointBox[{89.3, 0.6252137530987832}], 
             PointBox[{89.4, 0.6252831759260113}], 
             PointBox[{89.5, 0.6266744774795953}], 
             PointBox[{89.6, 0.6279279285894396}], 
             PointBox[{89.7, 0.6294541340795905}], 
             PointBox[{89.8, 0.6318412666138488}], 
             PointBox[{89.9, 0.6314601323988024}], 
             PointBox[{90., 0.6291589670281746}], 
             PointBox[{90.1, 0.6277424483401086}], 
             PointBox[{90.2, 0.6264476948249466}], 
             PointBox[{90.3, 0.625170770330138}], 
             PointBox[{90.4, 0.6253449604504022}], 
             PointBox[{90.5, 0.6267693582730601}], 
             PointBox[{90.6, 0.6280148144824339}], 
             PointBox[{90.7, 0.6295975835326599}], 
             PointBox[{90.8, 0.6319801397858834}], 
             PointBox[{90.9, 0.6312654725360427}], 
             PointBox[{91., 0.6290206788068567}], 
             PointBox[{91.1, 0.6276433318541823}], 
             PointBox[{91.2, 0.6263293866396245}], 
             PointBox[{91.3, 0.6251450094032788}], 
             PointBox[{91.4, 0.625421749178394}], 
             PointBox[{91.5, 0.6268637652709697}], 
             PointBox[{91.6, 0.6281051405039517}], 
             PointBox[{91.7, 0.6297498906358433}], 
             PointBox[{91.8, 0.6320983612877615}], 
             PointBox[{91.9, 0.6310668176554908}], 
             PointBox[{92., 0.6288886210091138}], 
             PointBox[{92.1, 0.6275452777469785}], 
             PointBox[{92.2, 0.6262093947656503}], 
             PointBox[{92.3, 0.6251339158396614}], 
             PointBox[{92.4, 0.6255115983749816}], 
             PointBox[{92.5, 0.6269579465229389}], 
             PointBox[{92.6, 0.6281995505736464}], 
             PointBox[{92.7, 0.62991130922246}], 
             PointBox[{92.8, 0.6321923419997983}], 
             PointBox[{92.9, 0.6308673830259482}], 
             PointBox[{93., 0.6287626291822278}], 
             PointBox[{93.1, 0.6274482223326767}], 
             PointBox[{93.2, 0.6260894767983626}], 
             PointBox[{93.3, 0.6251325861680909}], 
             PointBox[{93.4, 0.6256115716635974}], 
             PointBox[{93.5, 0.6270521299367073}], 
             PointBox[{93.6, 0.6282980758735782}], 
             PointBox[{93.7, 0.6300812585284722}], 
             PointBox[{93.8, 0.6322579136055524}], 
             PointBox[{93.9, 0.6306699544483019}], 
             PointBox[{94., 0.6286424681261874}], 
             PointBox[{94.1, 0.6273520931046772}], 
             PointBox[{94.2, 0.625969883963559}], 
             PointBox[{94.3, 0.6251355686279306}], 
             PointBox[{94.4, 0.6257195111859242}], 
             PointBox[{94.5, 0.6271465145014455}], 
             PointBox[{94.6, 0.6284018055802644}], 
             PointBox[{94.7, 0.6302597087640565}], 
             PointBox[{94.8, 0.6322933877433136}], 
             PointBox[{94.9, 0.6304769592808969}], 
             PointBox[{95., 0.6285280092484813}], 
             PointBox[{95.1, 0.6272567313423718}], 
             PointBox[{95.2, 0.6258523867653355}], 
             PointBox[{95.3, 0.6251375237064026}], 
             PointBox[{95.4, 0.6258331592229144}], 
             PointBox[{95.5, 0.6272413496381763}], 
             PointBox[{95.6, 0.6285097814640275}], 
             PointBox[{95.7, 0.6304457272756352}], 
             PointBox[{95.8, 0.6322964585266395}], 
             PointBox[{95.9, 0.6302901553406737}], 
             PointBox[{96., 0.6284190035922119}], 
             PointBox[{96.1, 0.6271620498551731}], 
             PointBox[{96.2, 0.6257384111326935}], 
             PointBox[{96.3, 0.6251359863139266}], 
             PointBox[{96.4, 0.6259505113661853}], 
             PointBox[{96.5, 0.627336806409107}], 
             PointBox[{96.6, 0.6286241102411907}], 
             PointBox[{96.7, 0.6306380777558349}], 
             PointBox[{96.8, 0.6322667679434766}], 
             PointBox[{96.9, 0.6301107469444536}], 
             PointBox[{97., 0.6283151504520813}], 
             PointBox[{97.1, 0.62706791456341}], 
             PointBox[{97.2, 0.625629732837334}], 
             PointBox[{97.3, 0.6251337023793091}], 
             PointBox[{97.4, 0.6260699343826621}], 
             PointBox[{97.5, 0.627433004371446}], 
             PointBox[{97.6, 0.6287431811302752}], 
             PointBox[{97.7, 0.6308350621510388}], 
             PointBox[{97.8, 0.632206173130412}], 
             PointBox[{97.9, 0.6299396235730527}], 
             PointBox[{98., 0.6282161065510056}], 
             PointBox[{98.1, 0.6269741075109452}], 
             PointBox[{98.2, 0.6255285421281975}], 
             PointBox[{98.3, 0.6251338383273123}], 
             PointBox[{98.4, 0.6261901238305466}], 
             PointBox[{98.5, 0.6275301272339404}], 
             PointBox[{98.6, 0.6288685751680253}], 
             PointBox[{98.7, 0.6310345349473232}], 
             PointBox[{98.8, 0.6321172289500661}], 
             PointBox[{98.9, 0.6297772737047116}], 
             PointBox[{99., 0.6281214999406219}], 
             PointBox[{99.1, 0.6268803219246503}], 
             PointBox[{99.2, 0.6254372910652852}], 
             PointBox[{99.3, 0.6251434471950595}], 
             PointBox[{99.4, 0.6263101114822107}], 
             PointBox[{99.5, 0.6276282629365149}], 
             PointBox[{99.6, 0.6289999987964845}], 
             PointBox[{99.7, 0.6312337571467997}], 
             PointBox[{99.8, 0.6320028525361713}], 
             PointBox[{99.9, 0.6296238839817937}], 
             PointBox[{100., 0.6280310025039963}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0.6, 0.65}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], 
             PointBox[{0, 0.12838599999999997`}], 
             PointBox[{0.1, 0.13152194666206846`}], 
             PointBox[{0.2, 0.1316563374627984}], 
             PointBox[{0.3, 0.12959517922368982`}], 
             PointBox[{0.4, 0.13000519748419267`}], 
             PointBox[{0.5, 0.13385964382219862`}], 
             PointBox[{0.6, 0.1297720236103665}], 
             PointBox[{0.7, 0.1297217005105911}], 
             PointBox[{0.8, 0.13177452296912948`}], 
             PointBox[{0.9, 0.1313073722194011}], 
             PointBox[{1., 0.12841657493830716`}], 
             PointBox[{1.1, 0.13171547889091897`}], 
             PointBox[{1.2, 0.13153857678786818`}], 
             PointBox[{1.3, 0.12948941241697162`}], 
             PointBox[{1.4, 0.1302850283400506}], 
             PointBox[{1.5, 0.13379014350206456`}], 
             PointBox[{1.6, 0.12958654402001124`}], 
             PointBox[{1.7, 0.12986773573759847`}], 
             PointBox[{1.8, 0.13189115749623928`}], 
             PointBox[{1.9, 0.1310739060236639}], 
             PointBox[{2., 0.12850940572291975`}], 
             PointBox[{2.1, 0.13188772687512526`}], 
             PointBox[{2.2, 0.13142293451705347`}], 
             PointBox[{2.3, 0.12940686919098768`}], 
             PointBox[{2.4, 0.13060996554324025`}], 
             PointBox[{2.5, 0.13365509039569154`}], 
             PointBox[{2.6, 0.1294487117901592}], 
             PointBox[{2.7, 0.13003171896035873`}], 
             PointBox[{2.8, 0.13200594677085797`}], 
             PointBox[{2.9, 0.13082466050594316`}], 
             PointBox[{3., 0.1286639637616213}], 
             PointBox[{3.1, 0.13203848078815317`}], 
             PointBox[{3.2, 0.13131014925386372`}], 
             PointBox[{3.3, 0.12934878878082595`}], 
             PointBox[{3.4, 0.13097576313588957`}], 
             PointBox[{3.5, 0.13346187839808826`}], 
             PointBox[{3.6, 0.12935710229188274`}], 
             PointBox[{3.7, 0.13021199975740008`}], 
             PointBox[{3.8, 0.13211576776133105`}], 
             PointBox[{3.9, 0.13056472637115932`}], 
             PointBox[{4., 0.12887811168500957`}], 
             PointBox[{4.1, 0.13216777549477826`}], 
             PointBox[{4.2, 0.131200941091498}], 
             PointBox[{4.3, 0.12931707473793327`}], 
             PointBox[{4.4, 0.13137640820766175`}], 
             PointBox[{4.5, 0.133219062830096}], 
             PointBox[{4.6, 0.1293093873248356}], 
             PointBox[{4.7, 0.13040603551575286`}], 
             PointBox[{4.8, 0.13221743370473946`}], 
             PointBox[{4.9, 0.13029954512458145`}], 
             PointBox[{5., 0.12914670712765333`}], 
             PointBox[{5.1, 0.13227572677623448`}], 
             PointBox[{5.2, 0.13109533788281164`}], 
             PointBox[{5.3, 0.129313103636764}], 
             PointBox[{5.4, 0.13180268477002277`}], 
             PointBox[{5.5, 0.13293712192902282`}], 
             PointBox[{5.6, 0.12930228529157986`}], 
             PointBox[{5.7, 0.13061150900391996`}], 
             PointBox[{5.8, 0.13230749543078513`}], 
             PointBox[{5.9, 0.13003649577515958`}], 
             PointBox[{6., 0.12946144845618962`}], 
             PointBox[{6.1, 0.132362518235856}], 
             PointBox[{6.2, 0.13099286413613043`}], 
             PointBox[{6.3, 0.1293385101130139}], 
             PointBox[{6.4, 0.13224393482071584`}], 
             PointBox[{6.5, 0.13262866381967053`}], 
             PointBox[{6.6, 0.12933246287458808`}], 
             PointBox[{6.7, 0.13082568685585116`}], 
             PointBox[{6.8, 0.13238292267697221`}], 
             PointBox[{6.9, 0.12978481908021156`}], 
             PointBox[{7., 0.12981150799641222`}], 
             PointBox[{7.1, 0.13242837239348457`}], 
             PointBox[{7.2, 0.13089378207579075`}], 
             PointBox[{7.3, 0.12939378311813807`}], 
             PointBox[{7.4, 0.13268706338201172`}], 
             PointBox[{7.5, 0.13230530515559208`}], 
             PointBox[{7.6, 0.12939574585950592`}], 
             PointBox[{7.7, 0.13104566650827865`}], 
             PointBox[{7.8, 0.1324388411914163}], 
             PointBox[{7.9, 0.12955447351478164`}], 
             PointBox[{8., 0.1301844681083588}], 
             PointBox[{8.1, 0.1324735713519455}], 
             PointBox[{8.2, 0.13079727735066046`}], 
             PointBox[{8.3, 0.12948088233069444`}], 
             PointBox[{8.4, 0.13311666664674796`}], 
             PointBox[{8.5, 0.13197916446516972`}], 
             PointBox[{8.6, 0.12948883870657846`}], 
             PointBox[{8.7, 0.13126881645431354`}], 
             PointBox[{8.8, 0.13247169559763308`}], 
             PointBox[{8.9, 0.129355682164761}], 
             PointBox[{9., 0.13056726536217245`}], 
             PointBox[{9.1, 0.13249838627436206`}], 
             PointBox[{9.2, 0.1307034783947848}], 
             PointBox[{9.3, 0.12960143553616005`}], 
             PointBox[{9.4, 0.1335168790931208}], 
             PointBox[{9.5, 0.1316601032836814}], 
             PointBox[{9.6, 0.12960699594286149`}], 
             PointBox[{9.7, 0.13149162652333227`}], 
             PointBox[{9.8, 0.13247656961523716`}], 
             PointBox[{9.9, 0.12919663484594393`}], 
             PointBox[{10., 0.1309472534909155}], 
             PointBox[{10.1, 0.13250311905898413`}], 
             PointBox[{10.2, 0.13061183754518768`}], 
             PointBox[{10.3, 0.12975659556389235`}], 
             PointBox[{10.4, 0.13387102043733945`}], 
             PointBox[{10.5, 0.13135739784893238`}], 
             PointBox[{10.6, 0.12974650642383964`}], 
             PointBox[{10.7, 0.13171079199560456`}], 
             PointBox[{10.8, 0.1324498301770732}], 
             PointBox[{10.9, 0.12908452502498552`}], 
             PointBox[{11., 0.13131290585715974`}], 
             PointBox[{11.1, 0.13248760217966501`}], 
             PointBox[{11.2, 0.13052220183752564`}], 
             PointBox[{11.3, 0.12994730718580783`}], 
             PointBox[{11.4, 0.1341621627816046}], 
             PointBox[{11.5, 0.13107774281426737`}], 
             PointBox[{11.6, 0.129903076525852}], 
             PointBox[{11.7, 0.1319234617336822}], 
             PointBox[{11.8, 0.13238743864294325`}], 
             PointBox[{11.9, 0.12902230711842502`}], 
             PointBox[{12., 0.13165470186003933`}], 
             PointBox[{12.1, 0.13245205544444916`}], 
             PointBox[{12.2, 0.1304344734377745}], 
             PointBox[{12.3, 0.1301744655486561}], 
             PointBox[{12.4, 0.13437798228273662`}], 
             PointBox[{12.5, 0.13082632951321752`}], 
             PointBox[{12.6, 0.13007251648145138`}], 
             PointBox[{12.7, 0.1321256341199981}], 
             PointBox[{12.8, 0.13228640507965778`}], 
             PointBox[{12.9, 0.12901048466152468`}], 
             PointBox[{13., 0.13196493891088734`}], 
             PointBox[{13.1, 0.13239714096216088`}], 
             PointBox[{13.2, 0.13034966009896018`}], 
             PointBox[{13.3, 0.13043747153367347`}], 
             PointBox[{13.4, 0.1345067579480802}], 
             PointBox[{13.5, 0.13060634700884594`}], 
             PointBox[{13.6, 0.13025168704505646`}], 
             PointBox[{13.7, 0.13231398844407138`}], 
             PointBox[{13.8, 0.13214457695797185`}], 
             PointBox[{13.9, 0.12904710099933395`}], 
             PointBox[{14., 0.13223771167963755`}], 
             PointBox[{14.1, 0.13232279600218047`}], 
             PointBox[{14.2, 0.13026741118865795`}], 
             PointBox[{14.3, 0.13073569020150355`}], 
             PointBox[{14.4, 0.1345424762162907}], 
             PointBox[{14.5, 0.13041897337709465`}], 
             PointBox[{14.6, 0.13043595153268986`}], 
             PointBox[{14.7, 0.132485306804487}], 
             PointBox[{14.8, 0.1319612134721859}], 
             PointBox[{14.9, 0.12913107133262555`}], 
             PointBox[{15., 0.13246894466411485`}], 
             PointBox[{15.1, 0.13222935532078128`}], 
             PointBox[{15.2, 0.13018913979351723`}], 
             PointBox[{15.3, 0.13106687579036225`}], 
             PointBox[{15.4, 0.13448420107317643`}], 
             PointBox[{15.5, 0.13026458240551592`}], 
             PointBox[{15.6, 0.1306227506171739}], 
             PointBox[{15.7, 0.1326357908911194}], 
             PointBox[{15.8, 0.1317374969346222}], 
             PointBox[{15.9, 0.1292619620816215}], 
             PointBox[{16., 0.1326565043230766}], 
             PointBox[{16.1, 0.13211806090192546`}], 
             PointBox[{16.2, 0.13011620650681668`}], 
             PointBox[{16.3, 0.13142696321919523`}], 
             PointBox[{16.4, 0.13433487679825676`}], 
             PointBox[{16.5, 0.13014186489655177`}], 
             PointBox[{16.6, 0.13080868641999047`}], 
             PointBox[{16.7, 0.13276198772602954`}], 
             PointBox[{16.8, 0.13147673232967647`}], 
             PointBox[{16.9, 0.1294382149520655}], 
             PointBox[{17., 0.13279932912713335`}], 
             PointBox[{17.1, 0.13198901452363468`}], 
             PointBox[{17.2, 0.13005110346599003`}], 
             PointBox[{17.3, 0.1318097118431683}], 
             PointBox[{17.4, 0.13410337736796335`}], 
             PointBox[{17.5, 0.13004910569631456`}], 
             PointBox[{17.6, 0.13099116052937726`}], 
             PointBox[{17.7, 0.13286106199992895`}], 
             PointBox[{17.8, 0.131185105178444}], 
             PointBox[{17.9, 0.1296565691659563}], 
             PointBox[{18., 0.13289792000489967`}], 
             PointBox[{18.1, 0.13184394086640075`}], 
             PointBox[{18.2, 0.12999558377469422`}], 
             PointBox[{18.3, 0.13220739897056358`}], 
             PointBox[{18.4, 0.13380145348324057`}], 
             PointBox[{18.5, 0.1299835079570703}], 
             PointBox[{18.6, 0.1311673123828926}], 
             PointBox[{18.7, 0.13292982001999273`}], 
             PointBox[{18.8, 0.1308706715605631}], 
             PointBox[{18.9, 0.12991118042710526`}], 
             PointBox[{19., 0.13295345207435508`}], 
             PointBox[{19.1, 0.13168383035399572`}], 
             PointBox[{19.2, 0.12995174624242967`}], 
             PointBox[{19.3, 0.1326094512626441}], 
             PointBox[{19.4, 0.1334443364497979}], 
             PointBox[{19.5, 0.12994259697209223`}], 
             PointBox[{19.6, 0.1313354647022849}], 
             PointBox[{19.7, 0.13296530609814947`}], 
             PointBox[{19.8, 0.13054467802332426`}], 
             PointBox[{19.9, 0.1301928363364809}], 
             PointBox[{20., 0.13296821216990906`}], 
             PointBox[{20.1, 0.13151071346109441`}], 
             PointBox[{20.2, 0.12992329331103492`}], 
             PointBox[{20.3, 0.1330035793253429}], 
             PointBox[{20.4, 0.13304813734804205`}], 
             PointBox[{20.5, 0.1299232875368943}], 
             PointBox[{20.6, 0.1314937036643119}], 
             PointBox[{20.7, 0.13296524624654085`}], 
             PointBox[{20.8, 0.13021967549522756`}], 
             PointBox[{20.9, 0.13048901827094458`}], 
             PointBox[{21., 0.13294439427923438`}], 
             PointBox[{21.1, 0.13132617815195338`}], 
             PointBox[{21.2, 0.1299131241662458}], 
             PointBox[{21.3, 0.1333751867328834}], 
             PointBox[{21.4, 0.13262866154616398`}], 
             PointBox[{21.5, 0.12992251127576232`}], 
             PointBox[{21.6, 0.13164003945591915`}], 
             PointBox[{21.7, 0.13292711730398404`}], 
             PointBox[{21.8, 0.12990853376618544`}], 
             PointBox[{21.9, 0.13078775538830822`}], 
             PointBox[{22., 0.1328855555872885}], 
             PointBox[{22.1, 0.13113260954757183`}], 
             PointBox[{22.2, 0.12992497916050968`}], 
             PointBox[{22.3, 0.133710006389511}], 
             PointBox[{22.4, 0.13220097583616608`}], 
             PointBox[{22.5, 0.12993778319808721`}], 
             PointBox[{22.6, 0.13177418619109565`}], 
             PointBox[{22.7, 0.13284924476902962`}], 
             PointBox[{22.8, 0.12962417104596433`}], 
             PointBox[{22.9, 0.13107671220436623`}], 
             PointBox[{23., 0.13279474241186487`}], 
             PointBox[{23.1, 0.13093224763874703`}], 
             PointBox[{23.2, 0.12996194657087856`}], 
             PointBox[{23.3, 0.13399187198114126`}], 
             PointBox[{23.4, 0.1317784614261312}], 
             PointBox[{23.5, 0.12996653731487043`}], 
             PointBox[{23.6, 0.1318946921111864}], 
             PointBox[{23.7, 0.1327305790207622}], 
             PointBox[{23.8, 0.12937651006827636`}], 
             PointBox[{23.9, 0.13134579745338987`}], 
             PointBox[{24., 0.13267566534922173`}], 
             PointBox[{24.1, 0.13072820376094732`}], 
             PointBox[{24.2, 0.13002753364920544`}], 
             PointBox[{24.3, 0.13420797237798776`}], 
             PointBox[{24.4, 0.13137213627027927`}], 
             PointBox[{24.5, 0.1300069415525443}], 
             PointBox[{24.6, 0.1320009445882247}], 
             PointBox[{24.7, 0.1325706183212571}], 
             PointBox[{24.8, 0.12917306225536554`}], 
             PointBox[{24.9, 0.1315872663351731}], 
             PointBox[{25., 0.132532214356959}], 
             PointBox[{25.1, 0.13052315911448467`}], 
             PointBox[{25.2, 0.13012494790600107`}], 
             PointBox[{25.3, 0.13434613403329326`}], 
             PointBox[{25.4, 0.13099084296293637`}], 
             PointBox[{25.5, 0.13005728850012677`}], 
             PointBox[{25.6, 0.1320930862249099}], 
             PointBox[{25.7, 0.1323698261532206}], 
             PointBox[{25.8, 0.1290165848705013}], 
             PointBox[{25.9, 0.131795715703944}], 
             PointBox[{26., 0.132368039343116}], 
             PointBox[{26.1, 0.13032047545627357`}], 
             PointBox[{26.2, 0.1302561914319324}], 
             PointBox[{26.3, 0.13439925079758816`}], 
             PointBox[{26.4, 0.1306408546662235}], 
             PointBox[{26.5, 0.13011613366175695`}], 
             PointBox[{26.6, 0.1321698004348548}], 
             PointBox[{26.7, 0.13212939311804672`}], 
             PointBox[{26.8, 0.12891043661241122`}], 
             PointBox[{26.9, 0.13196824880726646`}], 
             PointBox[{27., 0.13218703764722226`}], 
             PointBox[{27.1, 0.13012360216955746`}], 
             PointBox[{27.2, 0.13042318429963007`}], 
             PointBox[{27.3, 0.134363504632502}], 
             PointBox[{27.4, 0.13032666999378598`}], 
             PointBox[{27.5, 0.13018271530706388`}], 
             PointBox[{27.6, 0.13223281414523966`}], 
             PointBox[{27.7, 0.13185210543502696`}], 
             PointBox[{27.8, 0.12885421247133902`}], 
             PointBox[{27.9, 0.13210415225913574`}], 
             PointBox[{28., 0.13199298279779742`}], 
             PointBox[{28.1, 0.12993602192514828`}], 
             PointBox[{28.2, 0.1306263863261076}], 
             PointBox[{28.3, 0.13423985684768902`}], 
             PointBox[{28.4, 0.13005096454976756`}], 
             PointBox[{28.5, 0.130256439259612}], 
             PointBox[{28.6, 0.13227989326540368`}], 
             PointBox[{28.7, 0.13154196131893722`}], 
             PointBox[{28.8, 0.12885048183430525`}], 
             PointBox[{28.9, 0.13220433702603998`}], 
             PointBox[{29., 0.13178954862255488`}], 
             PointBox[{29.1, 0.12976139620222987`}], 
             PointBox[{29.2, 0.13086478954653266`}], 
             PointBox[{29.3, 0.13403552158265056`}], 
             PointBox[{29.4, 0.12981509343304382`}], 
             PointBox[{29.5, 0.1303370599347134}], 
             PointBox[{29.6, 0.1323135413335269}], 
             PointBox[{29.7, 0.1312043355619112}], 
             PointBox[{29.8, 0.1289009089263708}], 
             PointBox[{29.9, 0.1322709539093704}], 
             PointBox[{30., 0.1315802879659247}], 
             PointBox[{30.1, 0.12960357897758482`}], 
             PointBox[{30.2, 0.1311358839817626}], 
             PointBox[{30.3, 0.13375873349328793`}], 
             PointBox[{30.4, 0.12961934724996638`}], 
             PointBox[{30.5, 0.13042431875475036`}], 
             PointBox[{30.6, 0.13233153437342743`}], 
             PointBox[{30.7, 0.13084687331403771`}], 
             PointBox[{30.8, 0.12900504286929626`}], 
             PointBox[{30.9, 0.132306991064313}], 
             PointBox[{31., 0.1313685440864738}], 
             PointBox[{31.1, 0.12946650119427333`}], 
             PointBox[{31.2, 0.13143518369054227`}], 
             PointBox[{31.3, 0.13342376213747334`}], 
             PointBox[{31.4, 0.12946321359130164`}], 
             PointBox[{31.5, 0.13051812317503492`}], 
             PointBox[{31.6, 0.13233542639169932`}], 
             PointBox[{31.7, 0.13047842911132201`}], 
             PointBox[{31.8, 0.1291605345687171}], 
             PointBox[{31.9, 0.13231605280468792`}], 
             PointBox[{32., 0.1311574903676441}], 
             PointBox[{32.1, 0.12935393720479338`}], 
             PointBox[{32.2, 0.13175667492096155`}], 
             PointBox[{32.3, 0.1330446523520809}], 
             PointBox[{32.4, 0.12934577265826985`}], 
             PointBox[{32.5, 0.13061916360733042`}], 
             PointBox[{32.6, 0.1323240318645982}], 
             PointBox[{32.7, 0.13010953706192363`}], 
             PointBox[{32.8, 0.1293619344556918}], 
             PointBox[{32.9, 0.13230216253769395`}], 
             PointBox[{33., 0.13095027245401225`}], 
             PointBox[{33.1, 0.12926994941173894`}], 
             PointBox[{33.2, 0.13209215555664774`}], 
             PointBox[{33.3, 0.13263784081376626`}], 
             PointBox[{33.4, 0.1292657301558782}], 
             PointBox[{33.5, 0.13072744883643034`}], 
             PointBox[{33.6, 0.13229792765906892`}], 
             PointBox[{33.7, 0.1297519465853703}], 
             PointBox[{33.8, 0.12960057897418736`}], 
             PointBox[{33.9, 0.13226864849098166`}], 
             PointBox[{34., 0.13074931755541902`}], 
             PointBox[{34.1, 0.12921798795960038`}], 
             PointBox[{34.2, 0.1324314797886258}], 
             PointBox[{34.3, 0.13221816464302166`}], 
             PointBox[{34.4, 0.12922131532048536`}], 
             PointBox[{34.5, 0.13084260146606366`}], 
             PointBox[{34.6, 0.1322554226680197}], 
             PointBox[{34.7, 0.12941770617117188`}], 
             PointBox[{34.8, 0.12986651638180016`}], 
             PointBox[{34.9, 0.13221930841395738`}], 
             PointBox[{35., 0.13055698728788837`}], 
             PointBox[{35.1, 0.12920154286483887`}], 
             PointBox[{35.2, 0.13276306622131817`}], 
             PointBox[{35.3, 0.13180032354516982`}], 
             PointBox[{35.4, 0.12921090465309257`}], 
             PointBox[{35.5, 0.13096478027134786`}], 
             PointBox[{35.6, 0.13219658841771992`}], 
             PointBox[{35.7, 0.12911911793757694`}], 
             PointBox[{35.8, 0.13014975797547626`}], 
             PointBox[{35.9, 0.13215769143760628`}], 
             PointBox[{36., 0.13037562766395652`}], 
             PointBox[{36.1, 0.12922411793154556`}], 
             PointBox[{36.2, 0.13307477090257971`}], 
             PointBox[{36.3, 0.13139697504738804`}], 
             PointBox[{36.4, 0.12923263143186234`}], 
             PointBox[{36.5, 0.1310937726113514}], 
             PointBox[{36.6, 0.13211987704766515`}], 
             PointBox[{36.7, 0.12886653538534065`}], 
             PointBox[{36.8, 0.13044044908136276`}], 
             PointBox[{36.9, 0.13208643922908636`}], 
             PointBox[{37., 0.13020705856475198`}], 
             PointBox[{37.1, 0.12928865103658677`}], 
             PointBox[{37.2, 0.13335417322616816`}], 
             PointBox[{37.3, 0.13101870952654224`}], 
             PointBox[{37.4, 0.12928463154100645`}], 
             PointBox[{37.5, 0.13122919392218974`}], 
             PointBox[{37.6, 0.1320244944058594}], 
             PointBox[{37.7, 0.1286682920840929}], 
             PointBox[{37.8, 0.13073015252940295`}], 
             PointBox[{37.9, 0.1320082086423036}], 
             PointBox[{38., 0.13005287586900013`}], 
             PointBox[{38.1, 0.12939762055839005`}], 
             PointBox[{38.2, 0.13358875226944428`}], 
             PointBox[{38.3, 0.13067361165241304`}], 
             PointBox[{38.4, 0.1293645511860508}], 
             PointBox[{38.5, 0.13137013336144335`}], 
             PointBox[{38.6, 0.13190893631693992`}], 
             PointBox[{38.7, 0.12852895172107165`}], 
             PointBox[{38.8, 0.13101168274510866`}], 
             PointBox[{38.9, 0.1319247509140769}], 
             PointBox[{39., 0.1299146933544891}], 
             PointBox[{39.1, 0.1295531028740669}], 
             PointBox[{39.2, 0.13376805319111576`}], 
             PointBox[{39.3, 0.13036811439344495`}], 
             PointBox[{39.4, 0.1294706545103891}], 
             PointBox[{39.5, 0.13151506241920227`}], 
             PointBox[{39.6, 0.13177229283651398`}], 
             PointBox[{39.7, 0.1284517820448388}], 
             PointBox[{39.8, 0.13127940216443426`}], 
             PointBox[{39.9, 0.1318382425691512}], 
             PointBox[{40., 0.12979370532930853`}], 
             PointBox[{40.1, 0.12975622996399727`}], 
             PointBox[{40.2, 0.13388430098729195`}], 
             PointBox[{40.3, 0.13010612800737978`}], 
             PointBox[{40.4, 0.12960050335687154`}], 
             PointBox[{40.5, 0.1316620961920453}], 
             PointBox[{40.6, 0.13161384689457198`}], 
             PointBox[{40.7, 0.12843672700290085`}], 
             PointBox[{40.8, 0.13152920078932415`}], 
             PointBox[{40.9, 0.13174993332003565`}], 
             PointBox[{41., 0.12969111511976586`}], 
             PointBox[{41.1, 0.13000739720768364`}], 
             PointBox[{41.2, 0.1339307365136705}], 
             PointBox[{41.3, 0.12988997746945383`}], 
             PointBox[{41.4, 0.12975213029287294`}], 
             PointBox[{41.5, 0.13181096507981307`}], 
             PointBox[{41.6, 0.13143330185238758`}], 
             PointBox[{41.7, 0.12848263627413503`}], 
             PointBox[{41.8, 0.131757974403741}], 
             PointBox[{41.9, 0.1316601905722038}], 
             PointBox[{42., 0.12960803012674227`}], 
             PointBox[{42.1, 0.1303055318322327}], 
             PointBox[{42.2, 0.13390631745240722`}], 
             PointBox[{42.3, 0.12972037738707173`}], 
             PointBox[{42.4, 0.1299228787221933}], 
             PointBox[{42.5, 0.1319575953670399}], 
             PointBox[{42.6, 0.13123131994259002`}], 
             PointBox[{42.7, 0.1285897075688546}], 
             PointBox[{42.8, 0.13196356613289004`}], 
             PointBox[{42.9, 0.1315695129770948}], 
             PointBox[{43., 0.12954519076087243`}], 
             PointBox[{43.1, 0.13064787126385938`}], 
             PointBox[{43.2, 0.13381192162948463`}], 
             PointBox[{43.3, 0.1295961312404058}], 
             PointBox[{43.4, 0.13010993842213378`}], 
             PointBox[{43.5, 0.1321001543753936}], 
             PointBox[{43.6, 0.13100938592002262`}], 
             PointBox[{43.7, 0.12875613382605258`}], 
             PointBox[{43.8, 0.13214421421385592`}], 
             PointBox[{43.9, 0.13147836500843602`}], 
             PointBox[{44., 0.12950357597893175`}], 
             PointBox[{44.1, 0.13103029768080995`}], 
             PointBox[{44.2, 0.1336526790565551}], 
             PointBox[{44.3, 0.1295159247906867}], 
             PointBox[{44.4, 0.1303110022530478}], 
             PointBox[{44.5, 0.13223469795412907`}], 
             PointBox[{44.6, 0.1307712383576199}], 
             PointBox[{44.7, 0.1289797882661882}], 
             PointBox[{44.8, 0.1322992424776394}], 
             PointBox[{44.9, 0.13138609808098345`}], 
             PointBox[{45., 0.12948415224566592`}], 
             PointBox[{45.1, 0.1314459873766058}], 
             PointBox[{45.2, 0.13343616429354657`}], 
             PointBox[{45.3, 0.12947677737543098`}], 
             PointBox[{45.4, 0.13052301803042565`}], 
             PointBox[{45.5, 0.13235811973229789`}], 
             PointBox[{45.6, 0.1305216189797579}], 
             PointBox[{45.7, 0.12925624041041153`}], 
             PointBox[{45.8, 0.13242805800566868`}], 
             PointBox[{45.9, 0.13129298427684805`}], 
             PointBox[{46., 0.1294880303018846}], 
             PointBox[{46.1, 0.13188643603756944`}], 
             PointBox[{46.2, 0.13317298826057394`}], 
             PointBox[{46.3, 0.12947554898578192`}], 
             PointBox[{46.4, 0.13074292311288646`}], 
             PointBox[{46.5, 0.1324662345249697}], 
             PointBox[{46.6, 0.13026761386508}], 
             PointBox[{46.7, 0.12957689545472212`}], 
             PointBox[{46.8, 0.13253046028819673`}], 
             PointBox[{46.9, 0.13119821120010627`}], 
             PointBox[{47., 0.12951641079734935`}], 
             PointBox[{47.1, 0.13234026963726103`}], 
             PointBox[{47.2, 0.13287485553144765`}], 
             PointBox[{47.3, 0.1295084312571413}], 
             PointBox[{47.4, 0.13096787256282882`}], 
             PointBox[{47.5, 0.1325548804122664}], 
             PointBox[{47.6, 0.13001824123049632`}], 
             PointBox[{47.7, 0.12993132401522867`}], 
             PointBox[{47.8, 0.13260630202568302`}], 
             PointBox[{47.9, 0.1311015679553164}], 
             PointBox[{48., 0.1295705174228006}], 
             PointBox[{48.1, 0.13279383173500287`}], 
             PointBox[{48.2, 0.13255395960494196`}], 
             PointBox[{48.3, 0.12957113917701055`}], 
             PointBox[{48.4, 0.1311941220067462}], 
             PointBox[{48.5, 0.13261904524426468`}], 
             PointBox[{48.6, 0.12978328665479313`}], 
             PointBox[{48.7, 0.1303063459967065}], 
             PointBox[{48.8, 0.1326557551883149}], 
             PointBox[{48.9, 0.1310029645637543}], 
             PointBox[{49., 0.12965200237980345`}], 
             PointBox[{49.1, 0.13323186442046986`}], 
             PointBox[{49.2, 0.132222847368207}], 
             PointBox[{49.3, 0.12965980136208602`}], 
             PointBox[{49.4, 0.13141905410339225`}], 
             PointBox[{49.5, 0.13265576294244624`}], 
             PointBox[{49.6, 0.1295734902582249}], 
             PointBox[{49.7, 0.1306886487226928}], 
             PointBox[{49.8, 0.13267917921442043`}], 
             PointBox[{49.9, 0.13090156128177213`}], 
             PointBox[{50., 0.12976234891622293`}], 
             PointBox[{50.1, 0.13363752321520642`}], 
             PointBox[{50.2, 0.13189266586769122`}], 
             PointBox[{50.3, 0.1297701957285554}], 
             PointBox[{50.4, 0.13163913364069013`}], 
             PointBox[{50.5, 0.1326594674724837}], 
             PointBox[{50.6, 0.12939835434937716`}], 
             PointBox[{50.7, 0.13106519519192172`}], 
             PointBox[{50.8, 0.13267708601079856`}], 
             PointBox[{50.9, 0.13079791770131813`}], 
             PointBox[{51., 0.12990325305086978`}], 
             PointBox[{51.1, 0.13399368247452056`}], 
             PointBox[{51.2, 0.13157331464444494`}], 
             PointBox[{51.3, 0.12989821450520678`}], 
             PointBox[{51.4, 0.13185139215966296`}], 
             PointBox[{51.5, 0.13262664049538742`}], 
             PointBox[{51.6, 0.12926538099360496`}], 
             PointBox[{51.7, 0.13142398804178895`}], 
             PointBox[{51.8, 0.13264984269002575`}], 
             PointBox[{51.9, 0.13069255351542983`}], 
             PointBox[{52., 0.1300758906376967}], 
             PointBox[{52.1, 0.13428404300551916`}], 
             PointBox[{52.2, 0.13127251813327145`}], 
             PointBox[{52.3, 0.13003969106129729`}], 
             PointBox[{52.4, 0.13205261632585702`}], 
             PointBox[{52.5, 0.13255357349376895`}], 
             PointBox[{52.6, 0.1291783886040068}], 
             PointBox[{52.7, 0.1317551140725517}], 
             PointBox[{52.8, 0.1325982946701035}], 
             PointBox[{52.9, 0.13058511814900733`}], 
             PointBox[{53., 0.13028125949107064`}], 
             PointBox[{53.1, 0.13449408270771954`}], 
             PointBox[{53.2, 0.13099617682938144`}], 
             PointBox[{53.3, 0.1301907977904752}], 
             PointBox[{53.4, 0.1322393848567269}], 
             PointBox[{53.5, 0.13243742943086514`}], 
             PointBox[{53.6, 0.12913822124093632`}], 
             PointBox[{53.7, 0.1320508031073647}], 
             PointBox[{53.8, 0.13252310120276595`}], 
             PointBox[{53.9, 0.13047646027460372`}], 
             PointBox[{54., 0.13051967823925117`}], 
             PointBox[{54.1, 0.13461387431688848`}], 
             PointBox[{54.2, 0.130748273674872}], 
             PointBox[{54.3, 0.1303482470099655}], 
             PointBox[{54.4, 0.13240875567321075`}], 
             PointBox[{54.5, 0.13227691338760889`}], 
             PointBox[{54.6, 0.12914479252411704`}], 
             PointBox[{54.7, 0.13230550576217756`}], 
             PointBox[{54.8, 0.13242532296537776`}], 
             PointBox[{54.9, 0.13036852499170926`}], 
             PointBox[{55., 0.13079077831618366`}], 
             PointBox[{55.1, 0.13463630127313975`}], 
             PointBox[{55.2, 0.13053111785846538`}], 
             PointBox[{55.3, 0.13050861991500992`}], 
             PointBox[{55.4, 0.13255764806171672`}], 
             PointBox[{55.5, 0.1320717809993851}], 
             PointBox[{55.6, 0.12919601974433606`}], 
             PointBox[{55.7, 0.13251587782528454`}], 
             PointBox[{55.8, 0.13230619862414922`}], 
             PointBox[{55.9, 0.13026237145880082`}], 
             PointBox[{56., 0.13109265732172623`}], 
             PointBox[{56.1, 0.13456121470393434`}], 
             PointBox[{56.2, 0.13034524014263976`}], 
             PointBox[{56.3, 0.13066893792361325`}], 
             PointBox[{56.4, 0.132684071290779}], 
             PointBox[{56.5, 0.13182384515747764`}], 
             PointBox[{56.6, 0.1292926289457918}], 
             PointBox[{56.7, 0.1326803153986696}], 
             PointBox[{56.8, 0.13216756083533746`}], 
             PointBox[{56.9, 0.1301599757582354}], 
             PointBox[{57., 0.1314223572274545}], 
             PointBox[{57.1, 0.13439330065924407`}], 
             PointBox[{57.2, 0.1301906398925734}], 
             PointBox[{57.3, 0.13082731041532678`}], 
             PointBox[{57.4, 0.1327847088381545}], 
             PointBox[{57.5, 0.13153761851195908`}], 
             PointBox[{57.6, 0.12943425258838556`}], 
             PointBox[{57.7, 0.13279889690455138`}], 
             PointBox[{57.8, 0.1320109584281187}], 
             PointBox[{57.9, 0.1300649501715927}], 
             PointBox[{58., 0.13177440711196117`}], 
             PointBox[{58.1, 0.134140828316157}], 
             PointBox[{58.2, 0.1300655983774922}], 
             PointBox[{58.3, 0.1309809228360747}], 
             PointBox[{58.4, 0.13285727697009606`}], 
             PointBox[{58.5, 0.13121919568488477`}], 
             PointBox[{58.6, 0.12961786262812094`}], 
             PointBox[{58.7, 0.13287232849569597`}], 
             PointBox[{58.8, 0.1318379546962399}], 
             PointBox[{58.9, 0.12997850095407182`}], 
             PointBox[{59., 0.13214124295070515`}], 
             PointBox[{59.1, 0.13381699538688765`}], 
             PointBox[{59.2, 0.12996803271253887`}], 
             PointBox[{59.3, 0.131128210166918}], 
             PointBox[{59.4, 0.13289955752242952`}], 
             PointBox[{59.5, 0.13087795116055817`}], 
             PointBox[{59.6, 0.12983892656996393`}], 
             PointBox[{59.7, 0.1329033840837078}], 
             PointBox[{59.8, 0.13165121544349973`}], 
             PointBox[{59.9, 0.12990532089652795`}], 
             PointBox[{60., 0.13251392980579693`}], 
             PointBox[{60.1, 0.13343792294061152`}], 
             PointBox[{60.2, 0.12989630568353916`}], 
             PointBox[{60.3, 0.1312682194182265}], 
             PointBox[{60.4, 0.13290975950036354`}], 
             PointBox[{60.5, 0.13052548382379167`}], 
             PointBox[{60.6, 0.13008880145666055`}], 
             PointBox[{60.7, 0.13289471600615216`}], 
             PointBox[{60.8, 0.13145289065671342`}], 
             PointBox[{60.9, 0.12984806680471464`}], 
             PointBox[{61., 0.13288073713240486`}], 
             PointBox[{61.1, 0.133020023607045}], 
             PointBox[{61.2, 0.12984763049912532`}], 
             PointBox[{61.3, 0.13139932876475097`}], 
             PointBox[{61.4, 0.13288657772137916`}], 
             PointBox[{61.5, 0.1301743437625177}], 
             PointBox[{61.6, 0.13035646374538656`}], 
             PointBox[{61.7, 0.13284997841524843`}], 
             PointBox[{61.8, 0.1312457910191116}], 
             PointBox[{61.9, 0.12981067193269355`}], 
             PointBox[{62., 0.1332287430390332}], 
             PointBox[{62.1, 0.13258021631349612`}], 
             PointBox[{62.2, 0.12981980313088967`}], 
             PointBox[{62.3, 0.1315211540619721}], 
             PointBox[{62.4, 0.13282843198819758`}], 
             PointBox[{62.5, 0.1298380457646456}], 
             PointBox[{62.6, 0.13063000160398688`}], 
             PointBox[{62.7, 0.13277285705048728`}], 
             PointBox[{62.8, 0.13103238585294033`}], 
             PointBox[{62.9, 0.12979753705130542`}], 
             PointBox[{63., 0.13354392849826435`}], 
             PointBox[{63.1, 0.13213396391237833`}], 
             PointBox[{63.2, 0.129810727878853}], 
             PointBox[{63.3, 0.1316334454505071}], 
             PointBox[{63.4, 0.13273431006572953`}], 
             PointBox[{63.5, 0.12953092195296453`}], 
             PointBox[{63.6, 0.1308983053955393}], 
             PointBox[{63.7, 0.13266723496122163`}], 
             PointBox[{63.8, 0.13081563371368543`}], 
             PointBox[{63.9, 0.12981191807046408`}], 
             PointBox[{64., 0.13381227734523896`}], 
             PointBox[{64.1, 0.1316947050124147}], 
             PointBox[{64.2, 0.12981816891009856`}], 
             PointBox[{64.3, 0.13173523298473216`}], 
             PointBox[{64.4, 0.13260339297297857`}], 
             PointBox[{64.5, 0.12926178821415663`}], 
             PointBox[{64.6, 0.13115162838747205`}], 
             PointBox[{64.7, 0.13253728955296326`}], 
             PointBox[{64.8, 0.13059883195946895`}], 
             PointBox[{64.9, 0.12985742628314328`}], 
             PointBox[{65., 0.13402080531163707`}], 
             PointBox[{65.1, 0.13127423706662256`}], 
             PointBox[{65.2, 0.12984096608201987`}], 
             PointBox[{65.3, 0.13182682817086622`}], 
             PointBox[{65.4, 0.13243614337210888`}], 
             PointBox[{65.5, 0.12903937388004236`}], 
             PointBox[{65.6, 0.13138270840246621`}], 
             PointBox[{65.7, 0.13238734119791248`}], 
             PointBox[{65.8, 0.13038504724292566`}], 
             PointBox[{65.9, 0.12993764571124936`}], 
             PointBox[{66., 0.13415887486682748`}], 
             PointBox[{66.1, 0.1308814213338612}], 
             PointBox[{66.2, 0.12987768046898207`}], 
             PointBox[{66.3, 0.13190863592132496`}], 
             PointBox[{66.4, 0.13223320298151225`}], 
             PointBox[{66.5, 0.1288676980133094}], 
             PointBox[{66.6, 0.13158663958087452`}], 
             PointBox[{66.7, 0.13222110315581959`}], 
             PointBox[{66.8, 0.13017738673537232`}], 
             PointBox[{66.9, 0.13005517454182913`}], 
             PointBox[{67., 0.13421912701006977`}], 
             PointBox[{67.1, 0.13052337916799947`}], 
             PointBox[{67.2, 0.12992768815146116`}], 
             PointBox[{67.3, 0.131980901557305}], 
             PointBox[{67.4, 0.13199631220920624`}], 
             PointBox[{67.5, 0.12874899847516708`}], 
             PointBox[{67.6, 0.13176078761451746`}], 
             PointBox[{67.7, 0.1320431316138953}], 
             PointBox[{67.8, 0.12998032008491886`}], 
             PointBox[{67.9, 0.1302124663207749}], 
             PointBox[{68., 0.13419757953425188`}], 
             PointBox[{68.1, 0.13020433590916722`}], 
             PointBox[{68.2, 0.12999000409674966`}], 
             PointBox[{68.3, 0.13204334042747712`}], 
             PointBox[{68.4, 0.13172784801909526`}], 
             PointBox[{68.5, 0.1286852757756321}], 
             PointBox[{68.6, 0.13190398744074822`}], 
             PointBox[{68.7, 0.1318565270676999}], 
             PointBox[{68.8, 0.1297958188051084}], 
             PointBox[{68.9, 0.13040964237874653`}], 
             PointBox[{69., 0.13409509754758495`}], 
             PointBox[{69.1, 0.12992743090709838`}], 
             PointBox[{69.2, 0.13006442627355258`}], 
             PointBox[{69.3, 0.1320968115385489}], 
             PointBox[{69.4, 0.13143131203512012`}], 
             PointBox[{69.5, 0.12867740488703922`}], 
             PointBox[{69.6, 0.13201696231073853`}], 
             PointBox[{69.7, 0.13166494310280227`}], 
             PointBox[{69.8, 0.12962867416971652`}], 
             PointBox[{69.9, 0.13064607403453626`}], 
             PointBox[{70., 0.13391618922955656`}], 
             PointBox[{70.1, 0.12969386997339954`}], 
             PointBox[{70.2, 0.1301503939279608}], 
             PointBox[{70.3, 0.13214078324503462`}], 
             PointBox[{70.4, 0.13111172252160042`}], 
             PointBox[{70.5, 0.12872671064785068`}], 
             PointBox[{70.6, 0.13210153030106417`}], 
             PointBox[{70.7, 0.13147155094137863`}], 
             PointBox[{70.8, 0.1294813221955896}], 
             PointBox[{70.9, 0.13092018869575517`}], 
             PointBox[{71., 0.13366927338693574`}], 
             PointBox[{71.1, 0.12950399797756307`}], 
             PointBox[{71.2, 0.13024762987447475`}], 
             PointBox[{71.3, 0.1321747328108965}], 
             PointBox[{71.4, 0.13077535005704438`}], 
             PointBox[{71.5, 0.1288342859454984}], 
             PointBox[{71.6, 0.132160158667151}], 
             PointBox[{71.7, 0.13127944816822656`}], 
             PointBox[{71.8, 0.12935795857479354`}], 
             PointBox[{71.9, 0.1312280727769153}], 
             PointBox[{72., 0.13336622241895787`}], 
             PointBox[{72.1, 0.12935751543996393`}], 
             PointBox[{72.2, 0.1303561487702934}], 
             PointBox[{72.3, 0.13219925297263316`}], 
             PointBox[{72.4, 0.13043028336451945`}], 
             PointBox[{72.5, 0.12899729129205234`}], 
             PointBox[{72.6, 0.13219568806272963`}], 
             PointBox[{72.7, 0.13109093154350318`}], 
             PointBox[{72.8, 0.12926152760095289`}], 
             PointBox[{72.9, 0.13156322939808943`}], 
             PointBox[{73., 0.13302022116362938`}], 
             PointBox[{73.1, 0.12925301310077794`}], 
             PointBox[{73.2, 0.13047587157210092`}], 
             PointBox[{73.3, 0.13221354353187995`}], 
             PointBox[{73.4, 0.1300855164637204}], 
             PointBox[{73.5, 0.12921068709249517`}], 
             PointBox[{73.6, 0.13221125195047426`}], 
             PointBox[{73.7, 0.13090864119764167`}], 
             PointBox[{73.8, 0.12919525784217684`}], 
             PointBox[{73.9, 0.13191814955496775`}], 
             PointBox[{74., 0.13264559668786882`}], 
             PointBox[{74.1, 0.12918876698520015`}], 
             PointBox[{74.2, 0.13060568184914884`}], 
             PointBox[{74.3, 0.1322161723957864}], 
             PointBox[{74.4, 0.12975160411118253`}], 
             PointBox[{74.5, 0.1294661979949047}], 
             PointBox[{74.6, 0.1322094407367716}], 
             PointBox[{74.7, 0.13073398082804197`}], 
             PointBox[{74.8, 0.12916239284789585`}], 
             PointBox[{74.9, 0.13228261508395772`}], 
             PointBox[{75., 0.13225700685479352`}], 
             PointBox[{75.1, 0.12916291008293015`}], 
             PointBox[{75.2, 0.13074609301161902`}], 
             PointBox[{75.3, 0.1322058044827936}], 
             PointBox[{75.4, 0.12944007969503887`}], 
             PointBox[{75.5, 0.1297539727958715}], 
             PointBox[{75.6, 0.13219323032847907`}], 
             PointBox[{75.7, 0.1305693205422184}], 
             PointBox[{75.8, 0.12916560363197133`}], 
             PointBox[{75.9, 0.13264494086301631`}], 
             PointBox[{76., 0.1318677080424533}], 
             PointBox[{76.1, 0.12917285383453933`}], 
             PointBox[{76.2, 0.13089512772202072`}], 
             PointBox[{76.3, 0.13218053796788734`}], 
             PointBox[{76.4, 0.1291619199947478}], 
             PointBox[{76.5, 0.13006331998554602`}], 
             PointBox[{76.6, 0.13216488630117773`}], 
             PointBox[{76.7, 0.13041557778225632`}], 
             PointBox[{76.8, 0.12920811114309186`}], 
             PointBox[{76.9, 0.13299277532297846`}], 
             PointBox[{77., 0.13149025342683718`}], 
             PointBox[{77.1, 0.12921657458008742`}], 
             PointBox[{77.2, 0.13105296716250142`}], 
             PointBox[{77.3, 0.13213925654055542`}], 
             PointBox[{77.4, 0.12892761228460756`}], 
             PointBox[{77.5, 0.13038352176683257`}], 
             PointBox[{77.6, 0.1321265815942741}], 
             PointBox[{77.7, 0.13027411762747776`}], 
             PointBox[{77.8, 0.12929186884256397`}], 
             PointBox[{77.9, 0.1333116548349074}], 
             PointBox[{78., 0.13113464295949573`}], 
             PointBox[{78.1, 0.12929130366400637`}], 
             PointBox[{78.2, 0.13121735750907848`}], 
             PointBox[{78.3, 0.13207918873096544`}], 
             PointBox[{78.4, 0.12874563078665627`}], 
             PointBox[{78.5, 0.13070465158611472`}], 
             PointBox[{78.6, 0.132079715716736}], 
             PointBox[{78.7, 0.1301454023256908}], 
             PointBox[{78.8, 0.1294189997108134}], 
             PointBox[{78.9, 0.133588683721474}], 
             PointBox[{79., 0.13080922702168188`}], 
             PointBox[{79.1, 0.12939427854170088`}], 
             PointBox[{79.2, 0.13138727307500056`}], 
             PointBox[{79.3, 0.13199842199973513`}], 
             PointBox[{79.4, 0.12862074980095894`}], 
             PointBox[{79.5, 0.13101876187269576`}], 
             PointBox[{79.6, 0.13202603196808368`}], 
             PointBox[{79.7, 0.13003057385178615`}], 
             PointBox[{79.8, 0.12959151729488722`}], 
             PointBox[{79.9, 0.1338122631252337}], 
             PointBox[{80., 0.13052027588880552`}], 
             PointBox[{80.1, 0.12952279704727057`}], 
             PointBox[{80.2, 0.1315604020095666}], 
             PointBox[{80.3, 0.13189499541649455`}], 
             PointBox[{80.4, 0.12855682044372255`}], 
             PointBox[{80.5, 0.13131880047990066`}], 
             PointBox[{80.6, 0.1319663132272711}], 
             PointBox[{80.7, 0.12993069011112382`}], 
             PointBox[{80.8, 0.1298101343399092}], 
             PointBox[{80.9, 0.1339703034989869}], 
             PointBox[{81., 0.13027170652543157`}], 
             PointBox[{81.1, 0.12967413609352316`}], 
             PointBox[{81.2, 0.13173498305463122`}], 
             PointBox[{81.3, 0.13176638923608808`}], 
             PointBox[{81.4, 0.12855205240846995`}], 
             PointBox[{81.5, 0.13159885839899985`}], 
             PointBox[{81.6, 0.13190082705259434`}], 
             PointBox[{81.7, 0.12984550265252207`}], 
             PointBox[{81.8, 0.13007439640748905`}], 
             PointBox[{81.9, 0.13405755840505498`}], 
             PointBox[{82., 0.13006579908272659`}], 
             PointBox[{82.1, 0.12984511377207622`}], 
             PointBox[{82.2, 0.1319074344159671}], 
             PointBox[{82.3, 0.13161192853637954`}], 
             PointBox[{82.4, 0.1286071753447869}], 
             PointBox[{82.5, 0.1318550879668773}], 
             PointBox[{82.6, 0.13183014638594823`}], 
             PointBox[{82.7, 0.12977648686933582`}], 
             PointBox[{82.8, 0.13038387034478008`}], 
             PointBox[{82.9, 0.13406854818621763`}], 
             PointBox[{83., 0.12990334700167996`}], 
             PointBox[{83.1, 0.13003270320013252`}], 
             PointBox[{83.2, 0.13207557553551202`}], 
             PointBox[{83.3, 0.13143159841030141`}], 
             PointBox[{83.4, 0.12871958862453398`}], 
             PointBox[{83.5, 0.13208431743665486`}], 
             PointBox[{83.6, 0.13175460393133787`}], 
             PointBox[{83.7, 0.12972344590908882`}], 
             PointBox[{83.8, 0.13073538137055793`}], 
             PointBox[{83.9, 0.13400320324732026`}], 
             PointBox[{84., 0.12978360379418555`}], 
             PointBox[{84.1, 0.13023429555288987`}], 
             PointBox[{84.2, 0.13223595390020149`}], 
             PointBox[{84.3, 0.13122622108055573`}], 
             PointBox[{84.4, 0.12888839135050667`}], 
             PointBox[{84.5, 0.13228397554147223`}], 
             PointBox[{84.6, 0.13167321282750136`}], 
             PointBox[{84.7, 0.12968725540960607`}], 
             PointBox[{84.8, 0.13112452624370688`}], 
             PointBox[{84.9, 0.1338661450256824}], 
             PointBox[{85., 0.12970438879627133`}], 
             PointBox[{85.1, 0.13044583126161707`}], 
             PointBox[{85.2, 0.13238450212862266`}], 
             PointBox[{85.3, 0.13099819236947619`}], 
             PointBox[{85.4, 0.12911173026127795`}], 
             PointBox[{85.5, 0.13245297916224094`}], 
             PointBox[{85.6, 0.13158655550741777`}], 
             PointBox[{85.7, 0.12966886815472153`}], 
             PointBox[{85.8, 0.13154498796332667`}], 
             PointBox[{85.9, 0.13366359787056692`}], 
             PointBox[{86., 0.12966315026754804`}], 
             PointBox[{86.1, 0.13066458417108523`}], 
             PointBox[{86.2, 0.1325180942765353}], 
             PointBox[{86.3, 0.13075242393588077`}], 
             PointBox[{86.4, 0.12938475013418851`}], 
             PointBox[{86.5, 0.1325903397314447}], 
             PointBox[{86.6, 0.13149379913416173`}], 
             PointBox[{86.7, 0.12966958828826797`}], 
             PointBox[{86.8, 0.13198801664540688`}], 
             PointBox[{86.9, 0.13340666175131197`}], 
             PointBox[{87., 0.12965668868465494`}], 
             PointBox[{87.1, 0.13088734017152728`}], 
             PointBox[{87.2, 0.13263153951370038`}], 
             PointBox[{87.3, 0.1304959663250922}], 
             PointBox[{87.4, 0.12969999001075944`}], 
             PointBox[{87.5, 0.13269589144518382`}], 
             PointBox[{87.6, 0.1313950661017856}], 
             PointBox[{87.7, 0.12969028131565719`}], 
             PointBox[{87.8, 0.13244221292857766`}], 
             PointBox[{87.9, 0.13310688381632246`}], 
             PointBox[{88., 0.1296809349498669}], 
             PointBox[{88.1, 0.13111058092066594`}], 
             PointBox[{88.2, 0.13272069574281375`}], 
             PointBox[{88.3, 0.1302374774725365}], 
             PointBox[{88.4, 0.13004687871916135`}], 
             PointBox[{88.5, 0.13276969677737674`}], 
             PointBox[{88.6, 0.13128993857231575`}], 
             PointBox[{88.7, 0.1297326143861445}], 
             PointBox[{88.8, 0.1328941536073291}], 
             PointBox[{88.9, 0.1327778430775772}], 
             PointBox[{89., 0.12973237475023366`}], 
             PointBox[{89.1, 0.13133185038229153`}], 
             PointBox[{89.2, 0.13278237648806934`}], 
             PointBox[{89.3, 0.12998813014012411`}], 
             PointBox[{89.4, 0.13041288421486763`}], 
             PointBox[{89.5, 0.13281230533885516`}], 
             PointBox[{89.6, 0.13117850234997447`}], 
             PointBox[{89.7, 0.12979880747593614`}], 
             PointBox[{89.8, 0.1333284090992723}], 
             PointBox[{89.9, 0.1324325179764413}], 
             PointBox[{90., 0.12980677161477103`}], 
             PointBox[{90.1, 0.13154766956998865`}], 
             PointBox[{90.2, 0.13281115803097943`}], 
             PointBox[{90.3, 0.12975858590465453`}], 
             PointBox[{90.4, 0.13078377596647991`}], 
             PointBox[{90.5, 0.13282415548310433`}], 
             PointBox[{90.6, 0.13106080107437076`}], 
             PointBox[{90.7, 0.12989010445997604`}], 
             PointBox[{90.8, 0.1337280504545036}], 
             PointBox[{90.9, 0.13208293164404014`}], 
             PointBox[{91., 0.12989980689025535`}], 
             PointBox[{91.1, 0.13175476283283818`}], 
             PointBox[{91.2, 0.1328034146964474}], 
             PointBox[{91.3, 0.12955929595776883`}], 
             PointBox[{91.4, 0.13114652477469893`}], 
             PointBox[{91.5, 0.13280632892908142`}], 
             PointBox[{91.6, 0.13093741656048086`}], 
             PointBox[{91.7, 0.13000861056774624`}], 
             PointBox[{91.8, 0.13407551717963762`}], 
             PointBox[{91.9, 0.13173990644707662`}], 
             PointBox[{92., 0.1300076959707462}], 
             PointBox[{92.1, 0.13195061800744315`}], 
             PointBox[{92.2, 0.13275569385239624`}], 
             PointBox[{92.3, 0.12939838079566424`}], 
             PointBox[{92.4, 0.13148922870906243`}], 
             PointBox[{92.5, 0.13276014067332503`}], 
             PointBox[{92.6, 0.13080901533789352`}], 
             PointBox[{92.7, 0.13015621811767178`}], 
             PointBox[{92.8, 0.13435516443253337`}], 
             PointBox[{92.9, 0.13141239297117865`}], 
             PointBox[{93., 0.1301267320562365}], 
             PointBox[{93.1, 0.13213237524210517`}], 
             PointBox[{93.2, 0.13266489981153892`}], 
             PointBox[{93.3, 0.12928112016742532`}], 
             PointBox[{93.4, 0.13180217123920243`}], 
             PointBox[{93.5, 0.13268672741002657`}], 
             PointBox[{93.6, 0.13067686149220453`}], 
             PointBox[{93.7, 0.13033431840060958`}], 
             PointBox[{93.8, 0.13455258137016207`}], 
             PointBox[{93.9, 0.13110723261301482`}], 
             PointBox[{94., 0.13025354780915308`}], 
             PointBox[{94.1, 0.13229740984574748`}], 
             PointBox[{94.2, 0.13252872869649285`}], 
             PointBox[{94.3, 0.1292091849138332}], 
             PointBox[{94.4, 0.13207778027022588`}], 
             PointBox[{94.5, 0.13258782408390285`}], 
             PointBox[{94.6, 0.1305415725533947}], 
             PointBox[{94.7, 0.13054388183466809`}], 
             PointBox[{94.8, 0.13465847470831702`}], 
             PointBox[{94.9, 0.1308292277164276}], 
             PointBox[{95., 0.13038507088481177`}], 
             PointBox[{95.1, 0.13244343425048666`}], 
             PointBox[{95.2, 0.13234652512947676`}], 
             PointBox[{95.3, 0.1291821989070602}], 
             PointBox[{95.4, 0.13231112750904395`}], 
             PointBox[{95.5, 0.13246527014844256`}], 
             PointBox[{95.6, 0.13040684618123322`}], 
             PointBox[{95.7, 0.13078498494105228`}], 
             PointBox[{95.8, 0.13466618407466738`}], 
             PointBox[{95.9, 0.13058129485595807`}], 
             PointBox[{96., 0.13051862385164542`}], 
             PointBox[{96.1, 0.13256814617185522`}], 
             PointBox[{96.2, 0.1321189873396689}], 
             PointBox[{96.3, 0.1291994642351795}], 
             PointBox[{96.4, 0.1324993399721817}], 
             PointBox[{96.5, 0.1323210978007976}], 
             PointBox[{96.6, 0.13027248491113275`}], 
             PointBox[{96.7, 0.1310564703440681}], 
             PointBox[{96.8, 0.13457500460340144`}], 
             PointBox[{96.9, 0.13036479233791565`}], 
             PointBox[{97., 0.13065192928833502`}], 
             PointBox[{97.1, 0.13266946728018053`}], 
             PointBox[{97.2, 0.13184858724846593`}], 
             PointBox[{97.3, 0.1292626895296717}], 
             PointBox[{97.4, 0.13264153416970823`}], 
             PointBox[{97.5, 0.1321575871054905}], 
             PointBox[{97.6, 0.13014357541737143`}], 
             PointBox[{97.7, 0.13135566828532338`}], 
             PointBox[{97.8, 0.13439057283478378`}], 
             PointBox[{97.9, 0.13017992915040696`}], 
             PointBox[{98., 0.13078312988920002`}], 
             PointBox[{98.1, 0.1327456244040199}], 
             PointBox[{98.2, 0.13154005795990287`}], 
             PointBox[{98.3, 0.12937051343203398`}], 
             PointBox[{98.4, 0.13273841930842678`}], 
             PointBox[{98.5, 0.13197703474018566`}], 
             PointBox[{98.6, 0.13002138805817182`}], 
             PointBox[{98.7, 0.13167813295229866`}], 
             PointBox[{98.8, 0.13412260275769156`}], 
             PointBox[{98.9, 0.13002591451165676`}], 
             PointBox[{99., 0.13091071825287295`}], 
             PointBox[{99.1, 0.13279508695363995`}], 
             PointBox[{99.2, 0.1312003143962034}], 
             PointBox[{99.3, 0.12952296832046575`}], 
             PointBox[{99.4, 0.1327919158031773}], 
             PointBox[{99.5, 0.1317820380464768}], 
             PointBox[{99.6, 0.12990990785153714`}], 
             PointBox[{99.7, 0.13201754148944114`}], 
             PointBox[{99.8, 0.13378397401600647`}], 
             PointBox[{99.9, 0.1299013719277646}], 
             PointBox[{100., 0.13103352621476244`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 0.2}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
             PointBox[{0.1, 358.3502079336781}], 
             PointBox[{0.2, 359.2793241430707}], 
             PointBox[{0.3, 359.1604036957593}], 
             PointBox[{0.4, 357.8390521842123}], 
             PointBox[{0.5, 358.77709198859844`}], 
             PointBox[{0.6, 359.4361414904088}], 
             PointBox[{0.7, 358.147309015734}], 
             PointBox[{0.8, 358.12888783242124`}], 
             PointBox[{0.9, 359.0578619902845}], 
             PointBox[{1., 357.0988497752025}], 
             PointBox[{1.1, 355.77056834689006`}], 
             PointBox[{1.2, 356.6812151505747}], 
             PointBox[{1.3, 356.46078065339805`}], 
             PointBox[{1.4, 355.12631912826265`}], 
             PointBox[{1.5, 356.3280290493072}], 
             PointBox[{1.6, 356.7026095048906}], 
             PointBox[{1.7, 355.4625329282155}], 
             PointBox[{1.8, 355.5431730050033}], 
             PointBox[{1.9, 356.4507438601889}], 
             PointBox[{2., 354.2052298419656}], 
             PointBox[{2.1, 353.2004747943116}], 
             PointBox[{2.2, 354.0770076752774}], 
             PointBox[{2.3, 353.7543142628952}], 
             PointBox[{2.4, 352.42914171754353`}], 
             PointBox[{2.5, 353.8694687968902}], 
             PointBox[{2.6, 353.96347006667986`}], 
             PointBox[{2.7, 352.7858547620251}], 
             PointBox[{2.8, 352.96418471193175`}], 
             PointBox[{2.9, 353.825246371384}], 
             PointBox[{3., 351.326470075411}], 
             PointBox[{3.1, 350.63770522385397`}], 
             PointBox[{3.2, 351.4669894959734}], 
             PointBox[{3.3, 351.04151677089646`}], 
             PointBox[{3.4, 349.75129592120516`}], 
             PointBox[{3.5, 351.39580050490355`}], 
             PointBox[{3.6, 351.2214924871311}], 
             PointBox[{3.7, 350.11739686529427`}], 
             PointBox[{3.8, 350.3914448239327}], 
             PointBox[{3.9, 351.1777989140354}], 
             PointBox[{4., 348.46929152111085`}], 
             PointBox[{4.1, 348.08024063678994`}], 
             PointBox[{4.2, 348.8512678622046}], 
             PointBox[{4.3, 348.32301427755675`}], 
             PointBox[{4.4, 347.0965063761202}], 
             PointBox[{4.5, 348.902254189753}], 
             PointBox[{4.6, 348.47925256718105`}], 
             PointBox[{4.7, 347.45770301957623`}], 
             PointBox[{4.8, 347.82499465116}], 
             PointBox[{4.9, 348.5053682507056}], 
             PointBox[{5., 345.63939154548746`}], 
             PointBox[{5.1, 345.5264810980627}], 
             PointBox[{5.2, 346.23005263587567`}], 
             PointBox[{5.3, 345.59960218847823`}], 
             PointBox[{5.4, 344.46750763957385`}], 
             PointBox[{5.5, 346.38506082683836`}], 
             PointBox[{5.6, 345.7387380606798}], 
             PointBox[{5.7, 344.8069252958759}], 
             PointBox[{5.8, 345.26435069482517`}], 
             PointBox[{5.9, 345.8045369775848}], 
             PointBox[{6., 342.8407132498639}], 
             PointBox[{6.1, 342.9745879789635}], 
             PointBox[{6.2, 343.60314339304375`}], 
             PointBox[{6.3, 342.8720528041634}], 
             PointBox[{6.4, 341.8675082960006}], 
             PointBox[{6.5, 343.84195230795416`}], 
             PointBox[{6.6, 343.0019005422334}], 
             PointBox[{6.7, 342.165307751132}], 
             PointBox[{6.8, 342.70948238162924`}], 
             PointBox[{6.9, 343.07313775826543`}], 
             PointBox[{7., 340.0760685477161}], 
             PointBox[{7.1, 340.42361718366107`}], 
             PointBox[{7.2, 340.97076819058566`}], 
             PointBox[{7.3, 340.1409425511375}], 
             PointBox[{7.4, 339.2978797850032}], 
             PointBox[{7.5, 341.2717595181899}], 
             PointBox[{7.6, 340.270324991596}], 
             PointBox[{7.7, 339.5329931869483}], 
             PointBox[{7.8, 340.1590591716513}], 
             PointBox[{7.9, 340.3097975609615}], 
             PointBox[{8., 337.34632149718607`}], 
             PointBox[{8.1, 337.87247420677164`}], 
             PointBox[{8.2, 338.3328546046783}], 
             PointBox[{8.3, 337.4075391816423}], 
             PointBox[{8.4, 336.75987164846833`}], 
             PointBox[{8.5, 338.67477399371023`}], 
             PointBox[{8.6, 337.54515627873326`}], 
             PointBox[{8.7, 336.9102049342179}], 
             PointBox[{8.8, 337.61235499791854`}], 
             PointBox[{8.9, 337.5144353864925}], 
             PointBox[{9., 334.65071724817045`}], 
             PointBox[{9.1, 335.3200429983023}], 
             PointBox[{9.2, 335.68921567896774`}], 
             PointBox[{9.3, 334.6734346479212}], 
             PointBox[{9.4, 334.25238835785893`}], 
             PointBox[{9.5, 336.05208205134784`}], 
             PointBox[{9.6, 334.82741041452095`}], 
             PointBox[{9.7, 334.296923285003}], 
             PointBox[{9.8, 335.0675759687187}], 
             PointBox[{9.9, 334.68911274824995`}], 
             PointBox[{10., 331.9874946302054}], 
             PointBox[{10.1, 332.76557139776514`}], 
             PointBox[{10.2, 333.03980928442945`}], 
             PointBox[{10.3, 331.9401920585522}], 
             PointBox[{10.4, 331.7734743263253}], 
             PointBox[{10.5, 333.40586485127017`}], 
             PointBox[{10.6, 332.11800177435964`}], 
             PointBox[{10.7, 331.6932514272252}], 
             PointBox[{10.8, 332.52364455840694`}], 
             PointBox[{10.9, 331.83724883942796`}], 
             PointBox[{11., 329.3537436861166}], 
             PointBox[{11.1, 330.20835418546665`}], 
             PointBox[{11.2, 330.3844271850195}], 
             PointBox[{11.3, 329.21008696905506`}], 
             PointBox[{11.4, 329.31941519404546`}], 
             PointBox[{11.5, 330.7389053720917}], 
             PointBox[{11.6, 329.4174378498699}], 
             PointBox[{11.7, 329.09907025595834`}], 
             PointBox[{11.8, 329.9773774753127}], 
             PointBox[{11.9, 328.9642575120795}], 
             PointBox[{12., 326.745857085319}], 
             PointBox[{12.1, 327.6475949734674}], 
             PointBox[{12.2, 327.7227308168254}], 
             PointBox[{12.3, 326.48458867892384`}], 
             PointBox[{12.4, 326.8844083480491}], 
             PointBox[{12.5, 328.05422936764813`}], 
             PointBox[{12.6, 326.72615768417097`}], 
             PointBox[{12.7, 326.5141480263653}], 
             PointBox[{12.8, 327.42639672343586`}], 
             PointBox[{12.9, 326.0772202461855}], 
             PointBox[{13., 324.16024450304656`}], 
             PointBox[{13.1, 325.082768989981}], 
             PointBox[{13.2, 325.0548145703278}], 
             PointBox[{13.3, 323.7679763178753}], 
             PointBox[{13.4, 324.4619625978213}], 
             PointBox[{13.5, 325.35538655525846`}], 
             PointBox[{13.6, 324.04426290388824`}], 
             PointBox[{13.7, 323.93822976538667`}], 
             PointBox[{13.8, 324.8670707002202}], 
             PointBox[{13.9, 323.18370868991684`}], 
             PointBox[{14., 321.59269070671104`}], 
             PointBox[{14.1, 322.5130451803078}], 
             PointBox[{14.2, 322.38001756196167`}], 
             PointBox[{14.3, 321.0621964336155}], 
             PointBox[{14.4, 322.04416973543806`}], 
             PointBox[{14.5, 322.6454458748488}], 
             PointBox[{14.6, 321.37192540702114`}], 
             PointBox[{14.7, 321.37098516353905`}], 
             PointBox[{14.8, 322.2957187611045}], 
             PointBox[{14.9, 320.29219965338484`}], 
             PointBox[{15., 319.0395945147182}], 
             PointBox[{15.1, 319.93806046464374`}], 
             PointBox[{15.2, 319.6984788215101}], 
             PointBox[{15.3, 318.37106524565036`}], 
             PointBox[{15.4, 319.623234577781}], 
             PointBox[{15.5, 319.92791406997924`}], 
             PointBox[{15.6, 318.7091751634237}], 
             PointBox[{15.7, 318.81193425489926`}], 
             PointBox[{15.8, 319.708135456955}], 
             PointBox[{15.9, 317.4111024074101}], 
             PointBox[{16., 316.49728115228567`}], 
             PointBox[{16.1, 317.35712085810985`}], 
             PointBox[{16.2, 317.00998194654863`}], 
             PointBox[{16.3, 315.6981301963324}], 
             PointBox[{16.4, 317.1911030585373}], 
             PointBox[{16.5, 317.2054982328199}], 
             PointBox[{16.6, 316.05573281312377`}], 
             PointBox[{16.7, 316.2602619673967}], 
             PointBox[{16.8, 317.0995547535383}], 
             PointBox[{16.9, 314.54826555651493`}], 
             PointBox[{17., 313.9622531702352}], 
             PointBox[{17.1, 314.769578242792}], 
             PointBox[{17.2, 314.31463171309406`}], 
             PointBox[{17.3, 313.0470290741567}], 
             PointBox[{17.4, 314.7406862796836}], 
             PointBox[{17.5, 314.48088372481385`}], 
             PointBox[{17.6, 313.41140434809995`}], 
             PointBox[{17.7, 313.7153286299096}], 
             PointBox[{17.8, 314.46569896500915`}], 
             PointBox[{17.9, 311.71083761663016`}], 
             PointBox[{18., 311.4317709693296}], 
             PointBox[{18.1, 312.175094720217}], 
             PointBox[{18.2, 311.61265534894994`}], 
             PointBox[{18.3, 310.4210015148353}], 
             PointBox[{18.4, 312.2661877100583}], 
             PointBox[{18.5, 311.7560767916115}], 
             PointBox[{18.6, 310.77588702985173`}], 
             PointBox[{18.7, 311.1761600059232}], 
             PointBox[{18.8, 311.8021311123006}], 
             PointBox[{18.9, 308.90436104678395`}], 
             PointBox[{19., 308.90312446430306`}], 
             PointBox[{19.1, 309.5731031604098}], 
             PointBox[{19.2, 308.90402928685967`}], 
             PointBox[{19.3, 307.8230352280747}], 
             PointBox[{19.4, 309.76343459710745`}], 
             PointBox[{19.5, 309.03317123889127`}], 
             PointBox[{19.6, 308.14885874523577`}], 
             PointBox[{19.7, 308.64141299361575`}], 
             PointBox[{19.8, 309.1053731688687}], 
             PointBox[{19.9, 306.1323074429031}], 
             PointBox[{20., 306.3739703643249}], 
             PointBox[{20.1, 306.9630448320607}], 
             PointBox[{20.2, 306.18941493609543`}], 
             PointBox[{20.3, 305.2548931752382}], 
             PointBox[{20.4, 307.22997192030635`}], 
             PointBox[{20.5, 306.31345320007205`}], 
             PointBox[{20.6, 305.5298524041207}], 
             PointBox[{20.7, 306.10996115338304`}], 
             PointBox[{20.8, 306.3728946846317}], 
             PointBox[{20.9, 303.39584911868354`}], 
             PointBox[{21., 303.84238461466015`}], 
             PointBox[{21.1, 304.3445049212851}], 
             PointBox[{21.2, 303.46969962065447`}], 
             PointBox[{21.3, 302.71739262237907`}], 
             PointBox[{21.4, 304.6650142836361}], 
             PointBox[{21.5, 303.59812871052725`}], 
             PointBox[{21.6, 302.9184712401066}], 
             PointBox[{21.7, 303.58012661737564`}], 
             PointBox[{21.8, 303.60447194460573`}], 
             PointBox[{21.9, 300.6945234723111}], 
             PointBox[{22., 301.30695220033454`}], 
             PointBox[{22.1, 301.7172987368868}], 
             PointBox[{22.2, 300.7461848901797}], 
             PointBox[{22.3, 300.20957075455283`}], 
             PointBox[{22.4, 302.06935078111275`}], 
             PointBox[{22.5, 300.8879602465453}], 
             PointBox[{22.6, 300.31430066628155`}], 
             PointBox[{22.7, 301.04989279138886`}], 
             PointBox[{22.8, 300.800915028909}], 
             PointBox[{22.9, 298.0258460072547}], 
             PointBox[{23., 298.7661341627095}], 
             PointBox[{23.1, 299.08089320995816`}], 
             PointBox[{23.2, 298.01997519015424`}], 
             PointBox[{23.3, 297.7294957451959}], 
             PointBox[{23.4, 299.44483672863544`}], 
             PointBox[{23.5, 298.1836129827985}], 
             PointBox[{23.6, 297.716839962288}], 
             PointBox[{23.7, 298.517306801637}], 
             PointBox[{23.8, 297.9657843540017}], 
             PointBox[{23.9, 295.3862553191743}], 
             PointBox[{24., 296.21883267998874`}], 
             PointBox[{24.1, 296.43499950426974`}], 
             PointBox[{24.2, 295.2928988385356}], 
             PointBox[{24.3, 295.2725970795984}], 
             PointBox[{24.4, 296.79420523803486`}], 
             PointBox[{24.5, 295.48507533338363`}], 
             PointBox[{24.6, 295.12538062287985`}], 
             PointBox[{24.7, 295.9794610039158}], 
             PointBox[{24.8, 295.10429212124063`}], 
             PointBox[{24.9, 292.77146715702685`}], 
             PointBox[{25., 293.6640890548902}], 
             PointBox[{25.1, 293.7793715757623}], 
             PointBox[{25.2, 292.56698474730456`}], 
             PointBox[{25.3, 292.83371008229904`}], 
             PointBox[{25.4, 294.1209354069697}], 
             PointBox[{25.5, 292.7927875802915}], 
             PointBox[{25.6, 292.5396860304821}], 
             PointBox[{25.7, 293.43406804567945`}], 
             PointBox[{25.8, 292.22362218565235`}], 
             PointBox[{25.9, 290.17715691160896`}], 
             PointBox[{26., 291.1014096742194}], 
             PointBox[{26.1, 291.11406679675673`}], 
             PointBox[{26.2, 289.845395968811}], 
             PointBox[{26.3, 290.4060054584818}], 
             PointBox[{26.4, 291.42876148853384`}], 
             PointBox[{26.5, 290.10681157126385`}], 
             PointBox[{26.6, 289.9591941709009}], 
             PointBox[{26.7, 290.87782816430274`}], 
             PointBox[{26.8, 289.3313970090737}], 
             PointBox[{26.9, 287.5988995975648}], 
             PointBox[{27., 288.5302249171775}], 
             PointBox[{27.1, 288.4389969217781}], 
             PointBox[{27.2, 287.13049821345703`}], 
             PointBox[{27.3, 287.9820189294353}], 
             PointBox[{27.4, 288.7212959474466}], 
             PointBox[{27.5, 287.4270802779515}], 
             PointBox[{27.6, 287.3836974100771}], 
             PointBox[{27.7, 288.307507225387}], 
             PointBox[{27.8, 286.43592981063045`}], 
             PointBox[{27.9, 285.0325750279003}], 
             PointBox[{28., 285.9501824649849}], 
             PointBox[{28.1, 285.75423170463125`}], 
             PointBox[{28.2, 284.4255460482707}], 
             PointBox[{28.3, 285.5539927210415}], 
             PointBox[{28.4, 286.0020074056032}], 
             PointBox[{28.5, 284.75352580530506`}], 
             PointBox[{28.6, 284.8122672237623}], 
             PointBox[{28.7, 285.7196111655}], 
             PointBox[{28.8, 283.5453233376518}], 
             PointBox[{28.9, 282.4745367071527}], 
             PointBox[{29., 283.3610622408474}], 
             PointBox[{29.1, 283.05995972461983`}], 
             PointBox[{29.2, 281.7339066088973}], 
             PointBox[{29.3, 283.11464948410594`}], 
             PointBox[{29.4, 283.27410144108694`}], 
             PointBox[{29.5, 282.0860285478823}], 
             PointBox[{29.6, 282.2450402560779}], 
             PointBox[{29.7, 283.11052826201865`}], 
             PointBox[{29.8, 280.66730129519505`}], 
             PointBox[{29.9, 279.9216052082134}], 
             PointBox[{30., 280.76270752603483`}], 
             PointBox[{30.1, 280.35647279163084`}], 
             PointBox[{30.2, 279.0588779464245}], 
             PointBox[{30.3, 280.6572312038646}], 
             PointBox[{30.4, 280.5404206670406}], 
             PointBox[{30.5, 279.4244981443479}], 
             PointBox[{30.6, 279.68088034471003`}], 
             PointBox[{30.7, 280.4765607852566}], 
             PointBox[{30.8, 277.80865255465284`}], 
             PointBox[{30.9, 277.3709822121359}], 
             PointBox[{31., 278.15513432223685`}], 
             PointBox[{31.1, 277.6443326847554}], 
             PointBox[{31.2, 276.4036740008294}], 
             PointBox[{31.3, 278.17668595963767`}], 
             PointBox[{31.4, 277.8035216882221}], 
             PointBox[{31.5, 276.76888594558903`}], 
             PointBox[{31.6, 277.1198579781413}], 
             PointBox[{31.7, 277.8145005328924}], 
             PointBox[{31.8, 274.9750232514074}], 
             PointBox[{31.9, 274.8205864491447}], 
             PointBox[{32., 275.5384123257761}], 
             PointBox[{32.1, 274.924140926527}], 
             PointBox[{32.2, 273.7712871489956}], 
             PointBox[{32.3, 275.6689156046957}], 
             PointBox[{32.4, 275.0654614463366}], 
             PointBox[{32.5, 274.11913597441236`}], 
             PointBox[{32.6, 274.56103233379946`}], 
             PointBox[{32.7, 275.1218049379088}], 
             PointBox[{32.8, 272.17049180686803`}], 
             PointBox[{32.9, 272.2687549008361}], 
             PointBox[{33., 272.91272436004715`}], 
             PointBox[{33.1, 272.19680582203495`}], 
             PointBox[{33.2, 271.16412063975145`}], 
             PointBox[{33.3, 273.1318564941738}], 
             PointBox[{33.4, 272.3282945243469}], 
             PointBox[{33.5, 271.4753487831774}], 
             PointBox[{33.6, 272.00430814274216`}], 
             PointBox[{33.7, 272.3958019355332}], 
             PointBox[{33.8, 269.3973197503127}], 
             PointBox[{33.9, 269.71419803795357`}], 
             PointBox[{34., 270.27813959991204`}], 
             PointBox[{34.1, 269.4632442039911}], 
             PointBox[{34.2, 268.5834662355545}], 
             PointBox[{34.3, 270.5643879236461}], 
             PointBox[{34.4, 269.5932177862132}], 
             PointBox[{34.5, 268.8374526769515}], 
             PointBox[{34.6, 269.4482882740403}], 
             PointBox[{34.7, 269.6362861436416}], 
             PointBox[{34.8, 266.6559196808144}], 
             PointBox[{34.9, 267.1558866163378}], 
             PointBox[{35., 267.63496382348853`}], 
             PointBox[{35.1, 266.72478304604743`}], 
             PointBox[{35.2, 266.0302344838898}], 
             PointBox[{35.3, 267.96719605794857`}], 
             PointBox[{35.4, 266.86168559086343`}], 
             PointBox[{35.5, 266.2056445481513}], 
             PointBox[{35.6, 266.8927898727196}], 
             PointBox[{35.7, 266.8434752489871}], 
             PointBox[{35.8, 263.9457526383793}], 
             PointBox[{35.9, 264.59320961949004`}], 
             PointBox[{36., 264.98355798015535`}], 
             PointBox[{36.1, 263.9830304532801}], 
             PointBox[{36.2, 263.5039150763507}], 
             PointBox[{36.3, 265.3419616084346}], 
             PointBox[{36.4, 264.13487888853746`}], 
             PointBox[{36.5, 263.5801244472978}], 
             PointBox[{36.6, 264.33628425166853`}], 
             PointBox[{36.7, 264.0194812163187}], 
             PointBox[{36.8, 261.26477357913865`}], 
             PointBox[{36.9, 262.02573243104735`}], 
             PointBox[{37., 262.3240785017744}], 
             PointBox[{37.1, 261.2396731726385}], 
             PointBox[{37.2, 261.002477063164}], 
             PointBox[{37.3, 262.69105841776224`}], 
             PointBox[{37.4, 261.41360602767475`}], 
             PointBox[{37.5, 260.9610224422102}], 
             PointBox[{37.6, 261.77759049745634`}], 
             PointBox[{37.7, 261.1678616791415}], 
             PointBox[{37.8, 258.6101987141471}], 
             PointBox[{37.9, 259.4530592338936}], 
             PointBox[{38., 259.65677329943526`}], 
             PointBox[{38.1, 258.49681380512396`}], 
             PointBox[{38.2, 258.5229232715662}], 
             PointBox[{38.3, 260.0174344382603}], 
             PointBox[{38.4, 258.6985611291806}], 
             PointBox[{38.5, 258.34851100440255`}], 
             PointBox[{38.6, 259.2152272221544}], 
             PointBox[{38.7, 258.2939093813947}], 
             PointBox[{38.8, 255.97911133429096`}], 
             PointBox[{38.9, 256.87521866767503`}], 
             PointBox[{39., 256.9819858102196}], 
             PointBox[{39.1, 255.75693308987792`}], 
             PointBox[{39.2, 256.0609074352036}], 
             PointBox[{39.3, 257.3245837841518}], 
             PointBox[{39.4, 255.99044303785126`}], 
             PointBox[{39.5, 255.74282651354008`}], 
             PointBox[{39.6, 256.64725471653924`}], 
             PointBox[{39.7, 255.40376100937}], 
             PointBox[{39.8, 253.368287965977}], 
             PointBox[{39.9, 254.29200707216927`}], 
             PointBox[{40., 254.30004537991013`}], 
             PointBox[{40.1, 253.02270682647304`}], 
             PointBox[{40.2, 253.61104045873677`}], 
             PointBox[{40.3, 254.61602174438588`}], 
             PointBox[{40.4, 253.28987619421716`}], 
             PointBox[{40.5, 253.14408486654625`}], 
             PointBox[{40.6, 254.07132411059808`}], 
             PointBox[{40.7, 252.50460240210145`}], 
             PointBox[{40.8, 250.77454175854405`}], 
             PointBox[{40.9, 251.70346012149622`}], 
             PointBox[{41., 251.6112298064572}], 
             PointBox[{41.1, 250.29711687540967`}], 
             PointBox[{41.2, 251.16726735440002`}], 
             PointBox[{41.3, 251.89524231341107`}], 
             PointBox[{41.4, 250.59726832420557`}], 
             PointBox[{41.5, 250.55276152400208`}], 
             PointBox[{41.6, 251.48494214358468`}], 
             PointBox[{41.7, 249.60398947597753`}], 
             PointBox[{41.8, 248.19496524132927`}], 
             PointBox[{41.9, 249.10976100022168`}], 
             PointBox[{42., 248.9158912728089}], 
             PointBox[{42.1, 247.58366751060416`}], 
             PointBox[{42.2, 248.7230319890951}], 
             PointBox[{42.3, 249.16568999957104`}], 
             PointBox[{42.4, 247.9131509359598}], 
             PointBox[{42.5, 247.96868144107927`}], 
             PointBox[{42.6, 248.88493848999892`}], 
             PointBox[{42.7, 246.70951972459446`}], 
             PointBox[{42.8, 245.62661727701345`}], 
             PointBox[{42.9, 246.51090959824234`}], 
             PointBox[{43., 246.2143461290805}], 
             PointBox[{43.1, 244.88586404886266`}], 
             PointBox[{43.2, 246.27185886396302`}], 
             PointBox[{43.3, 246.43036474980585`}], 
             PointBox[{43.4, 245.23787784047147`}], 
             PointBox[{43.5, 245.392280177993}], 
             PointBox[{43.6, 246.26797942458595`}], 
             PointBox[{43.7, 243.82884339578948`}], 
             PointBox[{43.8, 243.06727340634905`}], 
             PointBox[{43.9, 243.9069306293825}], 
             PointBox[{44., 243.50703174658068`}], 
             PointBox[{44.1, 242.20742391720822`}], 
             PointBox[{44.2, 243.80762249537761`}], 
             PointBox[{44.3, 243.69235642285176`}], 
             PointBox[{44.4, 242.57171970831493`}], 
             PointBox[{44.5, 242.823072548858}], 
             PointBox[{44.6, 243.63038459184656`}], 
             PointBox[{44.7, 240.96882380724387`}], 
             PointBox[{44.8, 240.51442904622974`}], 
             PointBox[{44.9, 241.29782031030595`}], 
             PointBox[{45., 240.79427536599292`}], 
             PointBox[{45.1, 239.55187232273744`}], 
             PointBox[{45.2, 241.32489019252336`}], 
             PointBox[{45.3, 240.95386932522638`}], 
             PointBox[{45.4, 239.91490247829427`}], 
             PointBox[{45.5, 240.2610748063128}], 
             PointBox[{45.6, 240.96845484713367`}], 
             PointBox[{45.7, 238.1357023406295}], 
             PointBox[{45.8, 237.96619692689643`}], 
             PointBox[{45.9, 238.6834654390662}], 
             PointBox[{46., 238.07657893239798`}], 
             PointBox[{46.1, 236.92267782966627`}], 
             PointBox[{46.2, 238.81947700216568`}], 
             PointBox[{46.3, 238.2171043987271}], 
             PointBox[{46.4, 237.26761381247903`}], 
             PointBox[{46.5, 237.7057703182964}], 
             PointBox[{46.6, 238.2786565093689}], 
             PointBox[{46.7, 235.33395143000018`}], 
             PointBox[{46.8, 235.42078091979616`}], 
             PointBox[{46.9, 236.06379547266692`}], 
             PointBox[{47., 235.35456174243927`}], 
             PointBox[{47.1, 234.32252656948708`}], 
             PointBox[{47.2, 236.2883667950531}], 
             PointBox[{47.3, 235.4841189653429}], 
             PointBox[{47.4, 234.62996677063302`}], 
             PointBox[{47.5, 235.15643829198845`}], 
             PointBox[{47.6, 235.55820492555068`}], 
             PointBox[{47.7, 232.56670237279053`}], 
             PointBox[{47.8, 232.87671411111978`}], 
             PointBox[{47.9, 233.43857652009652`}], 
             PointBox[{48., 232.62894815174153`}], 
             PointBox[{48.1, 231.75352361213993`}], 
             PointBox[{48.2, 233.72984905595018`}], 
             PointBox[{48.3, 232.7562137148418}], 
             PointBox[{48.4, 232.00193964216658`}], 
             PointBox[{48.5, 232.6118264682792}], 
             PointBox[{48.6, 232.80515658383788`}], 
             PointBox[{48.7, 229.83512793104472`}], 
             PointBox[{48.8, 230.33256682956466`}], 
             PointBox[{48.9, 230.80765163003832`}], 
             PointBox[{49., 229.90078438373652`}], 
             PointBox[{49.1, 229.21648975311066`}], 
             PointBox[{49.2, 231.1437623051617}], 
             PointBox[{49.3, 230.03469592378167`}], 
             PointBox[{49.4, 229.38358322746922`}], 
             PointBox[{49.5, 230.07188602964314`}], 
             PointBox[{49.6, 230.01927096884776`}], 
             PointBox[{49.7, 227.1387468118555}], 
             PointBox[{49.8, 227.78724092714967`}], 
             PointBox[{49.9, 228.17078389652497`}], 
             PointBox[{50., 227.17134335054982`}], 
             PointBox[{50.1, 226.71089676873785`}], 
             PointBox[{50.2, 228.53106152743132`}], 
             PointBox[{50.3, 227.32052368623442`}], 
             PointBox[{50.4, 226.7748240760156}], 
             PointBox[{50.5, 227.53389697505725`}], 
             PointBox[{50.6, 227.20194876448045`}], 
             PointBox[{50.7, 224.4755512410636}], 
             PointBox[{50.8, 225.2396319077804}], 
             PointBox[{50.9, 225.52768050336945`}], 
             PointBox[{51., 224.44218777260247`}], 
             PointBox[{51.1, 224.2345925812267}], 
             PointBox[{51.2, 225.89363995815518`}], 
             PointBox[{51.3, 224.61447601631795`}], 
             PointBox[{51.4, 224.17549397802634`}], 
             PointBox[{51.5, 224.99620145513867`}], 
             PointBox[{51.6, 224.356604968723}], 
             PointBox[{51.7, 221.8426179179819}], 
             PointBox[{51.8, 222.6888210226586}], 
             PointBox[{51.9, 222.87809468261642`}], 
             PointBox[{52., 221.7152529780911}], 
             PointBox[{52.1, 221.7835788662339}], 
             PointBox[{52.2, 223.23417164014393`}], 
             PointBox[{52.3, 221.9170568647748}], 
             PointBox[{52.4, 221.58542065676895`}], 
             PointBox[{52.5, 222.4563284314039}], 
             PointBox[{52.6, 221.4887299720348}], 
             PointBox[{52.7, 219.23629798403528`}], 
             PointBox[{52.8, 220.1340104615061}], 
             PointBox[{52.9, 220.22175770390987`}], 
             PointBox[{53., 218.99294458868698`}], 
             PointBox[{53.1, 219.35244531337278`}], 
             PointBox[{53.2, 220.55586889813486`}], 
             PointBox[{53.3, 219.22858276727592`}], 
             PointBox[{53.4, 219.0042473662064}], 
             PointBox[{53.5, 219.91110829415294`}], 
             PointBox[{53.6, 218.60498328549207`}], 
             PointBox[{53.7, 216.65228449026202`}], 
             PointBox[{53.8, 217.5742055221148}], 
             PointBox[{53.9, 217.55813533132402`}], 
             PointBox[{54., 216.27777861373906`}], 
             PointBox[{54.1, 216.93396214779074`}], 
             PointBox[{54.2, 217.86207384797336`}], 
             PointBox[{54.3, 216.5490199881044}], 
             PointBox[{54.4, 216.43148366411964`}], 
             PointBox[{54.5, 217.35728094251698`}], 
             PointBox[{54.6, 215.71343016784374`}], 
             PointBox[{54.7, 214.08641521446094`}], 
             PointBox[{54.8, 215.00882789105103`}], 
             PointBox[{54.9, 214.88720643589326`}], 
             PointBox[{55., 213.5729762662331}], 
             PointBox[{55.1, 214.52043897748598`}], 
             PointBox[{55.2, 215.15621140585475`}], 
             PointBox[{55.3, 213.87855164322983`}], 
             PointBox[{55.4, 213.86669617261776`}], 
             PointBox[{55.5, 214.79086221707553`}], 
             PointBox[{55.6, 212.8224983423702}], 
             PointBox[{55.7, 211.53475784977016`}], 
             PointBox[{55.8, 212.4372434391528}], 
             PointBox[{55.9, 212.2086545744383}], 
             PointBox[{56., 210.88174674732747`}], 
             PointBox[{56.1, 212.103423918013}], 
             PointBox[{56.2, 212.441409051845}], 
             PointBox[{56.3, 211.21688808485692`}], 
             PointBox[{56.4, 211.30935339039328`}], 
             PointBox[{56.5, 212.2075623098377}], 
             PointBox[{56.6, 209.94061209684938`}], 
             PointBox[{56.7, 208.9932635448455}], 
             PointBox[{56.8, 209.8586449766629}], 
             PointBox[{56.9, 209.52211574589535`}], 
             PointBox[{57., 208.20768078745598`}], 
             PointBox[{57.1, 209.67495493082328`}], 
             PointBox[{57.2, 209.72077882277821`}], 
             PointBox[{57.3, 208.56385652961345`}], 
             PointBox[{57.4, 208.75854729746877`}], 
             PointBox[{57.5, 209.6029985901462}], 
             PointBox[{57.6, 207.07609499916168`}], 
             PointBox[{57.7, 206.45864406179433`}], 
             PointBox[{57.8, 207.27275653044032`}], 
             PointBox[{57.9, 206.828237597405}], 
             PointBox[{58., 205.5543899268923}], 
             PointBox[{58.1, 207.22781289713708`}], 
             PointBox[{58.2, 206.99694660851543`}], 
             PointBox[{58.3, 205.9192079413389}], 
             PointBox[{58.4, 206.2135183262945}], 
             PointBox[{58.5, 206.97237886631535`}], 
             PointBox[{58.6, 204.23562292006127`}], 
             PointBox[{58.7, 203.92748431997865`}], 
             PointBox[{58.8, 204.67864701900777`}], 
             PointBox[{58.9, 204.12630312821528`}], 
             PointBox[{59., 202.924838223034}], 
             PointBox[{59.1, 204.75586433132}], 
             PointBox[{59.2, 204.2720229818693}], 
             PointBox[{59.3, 203.2823235555128}], 
             PointBox[{59.4, 203.6730989834395}], 
             PointBox[{59.5, 204.31178399237155`}], 
             PointBox[{59.6, 201.4251077784165}], 
             PointBox[{59.7, 201.39751255288013`}], 
             PointBox[{59.8, 202.07634750996297`}], 
             PointBox[{59.9, 201.41752096684132`}], 
             PointBox[{60., 200.32221511588136`}], 
             PointBox[{60.1, 202.25530570874798`}], 
             PointBox[{60.2, 201.54812442875743`}], 
             PointBox[{60.3, 200.653243150918}], 
             PointBox[{60.4, 201.13627862889103`}], 
             PointBox[{60.5, 201.61773587233185`}], 
             PointBox[{60.6, 198.64798568573468`}], 
             PointBox[{60.7, 198.8663398194687}], 
             PointBox[{60.8, 199.46522791156255`}], 
             PointBox[{60.9, 198.70193383479977`}], 
             PointBox[{61., 197.74815859882813`}], 
             PointBox[{61.1, 199.72335542167954`}], 
             PointBox[{61.2, 198.82652623843}], 
             PointBox[{61.3, 198.03126255664708`}], 
             PointBox[{61.4, 198.60200865938526`}], 
             PointBox[{61.5, 198.88793916139895`}], 
             PointBox[{61.6, 195.90561115415605`}], 
             PointBox[{61.7, 196.33188882027414`}], 
             PointBox[{61.8, 196.8449048077587}], 
             PointBox[{61.9, 195.98012692276401`}], 
             PointBox[{62., 195.20361289055398`}], 
             PointBox[{62.1, 197.15941638958336`}], 
             PointBox[{62.2, 196.10860344703178`}], 
             PointBox[{62.3, 195.4161389472864}], 
             PointBox[{62.4, 196.06867486397724`}], 
             PointBox[{62.5, 196.1223268618864}], 
             PointBox[{62.6, 193.19760814893928`}], 
             PointBox[{62.7, 193.79305039306462`}], 
             PointBox[{62.8, 194.21547321990764`}], 
             PointBox[{62.9, 193.25451277032548`}], 
             PointBox[{63., 192.68797159266677`}], 
             PointBox[{63.1, 194.56424934567042`}], 
             PointBox[{63.2, 193.39509865686514`}], 
             PointBox[{63.3, 192.8074169003768}], 
             PointBox[{63.4, 193.53443998268804`}], 
             PointBox[{63.5, 193.32069435035467`}], 
             PointBox[{63.6, 190.52127383491762`}], 
             PointBox[{63.7, 191.2481632642705}], 
             PointBox[{63.8, 191.57620568072682`}], 
             PointBox[{63.9, 190.52529151319547`}], 
             PointBox[{64., 190.1989927367695}], 
             PointBox[{64.1, 191.93964047142094`}], 
             PointBox[{64.2, 190.68650252041334`}], 
             PointBox[{64.3, 190.20451830146604`}], 
             PointBox[{64.4, 190.99704554983703`}], 
             PointBox[{64.5, 190.4875035468738}], 
             PointBox[{64.6, 187.87354621750032`}], 
             PointBox[{64.7, 188.69641323808352`}], 
             PointBox[{64.8, 188.92722270996282`}], 
             PointBox[{64.9, 187.79450018980538`}], 
             PointBox[{65., 187.73303318597664`}], 
             PointBox[{65.1, 189.28854183216416`}], 
             PointBox[{65.2, 187.98335238422743`}], 
             PointBox[{65.3, 187.60725278277275`}], 
             PointBox[{65.4, 188.4548849769371}], 
             PointBox[{65.5, 187.6274689053878}], 
             PointBox[{65.6, 185.25034281611153`}], 
             PointBox[{65.7, 186.13696002408463`}], 
             PointBox[{65.8, 186.26831077194083`}], 
             PointBox[{65.9, 185.0643577337282}], 
             PointBox[{66., 185.2848540712982}], 
             PointBox[{66.1, 186.61413376146675`}], 
             PointBox[{66.2, 185.28568009756623`}], 
             PointBox[{66.3, 185.01499243544734`}], 
             PointBox[{66.4, 185.9048113120269}], 
             PointBox[{66.5, 184.74711718921708`}], 
             PointBox[{66.6, 182.64740168358986`}], 
             PointBox[{66.7, 183.56945289774995`}], 
             PointBox[{66.8, 183.5995562493627}], 
             PointBox[{66.9, 182.3374958784367}], 
             PointBox[{67., 182.84836560552986`}], 
             PointBox[{67.1, 183.92025638880517`}], 
             PointBox[{67.2, 182.59380444115945`}], 
             PointBox[{67.3, 182.4275894815148}], 
             PointBox[{67.4, 183.34431570267188`}], 
             PointBox[{67.5, 181.85414932493038`}], 
             PointBox[{67.6, 180.06067998229284`}], 
             PointBox[{67.7, 180.99347138316006`}], 
             PointBox[{67.8, 180.9211628076504}], 
             PointBox[{67.9, 179.61656885633786`}], 
             PointBox[{68., 180.41673096677084`}], 
             PointBox[{68.1, 181.21078540434837`}], 
             PointBox[{68.2, 179.9080418772182}], 
             PointBox[{68.3, 179.8449229326018}], 
             PointBox[{68.4, 180.77077621610178`}], 
             PointBox[{68.5, 178.95668599113594`}], 
             PointBox[{68.6, 177.48636350068588`}], 
             PointBox[{68.7, 178.40900017988938`}], 
             PointBox[{68.8, 178.23328351968092`}], 
             PointBox[{68.9, 176.90514655334684`}], 
             PointBox[{69., 177.98263194513694`}], 
             PointBox[{69.1, 178.48916646212768`}], 
             PointBox[{69.2, 177.22836734080948`}], 
             PointBox[{69.3, 177.266731638423}], 
             PointBox[{69.4, 178.18071978867292`}], 
             PointBox[{69.5, 176.06230445721624`}], 
             PointBox[{69.6, 174.92067463678993`}], 
             PointBox[{69.7, 175.8156691720447}], 
             PointBox[{69.8, 175.53623892816316`}], 
             PointBox[{69.9, 174.2060000938221}], 
             PointBox[{70., 175.53866257256885`}], 
             PointBox[{70.1, 175.75827228203173`}], 
             PointBox[{70.2, 174.55443045526465`}], 
             PointBox[{70.3, 174.69225573010874`}], 
             PointBox[{70.4, 175.57055111935273`}], 
             PointBox[{70.5, 173.17866983777625`}], 
             PointBox[{70.6, 172.36081814411}], 
             PointBox[{70.7, 173.2136097070819}], 
             PointBox[{70.8, 172.83019692842015`}], 
             PointBox[{70.9, 171.52269382384594`}], 
             PointBox[{71., 173.07884490992532`}], 
             PointBox[{71.1, 173.02152167166898`}], 
             PointBox[{71.2, 171.8867693856918}], 
             PointBox[{71.3, 172.12158705166087`}], 
             PointBox[{71.4, 172.93733774738038`}], 
             PointBox[{71.5, 170.31299253607835`}], 
             PointBox[{71.6, 169.80427628830117`}], 
             PointBox[{71.7, 170.6030040735653}], 
             PointBox[{71.8, 170.11601204021645`}], 
             PointBox[{71.9, 168.85866268325915`}], 
             PointBox[{72., 170.59778144288927`}], 
             PointBox[{72.1, 170.28142357161778`}], 
             PointBox[{72.2, 169.22533037201694`}], 
             PointBox[{72.3, 169.554458382708}], 
             PointBox[{72.4, 170.27774223774085`}], 
             PointBox[{72.5, 167.470989398077}], 
             PointBox[{72.6, 167.24919158696298`}], 
             PointBox[{72.7, 167.98408303580385`}], 
             PointBox[{72.8, 167.39440240174994`}], 
             PointBox[{72.9, 166.21713469019033`}], 
             PointBox[{73., 168.0915805257898}], 
             PointBox[{73.1, 167.540261389033}], 
             PointBox[{73.2, 166.5703069080835}], 
             PointBox[{73.3, 166.99076374273542`}], 
             PointBox[{73.4, 167.5890460912106}], 
             PointBox[{73.5, 164.6571168476367}], 
             PointBox[{73.6, 164.6937462483405}], 
             PointBox[{73.7, 165.3569471952427}], 
             PointBox[{73.8, 164.66590358712628`}], 
             PointBox[{73.9, 163.6003048536495}], 
             PointBox[{74., 165.55743890853628`}], 
             PointBox[{74.1, 164.79975854474182`}], 
             PointBox[{74.2, 163.92165558080205`}], 
             PointBox[{74.3, 164.42969143449736`}], 
             PointBox[{74.4, 164.86884080314636`}], 
             PointBox[{74.5, 161.87420132289708`}], 
             PointBox[{74.6, 162.13681091163755`}], 
             PointBox[{74.7, 162.7218867421331}], 
             PointBox[{74.8, 161.9319314208456}], 
             PointBox[{74.9, 161.01068531637253`}], 
             PointBox[{75., 162.99448151816878`}], 
             PointBox[{75.1, 162.06196033071382`}], 
             PointBox[{75.2, 161.27982821079962`}], 
             PointBox[{75.3, 161.87084131336067`}], 
             PointBox[{75.4, 162.11603984782877`}], 
             PointBox[{75.5, 159.12347343317023`}], 
             PointBox[{75.6, 159.57739944007088`}], 
             PointBox[{75.7, 160.0791540333662}], 
             PointBox[{75.8, 159.193319533615}], 
             PointBox[{75.9, 158.44902334027364`}], 
             PointBox[{76., 160.4025849927736}], 
             PointBox[{76.1, 159.32796938036813`}], 
             PointBox[{76.2, 158.64477101251188`}], 
             PointBox[{76.3, 159.31313514839403`}], 
             PointBox[{76.4, 159.3304335273713}], 
             PointBox[{76.5, 156.40462646760494`}], 
             PointBox[{76.6, 157.01484267018884`}], 
             PointBox[{76.7, 157.42889980912454`}], 
             PointBox[{76.8, 156.45167556350296`}], 
             PointBox[{76.9, 155.91519487027608`}], 
             PointBox[{77., 157.78313705938612`}], 
             PointBox[{77.1, 156.599078503526}], 
             PointBox[{77.2, 156.01688571765436`}], 
             PointBox[{77.3, 156.75633227926204`}], 
             PointBox[{77.4, 156.51373616641027`}], 
             PointBox[{77.5, 153.7163140904196}], 
             PointBox[{77.6, 154.44865640853945`}], 
             PointBox[{77.7, 154.77155798192572`}], 
             PointBox[{77.8, 153.7088524483284}], 
             PointBox[{77.9, 153.40816661460633`}], 
             PointBox[{78., 155.13828416260486`}], 
             PointBox[{78.1, 153.87624018855533`}], 
             PointBox[{78.2, 153.39633819212463`}], 
             PointBox[{78.3, 154.19866847861465`}], 
             PointBox[{78.4, 153.66884922733516`}], 
             PointBox[{78.5, 151.0561439916964}], 
             PointBox[{78.6, 151.87848307292512`}], 
             PointBox[{78.7, 152.10723562160467`}], 
             PointBox[{78.8, 150.9664655383058}], 
             PointBox[{78.9, 150.92505204423176`}], 
             PointBox[{79., 152.47081633088675`}], 
             PointBox[{79.1, 151.160383680899}], 
             PointBox[{79.2, 150.7834013645706}], 
             PointBox[{79.3, 151.63908437161714`}], 
             PointBox[{79.4, 150.80062280559034`}], 
             PointBox[{79.5, 148.4212804220524}], 
             PointBox[{79.6, 149.3040783218962}], 
             PointBox[{79.7, 149.4361465088866}], 
             PointBox[{79.8, 148.22737803190202`}], 
             PointBox[{79.9, 148.46184535998262`}], 
             PointBox[{80., 149.78392184201928`}], 
             PointBox[{80.1, 148.4521847581865}], 
             PointBox[{80.2, 148.1782457802107}], 
             PointBox[{80.3, 149.07473034848147`}], 
             PointBox[{80.4, 147.9147893502138}], 
             PointBox[{80.5, 145.80859467883857`}], 
             PointBox[{80.6, 146.72538588796652`}], 
             PointBox[{80.7, 146.7586347556252}], 
             PointBox[{80.8, 145.4939189015497}], 
             PointBox[{80.9, 146.01361238822142`}], 
             PointBox[{81., 147.08109922597905`}], 
             PointBox[{81.1, 145.75220038609118`}], 
             PointBox[{81.2, 145.58121484599687`}], 
             PointBox[{81.3, 146.50479323645115`}], 
             PointBox[{81.4, 145.0184144035678}], 
             PointBox[{81.5, 143.21473908789403`}], 
             PointBox[{81.6, 144.14214540383284`}], 
             PointBox[{81.7, 144.07473173821523`}], 
             PointBox[{81.8, 142.76912583547858`}], 
             PointBox[{81.9, 143.57388372958204`}], 
             PointBox[{82., 144.3657152040876}], 
             PointBox[{82.1, 143.06090412567326`}], 
             PointBox[{82.2, 142.99218855834263`}], 
             PointBox[{82.3, 143.92534956264595`}], 
             PointBox[{82.4, 142.11902805359622`}], 
             PointBox[{82.5, 140.63674599858277`}], 
             PointBox[{82.6, 141.55435638078308`}], 
             PointBox[{82.7, 141.3847466203968}], 
             PointBox[{82.8, 140.056204971087}], 
             PointBox[{82.9, 141.1361097528283}], 
             PointBox[{83., 141.64113604108087`}], 
             PointBox[{83.1, 140.37870477657148`}], 
             PointBox[{83.2, 140.4113294059398}], 
             PointBox[{83.3, 141.33339046354075`}], 
             PointBox[{83.4, 139.2244580136908}], 
             PointBox[{83.5, 138.0714746239594}], 
             PointBox[{83.6, 138.9618665028708}], 
             PointBox[{83.7, 138.68878896496224`}], 
             PointBox[{83.8, 137.35891626603367`}], 
             PointBox[{83.9, 138.69330610067107`}], 
             PointBox[{84., 138.9105819710716}], 
             PointBox[{84.1, 137.70589663547318`}], 
             PointBox[{84.2, 137.83866176633683`}], 
             PointBox[{84.3, 138.72533749508406`}], 
             PointBox[{84.4, 136.34239289795084`}], 
             PointBox[{84.5, 135.5161405958296}], 
             PointBox[{84.6, 136.36453212103433`}], 
             PointBox[{84.7, 135.98707276237252`}], 
             PointBox[{84.8, 134.68078208708178`}], 
             PointBox[{84.9, 136.23899724160077`}], 
             PointBox[{85., 136.17688527086983`}], 
             PointBox[{85.1, 135.04274689560586`}], 
             PointBox[{85.2, 135.27391994195347`}], 
             PointBox[{85.3, 136.09745777928924`}], 
             PointBox[{85.4, 133.48036408782076`}], 
             PointBox[{85.5, 132.9684354699261}], 
             PointBox[{85.6, 133.76221973816416`}], 
             PointBox[{85.7, 133.2799328332417}], 
             PointBox[{85.8, 132.0253860291829}], 
             PointBox[{85.9, 133.76696434719972`}], 
             PointBox[{86., 133.4424681764031}], 
             PointBox[{86.1, 132.38923915027212`}], 
             PointBox[{86.2, 132.71692862499123`}], 
             PointBox[{86.3, 133.4455869237889}], 
             PointBox[{86.4, 130.6446731375327}], 
             PointBox[{86.5, 130.42597852506532`}], 
             PointBox[{86.6, 131.1546938107078}], 
             PointBox[{86.7, 130.56780003932053`}], 
             PointBox[{86.8, 129.3963457372823}], 
             PointBox[{86.9, 131.2727013266528}], 
             PointBox[{87., 130.70966822024147`}], 
             PointBox[{87.1, 129.74558653938007`}], 
             PointBox[{87.2, 130.16679894316985`}], 
             PointBox[{87.3, 130.76590418184006`}], 
             PointBox[{87.4, 127.84036662077031`}], 
             PointBox[{87.5, 127.88648941899524`}], 
             PointBox[{87.6, 128.5415796542848}], 
             PointBox[{87.7, 127.85086746646921`}], 
             PointBox[{87.8, 126.79636316499715`}], 
             PointBox[{87.9, 128.75251076018583`}], 
             PointBox[{88., 127.9801948451443}], 
             PointBox[{88.1, 127.11162980000358`}], 
             PointBox[{88.2, 127.62269202056942`}], 
             PointBox[{88.3, 128.055242754803}], 
             PointBox[{88.4, 125.07074695226954`}], 
             PointBox[{88.5, 125.34844126441197`}], 
             PointBox[{88.6, 125.92267356261667`}], 
             PointBox[{88.7, 125.12987522143949`}], 
             PointBox[{88.8, 124.22777733794068`}], 
             PointBox[{88.9, 126.20442911792509`}], 
             PointBox[{89., 125.2556409593821}], 
             PointBox[{89.1, 124.48736424389512`}], 
             PointBox[{89.2, 125.08408188126727`}], 
             PointBox[{89.3, 125.31135324254721`}], 
             PointBox[{89.4, 122.33747526327797`}], 
             PointBox[{89.5, 122.81038764431395`}], 
             PointBox[{89.6, 123.2977804955341}], 
             PointBox[{89.7, 122.40622575902357`}], 
             PointBox[{89.8, 121.69130850655935`}], 
             PointBox[{89.9, 123.62797156892712`}], 
             PointBox[{90., 122.53728833261891`}], 
             PointBox[{90.1, 121.87271980628141`}], 
             PointBox[{90.2, 122.54889420312692`}], 
             PointBox[{90.3, 122.53371113147561`}], 
             PointBox[{90.4, 119.63993980662187`}], 
             PointBox[{90.5, 120.27068881966738`}], 
             PointBox[{90.6, 120.66635982773796`}], 
             PointBox[{90.7, 119.68054937871854`}], 
             PointBox[{90.8, 119.18654924109381`}], 
             PointBox[{90.9, 121.02371482559127`}], 
             PointBox[{91., 119.82599437505442`}], 
             PointBox[{91.1, 119.26740599536531`}], 
             PointBox[{91.2, 120.01583347705733`}], 
             PointBox[{91.3, 119.72337488616715`}], 
             PointBox[{91.4, 116.97615259422432`}], 
             PointBox[{91.5, 117.72829968217175`}], 
             PointBox[{91.6, 118.0281968128926}], 
             PointBox[{91.7, 116.95448356785748`}], 
             PointBox[{91.8, 116.71141358183984`}], 
             PointBox[{91.9, 118.39361116913855`}], 
             PointBox[{92., 117.12241331488718`}], 
             PointBox[{92.1, 116.67114869171479`}], 
             PointBox[{92.2, 117.48307635359247`}], 
             PointBox[{92.3, 116.88368818919594`}], 
             PointBox[{92.4, 114.3429550764966}], 
             PointBox[{92.5, 115.18193172732731`}], 
             PointBox[{92.6, 115.38276335953026`}], 
             PointBox[{92.7, 114.22972216112133`}], 
             PointBox[{92.8, 114.26161593759599`}], 
             PointBox[{92.9, 115.74008397264646`}], 
             PointBox[{93., 114.42684987749018`}], 
             PointBox[{93.1, 114.08342836590711`}], 
             PointBox[{93.2, 114.94718824499749`}], 
             PointBox[{93.3, 114.01980978373419`}], 
             PointBox[{93.4, 111.73635237811283`}], 
             PointBox[{93.5, 112.63074769110253`}], 
             PointBox[{93.6, 112.72974199523958`}], 
             PointBox[{93.7, 111.50868476201538`}], 
             PointBox[{93.8, 111.83165082181101`}], 
             PointBox[{93.9, 113.06641519574018`}], 
             PointBox[{94., 111.73961958297232`}], 
             PointBox[{94.1, 111.50397196685111`}], 
             PointBox[{94.2, 112.40581568749664`}], 
             PointBox[{94.3, 111.13872143687063`}], 
             PointBox[{94.4, 109.15207488919035`}], 
             PointBox[{94.5, 110.07380811532943`}], 
             PointBox[{94.6, 110.06871379859535`}], 
             PointBox[{94.7, 108.7938939396636}], 
             PointBox[{94.8, 109.41445336700336`}], 
             PointBox[{94.9, 110.37608499792606`}], 
             PointBox[{95., 109.06080119444897`}], 
             PointBox[{95.1, 108.93227764435755`}], 
             PointBox[{95.2, 109.85514522898015`}], 
             PointBox[{95.3, 108.2484498491995}], 
             PointBox[{95.4, 106.58576460209332`}], 
             PointBox[{95.5, 107.51041669386146`}], 
             PointBox[{95.6, 107.39973917867631`}], 
             PointBox[{95.7, 106.08844047904891`}], 
             PointBox[{95.8, 107.00215290067295`}], 
             PointBox[{95.9, 107.67256436554703`}], 
             PointBox[{96., 106.39032264326704`}], 
             PointBox[{96.1, 106.36776219577654`}], 
             PointBox[{96.2, 107.29138354783808`}], 
             PointBox[{96.3, 105.35743240266618`}], 
             PointBox[{96.4, 104.03314821645961`}], 
             PointBox[{96.5, 104.93991441099882`}], 
             PointBox[{96.6, 104.72212555380864`}], 
             PointBox[{96.7, 103.39561937134592`}], 
             PointBox[{96.8, 104.58633454193478`}], 
             PointBox[{96.9, 104.95914219929764`}], 
             PointBox[{97., 103.72800810783616`}], 
             PointBox[{97.1, 103.80975887895225`}], 
             PointBox[{97.2, 104.71038507956864`}], 
             PointBox[{97.3, 102.47427529451784`}], 
             PointBox[{97.4, 101.4902523046348}], 
             PointBox[{97.5, 102.36169487344347`}], 
             PointBox[{97.6, 102.03634892870826`}], 
             PointBox[{97.7, 100.71886073052649`}], 
             PointBox[{97.8, 102.15891614061755`}], 
             PointBox[{97.9, 102.23887980254437`}], 
             PointBox[{98., 101.07358066937428`}], 
             PointBox[{98.1, 101.25750772864924`}], 
             PointBox[{98.2, 102.1077471857986}], 
             PointBox[{98.3, 99.60688723438551}], 
             PointBox[{98.4, 98.95356087542609}], 
             PointBox[{98.5, 99.77528095642583}], 
             PointBox[{98.6, 99.341991142704}], 
             PointBox[{98.7, 98.06157366827573}], 
             PointBox[{98.8, 99.71274334897967}], 
             PointBox[{98.9, 99.51449406193456}], 
             PointBox[{99., 98.42672801724393}], 
             PointBox[{99.1, 98.71021657945096}], 
             PointBox[{99.2, 99.47910769615861}], 
             PointBox[{99.3, 96.76262382317915}], 
             PointBox[{99.4, 96.4199949682951}], 
             PointBox[{99.5, 97.18021976841516}], 
             PointBox[{99.6, 96.6393917951635}], 
             PointBox[{99.7, 95.42699801652074}], 
             PointBox[{99.8, 97.24176542827745}], 
             PointBox[{99.9, 96.78827369160831}], 
             PointBox[{100., 95.78709309800837}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 360}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
             40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {
             0, -180}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
             PointBox[{0.1, 1.5119797898218508`}], 
             PointBox[{0.2, 0.19778021500053455`}], 
             PointBox[{0.3, -0.011912384163338174`}], 
             PointBox[{0.4, 1.0841340305275935`}], 
             PointBox[{0.5, -0.03852207638158234}], 
             PointBox[{0.6, -0.8815915943153527}], 
             PointBox[{0.7, 0.17530483139398712`}], 
             PointBox[{0.8, -0.1415932240767006}], 
             PointBox[{0.9, -1.4536683352553155`}], 
             PointBox[{1., 0.39932296459198824`}], 
             PointBox[{1.1, 1.5567503534749108`}], 
             PointBox[{1.2, 0.2600298527146947}], 
             PointBox[{1.3, 0.1584458821437238}], 
             PointBox[{1.4, 1.2736066934334076`}], 
             PointBox[{1.5, -0.11383465694359529`}], 
             PointBox[{1.6, -0.6724482509473546}], 
             PointBox[{1.7, 0.3284676470817658}], 
             PointBox[{1.8, -0.09431916203527635}], 
             PointBox[{1.9, -1.3818497351257975`}], 
             PointBox[{2., 0.786677597511698}], 
             PointBox[{2.1, 1.5876532553811558`}], 
             PointBox[{2.2, 0.32487312075431873`}], 
             PointBox[{2.3, 0.33200283261930963`}], 
             PointBox[{2.4, 1.443184521011517}], 
             PointBox[{2.5, -0.18439783863709636`}], 
             PointBox[{2.6, -0.463193962126752}], 
             PointBox[{2.7, 0.467498571353417}], 
             PointBox[{2.8, -0.05988034157326183}], 
             PointBox[{2.9, -1.2963190132788895`}], 
             PointBox[{3., 1.1505283729184157`}], 
             PointBox[{3.1, 1.603955585269432}], 
             PointBox[{3.2, 0.3889863917825096}], 
             PointBox[{3.3, 0.5052711052335326}], 
             PointBox[{3.4, 1.5861483250580477`}], 
             PointBox[{3.5, -0.2473239859559726}], 
             PointBox[{3.6, -0.25927281906160715`}], 
             PointBox[{3.7, 0.5897282695241302}], 
             PointBox[{3.8, -0.04023862672056566}], 
             PointBox[{3.9, -1.1956806066532408`}], 
             PointBox[{4., 1.4809928746367405`}], 
             PointBox[{4.1, 1.605363766922892}], 
             PointBox[{4.2, 0.4498052786225344}], 
             PointBox[{4.3, 0.6751101704112443}], 
             PointBox[{4.4, 1.6961132853853087`}], 
             PointBox[{4.5, -0.3004340321685959}], 
             PointBox[{4.6, -0.06602638813046724}], 
             PointBox[{4.7, 0.6918186818720642}], 
             PointBox[{4.8, -0.03823648800380397}], 
             PointBox[{4.9, -1.079407853173052}], 
             PointBox[{5., 1.7691060654187822`}], 
             PointBox[{5.1, 1.5907560877990363`}], 
             PointBox[{5.2, 0.5043149555763193}], 
             PointBox[{5.3, 0.837931609907173}], 
             PointBox[{5.4, 1.767682562202026}], 
             PointBox[{5.5, -0.3425948241151673}], 
             PointBox[{5.6, 0.11191265866864342`}], 
             PointBox[{5.7, 0.771077815685203}], 
             PointBox[{5.8, -0.055848144748779305`}], 
             PointBox[{5.9, -0.9461317107425202}], 
             PointBox[{6., 2.0084697304200745`}], 
             PointBox[{6.1, 1.5598353088180374`}], 
             PointBox[{6.2, 0.5505927661170062}], 
             PointBox[{6.3, 0.990915375984514}], 
             PointBox[{6.4, 1.7954428765960984`}], 
             PointBox[{6.5, -0.37353505807186593`}], 
             PointBox[{6.6, 0.2706238672180916}], 
             PointBox[{6.7, 0.8253569552762201}], 
             PointBox[{6.8, -0.09481695616432262}], 
             PointBox[{6.9, -0.7951127095948323}], 
             PointBox[{7., 2.1945544781183344`}], 
             PointBox[{7.1, 1.5118368374760394`}], 
             PointBox[{7.2, 0.586622467527377}], 
             PointBox[{7.3, 1.1316630599449127`}], 
             PointBox[{7.4, 1.7762984223727472`}], 
             PointBox[{7.5, -0.3937935163557995}], 
             PointBox[{7.6, 0.4068474653104204}], 
             PointBox[{7.7, 0.8529243653010781}], 
             PointBox[{7.8, -0.15531104233559745`}], 
             PointBox[{7.9, -0.626114182134188}], 
             PointBox[{8., 2.3252392461918134`}], 
             PointBox[{8.1, 1.4465097985676039`}], 
             PointBox[{8.2, 0.6111201647045164}], 
             PointBox[{8.3, 1.2575692232239817`}], 
             PointBox[{8.4, 1.7076123799506604`}], 
             PointBox[{8.5, -0.4049849727371111}], 
             PointBox[{8.6, 0.5181428684609273}], 
             PointBox[{8.7, 0.8523192991942778}], 
             PointBox[{8.8, -0.23771320571177057`}], 
             PointBox[{8.9, -0.4398240057807925}], 
             PointBox[{9., 2.400543131323502}], 
             PointBox[{9.1, 1.364079085481535}], 
             PointBox[{9.2, 0.6234003793797456}], 
             PointBox[{9.3, 1.3662174322516876`}], 
             PointBox[{9.4, 1.5897584649601413`}], 
             PointBox[{9.5, -0.4089220706546257}], 
             PointBox[{9.6, 0.6028479283322667}], 
             PointBox[{9.7, 0.8229985056368605}], 
             PointBox[{9.8, -0.34065414835367847`}], 
             PointBox[{9.9, -0.23860479014729208`}], 
             PointBox[{10., 2.4220789440441877`}], 
             PointBox[{10.1, 1.2649326076589205`}], 
             PointBox[{10.2, 0.6231239662456574}], 
             PointBox[{10.3, 1.4556425242781188`}], 
             PointBox[{10.4, 1.4243160141395492`}], 
             PointBox[{10.5, -0.408149983038129}], 
             PointBox[{10.6, 0.6597619496606058}], 
             PointBox[{10.7, 0.7646603223247439}], 
             PointBox[{10.8, -0.46302661359823105`}], 
             PointBox[{10.9, -0.025909733970365778`}], 
             PointBox[{11., 2.3931268838468895`}], 
             PointBox[{11.1, 1.1499391558936622`}], 
             PointBox[{11.2, 0.610678627622292}], 
             PointBox[{11.3, 1.5237719837023178`}], 
             PointBox[{11.4, 1.215267410450906}], 
             PointBox[{11.5, -0.4052109063950411}], 
             PointBox[{11.6, 0.6887183493063276}], 
             PointBox[{11.7, 0.6778220766091181}], 
             PointBox[{11.8, -0.6011400293782572}], 
             PointBox[{11.9, 0.19290584109876363`}], 
             PointBox[{12., 2.3180776894714654`}], 
             PointBox[{12.1, 1.0204587181615352`}], 
             PointBox[{12.2, 0.586975873568008}], 
             PointBox[{12.3, 1.5696390668690583`}], 
             PointBox[{12.4, 0.9691356875791826}], 
             PointBox[{12.5, -0.40248101834549743`}], 
             PointBox[{12.6, 0.6900472530232946}], 
             PointBox[{12.7, 0.5636048829092033}], 
             PointBox[{12.8, -0.7514571099673049}], 
             PointBox[{12.9, 0.41095457221308607`}], 
             PointBox[{13., 2.2018376068099315`}], 
             PointBox[{13.1, 0.8781191950129141}], 
             PointBox[{13.2, 0.5530086125745584}], 
             PointBox[{13.3, 1.5901436371386808`}], 
             PointBox[{13.4, 0.6935997290747764}], 
             PointBox[{13.5, -0.40237292401616287`}], 
             PointBox[{13.6, 0.6648897356590169}], 
             PointBox[{13.7, 0.42356956326511863`}], 
             PointBox[{13.8, -0.9088072826398275}], 
             PointBox[{13.9, 0.6209036210075283}], 
             PointBox[{14., 2.0504514859003393`}], 
             PointBox[{14.1, 0.7254549075369141}], 
             PointBox[{14.2, 0.5112043497574632}], 
             PointBox[{14.3, 1.5850314622402948`}], 
             PointBox[{14.4, 0.39851690785508254`}], 
             PointBox[{14.5, -0.4061288066459383}], 
             PointBox[{14.6, 0.6150193171870342}], 
             PointBox[{14.7, 0.26008816552348435`}], 
             PointBox[{14.8, -1.0672164436036837`}], 
             PointBox[{14.9, 0.8148279364468181}], 
             PointBox[{15., 1.8697677789004956`}], 
             PointBox[{15.1, 0.5648566772069898}], 
             PointBox[{15.2, 0.4633957933710917}], 
             PointBox[{15.3, 1.552350123089127}], 
             PointBox[{15.4, 0.09365211732620082}], 
             PointBox[{15.5, -0.41539113561884733`}], 
             PointBox[{15.6, 0.54233400724479}], 
             PointBox[{15.7, 0.07560761297463614}], 
             PointBox[{15.8, -1.2202260385893169`}], 
             PointBox[{15.9, 0.9848387986403395}], 
             PointBox[{16., 1.6657372713325458`}], 
             PointBox[{16.1, 0.3991538322534325}], 
             PointBox[{16.2, 0.4119409139002528}], 
             PointBox[{16.3, 1.4906907139957184`}], 
             PointBox[{16.4, -0.21060045415106288`}], 
             PointBox[{16.5, -0.4305964207069337}], 
             PointBox[{16.6, 0.4495170032751048}], 
             PointBox[{16.7, -0.12654205711260147`}], 
             PointBox[{16.8, -1.3602135822475248`}], 
             PointBox[{16.9, 1.1244656869530445`}], 
             PointBox[{17., 1.4447219012454298`}], 
             PointBox[{17.1, 0.2317507935113099}], 
             PointBox[{17.2, 0.35950597943156026`}], 
             PointBox[{17.3, 1.399162970663383}], 
             PointBox[{17.4, -0.5043164969702048}], 
             PointBox[{17.5, -0.4516675877966918}], 
             PointBox[{17.6, 0.3396055660050479}], 
             PointBox[{17.7, -0.3427859185849229}], 
             PointBox[{17.8, -1.4796601092039054`}], 
             PointBox[{17.9, 1.2286472154446528`}], 
             PointBox[{18., 1.2125244038506935`}], 
             PointBox[{18.1, 0.06590540377874277}], 
             PointBox[{18.2, 0.3087521428333275}], 
             PointBox[{18.3, 1.2773387227025523`}], 
             PointBox[{18.4, -0.7786925461205101}], 
             PointBox[{18.5, -0.4776667845690099}], 
             PointBox[{18.6, 0.21595381539555092`}], 
             PointBox[{18.7, -0.5690266874771623}], 
             PointBox[{18.8, -1.5705992543662433`}], 
             PointBox[{18.9, 1.2945395822207502`}], 
             PointBox[{19., 0.975097189846565}], 
             PointBox[{19.1, -0.09470629909810668}], 
             PointBox[{19.2, 0.2627611414882267}], 
             PointBox[{19.3, 1.1251908436788653`}], 
             PointBox[{19.4, -1.0265492876769713`}], 
             PointBox[{19.5, -0.5077364647077047}], 
             PointBox[{19.6, 0.08185692643019138}], 
             PointBox[{19.7, -0.8008966845482064}], 
             PointBox[{19.8, -1.6262169993588032`}], 
             PointBox[{19.9, 1.3216434258865775`}], 
             PointBox[{20., 0.7379370207509055}], 
             PointBox[{20.1, -0.24646465801743034`}], 
             PointBox[{20.2, 0.223909078129509}], 
             PointBox[{20.3, 0.9439751090794744}], 
             PointBox[{20.4, -1.2423633584003255`}], 
             PointBox[{20.5, -0.5401021311627119}], 
             PointBox[{20.6, -0.05909329773930949}], 
             PointBox[{20.7, -1.0340514157705911`}], 
             PointBox[{20.8, -1.64042384102504}], 
             PointBox[{20.9, 1.312142179820512}], 
             PointBox[{21., 0.5061764173660777}], 
             PointBox[{21.1, -0.38586672243400244`}], 
             PointBox[{21.2, 0.19433061885865754`}], 
             PointBox[{21.3, 0.7358143660512724}], 
             PointBox[{21.4, -1.4224136100401665`}], 
             PointBox[{21.5, -0.5730445839944878}], 
             PointBox[{21.6, -0.20354443266114686`}], 
             PointBox[{21.7, -1.2637971248477697`}], 
             PointBox[{21.8, -1.609807101005572}], 
             PointBox[{21.9, 1.2696962730351515`}], 
             PointBox[{22., 0.28413888465183845`}], 
             PointBox[{22.1, -0.5099262647090654}], 
             PointBox[{22.2, 0.175473222258006}], 
             PointBox[{22.3, 0.5044736708478013}], 
             PointBox[{22.4, -1.5647160465068737`}], 
             PointBox[{22.5, -0.6045123071598937}], 
             PointBox[{22.6, -0.3482215867334162}], 
             PointBox[{22.7, -1.48518018041068}], 
             PointBox[{22.8, -1.532070792032755}], 
             PointBox[{22.9, 1.2000615908218606`}], 
             PointBox[{23., 0.07629397104756208}], 
             PointBox[{23.1, -0.6152792503817182}], 
             PointBox[{23.2, 0.16897741156935808`}], 
             PointBox[{23.3, 0.2545347117957135}], 
             PointBox[{23.4, -1.668497509406734}], 
             PointBox[{23.5, -0.632511525425798}], 
             PointBox[{23.6, -0.4899412229497102}], 
             PointBox[{23.7, -1.6934558935572568`}], 
             PointBox[{23.8, -1.408157818554173}], 
             PointBox[{23.9, 1.109885794296133}], 
             PointBox[{24., -0.11353900015819818`}], 
             PointBox[{24.1, -0.6989897482926608}], 
             PointBox[{24.2, 0.175613492840057}], 
             PointBox[{24.3, -0.00671641866574646}], 
             PointBox[{24.4, -1.73388517895728}], 
             PointBox[{24.5, -0.654348856627621}], 
             PointBox[{24.6, -0.6252792088052956}], 
             PointBox[{24.7, -1.8829143691145873`}], 
             PointBox[{24.8, -1.2410077566128166`}], 
             PointBox[{24.9, 1.00641127934432}], 
             PointBox[{25., -0.28185679958187393`}], 
             PointBox[{25.1, -0.7583710601975326}], 
             PointBox[{25.2, 0.1956603622638795}], 
             PointBox[{25.3, -0.27181848593318136`}], 
             PointBox[{25.4, -1.76222390269686}], 
             PointBox[{25.5, -0.6683233863113855}], 
             PointBox[{25.6, -0.7518923515817733}], 
             PointBox[{25.7, -2.0490707035933156`}], 
             PointBox[{25.8, -1.0366146216911147`}], 
             PointBox[{25.9, 0.8962354464674718}], 
             PointBox[{26., -0.42627463018288836`}], 
             PointBox[{26.1, -0.7917045797948958}], 
             PointBox[{26.2, 0.2276740556844743}], 
             PointBox[{26.3, -0.5321917973342352}], 
             PointBox[{26.4, -1.7556569913140265`}], 
             PointBox[{26.5, -0.6728839304596477}], 
             PointBox[{26.6, -0.8676178514906496}], 
             PointBox[{26.7, -2.1869459407535032`}], 
             PointBox[{26.8, -0.8022655376080365}], 
             PointBox[{26.9, 0.7855610664737469}], 
             PointBox[{27., -0.5447527819924289}], 
             PointBox[{27.1, -0.7975080442156468}], 
             PointBox[{27.2, 0.27054061489980086`}], 
             PointBox[{27.3, -0.7789960422815057}], 
             PointBox[{27.4, -1.7165750992717221`}], 
             PointBox[{27.5, -0.6666861468256684}], 
             PointBox[{27.6, -0.9709765610496106}], 
             PointBox[{27.7, -2.2918889815264265`}], 
             PointBox[{27.8, -0.5465247594547691}], 
             PointBox[{27.9, 0.6799076211827924}], 
             PointBox[{28., -0.635855410440854}], 
             PointBox[{28.1, -0.7748572078089637}], 
             PointBox[{28.2, 0.32189909687440377`}], 
             PointBox[{28.3, -1.0035041436640313`}], 
             PointBox[{28.4, -1.6476552301137417`}], 
             PointBox[{28.5, -0.6488423281734867}], 
             PointBox[{28.6, -1.0602327063206758`}], 
             PointBox[{28.7, -2.3594659032933123`}], 
             PointBox[{28.8, -0.27825692864280427`}], 
             PointBox[{28.9, 0.5837710219493601}], 
             PointBox[{29., -0.6987903725930664}], 
             PointBox[{29.1, -0.7234554208771442}], 
             PointBox[{29.2, 0.37876862015764345`}], 
             PointBox[{29.3, -1.1979893084317155`}], 
             PointBox[{29.4, -1.5517969799730054`}], 
             PointBox[{29.5, -0.618910357101413}], 
             PointBox[{29.6, -1.1352255195561156`}], 
             PointBox[{29.7, -2.3855767660315905`}], 
             PointBox[{29.8, -0.006223039072210668}], 
             PointBox[{29.9, 0.5006501674797619}], 
             PointBox[{30., -0.7333242517779581}], 
             PointBox[{30.1, -0.6435993511986453}], 
             PointBox[{30.2, 0.4377377335658821}], 
             PointBox[{30.3, -1.3557156061433489`}], 
             PointBox[{30.4, -1.4320283624110743`}], 
             PointBox[{30.5, -0.5769758783862926}], 
             PointBox[{30.6, -1.1950061667412228`}], 
             PointBox[{30.7, -2.3665787844620354`}], 
             PointBox[{30.8, 0.26163064288994065`}], 
             PointBox[{30.9, 0.43309993178991135`}], 
             PointBox[{31., -0.7399148481199518}], 
             PointBox[{31.1, -0.5363684279545851}], 
             PointBox[{31.2, 0.4949911990224791}], 
             PointBox[{31.3, -1.4722112978779478`}], 
             PointBox[{31.4, -1.2915747745973931`}], 
             PointBox[{31.5, -0.5236551660200348}], 
             PointBox[{31.6, -1.2403268391353777`}], 
             PointBox[{31.7, -2.2997324804164236`}], 
             PointBox[{31.8, 0.5184157286894333}], 
             PointBox[{31.9, 0.38247491739093675`}], 
             PointBox[{32., -0.7195529182317841}], 
             PointBox[{32.1, -0.4033630841804552}], 
             PointBox[{32.2, 0.5463955351006007}], 
             PointBox[{32.3, -1.5444211438079947`}], 
             PointBox[{32.4, -1.1336698140221415`}], 
             PointBox[{32.5, -0.46007252643903485`}], 
             PointBox[{32.6, -1.27144576311548}], 
             PointBox[{32.7, -2.183528434827167}], 
             PointBox[{32.8, 0.758609811658971}], 
             PointBox[{32.9, 0.3491388898473815}], 
             PointBox[{33., -0.6738781257590745}], 
             PointBox[{33.1, -0.24701291854216834`}], 
             PointBox[{33.2, 0.5879700900804892}], 
             PointBox[{33.3, -1.5718810667422076`}], 
             PointBox[{33.4, -0.9620001432740537}], 
             PointBox[{33.5, -0.38797414171494893`}], 
             PointBox[{33.6, -1.2898955601922353`}], 
             PointBox[{33.7, -2.0165609598443552`}], 
             PointBox[{33.8, 0.9783886279510625}], 
             PointBox[{33.9, 0.3327411751342879}], 
             PointBox[{34., -0.6047328836102679}], 
             PointBox[{34.1, -0.07007176065235399}], 
             PointBox[{34.2, 0.6165519360547478}], 
             PointBox[{34.3, -1.5553587401627738`}], 
             PointBox[{34.4, -0.7797296794960857}], 
             PointBox[{34.5, -0.3092640481190756}], 
             PointBox[{34.6, -1.2962773428371293`}], 
             PointBox[{34.7, -1.8005831958835188`}], 
             PointBox[{34.8, 1.175435294124327}], 
             PointBox[{34.9, 0.33207514855166664`}], 
             PointBox[{35., -0.5147989346696704}], 
             PointBox[{35.1, 0.12367869640365825`}], 
             PointBox[{35.2, 0.6286751455445483}], 
             PointBox[{35.3, -1.4981037205470784`}], 
             PointBox[{35.4, -0.5908549503838003}], 
             PointBox[{35.5, -0.22667196784823318`}], 
             PointBox[{35.6, -1.292878157702944}], 
             PointBox[{35.7, -1.5380691244681657`}], 
             PointBox[{35.8, 1.3480316097920877`}], 
             PointBox[{35.9, 0.3452172901997983}], 
             PointBox[{36., -0.40704489495328744`}], 
             PointBox[{36.1, 0.32998061395119294`}], 
             PointBox[{36.2, 0.6222055938997073}], 
             PointBox[{36.3, -1.4044932680299098`}], 
             PointBox[{36.4, -0.3992732215556316}], 
             PointBox[{36.5, -0.14314626967097865`}], 
             PointBox[{36.6, -1.2809047509363154`}], 
             PointBox[{36.7, -1.2338182360799692`}], 
             PointBox[{36.8, 1.4957601283495023`}], 
             PointBox[{36.9, 0.3698190828290535}], 
             PointBox[{37., -0.2844788180445903}], 
             PointBox[{37.1, 0.5442547697639384}], 
             PointBox[{37.2, 0.5963107406932977}], 
             PointBox[{37.3, -1.2798339928522182`}], 
             PointBox[{37.4, -0.20867663163153338`}], 
             PointBox[{37.5, -0.061670511411648476`}], 
             PointBox[{37.6, -1.2619413658358098`}], 
             PointBox[{37.7, -0.8942766792170005}], 
             PointBox[{37.8, 1.6189109718688997`}], 
             PointBox[{37.9, 0.40345203921970096`}], 
             PointBox[{38., -0.1502070655078569}], 
             PointBox[{38.1, 0.7615237625723239}], 
             PointBox[{38.2, 0.5511516058577399}], 
             PointBox[{38.3, -1.1299623541272013`}], 
             PointBox[{38.4, -0.022620935978920897`}], 
             PointBox[{38.5, 0.014719785605848301`}], 
             PointBox[{38.6, -1.2372742218758503`}], 
             PointBox[{38.7, -0.5279737909404503}], 
             PointBox[{38.8, 1.7177499868812447`}], 
             PointBox[{38.9, 0.4431589148916828}], 
             PointBox[{39., -0.007554300496849464}], 
             PointBox[{39.1, 0.9762637457752135}], 
             PointBox[{39.2, 0.4880779865088698}], 
             PointBox[{39.3, -0.961487372755073}], 
             PointBox[{39.4, 0.1551137843998731}], 
             PointBox[{39.5, 0.08271531841091928}], 
             PointBox[{39.6, -1.2079244182095863`}], 
             PointBox[{39.7, -0.14471792283075047`}], 
             PointBox[{39.8, 1.7927114941594482`}], 
             PointBox[{39.9, 0.4860989947883354}], 
             PointBox[{40., 0.14008002600894542`}], 
             PointBox[{40.1, 1.1826892838653293`}], 
             PointBox[{40.2, 0.40947177302950877`}], 
             PointBox[{40.3, -0.7810398885339964}], 
             PointBox[{40.4, 0.3208627798703674}], 
             PointBox[{40.5, 0.1391831183937029}], 
             PointBox[{40.6, -1.1744296792203386`}], 
             PointBox[{40.7, 0.24430978266173042`}], 
             PointBox[{40.8, 1.8442080430650094`}], 
             PointBox[{40.9, 0.5292406072185258}], 
             PointBox[{41., 0.28940749132743804`}], 
             PointBox[{41.1, 1.3747624159113911`}], 
             PointBox[{41.2, 0.31844395844018436`}], 
             PointBox[{41.3, -0.5951503466712893}], 
             PointBox[{41.4, 0.47123381307392265`}], 
             PointBox[{41.5, 0.1806853159396269}], 
             PointBox[{41.6, -1.1370441640610807`}], 
             PointBox[{41.7, 0.6274311657325597}], 
             PointBox[{41.8, 1.8724273675543373`}], 
             PointBox[{41.9, 0.5694896208260616}], 
             PointBox[{42., 0.4371463136303646}], 
             PointBox[{42.1, 1.5460128887207247`}], 
             PointBox[{42.2, 0.21867836016826914`}], 
             PointBox[{42.3, -0.4102580035068968}], 
             PointBox[{42.4, 0.602743482675578}], 
             PointBox[{42.5, 0.20447652583243325`}], 
             PointBox[{42.6, -1.0953301925110281`}], 
             PointBox[{42.7, 0.9928866055342951}], 
             PointBox[{42.8, 1.8776184921516688`}], 
             PointBox[{42.9, 0.6040362696621742}], 
             PointBox[{43., 0.5802101886183664}], 
             PointBox[{43.1, 1.69017859016094}], 
             PointBox[{43.2, 0.1140626866799721}], 
             PointBox[{43.3, -0.23202729924742016`}], 
             PointBox[{43.4, 0.7124810744535353}], 
             PointBox[{43.5, 0.20763843579334207`}], 
             PointBox[{43.6, -1.0481579924999096`}], 
             PointBox[{43.7, 1.329467398019915}], 
             PointBox[{43.8, 1.8598035629584047`}], 
             PointBox[{43.9, 0.6305429311505577}], 
             PointBox[{44., 0.715844355217996}], 
             PointBox[{44.1, 1.801134426623321}], 
             PointBox[{44.2, 0.008476476883515716}], 
             PointBox[{44.3, -0.06582028265984263}], 
             PointBox[{44.4, 0.7979724110082316}], 
             PointBox[{44.5, 0.18852980954034138`}], 
             PointBox[{44.6, -0.9936534379703517}], 
             PointBox[{44.7, 1.6274008372129174`}], 
             PointBox[{44.8, 1.819606881308573}], 
             PointBox[{44.9, 0.6470477142029267}], 
             PointBox[{45., 0.8417891091958154}], 
             PointBox[{45.1, 1.8734699427513988`}], 
             PointBox[{45.2, -0.09441819127459894}], 
             PointBox[{45.3, 0.0843094525844208}], 
             PointBox[{45.4, 0.8572490994301916}], 
             PointBox[{45.5, 0.14547389233121066`}], 
             PointBox[{45.6, -0.9294107707792136}], 
             PointBox[{45.7, 1.878288677049568}], 
             PointBox[{45.8, 1.757502955792006}], 
             PointBox[{45.9, 0.6522060209717893}], 
             PointBox[{46., 0.9561188206716906}], 
             PointBox[{46.1, 1.9022219393809792`}], 
             PointBox[{46.2, -0.19176427018464892`}], 
             PointBox[{46.3, 0.2148235753447807}], 
             PointBox[{46.4, 0.8888585578970378}], 
             PointBox[{46.5, 0.07781815849011764}], 
             PointBox[{46.6, -0.8526705177064287}], 
             PointBox[{46.7, 2.076350622875907}], 
             PointBox[{46.8, 1.6743263845492038`}], 
             PointBox[{46.9, 0.6450799716549227}], 
             PointBox[{47., 1.0572235108047607`}], 
             PointBox[{47.1, 1.8837489953220938`}], 
             PointBox[{47.2, -0.2814283341940609}], 
             PointBox[{47.3, 0.3227986031852197}], 
             PointBox[{47.4, 0.8919095604287577}], 
             PointBox[{47.5, -0.014383254041604232`}], 
             PointBox[{47.6, -0.7609294957073871}], 
             PointBox[{47.7, 2.2178807771779248`}], 
             PointBox[{47.8, 1.5711337383763748`}], 
             PointBox[{47.9, 0.6254739010764752}], 
             PointBox[{48., 1.14399900691933}], 
             PointBox[{48.1, 1.8155597948498325`}], 
             PointBox[{48.2, -0.3619427658704808}], 
             PointBox[{48.3, 0.40670733983279206`}], 
             PointBox[{48.4, 0.8662889476545388}], 
             PointBox[{48.5, -0.12989309167460306`}], 
             PointBox[{48.6, -0.6518350110491156}], 
             PointBox[{48.7, 2.301907556473452}], 
             PointBox[{48.8, 1.4494733643441577`}], 
             PointBox[{48.9, 0.5936351526906947}], 
             PointBox[{49., 1.2154624097238411`}], 
             PointBox[{49.1, 1.696885728983034}], 
             PointBox[{49.2, -0.43309950234834105`}], 
             PointBox[{49.3, 0.46532008971553296`}], 
             PointBox[{49.4, 0.8120806875376729}], 
             PointBox[{49.5, -0.26837580402207095`}], 
             PointBox[{49.6, -0.5246102876626537}], 
             PointBox[{49.7, 2.3294333305821056`}], 
             PointBox[{49.8, 1.310797879646998}], 
             PointBox[{49.9, 0.5501308212042204}], 
             PointBox[{50., 1.2706900258199312`}], 
             PointBox[{50.1, 1.52865240907704}], 
             PointBox[{50.2, -0.4954194796664524}], 
             PointBox[{50.3, 0.49819885913893813`}], 
             PointBox[{50.4, 0.7299751688915421}], 
             PointBox[{50.5, -0.4263745227945037}], 
             PointBox[{50.6, -0.37965960794099374`}], 
             PointBox[{50.7, 2.303653795584978}], 
             PointBox[{50.8, 1.1571946312469663`}], 
             PointBox[{50.9, 0.4962594196695136}], 
             PointBox[{51., 1.3091439834461198`}], 
             PointBox[{51.1, 1.3141067762335297`}], 
             PointBox[{51.2, -0.5496785236900905}], 
             PointBox[{51.3, 0.5057883342451532}], 
             PointBox[{51.4, 0.6214657567979884}], 
             PointBox[{51.5, -0.6007028717212961}], 
             PointBox[{51.6, -0.21894065982633037`}], 
             PointBox[{51.7, 2.229293158350629}], 
             PointBox[{51.8, 0.9911440382202272}], 
             PointBox[{51.9, 0.43379434445523657`}], 
             PointBox[{52., 1.3303940214536851`}], 
             PointBox[{52.1, 1.0588259066134924`}], 
             PointBox[{52.2, -0.597039226697234}], 
             PointBox[{52.3, 0.4891779503595899}], 
             PointBox[{52.4, 0.488389274214569}], 
             PointBox[{52.5, -0.7870558021386387}], 
             PointBox[{52.6, -0.04658873004518682}], 
             PointBox[{52.7, 2.1120749599067494`}], 
             PointBox[{52.8, 0.8152722504892154}], 
             PointBox[{52.9, 0.36482393024198245`}], 
             PointBox[{53., 1.333824778732378}], 
             PointBox[{53.1, 0.7701100079430034}], 
             PointBox[{53.2, -0.6388833306773449}], 
             PointBox[{53.3, 0.44997324319410836`}], 
             PointBox[{53.4, 0.33308246881642845`}], 
             PointBox[{53.5, -0.9800860544637544}], 
             PointBox[{53.6, 0.132034684647806}], 
             PointBox[{53.7, 1.9588022204188746`}], 
             PointBox[{53.8, 0.6328608318654005}], 
             PointBox[{53.9, 0.29219383375311736`}], 
             PointBox[{54., 1.3192249416315462`}], 
             PointBox[{54.1, 0.45765058104734635`}], 
             PointBox[{54.2, -0.6761716527907993}], 
             PointBox[{54.3, 0.39071475715900306`}], 
             PointBox[{54.4, 0.15864042043540394`}], 
             PointBox[{54.5, -1.1737039840299985`}], 
             PointBox[{54.6, 0.3102390283966088}], 
             PointBox[{54.7, 1.7764886508812197`}], 
             PointBox[{54.8, 0.4470818520130706}], 
             PointBox[{54.9, 0.2184449070264236}], 
             PointBox[{55., 1.2857786245294847`}], 
             PointBox[{55.1, 0.13161342781677376`}], 
             PointBox[{55.2, -0.7100177152606193}], 
             PointBox[{55.3, 0.31357231523725204`}], 
             PointBox[{55.4, -0.032131457403011154`}], 
             PointBox[{55.5, -1.3613335954360082`}], 
             PointBox[{55.6, 0.480460002880136}], 
             PointBox[{55.7, 1.5717588805928244`}], 
             PointBox[{55.8, 0.26108258812018903`}], 
             PointBox[{55.9, 0.14641514149843715`}], 
             PointBox[{56., 1.232803153739951}], 
             PointBox[{56.1, -0.19679852351691807`}], 
             PointBox[{56.2, -0.7408466498745838}], 
             PointBox[{56.3, 0.22170342249592068`}], 
             PointBox[{56.4, -0.23571048148733098`}], 
             PointBox[{56.5, -1.535370389414311}], 
             PointBox[{56.6, 0.635839108392247}], 
             PointBox[{56.7, 1.352046139712911}], 
             PointBox[{56.8, 0.07891429392475402}], 
             PointBox[{56.9, 0.07971660655312007}], 
             PointBox[{57., 1.1598716026273905`}], 
             PointBox[{57.1, -0.5163496064196806}], 
             PointBox[{57.2, -0.7686229526952957}], 
             PointBox[{57.3, 0.1184827471151948}], 
             PointBox[{57.4, -0.44794310668658}], 
             PointBox[{57.5, -1.6879437279276317`}], 
             PointBox[{57.6, 0.769910473114578}], 
             PointBox[{57.7, 1.1239104515771032`}], 
             PointBox[{57.8, -0.09611504335771315}], 
             PointBox[{57.9, 0.020648316989536397`}], 
             PointBox[{58., 1.066239837979083}], 
             PointBox[{58.1, -0.8168121325797983}], 
             PointBox[{58.2, -0.7930878118568216}], 
             PointBox[{58.3, 0.007099400616425555}], 
             PointBox[{58.4, -0.6651003612350905}], 
             PointBox[{58.5, -1.8109588073639316`}], 
             PointBox[{58.6, 0.8781783399244887}], 
             PointBox[{58.7, 0.8940084243513411}], 
             PointBox[{58.8, -0.2599663692599279}], 
             PointBox[{58.9, -0.026988666286342777`}], 
             PointBox[{59., 0.9519438215720584}], 
             PointBox[{59.1, -1.0889685223883134`}], 
             PointBox[{59.2, -0.8133279860121547}], 
             PointBox[{59.3, -0.10873078485019505`}], 
             PointBox[{59.4, -0.8828453681489918}], 
             PointBox[{59.5, -1.8971070169864106`}], 
             PointBox[{59.6, 0.9572621163606527}], 
             PointBox[{59.7, 0.6676244095651782}], 
             PointBox[{59.8, -0.40981467821256956`}], 
             PointBox[{59.9, -0.06161201853683451}], 
             PointBox[{60., 0.8164952106817509}], 
             PointBox[{60.1, -1.326248209552432}], 
             PointBox[{60.2, -0.8287616938177962}], 
             PointBox[{60.3, -0.2263040664474829}], 
             PointBox[{60.4, -1.0973955094377743`}], 
             PointBox[{60.5, -1.9397250393303693`}], 
             PointBox[{60.6, 1.0065490935157868`}], 
             PointBox[{60.7, 0.45014294286374934`}], 
             PointBox[{60.8, -0.5421779952957877}], 
             PointBox[{60.9, -0.08046449610264972}], 
             PointBox[{61., 0.6610197332047392}], 
             PointBox[{61.1, -1.5230354959421675`}], 
             PointBox[{61.2, -0.8378452821270912}], 
             PointBox[{61.3, -0.3420546430788818}], 
             PointBox[{61.4, -1.3047453735489398`}], 
             PointBox[{61.5, -1.933305766659032}], 
             PointBox[{61.6, 1.0277345687063644`}], 
             PointBox[{61.7, 0.24658409701805795`}], 
             PointBox[{61.8, -0.6538058149453718}], 
             PointBox[{61.9, -0.08131613382283831}], 
             PointBox[{62., 0.48731699523341376`}], 
             PointBox[{62.1, -1.6760481202218216`}], 
             PointBox[{62.2, -0.8393296707436093}], 
             PointBox[{62.3, -0.45313973932206864`}], 
             PointBox[{62.4, -1.5006992206908762`}], 
             PointBox[{62.5, -1.8751221430284204`}], 
             PointBox[{62.6, 1.023794454340532}], 
             PointBox[{62.7, 0.06019669267698191}], 
             PointBox[{62.8, -0.7429200327242143}], 
             PointBox[{62.9, -0.06486358128313441}], 
             PointBox[{63., 0.29759953914617654`}], 
             PointBox[{63.1, -1.784463520765712}], 
             PointBox[{63.2, -0.8323473471609759}], 
             PointBox[{63.3, -0.5574656337921624}], 
             PointBox[{63.4, -1.6817111531127011`}], 
             PointBox[{63.5, -1.762984777604288}], 
             PointBox[{63.6, 0.9996248976094648}], 
             PointBox[{63.7, -0.1054086316289613}], 
             PointBox[{63.8, -0.8068196996027837}], 
             PointBox[{63.9, -0.029320355650270358`}], 
             PointBox[{64., 0.09616824991826434}], 
             PointBox[{64.1, -1.8480999782550498`}], 
             PointBox[{64.2, -0.815418766826042}], 
             PointBox[{64.3, -0.6525085623798077}], 
             PointBox[{64.4, -1.8435549499336048`}], 
             PointBox[{64.5, -1.599738823613734}], 
             PointBox[{64.6, 0.9602835527402931}], 
             PointBox[{64.7, -0.2479383815007168}], 
             PointBox[{64.8, -0.8443643013742985}], 
             PointBox[{64.9, 0.024346460617380217`}], 
             PointBox[{65., -0.11232679416571045`}], 
             PointBox[{65.1, -1.869025454070652}], 
             PointBox[{65.2, -0.7881575709252502}], 
             PointBox[{65.3, -0.7371196135281934}], 
             PointBox[{65.4, -1.9835301191269537`}], 
             PointBox[{65.5, -1.3893706439921516`}], 
             PointBox[{65.6, 0.9112971990034566}], 
             PointBox[{65.7, -0.36541658096393803`}], 
             PointBox[{65.8, -0.854233702266356}], 
             PointBox[{65.9, 0.09500884087901795}], 
             PointBox[{66., -0.32145493991993135`}], 
             PointBox[{66.1, -1.8493196820199955`}], 
             PointBox[{66.2, -0.7494344616206945}], 
             PointBox[{66.3, -0.8095230518301832}], 
             PointBox[{66.4, -2.097294861523551}], 
             PointBox[{66.5, -1.1381229728867766`}], 
             PointBox[{66.6, 0.8581482084919116}], 
             PointBox[{66.7, -0.4566796561484807}], 
             PointBox[{66.8, -0.8357994922916987}], 
             PointBox[{66.9, 0.18065432479488663`}], 
             PointBox[{67., -0.5244590878646704}], 
             PointBox[{67.1, -1.7922571398448781`}], 
             PointBox[{67.2, -0.6989420435638749}], 
             PointBox[{67.3, -0.8689138349946006}], 
             PointBox[{67.4, -2.181529968540417}], 
             PointBox[{67.5, -0.854095446804422}], 
             PointBox[{67.6, 0.8058774165765499}], 
             PointBox[{67.7, -0.5205788509992999}], 
             PointBox[{67.8, -0.7885967269103276}], 
             PointBox[{67.9, 0.27920175289182225`}], 
             PointBox[{68., -0.7138712241358007}], 
             PointBox[{68.1, -1.7013848382703145`}], 
             PointBox[{68.2, -0.6367420334136114}], 
             PointBox[{68.3, -0.9150535232329275}], 
             PointBox[{68.4, -2.2335278743994422`}], 
             PointBox[{68.5, -0.546970759431133}], 
             PointBox[{68.6, 0.7581525880959816}], 
             PointBox[{68.7, -0.5577014764130581}], 
             PointBox[{68.8, -0.7135924296380836}], 
             PointBox[{68.9, 0.3860641594219487}], 
             PointBox[{69., -0.8834196406969568}], 
             PointBox[{69.1, -1.5813402880376088`}], 
             PointBox[{69.2, -0.5639791743669775}], 
             PointBox[{69.3, -0.9488682807714213}], 
             PointBox[{69.4, -2.2508196689377655`}], 
             PointBox[{69.5, -0.22688775532878935`}], 
             PointBox[{69.6, 0.7177961693159887}], 
             PointBox[{69.7, -0.5688024552146089}], 
             PointBox[{69.8, -0.6122190804599086}], 
             PointBox[{69.9, 0.49738054713088786`}], 
             PointBox[{70., -1.0265669273358071`}], 
             PointBox[{70.1, -1.435900615855644}], 
             PointBox[{70.2, -0.4810753868150641}], 
             PointBox[{70.3, -0.9702761560256477}], 
             PointBox[{70.4, -2.2302702183296788`}], 
             PointBox[{70.5, 0.09655635194212664}], 
             PointBox[{70.6, 0.6870352301557432}], 
             PointBox[{70.7, -0.5547976166926674}], 
             PointBox[{70.8, -0.48548856924753636`}], 
             PointBox[{70.9, 0.6085895596916089}], 
             PointBox[{71., -1.138335942356207}], 
             PointBox[{71.1, -1.2697493470623158`}], 
             PointBox[{71.2, -0.3899468566160067}], 
             PointBox[{71.3, -0.9808758628059877}], 
             PointBox[{71.4, -2.1703837156892405`}], 
             PointBox[{71.5, 0.4135261921546771}], 
             PointBox[{71.6, 0.6667248057274264}], 
             PointBox[{71.7, -0.5177583991899155}], 
             PointBox[{71.8, -0.33625216109794565`}], 
             PointBox[{71.9, 0.7141368837765185}], 
             PointBox[{72., -1.215352599043399}], 
             PointBox[{72.1, -1.087489643781737}], 
             PointBox[{72.2, -0.29258489676431054`}], 
             PointBox[{72.3, -0.9824236246422515}], 
             PointBox[{72.4, -2.0695885748500586`}], 
             PointBox[{72.5, 0.7156970736759831}], 
             PointBox[{72.6, 0.6566581281731487}], 
             PointBox[{72.7, -0.46019389184220927`}], 
             PointBox[{72.8, -0.16757031135057332`}], 
             PointBox[{72.9, 0.8083876450546086}], 
             PointBox[{73., -1.2561096467688913`}], 
             PointBox[{73.1, -0.8938890828067088}], 
             PointBox[{73.2, -0.1916596775117796}], 
             PointBox[{73.3, -0.9772829745343188}], 
             PointBox[{73.4, -1.9274109650359605`}], 
             PointBox[{73.5, 0.995961670516408}], 
             PointBox[{73.6, 0.6563193145339028}], 
             PointBox[{73.7, -0.38458449689642293`}], 
             PointBox[{73.8, 0.017649493565841112`}], 
             PointBox[{73.9, 0.8868018137654872}], 
             PointBox[{74., -1.2600599644138128`}], 
             PointBox[{74.1, -0.6929414530677604}], 
             PointBox[{74.2, -0.08935049854335375}], 
             PointBox[{74.3, -0.966814258172235}], 
             PointBox[{74.4, -1.7433283831342123`}], 
             PointBox[{74.5, 1.24926550174132}], 
             PointBox[{74.6, 0.6645362107519759}], 
             PointBox[{74.7, -0.2936922914450406}], 
             PointBox[{74.8, 0.2154440358572174}], 
             PointBox[{74.9, 0.9441332770875306}], 
             PointBox[{75., -1.2290815273518092`}], 
             PointBox[{75.1, -0.48952559912140714`}], 
             PointBox[{75.2, 0.011011370814230759`}], 
             PointBox[{75.3, -0.9535186708380934}], 
             PointBox[{75.4, -1.518949640878418}], 
             PointBox[{75.5, 1.4716534765102551`}], 
             PointBox[{75.6, 0.6794250333477976}], 
             PointBox[{75.7, -0.19069188784487778`}], 
             PointBox[{75.8, 0.4220441540601314}], 
             PointBox[{75.9, 0.9767778119858121}], 
             PointBox[{76., -1.165838622553565}], 
             PointBox[{76.1, -0.2874833835157915}], 
             PointBox[{76.2, 0.10681069546262734`}], 
             PointBox[{76.3, -0.9388953439265606}], 
             PointBox[{76.4, -1.256365556459059}], 
             PointBox[{76.5, 1.6611267892076285`}], 
             PointBox[{76.6, 0.6991262614465086}], 
             PointBox[{76.7, -0.07830714085139334}], 
             PointBox[{76.8, 0.633254224601842}], 
             PointBox[{76.9, 0.9822507210410549}], 
             PointBox[{77., -1.0744264197201119`}], 
             PointBox[{77.1, -0.0908389912583516}], 
             PointBox[{77.2, 0.19489553311723284`}], 
             PointBox[{77.3, -0.9254001940498711}], 
             PointBox[{77.4, -0.9599256301662535}], 
             PointBox[{77.5, 1.8165117367971106`}], 
             PointBox[{77.6, 0.7212557583043235}], 
             PointBox[{77.7, 0.04006479883537395}], 
             PointBox[{77.8, 0.8442208014675998}], 
             PointBox[{77.9, 0.958576192278997}], 
             PointBox[{78., -0.9599693761847448}], 
             PointBox[{78.1, 0.09654794446396409}], 
             PointBox[{78.2, 0.2722387798712589}], 
             PointBox[{78.3, -0.9140397152659716}], 
             PointBox[{78.4, -0.6352896703610895}], 
             PointBox[{78.5, 1.9377147526320186`}], 
             PointBox[{78.6, 0.7434297599829733}], 
             PointBox[{78.7, 0.16154804353573127`}], 
             PointBox[{78.8, 1.0504960747202858`}], 
             PointBox[{78.9, 0.9058720672619529}], 
             PointBox[{79., -0.8281265297482605}], 
             PointBox[{79.1, 0.2709152429088135}], 
             PointBox[{79.2, 0.3357462461790419}], 
             PointBox[{79.3, -0.9064558944082819}], 
             PointBox[{79.4, -0.2903520205945824}], 
             PointBox[{79.5, 2.02510059139604}], 
             PointBox[{79.6, 0.7631595011553145}], 
             PointBox[{79.7, 0.2831947186423349}], 
             PointBox[{79.8, 1.2465123453148408`}], 
             PointBox[{79.9, 0.8254917005542666}], 
             PointBox[{80., -0.6848250240655034}], 
             PointBox[{80.1, 0.42888137500267476`}], 
             PointBox[{80.2, 0.38255667076737154`}], 
             PointBox[{80.3, -0.9024385175071075}], 
             PointBox[{80.4, 0.06596380739210872}], 
             PointBox[{80.5, 2.0793530226292205`}], 
             PointBox[{80.6, 0.7778198901723954}], 
             PointBox[{80.7, 0.4019529129436705}], 
             PointBox[{80.8, 1.4271811859071022`}], 
             PointBox[{80.9, 0.7197155025205575}], 
             PointBox[{81., -0.5362871746037854}], 
             PointBox[{81.1, 0.5672388875609613}], 
             PointBox[{81.2, 0.4097112284580362}], 
             PointBox[{81.3, -0.9034717782706139}], 
             PointBox[{81.4, 0.4231728647064301}], 
             PointBox[{81.5, 2.1015969464933733`}], 
             PointBox[{81.6, 0.785259019015939}], 
             PointBox[{81.7, 0.5153961446339963}], 
             PointBox[{81.8, 1.5870686335038044`}], 
             PointBox[{81.9, 0.5927542757854098}], 
             PointBox[{82., -0.38818848265509587`}], 
             PointBox[{82.1, 0.6833534562683781}], 
             PointBox[{82.2, 0.41529236628412036`}], 
             PointBox[{82.3, -0.9075155627579079}], 
             PointBox[{82.4, 0.7706684269214747}], 
             PointBox[{82.5, 2.093182288670505}], 
             PointBox[{82.6, 0.7837433372769738}], 
             PointBox[{82.7, 0.6215243122860556}], 
             PointBox[{82.8, 1.7212642450540443`}], 
             PointBox[{82.9, 0.44963066253694706`}], 
             PointBox[{83., -0.24552244856749894`}], 
             PointBox[{83.1, 0.7752319166247617}], 
             PointBox[{83.2, 0.397569229338842}], 
             PointBox[{83.3, -0.9129258141474565}], 
             PointBox[{83.4, 1.0977143902273383`}], 
             PointBox[{83.5, 2.055824097013101}], 
             PointBox[{83.6, 0.7718099266057834}], 
             PointBox[{83.7, 0.7185853980554384}], 
             PointBox[{83.8, 1.8243345638693427`}], 
             PointBox[{83.9, 0.29574615357705625`}], 
             PointBox[{84., -0.11319494365307037`}], 
             PointBox[{84.1, 0.8409868519811425}], 
             PointBox[{84.2, 0.3549991098770988}], 
             PointBox[{84.3, -0.9173193579481449}], 
             PointBox[{84.4, 1.3940088342351373`}], 
             PointBox[{84.5, 1.9911870147261652`}], 
             PointBox[{84.6, 0.7484075635948102}], 
             PointBox[{84.7, 0.8052117455445114}], 
             PointBox[{84.8, 1.8915637538011651`}], 
             PointBox[{84.9, 0.13654655903519597`}], 
             PointBox[{85., 0.004866055656748358}], 
             PointBox[{85.1, 0.87932606801769}], 
             PointBox[{85.2, 0.28688211854023393`}], 
             PointBox[{85.3, -0.9176316996017704}], 
             PointBox[{85.4, 1.6500030425013392`}], 
             PointBox[{85.5, 1.9007485351976356`}], 
             PointBox[{85.6, 0.7127150126034394}], 
             PointBox[{85.7, 0.8801104871454299}], 
             PointBox[{85.8, 1.9183894071247778`}], 
             PointBox[{85.9, -0.02251685097871814}], 
             PointBox[{86., 0.10544115611992311`}], 
             PointBox[{86.1, 0.8896034790886915}], 
             PointBox[{86.2, 0.19286820157867623`}], 
             PointBox[{86.3, -0.9098299232427962}], 
             PointBox[{86.4, 1.8583867087509134`}], 
             PointBox[{86.5, 1.7867303963575978`}], 
             PointBox[{86.6, 0.6647840291043394}], 
             PointBox[{86.7, 0.9427205013271305}], 
             PointBox[{86.8, 1.9010339277010644`}], 
             PointBox[{86.9, -0.17701682967162924`}], 
             PointBox[{87., 0.186065145113389}], 
             PointBox[{87.1, 0.8715291960106697}], 
             PointBox[{87.2, 0.07383057862170972}], 
             PointBox[{87.3, -0.889731611503521}], 
             PointBox[{87.4, 2.013854229102435}], 
             PointBox[{87.5, 1.6516176182340132`}], 
             PointBox[{87.6, 0.6051446908168145}], 
             PointBox[{87.7, 0.9930163683457067}], 
             PointBox[{87.8, 1.8369792749290355`}], 
             PointBox[{87.9, -0.3229452487503295}], 
             PointBox[{88., 0.24534668551495997`}], 
             PointBox[{88.1, 0.8256864895010949}], 
             PointBox[{88.2, -0.06884930395608535}], 
             PointBox[{88.3, -0.8532244417801849}], 
             PointBox[{88.4, 2.1136406855875975`}], 
             PointBox[{88.5, 1.4976423802581849`}], 
             PointBox[{88.6, 0.5346551443362841}], 
             PointBox[{88.7, 1.0309255252359435`}], 
             PointBox[{88.8, 1.7245005808072165`}], 
             PointBox[{88.9, -0.4576075625300291}], 
             PointBox[{89., 0.28245772347872844`}], 
             PointBox[{89.1, 0.7529471094385372}], 
             PointBox[{89.2, -0.23363368542050011`}], 
             PointBox[{89.3, -0.7966312795833801}], 
             PointBox[{89.4, 2.1572660893725697`}], 
             PointBox[{89.5, 1.3273642400745302`}], 
             PointBox[{89.6, 0.4545524630957516}], 
             PointBox[{89.7, 1.056076028595271}], 
             PointBox[{89.8, 1.5639523640929838`}], 
             PointBox[{89.9, -0.5794365179244778}], 
             PointBox[{90., 0.2972497937080334}], 
             PointBox[{90.1, 0.6546007029173779}], 
             PointBox[{90.2, -0.4171035720864893}], 
             PointBox[{90.3, -0.7177174580938299}], 
             PointBox[{90.4, 2.147127783333417}], 
             PointBox[{90.5, 1.144102853271761}], 
             PointBox[{90.6, 0.36708738400193397`}], 
             PointBox[{90.7, 1.0695740230366937`}], 
             PointBox[{90.8, 1.3574747021993971`}], 
             PointBox[{90.9, -0.6872235550181358}], 
             PointBox[{91., 0.29066091439744923`}], 
             PointBox[{91.1, 0.5327759385691024}], 
             PointBox[{91.2, -0.616006083379034}], 
             PointBox[{91.3, -0.6154476176889148}], 
             PointBox[{91.4, 2.0873826949173235`}], 
             PointBox[{91.5, 0.9507733251084574}], 
             PointBox[{91.6, 0.2742905222112313}], 
             PointBox[{91.7, 1.0715615549124777`}], 
             PointBox[{91.8, 1.1089952426991658`}], 
             PointBox[{91.9, -0.7810901631019078}], 
             PointBox[{92., 0.2640213272970868}], 
             PointBox[{92.1, 0.38984644089941867`}], 
             PointBox[{92.2, -0.8262044626462739}], 
             PointBox[{92.3, -0.49089119627024047`}], 
             PointBox[{92.4, 1.9838894013664685`}], 
             PointBox[{92.5, 0.751143991961726}], 
             PointBox[{92.6, 0.17916471112403087`}], 
             PointBox[{92.7, 1.0628097840817645`}], 
             PointBox[{92.8, 0.8253636330337031}], 
             PointBox[{92.9, -0.8609487104404252}], 
             PointBox[{93., 0.21958735267980956`}], 
             PointBox[{93.1, 0.22893949950230308`}], 
             PointBox[{93.2, -1.0415632038202602`}], 
             PointBox[{93.3, -0.3469694395607803}], 
             PointBox[{93.4, 1.8435261079721386`}], 
             PointBox[{93.5, 0.5486002703983104}], 
             PointBox[{93.6, 0.0844974380597705}], 
             PointBox[{93.7, 1.0433100112422835`}], 
             PointBox[{93.8, 0.5145270489738323}], 
             PointBox[{93.9, -0.9277495271817315}], 
             PointBox[{94., 0.15945765092328656`}], 
             PointBox[{94.1, 0.052813770656939596`}], 
             PointBox[{94.2, -1.2569913900224492`}], 
             PointBox[{94.3, -0.18886264454340562`}], 
             PointBox[{94.4, 1.673559561750153}], 
             PointBox[{94.5, 0.34684904156893026`}], 
             PointBox[{94.6, -0.006516006658785045}], 
             PointBox[{94.7, 1.0132654531480512`}], 
             PointBox[{94.8, 0.18642733972228598`}], 
             PointBox[{94.9, -0.9821850762527902}], 
             PointBox[{95., 0.08644304650078993}], 
             PointBox[{95.1, -0.1350831371091772}], 
             PointBox[{95.2, -1.4655711613449967`}], 
             PointBox[{95.3, -0.022892106775543652`}], 
             PointBox[{95.4, 1.4815888852463104`}], 
             PointBox[{95.5, 0.14956767979310825`}], 
             PointBox[{95.6, -0.09100653222412802}], 
             PointBox[{95.7, 0.9724632133584237}], 
             PointBox[{95.8, -0.14807437165291049`}], 
             PointBox[{95.9, -1.0248574239521986`}], 
             PointBox[{96., 0.003573482797946781}], 
             PointBox[{96.1, -0.33116061096370686`}], 
             PointBox[{96.2, -1.6602833618671866`}], 
             PointBox[{96.3, 0.14397926635865588`}], 
             PointBox[{96.4, 1.2751450131181628`}], 
             PointBox[{96.5, -0.03955902412417345}], 
             PointBox[{96.6, -0.16529358117259108`}], 
             PointBox[{96.7, 0.9205138109682593}], 
             PointBox[{96.8, -0.477524233632721}], 
             PointBox[{96.9, -1.0561608873686055`}], 
             PointBox[{97., -0.08600032987305894}], 
             PointBox[{97.1, -0.5317350592085859}], 
             PointBox[{97.2, -1.8337262587010628`}], 
             PointBox[{97.3, 0.3045738937216811}], 
             PointBox[{97.4, 1.0614194540830795`}], 
             PointBox[{97.5, -0.21692477761826012`}], 
             PointBox[{97.6, -0.2269095596857369}], 
             PointBox[{97.7, 0.8568572544609196}], 
             PointBox[{97.8, -0.7908505319792312}], 
             PointBox[{97.9, -1.0762888402387034`}], 
             PointBox[{98., -0.17907346272841096`}], 
             PointBox[{98.1, -0.7330824223899981}], 
             PointBox[{98.2, -1.9782876933022635`}], 
             PointBox[{98.3, 0.4526081597432494}], 
             PointBox[{98.4, 0.8470165978214936}], 
             PointBox[{98.5, -0.37917135638417676`}], 
             PointBox[{98.6, -0.2726058677653782}], 
             PointBox[{98.7, 0.7808210383082042}], 
             PointBox[{98.8, -1.0780597286939155`}], 
             PointBox[{98.9, -1.0852272207121132`}], 
             PointBox[{99., -0.2725493845064193}], 
             PointBox[{99.1, -0.9315911862649955}], 
             PointBox[{99.2, -2.0865031159337377`}], 
             PointBox[{99.3, 0.5825886369566433}], 
             PointBox[{99.4, 0.6379253604100086}], 
             PointBox[{99.5, -0.5231193167710444}], 
             PointBox[{99.6, -0.30006062968459446`}], 
             PointBox[{99.7, 0.6917267120588804}], 
             PointBox[{99.8, -1.3304155975056347`}], 
             PointBox[{99.9, -1.0826825691765407`}], 
             PointBox[{100., -0.36343950929585844`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {-180, 180}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-328., 0}},
       PlotRangePadding->{6, 5}], {190, -176.}, ImageScaled[{0.5, 0.5}], {360, 312.},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
            {Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
            {RGBColor[0.368417, 0.506779, 0.709798], 
             PointBox[{0, 0.6334239999999999}], 
             PointBox[{0.1, 0.6332498962087303}], 
             PointBox[{0.2, 0.6344668406907782}], 
             PointBox[{0.3, 0.635982153179724}], 
             PointBox[{0.4, 0.6379154938409733}], 
             PointBox[{0.5, 0.6394282925502547}], 
             PointBox[{0.6, 0.638392001099583}], 
             PointBox[{0.7, 0.6365302056747514}], 
             PointBox[{0.8, 0.6349471315809216}], 
             PointBox[{0.9, 0.6334498204093626}], 
             PointBox[{1., 0.6332112913511931}], 
             PointBox[{1.1, 0.6330684456009231}], 
             PointBox[{1.2, 0.6338831959061652}], 
             PointBox[{1.3, 0.6352525032256872}], 
             PointBox[{1.4, 0.6371782973986656}], 
             PointBox[{1.5, 0.6391049000088033}], 
             PointBox[{1.6, 0.6385830609328399}], 
             PointBox[{1.7, 0.6368545969916332}], 
             PointBox[{1.8, 0.6352744190962873}], 
             PointBox[{1.9, 0.6336208515406774}], 
             PointBox[{2., 0.6327465692788249}], 
             PointBox[{2.1, 0.6329099648788167}], 
             PointBox[{2.2, 0.6332389860744625}], 
             PointBox[{2.3, 0.6343898709501471}], 
             PointBox[{2.4, 0.6362224584976236}], 
             PointBox[{2.5, 0.6384755471851375}], 
             PointBox[{2.6, 0.6384832371001551}], 
             PointBox[{2.7, 0.6369262212502849}], 
             PointBox[{2.8, 0.6354028973590121}], 
             PointBox[{2.9, 0.6337020892676185}], 
             PointBox[{3., 0.6322468674020247}], 
             PointBox[{3.1, 0.632689795642041}], 
             PointBox[{3.2, 0.6325609980548488}], 
             PointBox[{3.3, 0.6334361795622722}], 
             PointBox[{3.4, 0.6351003048798219}], 
             PointBox[{3.5, 0.6375727815418756}], 
             PointBox[{3.6, 0.6381031272054718}], 
             PointBox[{3.7, 0.6367324399561531}], 
             PointBox[{3.8, 0.6352970333120203}], 
             PointBox[{3.9, 0.63363247527277}], 
             PointBox[{4., 0.6317557866602451}], 
             PointBox[{4.1, 0.6322405181030828}], 
             PointBox[{4.2, 0.6318550665272498}], 
             PointBox[{4.3, 0.6324217845603324}], 
             PointBox[{4.4, 0.633865295252233}], 
             PointBox[{4.5, 0.6364477877662101}], 
             PointBox[{4.6, 0.6374681481664235}], 
             PointBox[{4.7, 0.6362778095707823}], 
             PointBox[{4.8, 0.6349401869981492}], 
             PointBox[{4.9, 0.6333635650845298}], 
             PointBox[{5., 0.6312251053091821}], 
             PointBox[{5.1, 0.6314638567048276}], 
             PointBox[{5.2, 0.6311025722407306}], 
             PointBox[{5.3, 0.6313592694413815}], 
             PointBox[{5.4, 0.6325622562168242}], 
             PointBox[{5.5, 0.6351618651715573}], 
             PointBox[{5.6, 0.6366144301331003}], 
             PointBox[{5.7, 0.6355792801686836}], 
             PointBox[{5.8, 0.634332347868018}], 
             PointBox[{5.9, 0.6328642796694023}], 
             PointBox[{6., 0.6305881517730771}], 
             PointBox[{6.1, 0.6304297057976878}], 
             PointBox[{6.2, 0.6302647238221906}], 
             PointBox[{6.3, 0.6302487938594141}], 
             PointBox[{6.4, 0.6312241469107165}], 
             PointBox[{6.5, 0.633783747641372}], 
             PointBox[{6.6, 0.6355868410455616}], 
             PointBox[{6.7, 0.6346622403878545}], 
             PointBox[{6.8, 0.6334883223286049}], 
             PointBox[{6.9, 0.6321254203626127}], 
             PointBox[{7., 0.6297877592041969}], 
             PointBox[{7.1, 0.629252978413325}], 
             PointBox[{7.2, 0.6292974785930051}], 
             PointBox[{7.3, 0.6290827586738186}], 
             PointBox[{7.4, 0.6298724937197588}], 
             PointBox[{7.5, 0.6323829481996913}], 
             PointBox[{7.6, 0.6344334435654045}], 
             PointBox[{7.7, 0.6335563808032054}], 
             PointBox[{7.8, 0.6324336093249353}], 
             PointBox[{7.9, 0.6311555467905242}], 
             PointBox[{8., 0.6287841111666607}], 
             PointBox[{8.1, 0.6280003812658459}], 
             PointBox[{8.2, 0.6281722261675436}], 
             PointBox[{8.3, 0.6278563062529938}], 
             PointBox[{8.4, 0.6285271384196167}], 
             PointBox[{8.5, 0.6310256000321199}], 
             PointBox[{8.6, 0.6332002495219508}], 
             PointBox[{8.7, 0.6322929696264427}], 
             PointBox[{8.8, 0.6312002523598331}], 
             PointBox[{8.9, 0.6299766509614818}], 
             PointBox[{9., 0.6275586754952361}], 
             PointBox[{9.1, 0.6267102422737874}], 
             PointBox[{9.2, 0.6268935860981066}], 
             PointBox[{9.3, 0.626581821835137}], 
             PointBox[{9.4, 0.6272157876315276}], 
             PointBox[{9.5, 0.629782459029237}], 
             PointBox[{9.6, 0.6319217128684838}], 
             PointBox[{9.7, 0.6309052902865395}], 
             PointBox[{9.8, 0.6298264533182528}], 
             PointBox[{9.9, 0.6286196086720951}], 
             PointBox[{10., 0.6261143660015368}], 
             PointBox[{10.1, 0.6254206676942232}], 
             PointBox[{10.2, 0.6255050941245998}], 
             PointBox[{10.3, 0.6252966060398494}], 
             PointBox[{10.4, 0.6259837855402131}], 
             PointBox[{10.5, 0.6287220486135138}], 
             PointBox[{10.6, 0.6306121305429182}], 
             PointBox[{10.7, 0.6294295322301223}], 
             PointBox[{10.8, 0.6283557185978537}], 
             PointBox[{10.9, 0.6271221860920009}], 
             PointBox[{11., 0.6244817128078705}], 
             PointBox[{11.1, 0.6241583930715211}], 
             PointBox[{11.2, 0.6240914674977406}], 
             PointBox[{11.3, 0.6240647330523605}], 
             PointBox[{11.4, 0.6248977661206679}], 
             PointBox[{11.5, 0.6279043752661885}], 
             PointBox[{11.6, 0.6292647804056825}], 
             PointBox[{11.7, 0.6279073895860112}], 
             PointBox[{11.8, 0.6268348412453713}], 
             PointBox[{11.9, 0.6255200290308319}], 
             PointBox[{12., 0.6227387727676218}], 
             PointBox[{12.1, 0.6228891652979986}], 
             PointBox[{12.2, 0.6227684883026675}], 
             PointBox[{12.3, 0.6229667796766415}], 
             PointBox[{12.4, 0.6240427242950323}], 
             PointBox[{12.5, 0.6273436340818541}], 
             PointBox[{12.6, 0.6278672799105156}], 
             PointBox[{12.7, 0.6263856815828545}], 
             PointBox[{12.8, 0.6253108838320521}], 
             PointBox[{12.9, 0.6238442304138885}], 
             PointBox[{13., 0.6210522020282997}], 
             PointBox[{13.1, 0.6215821687327154}], 
             PointBox[{13.2, 0.6216488266012153}], 
             PointBox[{13.3, 0.6220838968343221}], 
             PointBox[{13.4, 0.6235121071861479}], 
             PointBox[{13.5, 0.6269438658482976}], 
             PointBox[{13.6, 0.6264278682908266}], 
             PointBox[{13.7, 0.6249120048227187}], 
             PointBox[{13.8, 0.623824108720507}], 
             PointBox[{13.9, 0.6221180645202896}], 
             PointBox[{14., 0.6196996314971734}], 
             PointBox[{14.1, 0.6204156954452044}], 
             PointBox[{14.2, 0.6208128451431258}], 
             PointBox[{14.3, 0.6214861036035972}], 
             PointBox[{14.4, 0.6233887847866301}], 
             PointBox[{14.5, 0.6264780772907141}], 
             PointBox[{14.6, 0.6249927424010909}], 
             PointBox[{14.7, 0.6235295674932002}], 
             PointBox[{14.8, 0.6224028506940628}], 
             PointBox[{14.9, 0.6203791429540494}], 
             PointBox[{15., 0.6188657818204438}], 
             PointBox[{15.1, 0.6196228412687154}], 
             PointBox[{15.2, 0.6202985587830376}], 
             PointBox[{15.3, 0.6212235102766082}], 
             PointBox[{15.4, 0.6237002708107418}], 
             PointBox[{15.5, 0.6257104832269197}], 
             PointBox[{15.6, 0.6236327636133016}], 
             PointBox[{15.7, 0.6222726276033614}], 
             PointBox[{15.8, 0.6210658491690395}], 
             PointBox[{15.9, 0.6187482519274405}], 
             PointBox[{16., 0.6182909928435837}], 
             PointBox[{16.1, 0.6192602969543334}], 
             PointBox[{16.2, 0.6201138680661427}], 
             PointBox[{16.3, 0.6213321370699321}], 
             PointBox[{16.4, 0.624325013090218}], 
             PointBox[{16.5, 0.6246103621603344}], 
             PointBox[{16.6, 0.6224157275994093}], 
             PointBox[{16.7, 0.6211669412548505}], 
             PointBox[{16.8, 0.6198283664128873}], 
             PointBox[{16.9, 0.6175359872605286}], 
             PointBox[{17., 0.6180114374520828}], 
             PointBox[{17.1, 0.6192750966170911}], 
             PointBox[{17.2, 0.6202496281688131}], 
             PointBox[{17.3, 0.621828932544787}], 
             PointBox[{17.4, 0.6248893612364672}], 
             PointBox[{17.5, 0.623378353730024}], 
             PointBox[{17.6, 0.6213927258325338}], 
             PointBox[{17.7, 0.6202342123082566}], 
             PointBox[{17.8, 0.6187279219132}], 
             PointBox[{17.9, 0.6170572494587445}], 
             PointBox[{18., 0.618261058612038}], 
             PointBox[{18.1, 0.6196013477162479}], 
             PointBox[{18.2, 0.6206906030006247}], 
             PointBox[{18.3, 0.6226897012813791}], 
             PointBox[{18.4, 0.6249144939125016}], 
             PointBox[{18.5, 0.6222594290069207}], 
             PointBox[{18.6, 0.620598078819143}], 
             PointBox[{18.7, 0.6194994312848597}], 
             PointBox[{18.8, 0.6178792346350072}], 
             PointBox[{18.9, 0.6170770489140859}], 
             PointBox[{19., 0.6189098700034703}], 
             PointBox[{19.1, 0.6201890755208733}], 
             PointBox[{19.2, 0.6214182146956576}], 
             PointBox[{19.3, 0.623794774566462}], 
             PointBox[{19.4, 0.6242859194000505}], 
             PointBox[{19.5, 0.6214079416640679}], 
             PointBox[{19.6, 0.6200580510047609}], 
             PointBox[{19.7, 0.6190009106463102}], 
             PointBox[{19.8, 0.6175119473611284}], 
             PointBox[{19.9, 0.6177114752136503}], 
             PointBox[{20., 0.6198038588445034}], 
             PointBox[{20.1, 0.6210029482155972}], 
             PointBox[{20.2, 0.6224049395932935}], 
             PointBox[{20.3, 0.6248651021393644}], 
             PointBox[{20.4, 0.6233875720991762}], 
             PointBox[{20.5, 0.620888018725721}], 
             PointBox[{20.6, 0.6197976510565971}], 
             PointBox[{20.7, 0.6188041000527336}], 
             PointBox[{20.8, 0.6176937466247931}], 
             PointBox[{20.9, 0.6189421626878003}], 
             PointBox[{21., 0.6208663411960083}], 
             PointBox[{21.1, 0.6220164461555461}], 
             PointBox[{21.2, 0.6236066215612092}], 
             PointBox[{21.3, 0.6255454370555696}], 
             PointBox[{21.4, 0.6226678503772843}], 
             PointBox[{21.5, 0.6207164851878437}], 
             PointBox[{21.6, 0.6198440361058691}], 
             PointBox[{21.7, 0.6190085246966784}], 
             PointBox[{21.8, 0.6181919941187436}], 
             PointBox[{21.9, 0.6204301789937887}], 
             PointBox[{22., 0.6220659561984948}], 
             PointBox[{22.1, 0.623205453461657}], 
             PointBox[{22.2, 0.62494190602397}], 
             PointBox[{22.3, 0.6257132813135763}], 
             PointBox[{22.4, 0.6223474202515312}], 
             PointBox[{22.5, 0.6208912381517957}], 
             PointBox[{22.6, 0.6202254101831072}], 
             PointBox[{22.7, 0.6196855295292819}], 
             PointBox[{22.8, 0.6193023828359389}], 
             PointBox[{22.9, 0.6219935915074173}], 
             PointBox[{23., 0.623384845567034}], 
             PointBox[{23.1, 0.6245406965433623}], 
             PointBox[{23.2, 0.6262984478025193}], 
             PointBox[{23.3, 0.6256299800577817}], 
             PointBox[{23.4, 0.6224618002335994}], 
             PointBox[{23.5, 0.6213975069864487}], 
             PointBox[{23.6, 0.6209606356468332}], 
             PointBox[{23.7, 0.6206788801285296}], 
             PointBox[{23.8, 0.6209646722254134}], 
             PointBox[{23.9, 0.6235792611779761}], 
             PointBox[{24., 0.6248034485070186}], 
             PointBox[{24.1, 0.6259846435360203}], 
             PointBox[{24.2, 0.6275702319777101}], 
             PointBox[{24.3, 0.6256681458301546}], 
             PointBox[{24.4, 0.6229662042269415}], 
             PointBox[{24.5, 0.6222048396501602}], 
             PointBox[{24.6, 0.6220366802296998}], 
             PointBox[{24.7, 0.6217002918834992}], 
             PointBox[{24.8, 0.6228198202573691}], 
             PointBox[{24.9, 0.6251702040442011}], 
             PointBox[{25., 0.6262935853051146}], 
             PointBox[{25.1, 0.627491630546836}], 
             PointBox[{25.2, 0.6287248499577497}], 
             PointBox[{25.3, 0.6260338957918725}], 
             PointBox[{25.4, 0.6237871700711861}], 
             PointBox[{25.5, 0.6232598680408403}], 
             PointBox[{25.6, 0.6233816969282711}], 
             PointBox[{25.7, 0.622821856547444}], 
             PointBox[{25.8, 0.6246424090115767}], 
             PointBox[{25.9, 0.6267452942435121}], 
             PointBox[{26., 0.6278158941753218}], 
             PointBox[{26.1, 0.6290123761511811}], 
             PointBox[{26.2, 0.6298150246987138}], 
             PointBox[{26.3, 0.6267512736947988}], 
             PointBox[{26.4, 0.6248411062971642}], 
             PointBox[{26.5, 0.6244860001063938}], 
             PointBox[{26.6, 0.6248609902381166}], 
             PointBox[{26.7, 0.624128899567727}], 
             PointBox[{26.8, 0.6263345317375065}], 
             PointBox[{26.9, 0.6282711435369815}], 
             PointBox[{27., 0.6293237513645397}], 
             PointBox[{27.1, 0.6305028814634527}], 
             PointBox[{27.2, 0.6309215499261476}], 
             PointBox[{27.3, 0.6277562387206986}], 
             PointBox[{27.4, 0.6260440559096518}], 
             PointBox[{27.5, 0.6257918628278233}], 
             PointBox[{27.6, 0.626332906814723}], 
             PointBox[{27.7, 0.6255214268369846}], 
             PointBox[{27.8, 0.6278513377666538}], 
             PointBox[{27.9, 0.6297063354244588}], 
             PointBox[{28., 0.6307686181007244}], 
             PointBox[{28.1, 0.6319276585545528}], 
             PointBox[{28.2, 0.6320921539674198}], 
             PointBox[{28.3, 0.6289644816632879}], 
             PointBox[{28.4, 0.6273229459744413}], 
             PointBox[{28.5, 0.627092894890826}], 
             PointBox[{28.6, 0.6277094213414295}], 
             PointBox[{28.7, 0.626880239730616}], 
             PointBox[{28.8, 0.6291648468053754}], 
             PointBox[{28.9, 0.6310082150115444}], 
             PointBox[{29., 0.6321053339575845}], 
             PointBox[{29.1, 0.6332576060672612}], 
             PointBox[{29.2, 0.6333232112801251}], 
             PointBox[{29.3, 0.6303021583433517}], 
             PointBox[{29.4, 0.6286245245606048}], 
             PointBox[{29.5, 0.6283300970526681}], 
             PointBox[{29.6, 0.6289451808949316}], 
             PointBox[{29.7, 0.6281404933791487}], 
             PointBox[{29.8, 0.6302555063852118}], 
             PointBox[{29.9, 0.6321367326727367}], 
             PointBox[{30., 0.6332936246292782}], 
             PointBox[{30.1, 0.6344643782087938}], 
             PointBox[{30.2, 0.6345735679220471}], 
             PointBox[{30.3, 0.6317110868014285}], 
             PointBox[{30.4, 0.6299173470050258}], 
             PointBox[{30.5, 0.6294770543966435}], 
             PointBox[{30.6, 0.6300060491424525}], 
             PointBox[{30.7, 0.6292914085002557}], 
             PointBox[{30.8, 0.6311148412031848}], 
             PointBox[{30.9, 0.6330584677094959}], 
             PointBox[{31., 0.6342983361351298}], 
             PointBox[{31.1, 0.6355178115707458}], 
             PointBox[{31.2, 0.6357829028870986}], 
             PointBox[{31.3, 0.6331428237963822}], 
             PointBox[{31.4, 0.6311870227588976}], 
             PointBox[{31.5, 0.6305366642015564}], 
             PointBox[{31.6, 0.6308695151818013}], 
             PointBox[{31.7, 0.6303510922001496}], 
             PointBox[{31.8, 0.6317497751955158}], 
             PointBox[{31.9, 0.6337481411465273}], 
             PointBox[{32., 0.635088513637285}], 
             PointBox[{32.1, 0.6363852406013507}], 
             PointBox[{32.2, 0.6368849536083219}], 
             PointBox[{32.3, 0.6345488593152702}], 
             PointBox[{32.4, 0.6324257069087716}], 
             PointBox[{32.5, 0.6315267055047036}], 
             PointBox[{32.6, 0.6315531360011423}], 
             PointBox[{32.7, 0.6313433697543029}], 
             PointBox[{32.8, 0.6321868144908234}], 
             PointBox[{32.9, 0.6341925676072548}], 
             PointBox[{33., 0.635639360756546}], 
             PointBox[{33.1, 0.6370341177849682}], 
             PointBox[{33.2, 0.6378167880845009}], 
             PointBox[{33.3, 0.6358746007960444}], 
             PointBox[{33.4, 0.6336222249134947}], 
             PointBox[{33.5, 0.632464733069582}], 
             PointBox[{33.6, 0.6321200022873912}], 
             PointBox[{33.7, 0.6322423235265241}], 
             PointBox[{33.8, 0.6324737092728252}], 
             PointBox[{33.9, 0.6343962010643173}], 
             PointBox[{34., 0.6359354891600729}], 
             PointBox[{34.1, 0.6374368297438144}], 
             PointBox[{34.2, 0.6385244266093189}], 
             PointBox[{34.3, 0.6370591987860487}], 
             PointBox[{34.4, 0.6347538770908222}], 
             PointBox[{34.5, 0.6333577391930458}], 
             PointBox[{34.6, 0.6326381186238835}], 
             PointBox[{34.7, 0.632907955152532}], 
             PointBox[{34.8, 0.6326739466407949}], 
             PointBox[{34.9, 0.634382357588541}], 
             PointBox[{35., 0.6359753514653956}], 
             PointBox[{35.1, 0.6375737986214182}], 
             PointBox[{35.2, 0.6389660145038529}], 
             PointBox[{35.3, 0.6380411935065629}], 
             PointBox[{35.4, 0.6357834108165977}], 
             PointBox[{35.5, 0.6341954927710366}], 
             PointBox[{35.6, 0.6331456432688961}], 
             PointBox[{35.7, 0.633184923588249}], 
             PointBox[{35.8, 0.6328573995895036}], 
             PointBox[{35.9, 0.6341926056325502}], 
             PointBox[{36., 0.635773841411017}], 
             PointBox[{36.1, 0.6374382096681591}], 
             PointBox[{36.2, 0.6391129953191236}], 
             PointBox[{36.3, 0.6387670529780242}], 
             PointBox[{36.4, 0.6366627294550673}], 
             PointBox[{36.5, 0.63495108254716}], 
             PointBox[{36.6, 0.6336433311900842}], 
             PointBox[{36.7, 0.6331677002102563}], 
             PointBox[{36.8, 0.6330731582766429}], 
             PointBox[{36.9, 0.6338799547180102}], 
             PointBox[{37., 0.6353626236833027}], 
             PointBox[{37.1, 0.6370396039598535}], 
             PointBox[{37.2, 0.6389520193843786}], 
             PointBox[{37.3, 0.6391989756366804}], 
             PointBox[{37.4, 0.6373417564493898}], 
             PointBox[{37.5, 0.6355828646162736}], 
             PointBox[{37.6, 0.6341038239036323}], 
             PointBox[{37.7, 0.6330844936325346}], 
             PointBox[{37.8, 0.6332836052042059}], 
             PointBox[{37.9, 0.6335007899889721}], 
             PointBox[{38., 0.6347863796822183}], 
             PointBox[{38.1, 0.6364062907380479}], 
             PointBox[{38.2, 0.638486605938082}], 
             PointBox[{38.3, 0.6393164471173187}], 
             PointBox[{38.4, 0.6377781751510279}], 
             PointBox[{38.5, 0.6360437939628976}], 
             PointBox[{38.6, 0.6344817796926845}], 
             PointBox[{38.7, 0.6330363891545516}], 
             PointBox[{38.8, 0.633283973575443}], 
             PointBox[{38.9, 0.6331020201205555}], 
             PointBox[{39., 0.6340925379849363}], 
             PointBox[{39.1, 0.6355803577611031}], 
             PointBox[{39.2, 0.6377389414820908}], 
             PointBox[{39.3, 0.6391178470138166}], 
             PointBox[{39.4, 0.637945462507085}], 
             PointBox[{39.5, 0.6362907813253612}], 
             PointBox[{39.6, 0.6347246679121329}], 
             PointBox[{39.7, 0.6330052267912051}], 
             PointBox[{39.8, 0.6328754559206918}], 
             PointBox[{39.9, 0.6327097260682802}], 
             PointBox[{40., 0.6333222222020942}], 
             PointBox[{40.1, 0.6346108007783284}], 
             PointBox[{40.2, 0.6367487625421234}], 
             PointBox[{40.3, 0.6386162967508817}], 
             PointBox[{40.4, 0.6378343808807926}], 
             PointBox[{40.5, 0.6362922245339554}], 
             PointBox[{40.6, 0.6347817010597001}], 
             PointBox[{40.7, 0.6329291101481397}], 
             PointBox[{40.8, 0.6321681196189334}], 
             PointBox[{40.9, 0.6323115628802132}], 
             PointBox[{41., 0.6325024340160761}], 
             PointBox[{41.1, 0.6335431450520396}], 
             PointBox[{41.2, 0.6355694991676583}], 
             PointBox[{41.3, 0.6378426766665706}], 
             PointBox[{41.4, 0.6374533424550866}], 
             PointBox[{41.5, 0.6360342947809898}], 
             PointBox[{41.6, 0.6346139358886391}], 
             PointBox[{41.7, 0.6327401933752129}], 
             PointBox[{41.8, 0.6313642761635812}], 
             PointBox[{41.9, 0.6318414118562339}], 
             PointBox[{42., 0.6316416570206504}], 
             PointBox[{42.1, 0.6324114488940439}], 
             PointBox[{42.2, 0.6342607326794093}], 
             PointBox[{42.3, 0.6368421292444428}], 
             PointBox[{42.4, 0.6368241759661569}], 
             PointBox[{42.5, 0.6355196464868128}], 
             PointBox[{42.6, 0.6342017378183681}], 
             PointBox[{42.7, 0.6323803205243925}], 
             PointBox[{42.8, 0.6305224724447508}], 
             PointBox[{42.9, 0.6312004489753061}], 
             PointBox[{43., 0.6307298131088771}], 
             PointBox[{43.1, 0.631234537237431}], 
             PointBox[{43.2, 0.6328771104319112}], 
             PointBox[{43.3, 0.6356711082793634}], 
             PointBox[{43.4, 0.6359769596229901}], 
             PointBox[{43.5, 0.6347638383925279}], 
             PointBox[{43.6, 0.6335416806148533}], 
             PointBox[{43.7, 0.6318081902509648}], 
             PointBox[{43.8, 0.629611694764778}], 
             PointBox[{43.9, 0.6303283853639553}], 
             PointBox[{44., 0.6297422113026148}], 
             PointBox[{44.1, 0.6300186056688656}], 
             PointBox[{44.2, 0.6314645520338357}], 
             PointBox[{44.3, 0.6343988600338498}], 
             PointBox[{44.4, 0.6349473249454258}], 
             PointBox[{44.5, 0.6337912119790124}], 
             PointBox[{44.6, 0.6326483625570001}], 
             PointBox[{44.7, 0.6310047049553117}], 
             PointBox[{44.8, 0.6285824362744097}], 
             PointBox[{44.9, 0.6292478363723094}], 
             PointBox[{45., 0.6286531671554745}], 
             PointBox[{45.1, 0.6287663941202398}], 
             PointBox[{45.2, 0.6300607733690823}], 
             PointBox[{45.3, 0.6330976025128873}], 
             PointBox[{45.4, 0.6337717081612069}], 
             PointBox[{45.5, 0.6326321814326474}], 
             PointBox[{45.6, 0.6315473027973836}], 
             PointBox[{45.7, 0.6299695648221016}], 
             PointBox[{45.8, 0.6273977587425196}], 
             PointBox[{45.9, 0.6280205642702421}], 
             PointBox[{46., 0.6274499947647039}], 
             PointBox[{46.1, 0.6274851861740677}], 
             PointBox[{46.2, 0.6287019296640644}], 
             PointBox[{46.3, 0.6318386983790429}], 
             PointBox[{46.4, 0.6324822341064136}], 
             PointBox[{46.5, 0.6313204558545705}], 
             PointBox[{46.6, 0.6302718862950798}], 
             PointBox[{46.7, 0.6287182207522329}], 
             PointBox[{46.8, 0.6260484609415189}], 
             PointBox[{46.9, 0.626693500050811}], 
             PointBox[{47., 0.6261501861747051}], 
             PointBox[{47.1, 0.6261992501359052}], 
             PointBox[{47.2, 0.6274339141357399}], 
             PointBox[{47.3, 0.630683660742261}], 
             PointBox[{47.4, 0.6311041592590995}], 
             PointBox[{47.5, 0.6298931297780687}], 
             PointBox[{47.6, 0.6288617371077381}], 
             PointBox[{47.7, 0.6272741790620401}], 
             PointBox[{47.8, 0.6245672199310615}], 
             PointBox[{47.9, 0.6252829602566323}], 
             PointBox[{48., 0.62480887654596}], 
             PointBox[{48.1, 0.6249557339643261}], 
             PointBox[{48.2, 0.6263201464519801}], 
             PointBox[{48.3, 0.6296665896865858}], 
             PointBox[{48.4, 0.629658097990782}], 
             PointBox[{48.5, 0.6283935039037596}], 
             PointBox[{48.6, 0.6273612948554047}], 
             PointBox[{48.7, 0.6256665970504918}], 
             PointBox[{48.8, 0.6230559550952102}], 
             PointBox[{48.9, 0.6238078523344932}], 
             PointBox[{49., 0.6235136611068618}], 
             PointBox[{49.1, 0.6238236548432999}], 
             PointBox[{49.2, 0.6254440339756023}], 
             PointBox[{49.3, 0.6287677507690487}], 
             PointBox[{49.4, 0.6281661097329257}], 
             PointBox[{49.5, 0.6268691295590649}], 
             PointBox[{49.6, 0.6258156564959755}], 
             PointBox[{49.7, 0.6239248506468223}], 
             PointBox[{49.8, 0.6216869461465437}], 
             PointBox[{49.9, 0.6223668267522929}], 
             PointBox[{50., 0.6223638588111846}], 
             PointBox[{50.1, 0.6228838892518002}], 
             PointBox[{50.2, 0.6248975745380311}], 
             PointBox[{50.3, 0.6278921404582491}], 
             PointBox[{50.4, 0.6266613335333631}], 
             PointBox[{50.5, 0.6253683429477134}], 
             PointBox[{50.6, 0.6242643832681911}], 
             PointBox[{50.7, 0.6220902652940811}], 
             PointBox[{50.8, 0.6206206510472978}], 
             PointBox[{50.9, 0.6211351877902815}], 
             PointBox[{51., 0.6214457812470764}], 
             PointBox[{51.1, 0.6222167587711502}], 
             PointBox[{51.2, 0.6247455371635382}], 
             PointBox[{51.3, 0.6269016433389596}], 
             PointBox[{51.4, 0.6251900599739922}], 
             PointBox[{51.5, 0.6239342565172221}], 
             PointBox[{51.6, 0.6227371828325629}], 
             PointBox[{51.7, 0.6202550767545267}], 
             PointBox[{51.8, 0.619748263535971}], 
             PointBox[{51.9, 0.6202466912776184}], 
             PointBox[{52., 0.6208180236060205}], 
             PointBox[{52.1, 0.6218926911900756}], 
             PointBox[{52.2, 0.6249497558831877}], 
             PointBox[{52.3, 0.6257217366867854}], 
             PointBox[{52.4, 0.6238052884313905}], 
             PointBox[{52.5, 0.6226012702715359}], 
             PointBox[{52.6, 0.6212490368482425}], 
             PointBox[{52.7, 0.6186562979644403}], 
             PointBox[{52.8, 0.61895743241399}], 
             PointBox[{52.9, 0.619738583485659}], 
             PointBox[{53., 0.6205116523178492}], 
             PointBox[{53.1, 0.6219676165143998}], 
             PointBox[{53.2, 0.6252630609908325}], 
             PointBox[{53.3, 0.6244154418319189}], 
             PointBox[{53.4, 0.6225546041255828}], 
             PointBox[{53.5, 0.6213935261342893}], 
             PointBox[{53.6, 0.6198185664078905}], 
             PointBox[{53.7, 0.6176760564695254}], 
             PointBox[{53.8, 0.6185557628038154}], 
             PointBox[{53.9, 0.6195884631445651}], 
             PointBox[{54., 0.6205375455033857}], 
             PointBox[{54.1, 0.622465728460601}], 
             PointBox[{54.2, 0.625253595255093}], 
             PointBox[{54.3, 0.6231347322796453}], 
             PointBox[{54.4, 0.6214761237660567}], 
             PointBox[{54.5, 0.6203297667338955}], 
             PointBox[{54.6, 0.6185091275490531}], 
             PointBox[{54.7, 0.6173237681102189}], 
             PointBox[{54.8, 0.6186366748679974}], 
             PointBox[{54.9, 0.619758332998838}], 
             PointBox[{55., 0.6208956167556613}], 
             PointBox[{55.1, 0.6233301642533039}], 
             PointBox[{55.2, 0.6246496502135371}], 
             PointBox[{55.3, 0.6220203961960347}], 
             PointBox[{55.4, 0.6205980136337548}], 
             PointBox[{55.5, 0.6194334351293611}], 
             PointBox[{55.6, 0.6175159247182276}], 
             PointBox[{55.7, 0.6173623213976962}], 
             PointBox[{55.8, 0.6190818369663009}], 
             PointBox[{55.9, 0.620211621824273}], 
             PointBox[{56., 0.6215759336031405}], 
             PointBox[{56.1, 0.624324991495882}], 
             PointBox[{56.2, 0.6236341913434867}], 
             PointBox[{56.3, 0.6211574539592067}], 
             PointBox[{56.4, 0.6199457119176912}], 
             PointBox[{56.5, 0.6187450192366519}], 
             PointBox[{56.6, 0.6171368165150019}], 
             PointBox[{56.7, 0.6180173716149523}], 
             PointBox[{56.8, 0.6197858165058928}], 
             PointBox[{56.9, 0.6209177891343495}], 
             PointBox[{57., 0.6225503095939571}], 
             PointBox[{57.1, 0.6250186789670104}], 
             PointBox[{57.2, 0.6226209383210896}], 
             PointBox[{57.3, 0.6205876459181223}], 
             PointBox[{57.4, 0.6195477064716148}], 
             PointBox[{57.5, 0.6183534531052856}], 
             PointBox[{57.6, 0.6172788596329417}], 
             PointBox[{57.7, 0.6191067873772513}], 
             PointBox[{57.8, 0.6206907122635884}], 
             PointBox[{57.9, 0.6218515352163901}], 
             PointBox[{58., 0.6237484984968219}], 
             PointBox[{58.1, 0.6250822118951576}], 
             PointBox[{58.2, 0.6219009899360439}], 
             PointBox[{58.3, 0.6203309466462572}], 
             PointBox[{58.4, 0.6194407683993168}], 
             PointBox[{58.5, 0.6184025447307039}], 
             PointBox[{58.6, 0.6179443738047214}], 
             PointBox[{58.7, 0.6203911513885975}], 
             PointBox[{58.8, 0.621765246232869}], 
             PointBox[{58.9, 0.6229856252742052}], 
             PointBox[{59., 0.6250283289898894}], 
             PointBox[{59.1, 0.6246668630402921}], 
             PointBox[{59.2, 0.6215805505000866}], 
             PointBox[{59.3, 0.6203982388849001}], 
             PointBox[{59.4, 0.6196716257068129}], 
             PointBox[{59.5, 0.6189419837311418}], 
             PointBox[{59.6, 0.6193268173191495}], 
             PointBox[{59.7, 0.6217710085122278}], 
             PointBox[{59.8, 0.6229884511067264}], 
             PointBox[{59.9, 0.6242851881142469}], 
             PointBox[{60., 0.6261946352763419}], 
             PointBox[{60.1, 0.6242348525657383}], 
             PointBox[{60.2, 0.6216636734382659}], 
             PointBox[{60.3, 0.620793402299342}], 
             PointBox[{60.4, 0.6202876516901863}], 
             PointBox[{60.5, 0.619679742991208}], 
             PointBox[{60.6, 0.6210749239842547}], 
             PointBox[{60.7, 0.6232187636771082}], 
             PointBox[{60.8, 0.6243392469980276}], 
             PointBox[{60.9, 0.6257012563676869}], 
             PointBox[{61., 0.6271123399294177}], 
             PointBox[{61.1, 0.6241252295871832}], 
             PointBox[{61.2, 0.6221153918681285}], 
             PointBox[{61.3, 0.6215074060460742}], 
             PointBox[{61.4, 0.6213034437923726}], 
             PointBox[{61.5, 0.6206090489589488}], 
             PointBox[{61.6, 0.6228912762999452}], 
             PointBox[{61.7, 0.6247204914268378}], 
             PointBox[{61.8, 0.6257880594283066}], 
             PointBox[{61.9, 0.6271769766070668}], 
             PointBox[{62., 0.6278235448860342}], 
             PointBox[{62.1, 0.62443593004817}], 
             PointBox[{62.2, 0.6228816158260936}], 
             PointBox[{62.3, 0.6225072708891513}], 
             PointBox[{62.4, 0.6226250808685994}], 
             PointBox[{62.5, 0.6219421421973529}], 
             PointBox[{62.6, 0.6246578119270514}], 
             PointBox[{62.7, 0.626254484090269}], 
             PointBox[{62.8, 0.6272981536496336}], 
             PointBox[{62.9, 0.6286570837472122}], 
             PointBox[{63., 0.6285050203086363}], 
             PointBox[{63.1, 0.6251250105682084}], 
             PointBox[{63.2, 0.6238936276712449}], 
             PointBox[{63.3, 0.62372846332552}], 
             PointBox[{63.4, 0.6240515213392918}], 
             PointBox[{63.5, 0.6235280783408268}], 
             PointBox[{63.6, 0.6263321874144369}], 
             PointBox[{63.7, 0.6277864471263596}], 
             PointBox[{63.8, 0.6288231766279934}], 
             PointBox[{63.9, 0.6301035485205815}], 
             PointBox[{64., 0.6293167904951246}], 
             PointBox[{64.1, 0.6261028975737802}], 
             PointBox[{64.2, 0.6250719058032759}], 
             PointBox[{64.3, 0.6250748722180192}], 
             PointBox[{64.4, 0.6254354346194202}], 
             PointBox[{64.5, 0.6251391080340074}], 
             PointBox[{64.6, 0.6278855200059992}], 
             PointBox[{64.7, 0.6292730354704459}], 
             PointBox[{64.8, 0.630314680806849}], 
             PointBox[{64.9, 0.6314987941300918}], 
             PointBox[{65., 0.6303215040972885}], 
             PointBox[{65.1, 0.6272773413841891}], 
             PointBox[{65.2, 0.626336330774203}], 
             PointBox[{65.3, 0.6264398677974}], 
             PointBox[{65.4, 0.6267675348748482}], 
             PointBox[{65.5, 0.6266312927419094}], 
             PointBox[{65.6, 0.6292870947990326}], 
             PointBox[{65.7, 0.6306675348109735}], 
             PointBox[{65.8, 0.6317275652821024}], 
             PointBox[{65.9, 0.6328344021516497}], 
             PointBox[{66., 0.6315011588068694}], 
             PointBox[{66.1, 0.628571364646479}], 
             PointBox[{66.2, 0.6276203130909346}], 
             PointBox[{66.3, 0.627734597393761}], 
             PointBox[{66.4, 0.6280637492428872}], 
             PointBox[{66.5, 0.6279389859667621}], 
             PointBox[{66.6, 0.6305040922690344}], 
             PointBox[{66.7, 0.6319255352714176}], 
             PointBox[{66.8, 0.633019942100492}], 
             PointBox[{66.9, 0.6340952734439254}], 
             PointBox[{67., 0.6327994154030748}], 
             PointBox[{67.1, 0.6299297364677008}], 
             PointBox[{67.2, 0.6288803849861394}], 
             PointBox[{67.3, 0.6289072857423924}], 
             PointBox[{67.4, 0.62930451582205}], 
             PointBox[{67.5, 0.6290480590422701}], 
             PointBox[{67.6, 0.6315091301485481}], 
             PointBox[{67.7, 0.6330083554401666}], 
             PointBox[{67.8, 0.6341577027650747}], 
             PointBox[{67.9, 0.6352548922886531}], 
             PointBox[{68., 0.6341470310489876}], 
             PointBox[{68.1, 0.6313155282119498}], 
             PointBox[{68.2, 0.6300977627614159}], 
             PointBox[{68.3, 0.6299469881659795}], 
             PointBox[{68.4, 0.6304352254314198}], 
             PointBox[{68.5, 0.6299757571419994}], 
             PointBox[{68.6, 0.6322831081942621}], 
             PointBox[{68.7, 0.6338823744108304}], 
             PointBox[{68.8, 0.6351075068742016}], 
             PointBox[{68.9, 0.6362767586888057}], 
             PointBox[{69., 0.6354708480491312}], 
             PointBox[{69.1, 0.6327000323317745}], 
             PointBox[{69.2, 0.6312693406351091}], 
             PointBox[{69.3, 0.6308734867541536}], 
             PointBox[{69.4, 0.6313711885570897}], 
             PointBox[{69.5, 0.6307642417881848}], 
             PointBox[{69.6, 0.6328215565770806}], 
             PointBox[{69.7, 0.6345223812040612}], 
             PointBox[{69.8, 0.6358401878408306}], 
             PointBox[{69.9, 0.6371207406647978}], 
             PointBox[{70., 0.6366978579676916}], 
             PointBox[{70.1, 0.6340536225004278}], 
             PointBox[{70.2, 0.632397613227377}], 
             PointBox[{70.3, 0.6317205475939536}], 
             PointBox[{70.4, 0.6320402686484782}], 
             PointBox[{70.5, 0.6314696886705667}], 
             PointBox[{70.6, 0.6331390136200185}], 
             PointBox[{70.7, 0.6349136244081495}], 
             PointBox[{70.8, 0.636330888249563}], 
             PointBox[{70.9, 0.6377475783668402}], 
             PointBox[{71., 0.6377584726021857}], 
             PointBox[{71.1, 0.6353367715971052}], 
             PointBox[{71.2, 0.6334792338481989}], 
             PointBox[{71.3, 0.6325179008780172}], 
             PointBox[{71.4, 0.6324688485280714}], 
             PointBox[{71.5, 0.6321470549496495}], 
             PointBox[{71.6, 0.6332710286523887}], 
             PointBox[{71.7, 0.6350568734492268}], 
             PointBox[{71.8, 0.6365631976113917}], 
             PointBox[{71.9, 0.6381239833967843}], 
             PointBox[{72., 0.6385918336350074}], 
             PointBox[{72.1, 0.6364985057501112}], 
             PointBox[{72.2, 0.6344978317829404}], 
             PointBox[{72.3, 0.633278603109726}], 
             PointBox[{72.4, 0.632777370418754}], 
             PointBox[{72.5, 0.632798941060443}], 
             PointBox[{72.6, 0.6332713091889584}], 
             PointBox[{72.7, 0.6349708094334697}], 
             PointBox[{72.8, 0.636533277659949}], 
             PointBox[{72.9, 0.6382266242760894}], 
             PointBox[{73., 0.6391506974269417}], 
             PointBox[{73.1, 0.6374820239323177}], 
             PointBox[{73.2, 0.6354214197256014}], 
             PointBox[{73.3, 0.6339955577689079}], 
             PointBox[{73.4, 0.6330705363774907}], 
             PointBox[{73.5, 0.6332818696330571}], 
             PointBox[{73.6, 0.633205083358932}], 
             PointBox[{73.7, 0.634692168201879}], 
             PointBox[{73.8, 0.6362547318806113}], 
             PointBox[{73.9, 0.6380464583876001}], 
             PointBox[{74., 0.6394046022948032}], 
             PointBox[{74.1, 0.638235037875992}], 
             PointBox[{74.2, 0.6362072535403867}], 
             PointBox[{74.3, 0.6346431320781124}], 
             PointBox[{74.4, 0.633382098471273}], 
             PointBox[{74.5, 0.6333700278558649}], 
             PointBox[{74.6, 0.633135988987496}], 
             PointBox[{74.7, 0.6342698359897582}], 
             PointBox[{74.8, 0.635758241355395}], 
             PointBox[{74.9, 0.6375905616977486}], 
             PointBox[{75., 0.6393369787552058}], 
             PointBox[{75.1, 0.6387152378630453}], 
             PointBox[{75.2, 0.6368058594284869}], 
             PointBox[{75.3, 0.6351785531533732}], 
             PointBox[{75.4, 0.6336903544022683}], 
             PointBox[{75.5, 0.6331153711240125}], 
             PointBox[{75.6, 0.6331018290680214}], 
             PointBox[{75.7, 0.6337542527120276}], 
             PointBox[{75.8, 0.6350857327801126}], 
             PointBox[{75.9, 0.6368848417856103}], 
             PointBox[{76., 0.6389499809423453}], 
             PointBox[{76.1, 0.638900111304503}], 
             PointBox[{76.2, 0.637175374396463}], 
             PointBox[{76.3, 0.6355546903168642}], 
             PointBox[{76.4, 0.6339473503339313}], 
             PointBox[{76.5, 0.6327723368698954}], 
             PointBox[{76.6, 0.633064638592519}], 
             PointBox[{76.7, 0.6331896687459213}], 
             PointBox[{76.8, 0.6342848809707403}], 
             PointBox[{76.9, 0.6359708514025991}], 
             PointBox[{77., 0.6382614093684826}], 
             PointBox[{77.1, 0.6387846535442171}], 
             PointBox[{77.2, 0.6372870599055759}], 
             PointBox[{77.3, 0.6357260858612375}], 
             PointBox[{77.4, 0.6340947225799485}], 
             PointBox[{77.5, 0.6324544655213868}], 
             PointBox[{77.6, 0.6328562167107051}], 
             PointBox[{77.7, 0.6326033860757643}], 
             PointBox[{77.8, 0.6333974545837107}], 
             PointBox[{77.9, 0.6349000955331263}], 
             PointBox[{78., 0.6373078323424803}], 
             PointBox[{78.1, 0.6383812140463282}], 
             PointBox[{78.2, 0.6371298903313839}], 
             PointBox[{78.3, 0.6356595425738588}], 
             PointBox[{78.4, 0.6340765481419617}], 
             PointBox[{78.5, 0.632138663753416}], 
             PointBox[{78.6, 0.6322945336337182}], 
             PointBox[{78.7, 0.6319992233712062}], 
             PointBox[{78.8, 0.632451304839629}], 
             PointBox[{78.9, 0.6337230215181024}], 
             PointBox[{79., 0.6361408096806818}], 
             PointBox[{79.1, 0.6377165275843106}], 
             PointBox[{79.2, 0.6367090121228511}], 
             PointBox[{79.3, 0.6353388005271909}], 
             PointBox[{79.4, 0.633848191396207}], 
             PointBox[{79.5, 0.6317582819298261}], 
             PointBox[{79.6, 0.6314108869612136}], 
             PointBox[{79.7, 0.6313507144819134}], 
             PointBox[{79.8, 0.6314583954511719}], 
             PointBox[{79.9, 0.632479279116795}], 
             PointBox[{80., 0.634822868864158}], 
             PointBox[{80.1, 0.6368304432989453}], 
             PointBox[{80.2, 0.6360430200991273}], 
             PointBox[{80.3, 0.6347654065453003}], 
             PointBox[{80.4, 0.6333831276079331}], 
             PointBox[{80.5, 0.6312470915855558}], 
             PointBox[{80.6, 0.6303575571946742}], 
             PointBox[{80.7, 0.630605777254823}], 
             PointBox[{80.8, 0.6304145902010628}], 
             PointBox[{80.9, 0.6311964212598697}], 
             PointBox[{81., 0.6334187234841773}], 
             PointBox[{81.1, 0.6357725489467752}], 
             PointBox[{81.2, 0.6351581039382818}], 
             PointBox[{81.3, 0.6339537716166368}], 
             PointBox[{81.4, 0.6326754525169326}], 
             PointBox[{81.5, 0.6305523335957071}], 
             PointBox[{81.6, 0.6292168778228943}], 
             PointBox[{81.7, 0.6297089649566748}], 
             PointBox[{81.8, 0.6293065780002675}], 
             PointBox[{81.9, 0.6298892241722561}], 
             PointBox[{82., 0.631989934837606}], 
             PointBox[{82.1, 0.6346001141860302}], 
             PointBox[{82.2, 0.6340849440183015}], 
             PointBox[{82.3, 0.6329291581644205}], 
             PointBox[{82.4, 0.6317357684270035}], 
             PointBox[{82.5, 0.6296409343635255}], 
             PointBox[{82.6, 0.6280016233845191}], 
             PointBox[{82.7, 0.6286313969225461}], 
             PointBox[{82.8, 0.6281233087268071}], 
             PointBox[{82.9, 0.628570799412655}], 
             PointBox[{83., 0.6305940124608995}], 
             PointBox[{83.1, 0.6333708106310918}], 
             PointBox[{83.2, 0.6328550716638375}], 
             PointBox[{83.3, 0.6317229903438702}], 
             PointBox[{83.4, 0.630588989750297}], 
             PointBox[{83.5, 0.628499601773753}], 
             PointBox[{83.6, 0.6267153594665027}], 
             PointBox[{83.7, 0.627378634482588}], 
             PointBox[{83.8, 0.6268678808857375}], 
             PointBox[{83.9, 0.627260520615682}], 
             PointBox[{84., 0.6292887420861195}], 
             PointBox[{84.1, 0.6321326205779291}], 
             PointBox[{84.2, 0.6314990238522707}], 
             PointBox[{84.3, 0.6303712838387313}], 
             PointBox[{84.4, 0.6292676447327391}], 
             PointBox[{84.5, 0.6271326530826102}], 
             PointBox[{84.6, 0.6253876035429193}], 
             PointBox[{84.7, 0.6259864372421351}], 
             PointBox[{84.8, 0.625571751989761}], 
             PointBox[{84.9, 0.6259952829287289}], 
             PointBox[{85., 0.6281409509089073}], 
             PointBox[{85.1, 0.6309122037905525}], 
             PointBox[{85.2, 0.6300488837392235}], 
             PointBox[{85.3, 0.6289161174258326}], 
             PointBox[{85.4, 0.627811136193076}], 
             PointBox[{85.5, 0.6255588915024096}], 
             PointBox[{85.6, 0.6240880708579246}], 
             PointBox[{85.7, 0.6245235659116072}], 
             PointBox[{85.8, 0.6242959902700602}], 
             PointBox[{85.9, 0.6248336462813643}], 
             PointBox[{86., 0.627226771230971}], 
             PointBox[{86.1, 0.6297006321992781}], 
             PointBox[{86.2, 0.628540224422624}], 
             PointBox[{86.3, 0.6274041891718}], 
             PointBox[{86.4, 0.6262603118721781}], 
             PointBox[{86.5, 0.6238158904284782}], 
             PointBox[{86.6, 0.6228899588681663}], 
             PointBox[{86.7, 0.6231019832828953}], 
             PointBox[{86.8, 0.6231231613517325}], 
             PointBox[{86.9, 0.6238528515163253}], 
             PointBox[{87., 0.6266135121132704}], 
             PointBox[{87.1, 0.6284562750751137}], 
             PointBox[{87.2, 0.6270142295930433}], 
             PointBox[{87.3, 0.6258831353133537}], 
             PointBox[{87.4, 0.6246515501497797}], 
             PointBox[{87.5, 0.6219845971284126}], 
             PointBox[{87.6, 0.6217569570881442}], 
             PointBox[{87.7, 0.6218547714863956}], 
             PointBox[{87.8, 0.6221391216301744}], 
             PointBox[{87.9, 0.6231407121836308}], 
             PointBox[{88., 0.6263115404076542}], 
             PointBox[{88.1, 0.6271381704795774}], 
             PointBox[{88.2, 0.6255188657449547}], 
             PointBox[{88.3, 0.6243979453675341}], 
             PointBox[{88.4, 0.6230132571294464}], 
             PointBox[{88.5, 0.6202461435460578}], 
             PointBox[{88.6, 0.6206057676118132}], 
             PointBox[{88.7, 0.620886967305227}], 
             PointBox[{88.8, 0.6214159769047533}], 
             PointBox[{88.9, 0.6227833690894014}], 
             PointBox[{89., 0.626191881954691}], 
             PointBox[{89.1, 0.6257514010773487}], 
             PointBox[{89.2, 0.6241009410998511}], 
             PointBox[{89.3, 0.6229835271697488}], 
             PointBox[{89.4, 0.6213638938291134}], 
             PointBox[{89.5, 0.6189189576662901}], 
             PointBox[{89.6, 0.6196419740220799}], 
             PointBox[{89.7, 0.6202499856347898}], 
             PointBox[{89.8, 0.6210051654310895}], 
             PointBox[{89.9, 0.6228504405997113}], 
             PointBox[{90., 0.6259587286178396}], 
             PointBox[{90.1, 0.624362810327135}], 
             PointBox[{90.2, 0.6228012595336927}], 
             PointBox[{90.3, 0.6216642316613997}], 
             PointBox[{90.4, 0.6197391415481932}], 
             PointBox[{90.5, 0.6182017447121492}], 
             PointBox[{90.6, 0.6191083166090017}], 
             PointBox[{90.7, 0.6199522866955253}], 
             PointBox[{90.8, 0.6209394361936706}], 
             PointBox[{90.9, 0.6233495537503905}], 
             PointBox[{91., 0.625322608387553}], 
             PointBox[{91.1, 0.6230663640438249}], 
             PointBox[{91.2, 0.6216516652108444}], 
             PointBox[{91.3, 0.6204557670346346}], 
             PointBox[{91.4, 0.6182689659101774}], 
             PointBox[{91.5, 0.6177959774967064}], 
             PointBox[{91.6, 0.6190111186473474}], 
             PointBox[{91.7, 0.6199795019641643}], 
             PointBox[{91.8, 0.621235554427211}], 
             PointBox[{91.9, 0.6241345712729547}], 
             PointBox[{92., 0.6242787839183408}], 
             PointBox[{92.1, 0.6219421929800494}], 
             PointBox[{92.2, 0.620676806832505}], 
             PointBox[{92.3, 0.6193794014890359}], 
             PointBox[{92.4, 0.6172724984967282}], 
             PointBox[{92.5, 0.6177937450804912}], 
             PointBox[{92.6, 0.6192658151900409}], 
             PointBox[{92.7, 0.6203104688458104}], 
             PointBox[{92.8, 0.6218947800525941}], 
             PointBox[{92.9, 0.6248105592344099}], 
             PointBox[{93., 0.6231010546712832}], 
             PointBox[{93.1, 0.6210432344936159}], 
             PointBox[{93.2, 0.6199005179571361}], 
             PointBox[{93.3, 0.6184856401231602}], 
             PointBox[{93.4, 0.6169870853150505}], 
             PointBox[{93.5, 0.6183338851157048}], 
             PointBox[{93.6, 0.6197980311667576}], 
             PointBox[{93.7, 0.6209223427545947}], 
             PointBox[{93.8, 0.6228765509493728}], 
             PointBox[{93.9, 0.6249066933555745}], 
             PointBox[{94., 0.6220774626332046}], 
             PointBox[{94.1, 0.62040195727219}], 
             PointBox[{94.2, 0.6193519522854725}], 
             PointBox[{94.3, 0.6179019479133572}], 
             PointBox[{94.4, 0.6171757278277935}], 
             PointBox[{94.5, 0.6192195589973004}], 
             PointBox[{94.6, 0.6205600301966765}], 
             PointBox[{94.7, 0.6217919465528752}], 
             PointBox[{94.8, 0.6240540459199507}], 
             PointBox[{94.9, 0.6243580827834468}], 
             PointBox[{95., 0.6213666446602887}], 
             PointBox[{95.1, 0.6200420169689858}], 
             PointBox[{95.2, 0.619075049606431}], 
             PointBox[{95.3, 0.6178292708088058}], 
             PointBox[{95.4, 0.6180513436386869}], 
             PointBox[{95.5, 0.6202986131996633}], 
             PointBox[{95.6, 0.6215205312215805}], 
             PointBox[{95.7, 0.6228885747579325}], 
             PointBox[{95.8, 0.6251723315752465}], 
             PointBox[{95.9, 0.623585690973215}], 
             PointBox[{96., 0.6210209591846552}], 
             PointBox[{96.1, 0.6199849563018763}], 
             PointBox[{96.2, 0.6191363841745845}], 
             PointBox[{96.3, 0.6182160942867151}], 
             PointBox[{96.4, 0.6194846781820406}], 
             PointBox[{96.5, 0.6215094378095987}], 
             PointBox[{96.6, 0.6226560866651746}], 
             PointBox[{96.7, 0.6241651240671485}], 
             PointBox[{96.8, 0.6259462754293563}], 
             PointBox[{96.9, 0.6230335669704763}], 
             PointBox[{97., 0.6210433073809684}], 
             PointBox[{97.1, 0.6202508812357874}], 
             PointBox[{97.2, 0.6196195428213443}], 
             PointBox[{97.3, 0.6188517276011517}], 
             PointBox[{97.4, 0.6211204932144052}], 
             PointBox[{97.5, 0.6228290392002795}], 
             PointBox[{97.6, 0.6239430366947631}], 
             PointBox[{97.7, 0.6255511893496322}], 
             PointBox[{97.8, 0.6263053941025112}], 
             PointBox[{97.9, 0.6228999931355392}], 
             PointBox[{98., 0.6214155938777364}], 
             PointBox[{98.1, 0.6208523004322558}], 
             PointBox[{98.2, 0.6205422724509766}], 
             PointBox[{98.3, 0.6200433845050777}], 
             PointBox[{98.4, 0.6227907848616568}], 
             PointBox[{98.5, 0.6242414810772641}], 
             PointBox[{98.6, 0.6253505035721563}], 
             PointBox[{98.7, 0.6269576851409322}], 
             PointBox[{98.8, 0.6264825975981547}], 
             PointBox[{98.9, 0.6231990992430818}], 
             PointBox[{99., 0.622105840046488}], 
             PointBox[{99.1, 0.6217823879717239}], 
             PointBox[{99.2, 0.6217171299186781}], 
             PointBox[{99.3, 0.6217094649340289}], 
             PointBox[{99.4, 0.6244472102857159}], 
             PointBox[{99.5, 0.6257251073338647}], 
             PointBox[{99.6, 0.6268402015687509}], 
             PointBox[{99.7, 0.6283139096090542}], 
             PointBox[{99.8, 0.6267812368293224}], 
             PointBox[{99.9, 0.6238675233150686}], 
             PointBox[{100., 0.6230629885851101}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0.6, 0.65}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], 
             PointBox[{0, 0.07250109999999833}], 
             PointBox[{0.1, 0.07492525989118362}], 
             PointBox[{0.2, 0.07568159991743756}], 
             PointBox[{0.3, 0.07340251056845964}], 
             PointBox[{0.4, 0.07388820516490957}], 
             PointBox[{0.5, 0.07746067546488739}], 
             PointBox[{0.6, 0.07436340448148457}], 
             PointBox[{0.7, 0.07312434526493018}], 
             PointBox[{0.8, 0.07546587921914504}], 
             PointBox[{0.9, 0.07557597736812857}], 
             PointBox[{1., 0.07315412664977412}], 
             PointBox[{1.1, 0.07596673139948219}], 
             PointBox[{1.2, 0.07763157486594136}], 
             PointBox[{1.3, 0.0756199014312367}], 
             PointBox[{1.4, 0.0753626530222707}], 
             PointBox[{1.5, 0.07917644110628048}], 
             PointBox[{1.6, 0.07674928360471313}], 
             PointBox[{1.7, 0.07480943537440353}], 
             PointBox[{1.8, 0.07702346383016827}], 
             PointBox[{1.9, 0.07791970681695323}], 
             PointBox[{2., 0.07531799456586312}], 
             PointBox[{2.1, 0.07854965584478972}], 
             PointBox[{2.2, 0.08114321425611394}], 
             PointBox[{2.3, 0.07959266979841036}], 
             PointBox[{2.4, 0.07867944391405121}], 
             PointBox[{2.5, 0.08247434527442062}], 
             PointBox[{2.6, 0.08086354769109758}], 
             PointBox[{2.7, 0.07832274008951423}], 
             PointBox[{2.8, 0.08025542073408994}], 
             PointBox[{2.9, 0.08181372124599702}], 
             PointBox[{3., 0.07917843088101834}], 
             PointBox[{3.1, 0.08241493072527863}], 
             PointBox[{3.2, 0.08595750551377243}], 
             PointBox[{3.3, 0.08502565223971824}], 
             PointBox[{3.4, 0.08361483108262978}], 
             PointBox[{3.5, 0.08713475973048443}], 
             PointBox[{3.6, 0.08642188682506965}], 
             PointBox[{3.7, 0.08340911680358798}], 
             PointBox[{3.8, 0.08496332892458063}], 
             PointBox[{3.9, 0.08702270048448679}], 
             PointBox[{4., 0.08459740187778829}], 
             PointBox[{4.1, 0.08730087468483891}], 
             PointBox[{4.2, 0.09179879570541605}], 
             PointBox[{4.3, 0.09158057986652197}], 
             PointBox[{4.4, 0.08987154275857721}], 
             PointBox[{4.5, 0.09291925070698494}], 
             PointBox[{4.6, 0.0930985365641698}], 
             PointBox[{4.7, 0.08975238116284513}], 
             PointBox[{4.8, 0.0908975099632994}], 
             PointBox[{4.9, 0.09328507081160067}], 
             PointBox[{5., 0.09125275645617416}], 
             PointBox[{5.1, 0.09307040764690926}], 
             PointBox[{5.2, 0.09842701787376724}], 
             PointBox[{5.3, 0.09893639133846197}], 
             PointBox[{5.4, 0.09712062717199549}], 
             PointBox[{5.5, 0.09960306135404907}], 
             PointBox[{5.6, 0.1005762274056247}], 
             PointBox[{5.7, 0.09702285061038346}], 
             PointBox[{5.8, 0.09779434054308503}], 
             PointBox[{5.9, 0.10035642438218949`}], 
             PointBox[{6., 0.09878339317794034}], 
             PointBox[{6.1, 0.09968377807309388}], 
             PointBox[{6.2, 0.10566256003990362`}], 
             PointBox[{6.3, 0.10681843436388591`}], 
             PointBox[{6.4, 0.10503579421118008`}], 
             PointBox[{6.5, 0.10698321452216863`}], 
             PointBox[{6.6, 0.10857332815450883`}], 
             PointBox[{6.7, 0.10490858663007069`}], 
             PointBox[{6.8, 0.10539670040263}], 
             PointBox[{6.9, 0.10802245170101231`}], 
             PointBox[{7., 0.10685532436428673`}], 
             PointBox[{7.1, 0.1070485971106568}], 
             PointBox[{7.2, 0.11337434550006534`}], 
             PointBox[{7.3, 0.11500184187362196`}], 
             PointBox[{7.4, 0.11331539863676586`}], 
             PointBox[{7.5, 0.1148666224145523}], 
             PointBox[{7.6, 0.11684309651495431`}], 
             PointBox[{7.7, 0.11312678109401751`}], 
             PointBox[{7.8, 0.11346001486151876`}], 
             PointBox[{7.9, 0.11608932293129423`}], 
             PointBox[{8., 0.11517767851689802`}], 
             PointBox[{8.1, 0.11499094644551835`}], 
             PointBox[{8.2, 0.121442624584545}], 
             PointBox[{8.3, 0.1232907090117487}], 
             PointBox[{8.4, 0.1216876366374642}], 
             PointBox[{8.5, 0.12306013754761899`}], 
             PointBox[{8.6, 0.1251545563108823}], 
             PointBox[{8.7, 0.12142606764516366`}], 
             PointBox[{8.8, 0.12175536445805231`}], 
             PointBox[{8.9, 0.12436705826141506`}], 
             PointBox[{9., 0.12348974043024213`}], 
             PointBox[{9.1, 0.12331415225666786`}], 
             PointBox[{9.2, 0.1297112565873786}], 
             PointBox[{9.3, 0.13148580234257073`}], 
             PointBox[{9.4, 0.12990524249125662`}], 
             PointBox[{9.5, 0.13137514904513958`}], 
             PointBox[{9.6, 0.13326062340947625`}], 
             PointBox[{9.7, 0.12958061277507835`}], 
             PointBox[{9.8, 0.1300626302185918}], 
             PointBox[{9.9, 0.13265097442956114`}], 
             PointBox[{10., 0.13153455040626938`}], 
             PointBox[{10.1, 0.13183293741115307`}], 
             PointBox[{10.2, 0.13795021510282302`}], 
             PointBox[{10.3, 0.13935986508968828`}], 
             PointBox[{10.4, 0.13773782893682748`}], 
             PointBox[{10.5, 0.13962687406087343`}], 
             PointBox[{10.6, 0.1408844520149188}], 
             PointBox[{10.7, 0.13739053974232304`}], 
             PointBox[{10.8, 0.13816681375127143`}], 
             PointBox[{10.9, 0.14070800086432517`}], 
             PointBox[{11., 0.1390519013523266}], 
             PointBox[{11.1, 0.14035350195834034`}], 
             PointBox[{11.2, 0.14585108387630333`}], 
             PointBox[{11.3, 0.14665881373626743`}], 
             PointBox[{11.4, 0.14498511799294803`}], 
             PointBox[{11.5, 0.14762751735448823`}], 
             PointBox[{11.6, 0.14774551163716165`}], 
             PointBox[{11.7, 0.14468738972344006`}], 
             PointBox[{11.8, 0.1458600420753345}], 
             PointBox[{11.9, 0.1482717221452726}], 
             PointBox[{12., 0.14582677960497906`}], 
             PointBox[{12.1, 0.14858968808427037`}], 
             PointBox[{12.2, 0.153062807794853}], 
             PointBox[{12.3, 0.15313417492408823`}], 
             PointBox[{12.4, 0.15151423879365652`}], 
             PointBox[{12.5, 0.15512855034510226`}], 
             PointBox[{12.6, 0.15364193277800411`}], 
             PointBox[{12.7, 0.15134376988580667`}], 
             PointBox[{12.8, 0.15294817127965551`}], 
             PointBox[{12.9, 0.15504062663922977`}], 
             PointBox[{13., 0.15182949022604078`}], 
             PointBox[{13.1, 0.15612400826925057`}], 
             PointBox[{13.2, 0.15926650296132416`}], 
             PointBox[{13.3, 0.15859384739663768`}], 
             PointBox[{13.4, 0.15731239191665325`}], 
             PointBox[{13.5, 0.16170567723765203`}], 
             PointBox[{13.6, 0.15853484449867913`}], 
             PointBox[{13.7, 0.15727327982367603`}], 
             PointBox[{13.8, 0.1592570228171368}], 
             PointBox[{13.9, 0.16068074792432055`}], 
             PointBox[{14., 0.15735634551351893`}], 
             PointBox[{14.1, 0.16254712151425613`}], 
             PointBox[{14.2, 0.16424189868539316`}], 
             PointBox[{14.3, 0.16294699006754304`}], 
             PointBox[{14.4, 0.16251371234898496`}], 
             PointBox[{14.5, 0.16674723791985693`}], 
             PointBox[{14.6, 0.16254587427236147`}], 
             PointBox[{14.7, 0.16241854111092566`}], 
             PointBox[{14.8, 0.16462832697468122`}], 
             PointBox[{14.9, 0.1648596826494777}], 
             PointBox[{15., 0.16273938219035874`}], 
             PointBox[{15.1, 0.16756860728164077`}], 
             PointBox[{15.2, 0.16789733330308454`}], 
             PointBox[{15.3, 0.16623356229805042`}], 
             PointBox[{15.4, 0.167316948367409}], 
             PointBox[{15.5, 0.16981311397235438`}], 
             PointBox[{15.6, 0.16584675502943125`}], 
             PointBox[{15.7, 0.16672973409818545`}], 
             PointBox[{15.8, 0.16889282482322504`}], 
             PointBox[{15.9, 0.1674084736217389}], 
             PointBox[{16., 0.16756793516753762`}], 
             PointBox[{16.1, 0.17104066098788195`}], 
             PointBox[{16.2, 0.1702594754529022}], 
             PointBox[{16.3, 0.16862468636412042`}], 
             PointBox[{16.4, 0.17167838360835283`}], 
             PointBox[{16.5, 0.17112677148543057`}], 
             PointBox[{16.6, 0.16853888998839675`}], 
             PointBox[{16.7, 0.17014038915461346`}], 
             PointBox[{16.8, 0.17184347399685018`}], 
             PointBox[{16.9, 0.1686957390309354}], 
             PointBox[{17., 0.17124966941586428`}], 
             PointBox[{17.1, 0.17296967765977447`}], 
             PointBox[{17.2, 0.17144202610485748`}], 
             PointBox[{17.3, 0.17040126796826674`}], 
             PointBox[{17.4, 0.17489113188025324`}], 
             PointBox[{17.5, 0.17142841372955403`}], 
             PointBox[{17.6, 0.17060794279672584`}], 
             PointBox[{17.7, 0.17254870400433447`}], 
             PointBox[{17.8, 0.1732344534083777}], 
             PointBox[{17.9, 0.16962592982924696`}], 
             PointBox[{18., 0.17345195632223986`}], 
             PointBox[{18.1, 0.17347803734007153`}], 
             PointBox[{18.2, 0.17161753551363046`}], 
             PointBox[{18.3, 0.1718644205975335}], 
             PointBox[{18.4, 0.17586462843457956`}], 
             PointBox[{18.5, 0.1713122431701296}], 
             PointBox[{18.6, 0.17194869133040877`}], 
             PointBox[{18.7, 0.1738100557648073}], 
             PointBox[{18.8, 0.1728900361000073}], 
             PointBox[{18.9, 0.1704224895637527}], 
             PointBox[{19., 0.17395422459145052`}], 
             PointBox[{19.1, 0.1727364030075183}], 
             PointBox[{19.2, 0.17098787364044887`}], 
             PointBox[{19.3, 0.1730919147166009}], 
             PointBox[{19.4, 0.1743991783749972}], 
             PointBox[{19.5, 0.17090962991560954`}], 
             PointBox[{19.6, 0.1724039638028615}], 
             PointBox[{19.7, 0.173741678996041}], 
             PointBox[{19.8, 0.17096765745900872`}], 
             PointBox[{19.9, 0.17084508318193675`}], 
             PointBox[{20., 0.17282606235401232`}], 
             PointBox[{20.1, 0.17091655924808688`}], 
             PointBox[{20.2, 0.16975099785276077`}], 
             PointBox[{20.3, 0.17360022073882372`}], 
             PointBox[{20.4, 0.17150671991820546`}], 
             PointBox[{20.5, 0.1700357045357364}], 
             PointBox[{20.6, 0.17179809176483524`}], 
             PointBox[{20.7, 0.17215658697160535`}], 
             PointBox[{20.8, 0.16796722417261079`}], 
             PointBox[{20.9, 0.17016704826312556`}], 
             PointBox[{21., 0.17028045658426036`}], 
             PointBox[{21.1, 0.16816149560074586`}], 
             PointBox[{21.2, 0.1680325145858632}], 
             PointBox[{21.3, 0.17240743588264956`}], 
             PointBox[{21.4, 0.16814719807486658`}], 
             PointBox[{21.5, 0.16841454584615606`}], 
             PointBox[{21.6, 0.1699637245284176}], 
             PointBox[{21.7, 0.16894085792853744`}], 
             PointBox[{21.8, 0.1643724640979489}], 
             PointBox[{21.9, 0.1678031916302149}], 
             PointBox[{22., 0.16652746370054458`}], 
             PointBox[{22.1, 0.16457599970444184`}], 
             PointBox[{22.2, 0.16580283637172383`}], 
             PointBox[{22.3, 0.16891780011472915`}], 
             PointBox[{22.4, 0.16452489385707184`}], 
             PointBox[{22.5, 0.1658045581045537}], 
             PointBox[{22.6, 0.1667700139945311}], 
             PointBox[{22.7, 0.16414070036405634`}], 
             PointBox[{22.8, 0.1607336215640572}], 
             PointBox[{22.9, 0.16377980022956784`}], 
             PointBox[{23., 0.161726480363736}], 
             PointBox[{23.1, 0.1602198427620612}], 
             PointBox[{23.2, 0.162814383175895}], 
             PointBox[{23.3, 0.1635468622134158}], 
             PointBox[{23.4, 0.16040089246242872`}], 
             PointBox[{23.5, 0.16204890199659638`}], 
             PointBox[{23.6, 0.16216081230118473`}], 
             PointBox[{23.7, 0.1579477348717323}], 
             PointBox[{23.8, 0.15663369392521959`}], 
             PointBox[{23.9, 0.1583730989358697}], 
             PointBox[{24., 0.1559975780055743}], 
             PointBox[{24.1, 0.15511193155327013`}], 
             PointBox[{24.2, 0.15870119603671345`}], 
             PointBox[{24.3, 0.1571096965461839}], 
             PointBox[{24.4, 0.1555022681586681}], 
             PointBox[{24.5, 0.15709810120903123`}], 
             PointBox[{24.6, 0.1561988082352811}], 
             PointBox[{24.7, 0.15070258629863106`}], 
             PointBox[{24.8, 0.1514479329089064}], 
             PointBox[{24.9, 0.15187718401928352`}], 
             PointBox[{25., 0.14945036072789836`}], 
             PointBox[{25.1, 0.14925079638895364`}], 
             PointBox[{25.2, 0.153240704360231}], 
             PointBox[{25.3, 0.15009211782128723`}], 
             PointBox[{25.4, 0.14969242245729614`}], 
             PointBox[{25.5, 0.15102208332087144`}], 
             PointBox[{25.6, 0.1490890116256018}], 
             PointBox[{25.7, 0.14293336289738365`}], 
             PointBox[{25.8, 0.14507402725344146`}], 
             PointBox[{25.9, 0.14455883712700915`}], 
             PointBox[{26., 0.14220868551446017`}], 
             PointBox[{26.1, 0.1426492467694952}], 
             PointBox[{26.2, 0.14653037388503068`}], 
             PointBox[{26.3, 0.14263419095142882`}], 
             PointBox[{26.4, 0.14299144000589697`}], 
             PointBox[{26.5, 0.14400261271511722`}], 
             PointBox[{26.6, 0.14116368630517395`}], 
             PointBox[{26.7, 0.13494408799194843`}], 
             PointBox[{26.8, 0.1377516145543327}], 
             PointBox[{26.9, 0.13666906561228373`}], 
             PointBox[{27., 0.13442395390504328`}], 
             PointBox[{27.1, 0.13537196416700403`}], 
             PointBox[{27.2, 0.13891133615829837`}], 
             PointBox[{27.3, 0.13478608636585046`}], 
             PointBox[{27.4, 0.1355409260512676}], 
             PointBox[{27.5, 0.13630384097114026`}], 
             PointBox[{27.6, 0.132811964169237}], 
             PointBox[{27.7, 0.12679187098897937`}], 
             PointBox[{27.8, 0.12980816996301137`}], 
             PointBox[{27.9, 0.12845097537804062`}], 
             PointBox[{28., 0.1262756634199512}], 
             PointBox[{28.1, 0.12755287620052883`}], 
             PointBox[{28.2, 0.13077701352903665`}], 
             PointBox[{28.3, 0.12664718481708317`}], 
             PointBox[{28.4, 0.12754934162500797`}], 
             PointBox[{28.5, 0.12821271422149874`}], 
             PointBox[{28.6, 0.12438983747050615`}], 
             PointBox[{28.7, 0.11853638192835027`}], 
             PointBox[{28.8, 0.1215449228839782}], 
             PointBox[{28.9, 0.12013577267262347`}], 
             PointBox[{29., 0.11796220349458271`}], 
             PointBox[{29.1, 0.1193811935747386}], 
             PointBox[{29.2, 0.12245431293880449`}], 
             PointBox[{29.3, 0.1183852174403432}], 
             PointBox[{29.4, 0.11924608206656365`}], 
             PointBox[{29.5, 0.11998766579002342`}], 
             PointBox[{29.6, 0.11617124025511323`}], 
             PointBox[{29.7, 0.11032846717934178`}], 
             PointBox[{29.8, 0.1132130051541203}], 
             PointBox[{29.9, 0.11194153236285763`}], 
             PointBox[{30., 0.10969655891306673`}], 
             PointBox[{30.1, 0.11107942865547414`}], 
             PointBox[{30.2, 0.11418881654390949`}], 
             PointBox[{30.3, 0.11021629562355358`}], 
             PointBox[{30.4, 0.11086070093255267`}], 
             PointBox[{30.5, 0.11183820425474521`}], 
             PointBox[{30.6, 0.10834600536439634`}], 
             PointBox[{30.7, 0.10240037944943532`}], 
             PointBox[{30.8, 0.10502894544777792`}], 
             PointBox[{30.9, 0.10407527956002513`}], 
             PointBox[{31., 0.10170717644126326`}], 
             PointBox[{31.1, 0.10289071918786488`}], 
             PointBox[{31.2, 0.10617404195256527`}], 
             PointBox[{31.3, 0.10238366159252316`}], 
             PointBox[{31.4, 0.10262633746689681`}], 
             PointBox[{31.5, 0.1039352519528248}], 
             PointBox[{31.6, 0.1010388736561047}], 
             PointBox[{31.7, 0.09503381416262291}], 
             PointBox[{31.8, 0.09720490350042915}], 
             PointBox[{31.9, 0.09674188278212605}], 
             PointBox[{32., 0.09424305073383424}], 
             PointBox[{32.1, 0.09508148379396672}], 
             PointBox[{32.2, 0.09859250253184733}], 
             PointBox[{32.3, 0.0951436045712517}], 
             PointBox[{32.4, 0.09479995627120907}], 
             PointBox[{32.5, 0.09644833197896716}], 
             PointBox[{32.6, 0.09434409319773719}], 
             PointBox[{32.7, 0.08853141344114089}], 
             PointBox[{32.8, 0.08998283768703143}], 
             PointBox[{32.9, 0.09015384785712635}], 
             PointBox[{33., 0.08757583784601616}], 
             PointBox[{33.1, 0.08794861727006167}], 
             PointBox[{33.2, 0.0916511810394598}], 
             PointBox[{33.3, 0.08875356383506144}], 
             PointBox[{33.4, 0.08767817148596416}], 
             PointBox[{33.5, 0.08958257212214113}], 
             PointBox[{33.6, 0.0883745313998313}], 
             PointBox[{33.7, 0.08313802774441446}], 
             PointBox[{33.8, 0.0836515176197607}], 
             PointBox[{33.9, 0.08453714834967364}], 
             PointBox[{34., 0.08199411095125733}], 
             PointBox[{34.1, 0.08181937076602988}], 
             PointBox[{34.2, 0.08560149190666697}], 
             PointBox[{34.3, 0.08346443304857518}], 
             PointBox[{34.4, 0.08159640346180333}], 
             PointBox[{34.5, 0.08359714746783442}], 
             PointBox[{34.6, 0.08330191813417266}], 
             PointBox[{34.7, 0.07892025919758401}], 
             PointBox[{34.8, 0.07853895734152402}], 
             PointBox[{34.9, 0.08013220941613786}], 
             PointBox[{35., 0.07778651247056396}], 
             PointBox[{35.1, 0.07703582312100558}], 
             PointBox[{35.2, 0.08073478361007644}], 
             PointBox[{35.3, 0.0795167529336264}], 
             PointBox[{35.4, 0.07690319260790253}], 
             PointBox[{35.5, 0.078797812124211}], 
             PointBox[{35.6, 0.07935828979665302}], 
             PointBox[{35.7, 0.07580978851291455}], 
             PointBox[{35.8, 0.07496418869657893}], 
             PointBox[{35.9, 0.0771715878227435}], 
             PointBox[{36., 0.07520899089885003}], 
             PointBox[{36.1, 0.07391666814795973}], 
             PointBox[{36.2, 0.07734536631616805}], 
             PointBox[{36.3, 0.07712964728692451}], 
             PointBox[{36.4, 0.07391398446101265}], 
             PointBox[{36.5, 0.07549741423807757}], 
             PointBox[{36.6, 0.07679896131832821}], 
             PointBox[{36.7, 0.0739439940975796}], 
             PointBox[{36.8, 0.07315041008687631}], 
             PointBox[{36.9, 0.07583521809666281}], 
             PointBox[{37., 0.07443814542147269}], 
             PointBox[{37.1, 0.07270191985895752}], 
             PointBox[{37.2, 0.07567079879684406}], 
             PointBox[{37.3, 0.07646812476619869}], 
             PointBox[{37.4, 0.07285271232599369}], 
             PointBox[{37.5, 0.07395481100498537}], 
             PointBox[{37.6, 0.07583904474262114}], 
             PointBox[{37.7, 0.07365343206229669}], 
             PointBox[{37.8, 0.07310372813743651}], 
             PointBox[{37.9, 0.07619456102436066}], 
             PointBox[{38., 0.0755232304306493}], 
             PointBox[{38.1, 0.07349636874995086}], 
             PointBox[{38.2, 0.07583321153938641}], 
             PointBox[{38.3, 0.0775912893283876}], 
             PointBox[{38.4, 0.0738002506923684}], 
             PointBox[{38.5, 0.07430556304770053}], 
             PointBox[{38.6, 0.07658744183216129}], 
             PointBox[{38.7, 0.07513209072308802}], 
             PointBox[{38.8, 0.07454797627834349}], 
             PointBox[{38.9, 0.07818087202156368}], 
             PointBox[{39., 0.0783620845981582}], 
             PointBox[{39.1, 0.07623801923537524}], 
             PointBox[{39.2, 0.0778138013450683}], 
             PointBox[{39.3, 0.08041998004394127}], 
             PointBox[{39.4, 0.07667384517413636}], 
             PointBox[{39.5, 0.07652950795850727}], 
             PointBox[{39.6, 0.07901439726848228}], 
             PointBox[{39.7, 0.07834365998910495}], 
             PointBox[{39.8, 0.07721856128804515}], 
             PointBox[{39.9, 0.08160604436450966}], 
             PointBox[{40., 0.08272485271845385}], 
             PointBox[{40.1, 0.08071229188725586}], 
             PointBox[{40.2, 0.08147318106749937}], 
             PointBox[{40.3, 0.08474962043256891}], 
             PointBox[{40.4, 0.08124904740881289}], 
             PointBox[{40.5, 0.08046395157293086}], 
             PointBox[{40.6, 0.0829693680687322}], 
             PointBox[{40.7, 0.08308125229427124}], 
             PointBox[{40.8, 0.08120061940721422}], 
             PointBox[{40.9, 0.08622412081535225}], 
             PointBox[{41., 0.08831585690064069}], 
             PointBox[{41.1, 0.08660513970750751}], 
             PointBox[{41.2, 0.0865941065745349}], 
             PointBox[{41.3, 0.09031107987618432}], 
             PointBox[{41.4, 0.08721433683645781}], 
             PointBox[{41.5, 0.08585148723306499}], 
             PointBox[{41.6, 0.08823354944653104}], 
             PointBox[{41.7, 0.08905347560611009}], 
             PointBox[{41.8, 0.0865745547253626}], 
             PointBox[{41.9, 0.09180052072569155}], 
             PointBox[{42., 0.09483947603779404}], 
             PointBox[{42.1, 0.0935668570375797}], 
             PointBox[{42.2, 0.09291586722574081}], 
             PointBox[{42.3, 0.09683092041063882}], 
             PointBox[{42.4, 0.09422820853523366}], 
             PointBox[{42.5, 0.0923914837898903}], 
             PointBox[{42.6, 0.09456381856861358}], 
             PointBox[{42.7, 0.09595839431827499}], 
             PointBox[{42.8, 0.09315431730456859}], 
             PointBox[{42.9, 0.09816275065827296}], 
             PointBox[{43., 0.10204380008354239`}], 
             PointBox[{43.1, 0.10126447658562834`}], 
             PointBox[{43.2, 0.10015541312186159`}], 
             PointBox[{43.3, 0.10407169804969704`}], 
             PointBox[{43.4, 0.10196191391577708`}], 
             PointBox[{43.5, 0.09977866375050563}], 
             PointBox[{43.6, 0.10172289125044405`}], 
             PointBox[{43.7, 0.10352925357102458`}], 
             PointBox[{43.8, 0.10061803484265336`}], 
             PointBox[{43.9, 0.10520765032797896`}], 
             PointBox[{44., 0.109733842529706}], 
             PointBox[{44.1, 0.10940821358092002`}], 
             PointBox[{44.2, 0.10802192463157538`}], 
             PointBox[{44.3, 0.11184122677815554`}], 
             PointBox[{44.4, 0.11011715826426462`}], 
             PointBox[{44.5, 0.10772574661319088`}], 
             PointBox[{44.6, 0.10948235711562107`}], 
             PointBox[{44.7, 0.11154251824941287`}], 
             PointBox[{44.8, 0.10862490666372392`}], 
             PointBox[{44.9, 0.11285242761463396`}], 
             PointBox[{45., 0.11775457465318516`}], 
             PointBox[{45.1, 0.11775236603897415`}], 
             PointBox[{45.2, 0.11623278378168113`}], 
             PointBox[{45.3, 0.1199716516300071}], 
             PointBox[{45.4, 0.11842634532887412`}], 
             PointBox[{45.5, 0.1159716534030746}], 
             PointBox[{45.6, 0.11762511500262246`}], 
             PointBox[{45.7, 0.11980170612522226`}], 
             PointBox[{45.8, 0.11686445528477742`}], 
             PointBox[{45.9, 0.12098031623913807`}], 
             PointBox[{46., 0.1259533096849559}], 
             PointBox[{46.1, 0.12607636689578752`}], 
             PointBox[{46.2, 0.12452400652791304`}], 
             PointBox[{46.3, 0.12829494646771522`}], 
             PointBox[{46.4, 0.1266399494494437}], 
             PointBox[{46.5, 0.12428040350743666`}], 
             PointBox[{46.6, 0.12593759138538235`}], 
             PointBox[{46.7, 0.12810989242598642`}], 
             PointBox[{46.8, 0.1250685071352855}], 
             PointBox[{46.9, 0.12941943640750406`}], 
             PointBox[{47., 0.13413789615740793`}], 
             PointBox[{47.1, 0.13415921516247276`}], 
             PointBox[{47.2, 0.13265746643600862`}], 
             PointBox[{47.3, 0.13661130993755868`}], 
             PointBox[{47.4, 0.1345172178464965}], 
             PointBox[{47.5, 0.13243714941370327`}], 
             PointBox[{47.6, 0.13420281219148966`}], 
             PointBox[{47.7, 0.1362402239579213}], 
             PointBox[{47.8, 0.13302458508540288`}], 
             PointBox[{47.9, 0.13793010632321004`}], 
             PointBox[{48., 0.14205378300842791`}], 
             PointBox[{48.1, 0.14176712339658212`}], 
             PointBox[{48.2, 0.14043395819901328`}], 
             PointBox[{48.3, 0.14465245488043413`}], 
             PointBox[{48.4, 0.14183798722680968`}], 
             PointBox[{48.5, 0.14024586300978234`}], 
             PointBox[{48.6, 0.1421985233282371}], 
             PointBox[{48.7, 0.14391863964388582`}], 
             PointBox[{48.8, 0.14062549728573123`}], 
             PointBox[{48.9, 0.14618702506700543`}], 
             PointBox[{49., 0.14939887832218685`}], 
             PointBox[{49.1, 0.14866810467854372`}], 
             PointBox[{49.2, 0.14772317511803087`}], 
             PointBox[{49.3, 0.1520467888900283}], 
             PointBox[{49.4, 0.14843725904402644`}], 
             PointBox[{49.5, 0.14753354266035051`}], 
             PointBox[{49.6, 0.14969944004649924`}], 
             PointBox[{49.7, 0.15081656444176558`}], 
             PointBox[{49.8, 0.14790766846866565`}], 
             PointBox[{49.9, 0.153795729959302}], 
             PointBox[{50., 0.15587433535374084`}], 
             PointBox[{50.1, 0.15467162341847596`}], 
             PointBox[{50.2, 0.1544955651615823}], 
             PointBox[{50.3, 0.15833032238788033`}], 
             PointBox[{50.4, 0.15424042760112575`}], 
             PointBox[{50.5, 0.15415851836830236`}], 
             PointBox[{50.6, 0.1564852152304024}], 
             PointBox[{50.7, 0.15658483675143942`}], 
             PointBox[{50.8, 0.15495699601112087`}], 
             PointBox[{50.9, 0.16036990642961235`}], 
             PointBox[{51., 0.1612482412749145}], 
             PointBox[{51.1, 0.15968051942161754`}], 
             PointBox[{51.2, 0.1607993113888366}], 
             PointBox[{51.3, 0.16310788307512708`}], 
             PointBox[{51.4, 0.159258651459012}], 
             PointBox[{51.5, 0.16000973249082306`}], 
             PointBox[{51.6, 0.16233455586837336`}], 
             PointBox[{51.7, 0.1609698860798469}], 
             PointBox[{51.8, 0.16149808910886837`}], 
             PointBox[{51.9, 0.16562289001069194`}], 
             PointBox[{52., 0.16539763212930075`}], 
             PointBox[{52.1, 0.1637336423887858}], 
             PointBox[{52.2, 0.1665821032102024}], 
             PointBox[{52.3, 0.16633475029439782`}], 
             PointBox[{52.4, 0.16353974374263425`}], 
             PointBox[{52.5, 0.1649972868586212}], 
             PointBox[{52.6, 0.16701332499040145`}], 
             PointBox[{52.7, 0.16410764160355987`}], 
             PointBox[{52.8, 0.16693912015577345`}], 
             PointBox[{52.9, 0.16941809626861412`}], 
             PointBox[{53., 0.16831906762982252`}], 
             PointBox[{53.1, 0.16702424799315763`}], 
             PointBox[{53.2, 0.17135520568719595`}], 
             PointBox[{53.3, 0.1683892553987475}], 
             PointBox[{53.4, 0.16711010860140207`}], 
             PointBox[{53.5, 0.16903149215269117`}], 
             PointBox[{53.6, 0.170251718702501}], 
             PointBox[{53.7, 0.16674063393970373`}], 
             PointBox[{53.8, 0.1709528986246096}], 
             PointBox[{53.9, 0.1717618058731533}], 
             PointBox[{54., 0.1701141070521789}], 
             PointBox[{54.1, 0.16985906170087384`}], 
             PointBox[{54.2, 0.1741882066932904}], 
             PointBox[{54.3, 0.1697631616633682}], 
             PointBox[{54.4, 0.16994178068715876`}], 
             PointBox[{54.5, 0.171997412160027}], 
             PointBox[{54.6, 0.17179729927455692`}], 
             PointBox[{54.7, 0.16934393330761754`}], 
             PointBox[{54.8, 0.17334364573552338`}], 
             PointBox[{54.9, 0.17275988510689383`}], 
             PointBox[{55., 0.17096806078987384`}], 
             PointBox[{55.1, 0.17247123238988113`}], 
             PointBox[{55.2, 0.17460662567735552`}], 
             PointBox[{55.3, 0.17072224492802493`}], 
             PointBox[{55.4, 0.17194990050816453`}], 
             PointBox[{55.5, 0.17373041628118083`}], 
             PointBox[{55.6, 0.17165280424141138`}], 
             PointBox[{55.7, 0.17145264607691352`}], 
             PointBox[{55.8, 0.17408412025989034`}], 
             PointBox[{55.9, 0.17256917846216435`}], 
             PointBox[{56., 0.17112102154907477`}], 
             PointBox[{56.1, 0.17461738321847867`}], 
             PointBox[{56.2, 0.1732987561674573}], 
             PointBox[{56.3, 0.17124758299293788`}], 
             PointBox[{56.4, 0.1730033641504145}], 
             PointBox[{56.5, 0.17402563337475332`}], 
             PointBox[{56.6, 0.17038285904486405`}], 
             PointBox[{56.7, 0.1725715042569167}], 
             PointBox[{56.8, 0.17332080605194164`}], 
             PointBox[{56.9, 0.17135951641106506`}], 
             PointBox[{57., 0.17081233052898714`}], 
             PointBox[{57.1, 0.1753249014533715}], 
             PointBox[{57.2, 0.17132043236832586`}], 
             PointBox[{57.3, 0.17115501161565644`}], 
             PointBox[{57.4, 0.17294188096814478`}], 
             PointBox[{57.5, 0.1726907667439835}], 
             PointBox[{57.6, 0.16860915142933225`}], 
             PointBox[{57.7, 0.17209608114740643`}], 
             PointBox[{57.8, 0.17125683004174508`}], 
             PointBox[{57.9, 0.16928863952289766`}], 
             PointBox[{58., 0.17016439267113728`}], 
             PointBox[{58.1, 0.1736321195970934}], 
             PointBox[{58.2, 0.16912733247470815`}], 
             PointBox[{58.3, 0.17021551698792212`}], 
             PointBox[{58.4, 0.17159531107655138`}], 
             PointBox[{58.5, 0.16968288350135663`}], 
             PointBox[{58.6, 0.16672787361701027`}], 
             PointBox[{58.7, 0.1698824737636245}], 
             PointBox[{58.8, 0.16807143142087533`}], 
             PointBox[{58.9, 0.16647935766224362`}], 
             PointBox[{59., 0.1690051771802653}], 
             PointBox[{59.1, 0.1697436103799821}], 
             PointBox[{59.2, 0.16658919176484266`}], 
             PointBox[{59.3, 0.16822111377099586`}], 
             PointBox[{59.4, 0.16881483140345543`}], 
             PointBox[{59.5, 0.16518773016516625`}], 
             PointBox[{59.6, 0.16452975221961308`}], 
             PointBox[{59.7, 0.16613281748780587`}], 
             PointBox[{59.8, 0.16389647099991517`}], 
             PointBox[{59.9, 0.16299684580416446`}], 
             PointBox[{60., 0.16680910367776927`}], 
             PointBox[{60.1, 0.1646696980120287}], 
             PointBox[{60.2, 0.16338897091838053`}], 
             PointBox[{60.3, 0.16502074738684355`}], 
             PointBox[{60.4, 0.1645241807381628}], 
             PointBox[{60.5, 0.15948933708006363`}], 
             PointBox[{60.6, 0.16113923580107267`}], 
             PointBox[{60.7, 0.16110770051012402`}], 
             PointBox[{60.8, 0.15882438289764467`}], 
             PointBox[{60.9, 0.1588320412455711}], 
             PointBox[{61., 0.16300228977518275`}], 
             PointBox[{61.1, 0.15907146933421928`}], 
             PointBox[{61.2, 0.15926775264101478`}], 
             PointBox[{61.3, 0.16054639986437302`}], 
             PointBox[{61.4, 0.158771177643141}], 
             PointBox[{61.5, 0.15317014206629578`}], 
             PointBox[{61.6, 0.15623064585245494`}], 
             PointBox[{61.7, 0.155030909822184}], 
             PointBox[{61.8, 0.1529285327793251}], 
             PointBox[{61.9, 0.15390494719701422`}], 
             PointBox[{62., 0.15744602502984106`}], 
             PointBox[{62.1, 0.15303168266920886`}], 
             PointBox[{62.2, 0.15410397313769886`}], 
             PointBox[{62.3, 0.15483841342401178`}], 
             PointBox[{62.4, 0.15176062754014552`}], 
             PointBox[{62.5, 0.14663982174274867`}], 
             PointBox[{62.6, 0.14998913740021314`}], 
             PointBox[{62.7, 0.14809829219798298`}], 
             PointBox[{62.8, 0.1462827551883528}], 
             PointBox[{62.9, 0.14812669487468766`}], 
             PointBox[{63., 0.1505104812694101}], 
             PointBox[{63.1, 0.1464299185601154}], 
             PointBox[{63.2, 0.14792032202966868`}], 
             PointBox[{63.3, 0.14805799834211553`}], 
             PointBox[{63.4, 0.14383270554449626`}], 
             PointBox[{63.5, 0.1397372590879385}], 
             PointBox[{63.6, 0.142759629740673}], 
             PointBox[{63.7, 0.14050480611126162`}], 
             PointBox[{63.8, 0.13898838572017744`}], 
             PointBox[{63.9, 0.14148256472858473`}], 
             PointBox[{64., 0.14272473725437254`}], 
             PointBox[{64.1, 0.13920913285116365`}], 
             PointBox[{64.2, 0.14085903632841718`}], 
             PointBox[{64.3, 0.14047438127771952`}], 
             PointBox[{64.4, 0.13539804883867326`}], 
             PointBox[{64.5, 0.13229603261078685`}], 
             PointBox[{64.6, 0.13488631550722566`}], 
             PointBox[{64.7, 0.13245689685354795`}], 
             PointBox[{64.8, 0.13118050143489615`}], 
             PointBox[{64.9, 0.13407987143015646`}], 
             PointBox[{65., 0.13451159815840966`}], 
             PointBox[{65.1, 0.1314382275261348}], 
             PointBox[{65.2, 0.13313869890110666`}], 
             PointBox[{65.3, 0.13241115631972222`}], 
             PointBox[{65.4, 0.1268343111174645}], 
             PointBox[{65.5, 0.12436400197919636`}], 
             PointBox[{65.6, 0.126670351646847}], 
             PointBox[{65.7, 0.12417129165818053`}], 
             PointBox[{65.8, 0.12302742269607883`}], 
             PointBox[{65.9, 0.12612718622887684`}], 
             PointBox[{66., 0.12616155880428853`}], 
             PointBox[{66.1, 0.12328136630439543`}], 
             PointBox[{66.2, 0.12500308530367502`}], 
             PointBox[{66.3, 0.1241778202181988}], 
             PointBox[{66.4, 0.1184240402152623}], 
             PointBox[{66.5, 0.11613037888731916`}], 
             PointBox[{66.6, 0.11836487671247826`}], 
             PointBox[{66.7, 0.1158655461433109}], 
             PointBox[{66.8, 0.11472575928671758`}], 
             PointBox[{66.9, 0.11787254059402046`}], 
             PointBox[{67., 0.1178896558167548}], 
             PointBox[{67.1, 0.11495491510485376`}], 
             PointBox[{67.2, 0.11668463082080252`}], 
             PointBox[{67.3, 0.11602129140044684`}], 
             PointBox[{67.4, 0.11037821848463135`}], 
             PointBox[{67.5, 0.10784201532448873`}], 
             PointBox[{67.6, 0.1101830476255952}], 
             PointBox[{67.7, 0.1077566501652862}], 
             PointBox[{67.8, 0.10649222242263127`}], 
             PointBox[{67.9, 0.10956567788024732`}], 
             PointBox[{68., 0.10987815708862284`}], 
             PointBox[{68.1, 0.10670551150893931`}], 
             PointBox[{68.2, 0.10839579917944174`}], 
             PointBox[{68.3, 0.10811960299581701`}], 
             PointBox[{68.4, 0.10286767334969119`}], 
             PointBox[{68.5, 0.09977526054672532}], 
             PointBox[{68.6, 0.10231572839627608`}], 
             PointBox[{68.7, 0.10006498246472594`}], 
             PointBox[{68.8, 0.09856966271580639}], 
             PointBox[{68.9, 0.10145437419312603`}], 
             PointBox[{69., 0.10229568959719727`}], 
             PointBox[{69.1, 0.09880432638724873}], 
             PointBox[{69.2, 0.10034752335287772`}], 
             PointBox[{69.3, 0.10061116942725319`}], 
             PointBox[{69.4, 0.09601888119276063}], 
             PointBox[{69.5, 0.09224153212222488}], 
             PointBox[{69.6, 0.09495440907246305}], 
             PointBox[{69.7, 0.09301894225957463}], 
             PointBox[{69.8, 0.09122808503611766}], 
             PointBox[{69.9, 0.09380074531964949}], 
             PointBox[{70., 0.09531227401794994}], 
             PointBox[{70.1, 0.0915457608698719}], 
             PointBox[{70.2, 0.09277548426625953}], 
             PointBox[{70.3, 0.09363968289256834}], 
             PointBox[{70.4, 0.08990774242712496}], 
             PointBox[{70.5, 0.08558584454364916}], 
             PointBox[{70.6, 0.08831448092994004}], 
             PointBox[{70.7, 0.08685861064971935}], 
             PointBox[{70.8, 0.08476590006732902}], 
             PointBox[{70.9, 0.08689766168589405}], 
             PointBox[{71., 0.0891193866114679}], 
             PointBox[{71.1, 0.08523955267403709}], 
             PointBox[{71.2, 0.08596212041188002}], 
             PointBox[{71.3, 0.0873924723633179}], 
             PointBox[{71.4, 0.08462032706118383}], 
             PointBox[{71.5, 0.08016231628580678}], 
             PointBox[{71.6, 0.08265031849705058}], 
             PointBox[{71.7, 0.08183284874824692}], 
             PointBox[{71.8, 0.07949975201794188}], 
             PointBox[{71.9, 0.08107136387170114}], 
             PointBox[{72., 0.08394488413974033}], 
             PointBox[{72.1, 0.08019176781570661}], 
             PointBox[{72.2, 0.0802359562663305}], 
             PointBox[{72.3, 0.0821154025115879}], 
             PointBox[{72.4, 0.08032629222817399}], 
             PointBox[{72.5, 0.07623882373108079}], 
             PointBox[{72.6, 0.07824470665904001}], 
             PointBox[{72.7, 0.07818679051944252}], 
             PointBox[{72.8, 0.07573891770107286}], 
             PointBox[{72.9, 0.07665848163281852}], 
             PointBox[{73., 0.08004683705968908}], 
             PointBox[{73.1, 0.07668016014406488}], 
             PointBox[{73.2, 0.07594337154148094}], 
             PointBox[{73.3, 0.07809515800958963}], 
             PointBox[{73.4, 0.0772680134637618}], 
             PointBox[{73.5, 0.07382467103269034}], 
             PointBox[{73.6, 0.07536468689581234}], 
             PointBox[{73.7, 0.07613077712449003}], 
             PointBox[{73.8, 0.07374072656435329}], 
             PointBox[{73.9, 0.07396095164334876}], 
             PointBox[{74., 0.0776741790324627}], 
             PointBox[{74.1, 0.07492470793763463}], 
             PointBox[{74.2, 0.07339314399126358}], 
             PointBox[{74.3, 0.07561244808797113}], 
             PointBox[{74.4, 0.07569063363069636}], 
             PointBox[{74.5, 0.07271353996992325}], 
             PointBox[{74.6, 0.07419361655631267}], 
             PointBox[{74.7, 0.07579401931326694}], 
             PointBox[{74.8, 0.07365799047889315}], 
             PointBox[{74.9, 0.07318940746205586}], 
             PointBox[{75., 0.0770031653634719}], 
             PointBox[{75.1, 0.0750508617411067}], 
             PointBox[{75.2, 0.07279004373043214}], 
             PointBox[{75.3, 0.07487477204337918}], 
             PointBox[{75.4, 0.07576349697485078}], 
             PointBox[{75.5, 0.07298268368358285}], 
             PointBox[{75.6, 0.07476170127241744}], 
             PointBox[{75.7, 0.07717705240130165}], 
             PointBox[{75.8, 0.07549223815100735}], 
             PointBox[{75.9, 0.07440951730302713}], 
             PointBox[{76., 0.07808036120086265}], 
             PointBox[{76.1, 0.0770510515356179}], 
             PointBox[{76.2, 0.07418222076772985}], 
             PointBox[{76.3, 0.07595813378751093}], 
             PointBox[{76.4, 0.07752618007674793}], 
             PointBox[{76.5, 0.07494808883560382}], 
             PointBox[{76.6, 0.0769130749024176}], 
             PointBox[{76.7, 0.08014351066825294}], 
             PointBox[{76.8, 0.07908633033407886}], 
             PointBox[{76.9, 0.07753034423966514}], 
             PointBox[{77., 0.08081538352371219}], 
             PointBox[{77.1, 0.0807767503063926}], 
             PointBox[{77.2, 0.07745279720662558}], 
             PointBox[{77.3, 0.0787938287959658}], 
             PointBox[{77.4, 0.08087803006016775}], 
             PointBox[{77.5, 0.07867860846292461}], 
             PointBox[{77.6, 0.08034818937201663}], 
             PointBox[{77.7, 0.08446037129918625}], 
             PointBox[{77.8, 0.08416555036334121}], 
             PointBox[{77.9, 0.08232775385978508}], 
             PointBox[{78., 0.08502231931430647}], 
             PointBox[{78.1, 0.08596896431333957}], 
             PointBox[{78.2, 0.08235454642228832}], 
             PointBox[{78.3, 0.0831963974661692}], 
             PointBox[{78.4, 0.08561614027560949}], 
             PointBox[{78.5, 0.08396544048541303}], 
             PointBox[{78.6, 0.0848242282714633}], 
             PointBox[{78.7, 0.08986291604956279}], 
             PointBox[{78.8, 0.09040528240027568}], 
             PointBox[{78.9, 0.08849161978776754}], 
             PointBox[{79., 0.0904754799463838}], 
             PointBox[{79.1, 0.09231802770399788}], 
             PointBox[{79.2, 0.08856809980949851}], 
             PointBox[{79.3, 0.08891255464296213}], 
             PointBox[{79.4, 0.09149623965107456}], 
             PointBox[{79.5, 0.090477930011422}], 
             PointBox[{79.6, 0.09031237902308831}], 
             PointBox[{79.7, 0.09611629245791337}], 
             PointBox[{79.8, 0.0974915134273831}], 
             PointBox[{79.9, 0.0956791880456254}], 
             PointBox[{80., 0.09694537653724661}], 
             PointBox[{80.1, 0.09952036947018739}], 
             PointBox[{80.2, 0.09575553323421467}], 
             PointBox[{80.3, 0.09566462829691597}], 
             PointBox[{80.4, 0.09827859502036876}], 
             PointBox[{80.5, 0.09787040135775733}], 
             PointBox[{80.6, 0.09679625229816348}], 
             PointBox[{80.7, 0.10304581422902687`}], 
             PointBox[{80.8, 0.10515860978692917`}], 
             PointBox[{80.9, 0.10355602128123027`}], 
             PointBox[{81., 0.1042050884847261}], 
             PointBox[{81.1, 0.1073103505517885}], 
             PointBox[{81.2, 0.10359424993499407`}], 
             PointBox[{81.3, 0.10317777649023425`}], 
             PointBox[{81.4, 0.10574330451589209`}], 
             PointBox[{81.5, 0.10583308818401628`}], 
             PointBox[{81.6, 0.1041108532500331}], 
             PointBox[{81.7, 0.11053111392525838`}], 
             PointBox[{81.8, 0.11319279796554418`}], 
             PointBox[{81.9, 0.11182148584248944`}], 
             PointBox[{82., 0.11202602379742509`}], 
             PointBox[{82.1, 0.11546383462294321`}], 
             PointBox[{82.2, 0.11179175286909745`}], 
             PointBox[{82.3, 0.1111918841200404}], 
             PointBox[{82.4, 0.11368823069841083`}], 
             PointBox[{82.5, 0.114103743603509}], 
             PointBox[{82.6, 0.11200618410591544`}], 
             PointBox[{82.7, 0.1184685347316652}], 
             PointBox[{82.8, 0.12141241691243512`}], 
             PointBox[{82.9, 0.12021081926843694`}], 
             PointBox[{83., 0.12017960730793231`}], 
             PointBox[{83.1, 0.12377684424147008`}], 
             PointBox[{83.2, 0.1200870007642298}], 
             PointBox[{83.3, 0.11946699854178208`}], 
             PointBox[{83.4, 0.12191628240426153`}], 
             PointBox[{83.5, 0.12244991410027656`}], 
             PointBox[{83.6, 0.12023601034097618`}], 
             PointBox[{83.7, 0.12672145414344327`}], 
             PointBox[{83.8, 0.1296335587842562}], 
             PointBox[{83.9, 0.1284822876125757}], 
             PointBox[{84., 0.12844574451725546`}], 
             PointBox[{84.1, 0.13202862251617667`}], 
             PointBox[{84.2, 0.12824444369067284`}], 
             PointBox[{84.3, 0.12777888639822985`}], 
             PointBox[{84.4, 0.13022338389295557`}], 
             PointBox[{84.5, 0.13063534161237686`}], 
             PointBox[{84.6, 0.12860062323463958`}], 
             PointBox[{84.7, 0.13508354697883593`}], 
             PointBox[{84.8, 0.13763856160677446`}], 
             PointBox[{84.9, 0.13640386106798988`}], 
             PointBox[{85., 0.13662865428112764`}], 
             PointBox[{85.1, 0.1399468965753081}], 
             PointBox[{85.2, 0.13605367746467234`}], 
             PointBox[{85.3, 0.13591471281103013`}], 
             PointBox[{85.4, 0.13838817114851565`}], 
             PointBox[{85.5, 0.13839299765675}], 
             PointBox[{85.6, 0.13696099699177813`}], 
             PointBox[{85.7, 0.14326076626047196`}], 
             PointBox[{85.8, 0.1451689966818059}], 
             PointBox[{85.9, 0.1437534965206625}], 
             PointBox[{86., 0.14457244957580948`}], 
             PointBox[{86.1, 0.14720051601741319`}], 
             PointBox[{86.2, 0.14333843688050232`}], 
             PointBox[{86.3, 0.14367158020633775`}], 
             PointBox[{86.4, 0.1461675318971457}], 
             PointBox[{86.5, 0.1454254534501609}], 
             PointBox[{86.6, 0.14519486493256994`}], 
             PointBox[{86.7, 0.15089186928754258`}], 
             PointBox[{86.8, 0.151952929682367}], 
             PointBox[{86.9, 0.15034940874694766`}], 
             PointBox[{87., 0.15215568911306226`}], 
             PointBox[{87.1, 0.15346288779667241`}], 
             PointBox[{87.2, 0.1499730381853973}], 
             PointBox[{87.3, 0.15086486736422267`}], 
             PointBox[{87.4, 0.15329881731606018`}], 
             PointBox[{87.5, 0.15147929812512123`}], 
             PointBox[{87.6, 0.15304171957768184`}], 
             PointBox[{87.7, 0.15761245494544202`}], 
             PointBox[{87.8, 0.157755922125599}], 
             PointBox[{87.9, 0.15609875108597188`}], 
             PointBox[{88., 0.15920761280363882`}], 
             PointBox[{88.1, 0.15854507271002619`}], 
             PointBox[{88.2, 0.15588474244888262`}], 
             PointBox[{88.3, 0.15733405304880144`}], 
             PointBox[{88.4, 0.1594978502623028}], 
             PointBox[{88.5, 0.15653533372628914`}], 
             PointBox[{88.6, 0.16003466184040951`}], 
             PointBox[{88.7, 0.1631383828737998}], 
             PointBox[{88.8, 0.16243263809249123`}], 
             PointBox[{88.9, 0.1610496829048688}], 
             PointBox[{89., 0.16532474065449643`}], 
             PointBox[{89.1, 0.16250521285541478`}], 
             PointBox[{89.2, 0.16103906927722644`}], 
             PointBox[{89.3, 0.1629425522872908}], 
             PointBox[{89.4, 0.1644551654091454}], 
             PointBox[{89.5, 0.16101704182505766`}], 
             PointBox[{89.6, 0.16577051940787157`}], 
             PointBox[{89.7, 0.16731734771851703`}], 
             PointBox[{89.8, 0.1659552791763926}], 
             PointBox[{89.9, 0.1654053271592904}], 
             PointBox[{90., 0.1698065715883771}], 
             PointBox[{90.1, 0.16559195986357486`}], 
             PointBox[{90.2, 0.1654117631474187}], 
             PointBox[{90.3, 0.1675608620329478}], 
             PointBox[{90.4, 0.1678606750965934}], 
             PointBox[{90.5, 0.16541712673868325`}], 
             PointBox[{90.6, 0.1700084539283393}], 
             PointBox[{90.7, 0.17012999481374944`}], 
             PointBox[{90.8, 0.16841918132451322`}], 
             PointBox[{90.9, 0.16941837415597305`}], 
             PointBox[{91., 0.1721249558611416}], 
             PointBox[{91.1, 0.1680513812593057}], 
             PointBox[{91.2, 0.1689610139162655}], 
             PointBox[{91.3, 0.17103812244382108`}], 
             PointBox[{91.4, 0.16957000252827095`}], 
             PointBox[{91.5, 0.16933212762611297`}], 
             PointBox[{91.6, 0.17264081269721604`}], 
             PointBox[{91.7, 0.17165805544250945`}], 
             PointBox[{91.8, 0.17003168286236953`}], 
             PointBox[{91.9, 0.17305186895017674`}], 
             PointBox[{92., 0.17258163221978548`}], 
             PointBox[{92.1, 0.1699824047890678}], 
             PointBox[{92.2, 0.1716089793098926}], 
             PointBox[{92.3, 0.1731723908309186}], 
             PointBox[{92.4, 0.16998675243521372`}], 
             PointBox[{92.5, 0.172195356766798}], 
             PointBox[{92.6, 0.1737190878832813}], 
             PointBox[{92.7, 0.17204761684927272`}], 
             PointBox[{92.8, 0.1710773436681719}], 
             PointBox[{92.9, 0.17555334241518758`}], 
             PointBox[{93., 0.1720668396497557}], 
             PointBox[{93.1, 0.1713292844398227}], 
             PointBox[{93.2, 0.17323705810882753`}], 
             PointBox[{93.3, 0.17373242605404243`}], 
             PointBox[{93.4, 0.1699786802575528}], 
             PointBox[{93.5, 0.1735884031169476}], 
             PointBox[{93.6, 0.17339976900382315`}], 
             PointBox[{93.7, 0.1714775602675704}], 
             PointBox[{93.8, 0.17182000583276166`}], 
             PointBox[{93.9, 0.17579209047485478`}], 
             PointBox[{94., 0.17121359514943016`}], 
             PointBox[{94.1, 0.1719402340478481}], 
             PointBox[{94.2, 0.1736869576620365}], 
             PointBox[{94.3, 0.17257099882662486`}], 
             PointBox[{94.4, 0.16980683334145039`}], 
             PointBox[{94.5, 0.17325873881703163`}], 
             PointBox[{94.6, 0.17186674391783904`}], 
             PointBox[{94.7, 0.17013229205426034`}], 
             PointBox[{94.8, 0.17227638932023323`}], 
             PointBox[{94.9, 0.17359209470119427`}], 
             PointBox[{95., 0.170099511807187}], 
             PointBox[{95.1, 0.1716288134024532}], 
             PointBox[{95.2, 0.17277835283090603`}], 
             PointBox[{95.3, 0.16984623258452608`}], 
             PointBox[{95.4, 0.16937089444883066`}], 
             PointBox[{95.5, 0.17130416268868656`}], 
             PointBox[{95.6, 0.16928417090744222`}], 
             PointBox[{95.7, 0.16816782504171346`}], 
             PointBox[{95.8, 0.17195254274103325`}], 
             PointBox[{95.9, 0.1699727937904354}], 
             PointBox[{96., 0.16848376554421624`}], 
             PointBox[{96.1, 0.17021076730578874`}], 
             PointBox[{96.2, 0.17034772885960578`}], 
             PointBox[{96.3, 0.16595213773837658`}], 
             PointBox[{96.4, 0.16785623725162907`}], 
             PointBox[{96.5, 0.167956458461854}], 
             PointBox[{96.6, 0.16577672987500774`}], 
             PointBox[{96.7, 0.16565849448219444`}], 
             PointBox[{96.8, 0.1699797323434466}], 
             PointBox[{96.9, 0.16585288540414794`}], 
             PointBox[{97., 0.16607009414550084`}], 
             PointBox[{97.1, 0.16753351435099334`}], 
             PointBox[{97.2, 0.16631860845099783`}], 
             PointBox[{97.3, 0.16137764149688086`}], 
             PointBox[{97.4, 0.16468783868582346`}], 
             PointBox[{97.5, 0.16342888401184358`}], 
             PointBox[{97.6, 0.16142688670463334`}], 
             PointBox[{97.7, 0.16254005483828468`}], 
             PointBox[{97.8, 0.16586849195975828`}], 
             PointBox[{97.9, 0.16141319059095138`}], 
             PointBox[{98., 0.1626325644247671}], 
             PointBox[{98.1, 0.1635063321172322}], 
             PointBox[{98.2, 0.1607671489570321}], 
             PointBox[{98.3, 0.15670221783625513`}], 
             PointBox[{98.4, 0.15992111766919892`}], 
             PointBox[{98.5, 0.15788571154504094`}], 
             PointBox[{98.6, 0.1562839009091726}], 
             PointBox[{98.7, 0.15860624187671934`}], 
             PointBox[{98.8, 0.15997009699979564`}], 
             PointBox[{98.9, 0.15643851157849256`}], 
             PointBox[{99., 0.1580582994797655}], 
             PointBox[{99.1, 0.15813626767304567`}], 
             PointBox[{99.2, 0.15391362108563067`}], 
             PointBox[{99.3, 0.15161933539422648`}], 
             PointBox[{99.4, 0.15385554963103676`}], 
             PointBox[{99.5, 0.1514642139369354}], 
             PointBox[{99.6, 0.15037915133614774`}], 
             PointBox[{99.7, 0.15361898541991245`}], 
             PointBox[{99.8, 0.1529844624914405}], 
             PointBox[{99.9, 0.15071054744889092`}], 
             PointBox[{100., 0.1523585578517085}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 0.2}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
             PointBox[{0.1, 356.4984926089873}], 
             PointBox[{0.2, 357.99288605058774`}], 
             PointBox[{0.3, 357.93575559614777`}], 
             PointBox[{0.4, 355.5903604434318}], 
             PointBox[{0.5, 356.86367695479544`}], 
             PointBox[{0.6, 358.7728388486302}], 
             PointBox[{0.7, 356.47623810491655`}], 
             PointBox[{0.8, 355.9191323611122}], 
             PointBox[{0.9, 357.5931765460047}], 
             PointBox[{1., 355.3429609282341}], 
             PointBox[{1.1, 350.99335322615593`}], 
             PointBox[{1.2, 352.05428458333785`}], 
             PointBox[{1.3, 352.4622482043273}], 
             PointBox[{1.4, 350.2924475704269}], 
             PointBox[{1.5, 350.8396401689289}], 
             PointBox[{1.6, 353.21405344729254`}], 
             PointBox[{1.7, 351.16961515984235`}], 
             PointBox[{1.8, 350.159057996016}], 
             PointBox[{1.9, 351.7683843150032}], 
             PointBox[{2., 350.76090683488223`}], 
             PointBox[{2.1, 346.2565051119769}], 
             PointBox[{2.2, 346.6923580826514}], 
             PointBox[{2.3, 347.4597549630073}], 
             PointBox[{2.4, 345.6530113836296}], 
             PointBox[{2.5, 345.48944773209115`}], 
             PointBox[{2.6, 348.11905951891805`}], 
             PointBox[{2.7, 346.46303677423947`}], 
             PointBox[{2.8, 345.1101265762109}], 
             PointBox[{2.9, 346.47084423477537`}], 
             PointBox[{3., 346.47670872898277`}], 
             PointBox[{3.1, 342.4025539296761}], 
             PointBox[{3.2, 342.1755734712045}], 
             PointBox[{3.3, 343.1600807177047}], 
             PointBox[{3.4, 341.82053438837875`}], 
             PointBox[{3.5, 341.06416976332616`}], 
             PointBox[{3.6, 343.7414193761788}], 
             PointBox[{3.7, 342.52618314463655`}], 
             PointBox[{3.8, 340.96990335508184`}], 
             PointBox[{3.9, 341.9856556986509}], 
             PointBox[{4., 342.7141266238099}], 
             PointBox[{4.1, 339.30186509554034`}], 
             PointBox[{4.2, 338.5851954349394}], 
             PointBox[{4.3, 339.6475648479149}], 
             PointBox[{4.4, 338.78467151194934`}], 
             PointBox[{4.5, 337.6179948218341}], 
             PointBox[{4.6, 340.17563448611736`}], 
             PointBox[{4.7, 339.37831404992204`}], 
             PointBox[{4.8, 337.74796338267663`}], 
             PointBox[{4.9, 338.4093538482188}], 
             PointBox[{5., 339.58314344708253`}], 
             PointBox[{5.1, 336.77382157224866`}], 
             PointBox[{5.2, 335.85182922671805`}], 
             PointBox[{5.3, 336.88748837043426`}], 
             PointBox[{5.4, 336.43561781253123`}], 
             PointBox[{5.5, 335.05095789573005`}], 
             PointBox[{5.6, 337.3878308310806}], 
             PointBox[{5.7, 336.93173887765033`}], 
             PointBox[{5.8, 335.3231253776275}], 
             PointBox[{5.9, 335.68493090347147`}], 
             PointBox[{6., 337.07918149922904`}], 
             PointBox[{6.1, 334.73032851982646`}], 
             PointBox[{6.2, 333.8146375007707}], 
             PointBox[{6.3, 334.76817699352114`}], 
             PointBox[{6.4, 334.6213368017363}], 
             PointBox[{6.5, 333.17285181648106`}], 
             PointBox[{6.6, 335.26327621317495`}], 
             PointBox[{6.7, 335.04038407327204`}], 
             PointBox[{6.8, 333.51044627304105`}], 
             PointBox[{6.9, 333.660235034576}], 
             PointBox[{7., 335.12084712438224`}], 
             PointBox[{7.1, 333.10243457678934`}], 
             PointBox[{7.2, 332.27776972353763`}], 
             PointBox[{7.3, 333.1386648170843}], 
             PointBox[{7.4, 333.1819611938781}], 
             PointBox[{7.5, 331.7625384119901}], 
             PointBox[{7.6, 333.6470271791086}], 
             PointBox[{7.7, 333.5364312144741}], 
             PointBox[{7.8, 332.1106164310315}], 
             PointBox[{7.9, 332.1436388023475}], 
             PointBox[{8., 333.58311741294824`}], 
             PointBox[{8.1, 331.77308512103536`}], 
             PointBox[{8.2, 331.05228583590554`}], 
             PointBox[{8.3, 331.83744040827736`}], 
             PointBox[{8.4, 331.9638471996275}], 
             PointBox[{8.5, 330.6130307066727}], 
             PointBox[{8.6, 332.3746257648844}], 
             PointBox[{8.7, 332.25423276521565`}], 
             PointBox[{8.8, 330.9406624027317}], 
             PointBox[{8.9, 330.94584719471413`}], 
             PointBox[{9., 332.3213156942056}], 
             PointBox[{9.1, 330.59923631660575`}], 
             PointBox[{9.2, 329.97970555330534`}], 
             PointBox[{9.3, 330.71339510267615`}], 
             PointBox[{9.4, 330.8296482435648}], 
             PointBox[{9.5, 329.55734195384133`}], 
             PointBox[{9.6, 331.2884372020393}], 
             PointBox[{9.7, 331.0453860508039}], 
             PointBox[{9.8, 329.8494991949824}], 
             PointBox[{9.9, 329.90551563147346`}], 
             PointBox[{10., 331.1868198883075}], 
             PointBox[{10.1, 329.4473714527174}], 
             PointBox[{10.2, 328.9418863981098}], 
             PointBox[{10.3, 329.63993117744974`}], 
             PointBox[{10.4, 329.6635932820543}], 
             PointBox[{10.5, 328.489850245364}], 
             PointBox[{10.6, 330.2486346029891}], 
             PointBox[{10.7, 329.7941355057087}], 
             PointBox[{10.8, 328.7299133947539}], 
             PointBox[{10.9, 328.9047530197746}], 
             PointBox[{11., 330.03593315432977`}], 
             PointBox[{11.1, 328.2122803335143}], 
             PointBox[{11.2, 327.86656707769674`}], 
             PointBox[{11.3, 328.52344529897374`}], 
             PointBox[{11.4, 328.37907701395727`}], 
             PointBox[{11.5, 327.37708992172}], 
             PointBox[{11.6, 329.13498562151165`}], 
             PointBox[{11.7, 328.42830000876415`}], 
             PointBox[{11.8, 327.5234794023363}], 
             PointBox[{11.9, 327.8766063628388}], 
             PointBox[{12., 328.73028285796863`}], 
             PointBox[{12.1, 326.82209822038044`}], 
             PointBox[{12.2, 326.7226995926927}], 
             PointBox[{12.3, 327.30329271514864`}], 
             PointBox[{12.4, 326.92255000794023`}], 
             PointBox[{12.5, 326.2565379006729}], 
             PointBox[{12.6, 327.85100669421433`}], 
             PointBox[{12.7, 326.92402043489034`}], 
             PointBox[{12.8, 326.2184453208742}], 
             PointBox[{12.9, 326.7948623709928}], 
             PointBox[{13., 327.1447263692993}], 
             PointBox[{13.1, 325.28164613584283`}], 
             PointBox[{13.2, 325.50112269308624`}], 
             PointBox[{13.3, 325.9445508413536}], 
             PointBox[{13.4, 325.2786730739625}], 
             PointBox[{13.5, 325.1951435521205}], 
             PointBox[{13.6, 326.3408963365443}], 
             PointBox[{13.7, 325.3007336319395}], 
             PointBox[{13.8, 324.83972250461545`}], 
             PointBox[{13.9, 325.6494725905415}], 
             PointBox[{14., 325.2198089751726}], 
             PointBox[{14.1, 323.7162716078427}], 
             PointBox[{14.2, 324.19563331916055`}], 
             PointBox[{14.3, 324.4274506743144}], 
             PointBox[{14.4, 323.4864045349165}], 
             PointBox[{14.5, 324.1869067091919}], 
             PointBox[{14.6, 324.61013026864015`}], 
             PointBox[{14.7, 323.60577244662744`}], 
             PointBox[{14.8, 323.4323462685147}], 
             PointBox[{14.9, 324.3981260601281}], 
             PointBox[{15., 323.0406042798468}], 
             PointBox[{15.1, 322.2331837911884}], 
             PointBox[{15.2, 322.7946625432034}], 
             PointBox[{15.3, 322.7414307261735}], 
             PointBox[{15.4, 321.66950938043846`}], 
             PointBox[{15.5, 323.07558566313736`}], 
             PointBox[{15.6, 322.7248253873889}], 
             PointBox[{15.7, 321.8967128842764}], 
             PointBox[{15.8, 322.0412032347339}], 
             PointBox[{15.9, 322.9083371592851}], 
             PointBox[{16., 320.81825080813735`}], 
             PointBox[{16.1, 320.8199241950927}], 
             PointBox[{16.2, 321.28250557659965`}], 
             PointBox[{16.3, 320.8876270058654}], 
             PointBox[{16.4, 320.04273737064005`}], 
             PointBox[{16.5, 321.65690260205656`}], 
             PointBox[{16.6, 320.7795644180392}], 
             PointBox[{16.7, 320.2258521811876}], 
             PointBox[{16.8, 320.68752332302023`}], 
             PointBox[{16.9, 320.96491143022115`}], 
             PointBox[{17., 318.8565833859575}], 
             PointBox[{17.1, 319.4088930908896}], 
             PointBox[{17.2, 319.64388777421124`}], 
             PointBox[{17.3, 318.8984443391849}], 
             PointBox[{17.4, 318.78085111416567`}], 
             PointBox[{17.5, 319.8826706287161}], 
             PointBox[{17.6, 318.8616152899092}], 
             PointBox[{17.7, 318.6304259609161}], 
             PointBox[{17.8, 319.33636050299896`}], 
             PointBox[{17.9, 318.50694283308025`}], 
             PointBox[{18., 317.2535118533449}], 
             PointBox[{18.1, 317.9393912183229}], 
             PointBox[{18.2, 317.870859637025}], 
             PointBox[{18.3, 316.8741299274849}], 
             PointBox[{18.4, 317.7561617513612}], 
             PointBox[{18.5, 317.88901245197144`}], 
             PointBox[{18.6, 317.03011960583416`}], 
             PointBox[{18.7, 317.1254997800455}], 
             PointBox[{18.8, 317.85470985305585`}], 
             PointBox[{18.9, 315.9305241681499}], 
             PointBox[{19., 315.84383306068696`}], 
             PointBox[{19.1, 316.3763480549192}], 
             PointBox[{19.2, 315.97236554602557`}], 
             PointBox[{19.3, 315.0032005218868}], 
             PointBox[{19.4, 316.56142379873876`}], 
             PointBox[{19.5, 315.85791347456757`}], 
             PointBox[{19.6, 315.31443972696144`}], 
             PointBox[{19.7, 315.6963832197337}], 
             PointBox[{19.8, 316.0161250629689}], 
             PointBox[{19.9, 313.78179518936827`}], 
             PointBox[{20., 314.46372033728966`}], 
             PointBox[{20.1, 314.71027928837304`}], 
             PointBox[{20.2, 313.98820401680763`}], 
             PointBox[{20.3, 313.4892898662141}], 
             PointBox[{20.4, 314.95733485872137`}], 
             PointBox[{20.5, 313.9142607601966}], 
             PointBox[{20.6, 313.72011082691034`}], 
             PointBox[{20.7, 314.2885297645221}], 
             PointBox[{20.8, 313.7209749738418}], 
             PointBox[{20.9, 312.1498041585354}], 
             PointBox[{21., 313.03378511835035`}], 
             PointBox[{21.1, 312.95522527181}], 
             PointBox[{21.2, 311.9994432259688}], 
             PointBox[{21.3, 312.3467753230145}], 
             PointBox[{21.4, 313.06313163012925`}], 
             PointBox[{21.5, 312.1136432432729}], 
             PointBox[{21.6, 312.23542902770913`}], 
             PointBox[{21.7, 312.80302080979567`}], 
             PointBox[{21.8, 311.28139126896303`}], 
             PointBox[{21.9, 310.80232761638456`}], 
             PointBox[{22., 311.5412063281964}], 
             PointBox[{22.1, 311.1467657944795}], 
             PointBox[{22.2, 310.12658573480417`}], 
             PointBox[{22.3, 311.3148357670217}], 
             PointBox[{22.4, 311.1175884903988}], 
             PointBox[{22.5, 310.4689407542772}], 
             PointBox[{22.6, 310.83724787974296`}], 
             PointBox[{22.7, 311.1382499080229}], 
             PointBox[{22.8, 309.10072999206335`}], 
             PointBox[{22.9, 309.5499730651725}], 
             PointBox[{23., 310.01287401723505`}], 
             PointBox[{23.1, 309.339668233337}], 
             PointBox[{23.2, 308.48717279498226`}], 
             PointBox[{23.3, 310.1204054015275}], 
             PointBox[{23.4, 309.2825958424093}], 
             PointBox[{23.5, 308.9747623349904}], 
             PointBox[{23.6, 309.49761239875824`}], 
             PointBox[{23.7, 309.3254246584147}], 
             PointBox[{23.8, 307.3574243755449}], 
             PointBox[{23.9, 308.32551414677}], 
             PointBox[{24., 308.4958370504981}], 
             PointBox[{24.1, 307.59981067975303`}], 
             PointBox[{24.2, 307.1327565483058}], 
             PointBox[{24.3, 308.7316576885316}], 
             PointBox[{24.4, 307.62487557859964`}], 
             PointBox[{24.5, 307.6205078122128}], 
             PointBox[{24.6, 308.195217716312}], 
             PointBox[{24.7, 307.56252189042874`}], 
             PointBox[{24.8, 305.98408587842425`}], 
             PointBox[{24.9, 307.13434510155133`}], 
             PointBox[{25., 307.04132732516575`}], 
             PointBox[{25.1, 305.98779042644196`}], 
             PointBox[{25.2, 306.0183213802817}], 
             PointBox[{25.3, 307.28606482921316`}], 
             PointBox[{25.4, 306.1551010455509}], 
             PointBox[{25.5, 306.3935055553108}], 
             PointBox[{25.6, 306.9301496227119}], 
             PointBox[{25.7, 305.95861505282386`}], 
             PointBox[{25.8, 304.8375035322624}], 
             PointBox[{25.9, 306.001776715982}], 
             PointBox[{26., 305.688994964517}], 
             PointBox[{26.1, 304.53782477388285`}], 
             PointBox[{26.2, 305.0462306222438}], 
             PointBox[{26.3, 305.91743434378446`}], 
             PointBox[{26.4, 304.85350467621504`}], 
             PointBox[{26.5, 305.27380961980674`}], 
             PointBox[{26.6, 305.72653713696087`}], 
             PointBox[{26.7, 304.5281041314897}], 
             PointBox[{26.8, 303.8000610490196}], 
             PointBox[{26.9, 304.93588539157156`}], 
             PointBox[{27., 304.44981309805496`}], 
             PointBox[{27.1, 303.2389585100879}], 
             PointBox[{27.2, 304.12294599060783`}], 
             PointBox[{27.3, 304.68240207103764`}], 
             PointBox[{27.4, 303.6750128022734}], 
             PointBox[{27.5, 304.2237533965846}], 
             PointBox[{27.6, 304.60067189932795`}], 
             PointBox[{27.7, 303.2480137613769}], 
             PointBox[{27.8, 302.77298066056727`}], 
             PointBox[{27.9, 303.90558888315445`}], 
             PointBox[{28., 303.29320031037537`}], 
             PointBox[{28.1, 302.0291850339168}], 
             PointBox[{28.2, 303.16638836933646`}], 
             PointBox[{28.3, 303.5601429528639}], 
             PointBox[{28.4, 302.54653317374976`}], 
             PointBox[{28.5, 303.17593381988996`}], 
             PointBox[{28.6, 303.5163595558203}], 
             PointBox[{28.7, 302.03723273252956`}], 
             PointBox[{28.8, 301.6448015027459}], 
             PointBox[{28.9, 302.8294951938373}], 
             PointBox[{29., 302.1409349240812}], 
             PointBox[{29.1, 300.8008285388246}], 
             PointBox[{29.2, 302.07909584070796`}], 
             PointBox[{29.3, 302.46865202294856`}], 
             PointBox[{29.4, 301.3650884042063}], 
             PointBox[{29.5, 302.02575502678286`}], 
             PointBox[{29.6, 302.381347951047}], 
             PointBox[{29.7, 300.76801383802496`}], 
             PointBox[{29.8, 300.2778948342696}], 
             PointBox[{29.9, 301.57544816363446`}], 
             PointBox[{30., 300.8701247174975}], 
             PointBox[{30.1, 299.41309183553693`}], 
             PointBox[{30.2, 300.72831248492355`}], 
             PointBox[{30.3, 301.27740345551905`}], 
             PointBox[{30.4, 300.0021744997496}], 
             PointBox[{30.5, 300.6330616564734}], 
             PointBox[{30.6, 301.0690336129504}], 
             PointBox[{30.7, 299.2880567998638}], 
             PointBox[{30.8, 298.513961114858}], 
             PointBox[{30.9, 299.9689753471911}], 
             PointBox[{31., 299.3220157810504}], 
             PointBox[{31.1, 297.7058954849001}], 
             PointBox[{31.2, 298.9483716398081}], 
             PointBox[{31.3, 299.81548272106335`}], 
             PointBox[{31.4, 298.31323346070457`}], 
             PointBox[{31.5, 298.831846426339}], 
             PointBox[{31.6, 299.42899548933565`}], 
             PointBox[{31.7, 297.441309383698}], 
             PointBox[{31.8, 296.1938544207426}], 
             PointBox[{31.9, 297.8092888259032}], 
             PointBox[{32., 297.31467869427297`}], 
             PointBox[{32.1, 295.51480745599963`}], 
             PointBox[{32.2, 296.56032788978104`}], 
             PointBox[{32.3, 297.8800532899833}], 
             PointBox[{32.4, 296.1496071645614}], 
             PointBox[{32.5, 296.4485022113174}], 
             PointBox[{32.6, 297.2771154096001}], 
             PointBox[{32.7, 295.0917232663443}], 
             PointBox[{32.8, 293.1867781062021}], 
             PointBox[{32.9, 294.8973444171548}], 
             PointBox[{33., 294.6619583547982}], 
             PointBox[{33.1, 292.69057609540926`}], 
             PointBox[{33.2, 293.4033350193944}], 
             PointBox[{33.3, 295.2557848987671}], 
             PointBox[{33.4, 293.37400375660167`}], 
             PointBox[{33.5, 293.32939957586746`}], 
             PointBox[{33.6, 294.4032612450975}], 
             PointBox[{33.7, 292.1685502237018}], 
             PointBox[{33.8, 289.42871889042647`}], 
             PointBox[{33.9, 291.08142901904813`}], 
             PointBox[{34., 291.2049060929289}], 
             PointBox[{34.1, 289.12628567296065`}], 
             PointBox[{34.2, 289.375592154992}], 
             PointBox[{34.3, 291.75609783880407`}], 
             PointBox[{34.4, 289.88224321197623`}], 
             PointBox[{34.5, 289.378464473926}], 
             PointBox[{34.6, 290.6309713728051}], 
             PointBox[{34.7, 288.70041361212725`}], 
             PointBox[{34.8, 284.96495889583923`}], 
             PointBox[{34.9, 286.31866576555336`}], 
             PointBox[{35., 286.8629932585454}], 
             PointBox[{35.1, 284.7989807659501}], 
             PointBox[{35.2, 284.48464714409783`}], 
             PointBox[{35.3, 287.2897532314179}], 
             PointBox[{35.4, 285.63853097432536`}], 
             PointBox[{35.5, 284.604730614385}], 
             PointBox[{35.6, 285.8989941290331}], 
             PointBox[{35.7, 284.71819441782844`}], 
             PointBox[{35.8, 279.9886682546141}], 
             PointBox[{35.9, 280.73876195014503`}], 
             PointBox[{36., 281.6968635363581}], 
             PointBox[{36.1, 279.81262487054516`}], 
             PointBox[{36.2, 278.8952890706387}], 
             PointBox[{36.3, 281.93313126987584`}], 
             PointBox[{36.4, 280.7211637842513}], 
             PointBox[{36.5, 279.1666846707135}], 
             PointBox[{36.6, 280.3297613702414}], 
             PointBox[{36.7, 280.13404985303686`}], 
             PointBox[{36.8, 274.83591950994173`}], 
             PointBox[{36.9, 274.67028769251124`}], 
             PointBox[{37., 275.95148705025747`}], 
             PointBox[{37.1, 274.41938774280146`}], 
             PointBox[{37.2, 272.94499110055483`}], 
             PointBox[{37.3, 275.96832905522217`}], 
             PointBox[{37.4, 275.3561282313424}], 
             PointBox[{37.5, 273.3834826995886}], 
             PointBox[{37.6, 274.2494361602185}], 
             PointBox[{37.7, 274.95756337628825`}], 
             PointBox[{37.8, 269.8802018116322}], 
             PointBox[{37.9, 268.5866260550169}], 
             PointBox[{38., 270.028089518984}], 
             PointBox[{38.1, 268.97933164194296`}], 
             PointBox[{38.2, 267.08681857747877`}], 
             PointBox[{38.3, 269.83778842144505`}], 
             PointBox[{38.4, 269.8940203879262}], 
             PointBox[{38.5, 267.67705944545685`}], 
             PointBox[{38.6, 268.1288292027854}], 
             PointBox[{38.7, 269.47900325797485`}], 
             PointBox[{38.8, 265.3286417125041}], 
             PointBox[{38.9, 262.97344173298234`}], 
             PointBox[{39., 264.37586563630066`}], 
             PointBox[{39.1, 263.8622894497559}], 
             PointBox[{39.2, 261.76051711449753`}], 
             PointBox[{39.3, 264.0202056204564}], 
             PointBox[{39.4, 264.7169075355263}], 
             PointBox[{39.5, 262.45212251922914`}], 
             PointBox[{39.6, 262.4488104787326}], 
             PointBox[{39.7, 264.1347564101102}], 
             PointBox[{39.8, 261.171398147811}], 
             PointBox[{39.9, 258.18280779748795`}], 
             PointBox[{40., 259.3579693622645}], 
             PointBox[{40.1, 259.3430542281621}], 
             PointBox[{40.2, 257.2614482356655}], 
             PointBox[{40.3, 258.89269189163207`}], 
             PointBox[{40.4, 260.1265673649151}], 
             PointBox[{40.5, 257.98169015571915`}], 
             PointBox[{40.6, 257.5609605754101}], 
             PointBox[{40.7, 259.31082702589583`}], 
             PointBox[{40.8, 257.444956922665}], 
             PointBox[{40.9, 254.3534587514352}], 
             PointBox[{41., 255.17517055263733`}], 
             PointBox[{41.1, 255.55676000307886`}], 
             PointBox[{41.2, 253.68617936264687`}], 
             PointBox[{41.3, 254.65706827189211`}], 
             PointBox[{41.4, 256.2818351959053}], 
             PointBox[{41.5, 254.36350749925384`}], 
             PointBox[{41.6, 253.6194124583618}], 
             PointBox[{41.7, 255.2396415738724}], 
             PointBox[{41.8, 254.27321294880159`}], 
             PointBox[{41.9, 251.41643044027342`}], 
             PointBox[{42., 251.86325392480586`}], 
             PointBox[{42.1, 252.511852757763}], 
             PointBox[{42.2, 250.96237507702176`}], 
             PointBox[{42.3, 251.34097427469675`}], 
             PointBox[{42.4, 253.20133815392637`}], 
             PointBox[{42.5, 251.54801312452852`}], 
             PointBox[{42.6, 250.59603420551383`}], 
             PointBox[{42.7, 251.98735276900456`}], 
             PointBox[{42.8, 251.70017820297238`}], 
             PointBox[{42.9, 249.17670837042078`}], 
             PointBox[{43., 249.3360145754088}], 
             PointBox[{43.1, 250.12983735801475`}], 
             PointBox[{43.2, 248.9226866761506}], 
             PointBox[{43.3, 248.8458059808795}], 
             PointBox[{43.4, 250.80540199992984`}], 
             PointBox[{43.5, 249.3987571353764}], 
             PointBox[{43.6, 248.34728365443098`}], 
             PointBox[{43.7, 249.49356749859015`}], 
             PointBox[{43.8, 249.66646142726734`}], 
             PointBox[{43.9, 247.4311651997266}], 
             PointBox[{44., 247.43902113324455`}], 
             PointBox[{44.1, 248.28438314681173`}], 
             PointBox[{44.2, 247.37025831424748`}], 
             PointBox[{44.3, 247.0006490683063}], 
             PointBox[{44.4, 248.95729786374807`}], 
             PointBox[{44.5, 247.74080563636488`}], 
             PointBox[{44.6, 246.67522590710962`}], 
             PointBox[{44.7, 247.61849991372233`}], 
             PointBox[{44.8, 248.0515631877683}], 
             PointBox[{44.9, 246.02515465298177`}], 
             PointBox[{45., 245.99091323181491`}], 
             PointBox[{45.1, 246.82630939193675`}], 
             PointBox[{45.2, 246.1159940133543}], 
             PointBox[{45.3, 245.6099427570829}], 
             PointBox[{45.4, 247.49633438500229`}], 
             PointBox[{45.5, 246.39545625405043`}], 
             PointBox[{45.6, 245.37713838969265`}], 
             PointBox[{45.7, 246.19024411185538`}], 
             PointBox[{45.8, 246.7109309966591}], 
             PointBox[{45.9, 244.83174001204839`}], 
             PointBox[{46., 244.81701214703912`}], 
             PointBox[{46.1, 245.60543760702532`}], 
             PointBox[{46.2, 244.9950236783022}], 
             PointBox[{46.3, 244.4922245882991}], 
             PointBox[{46.4, 246.25914376723017`}], 
             PointBox[{46.5, 245.2002310166192}], 
             PointBox[{46.6, 244.27343243308556`}], 
             PointBox[{46.7, 245.03801657203317`}], 
             PointBox[{46.8, 245.49290110397232`}], 
             PointBox[{46.9, 243.7240355802488}], 
             PointBox[{47., 243.7694056615788}], 
             PointBox[{47.1, 244.48517349416068`}], 
             PointBox[{47.2, 243.87252119637483`}], 
             PointBox[{47.3, 243.50801224949936`}], 
             PointBox[{47.4, 245.09451560947196`}], 
             PointBox[{47.5, 244.02287425132312`}], 
             PointBox[{47.6, 243.2242124950202}], 
             PointBox[{47.7, 244.01779501159828`}], 
             PointBox[{47.8, 244.25091587309763`}], 
             PointBox[{47.9, 242.5850738973882}], 
             PointBox[{48., 242.73836304968881`}], 
             PointBox[{48.1, 243.35401723235847`}], 
             PointBox[{48.2, 242.64922802495207`}], 
             PointBox[{48.3, 242.57246520956608`}], 
             PointBox[{48.4, 243.87576457735483`}], 
             PointBox[{48.5, 242.77245511032004`}], 
             PointBox[{48.6, 242.1383184812147}], 
             PointBox[{48.7, 243.02280399187853`}], 
             PointBox[{48.8, 242.86056423928295`}], 
             PointBox[{48.9, 241.3425283532514}], 
             PointBox[{49., 241.65379885100936`}], 
             PointBox[{49.1, 242.13075659383836`}], 
             PointBox[{49.2, 241.26897578463576`}], 
             PointBox[{49.3, 241.64360643665225`}], 
             PointBox[{49.4, 242.5134664369674}], 
             PointBox[{49.5, 241.40500630214052`}], 
             PointBox[{49.6, 240.9751603367442}], 
             PointBox[{49.7, 241.97969651597526`}], 
             PointBox[{49.8, 241.25129656376166`}], 
             PointBox[{49.9, 240.00612671153323`}], 
             PointBox[{50., 240.47810476522295`}], 
             PointBox[{50.1, 240.76355516977955`}], 
             PointBox[{50.2, 239.73277965446826`}], 
             PointBox[{50.3, 240.678573833261}], 
             PointBox[{50.4, 240.96773298413788`}], 
             PointBox[{50.5, 239.92123260008518`}], 
             PointBox[{50.6, 239.7384354526608}], 
             PointBox[{50.7, 240.8208524199964}], 
             PointBox[{50.8, 239.43576741285955`}], 
             PointBox[{50.9, 238.63779924118384`}], 
             PointBox[{51., 239.19246712971074`}], 
             PointBox[{51.1, 239.22318958697483`}], 
             PointBox[{51.2, 238.11933876309956`}], 
             PointBox[{51.3, 239.58413458465168`}], 
             PointBox[{51.4, 239.2524726474316}], 
             PointBox[{51.5, 238.35522262385132`}], 
             PointBox[{51.6, 238.45906531710747`}], 
             PointBox[{51.7, 239.43953251866805`}], 
             PointBox[{51.8, 237.4828567214982}], 
             PointBox[{51.9, 237.27343301832812`}], 
             PointBox[{52., 237.7851274882289}], 
             PointBox[{52.1, 237.49908455604577`}], 
             PointBox[{52.2, 236.5928482966326}], 
             PointBox[{52.3, 238.23460940400514`}], 
             PointBox[{52.4, 237.42357698233383`}], 
             PointBox[{52.5, 236.75787340514535`}], 
             PointBox[{52.6, 237.17232356808034`}], 
             PointBox[{52.7, 237.67148882616652`}], 
             PointBox[{52.8, 235.55681139513223`}], 
             PointBox[{52.9, 235.8983728548132}], 
             PointBox[{53., 236.24466218803838`}], 
             PointBox[{53.1, 235.6065207384317}], 
             PointBox[{53.2, 235.32403297685966`}], 
             PointBox[{53.3, 236.5704382987836}], 
             PointBox[{53.4, 235.55495737533008`}], 
             PointBox[{53.5, 235.18106356580824`}], 
             PointBox[{53.6, 235.8799582095453}], 
             PointBox[{53.7, 235.42009042282774`}], 
             PointBox[{53.8, 233.86566499036823`}], 
             PointBox[{53.9, 234.47466284595947`}], 
             PointBox[{54., 234.56027799179512`}], 
             PointBox[{54.1, 233.6166575339275}], 
             PointBox[{54.2, 234.28309548282976`}], 
             PointBox[{54.3, 234.65934980681226`}], 
             PointBox[{54.4, 233.71525148464045`}], 
             PointBox[{54.5, 233.6647100922296}], 
             PointBox[{54.6, 234.50224581379302`}], 
             PointBox[{54.7, 232.89483335238276`}], 
             PointBox[{54.8, 232.38917207536178`}], 
             PointBox[{54.9, 232.96638297207193`}], 
             PointBox[{55., 232.728648549464}], 
             PointBox[{55.1, 231.69581215331857`}], 
             PointBox[{55.2, 233.15275951953555`}], 
             PointBox[{55.3, 232.64393171630047`}], 
             PointBox[{55.4, 231.9535863981866}], 
             PointBox[{55.5, 232.22331378267137`}], 
             PointBox[{55.6, 232.83604797945344`}], 
             PointBox[{55.7, 230.58232282641114`}], 
             PointBox[{55.8, 230.9894948784906}], 
             PointBox[{55.9, 231.34986234806823`}], 
             PointBox[{56., 230.7677415763604}], 
             PointBox[{56.1, 230.08016433474663`}], 
             PointBox[{56.2, 231.63880846952577`}], 
             PointBox[{56.3, 230.6548733533147}], 
             PointBox[{56.4, 230.29639389829458`}], 
             PointBox[{56.5, 230.831274152032}], 
             PointBox[{56.6, 230.6570671638905}], 
             PointBox[{56.7, 228.77606997283613`}], 
             PointBox[{56.8, 229.5612632378382}], 
             PointBox[{56.9, 229.61869869502124`}], 
             PointBox[{57., 228.73935661074069`}], 
             PointBox[{57.1, 228.87779526313}], 
             PointBox[{57.2, 229.76553240461234`}], 
             PointBox[{57.3, 228.77137811666546`}], 
             PointBox[{57.4, 228.7480874779942}], 
             PointBox[{57.5, 229.40020162900362`}], 
             PointBox[{57.6, 228.09971945311838`}], 
             PointBox[{57.7, 227.32622049347685`}], 
             PointBox[{57.8, 228.05679779986193`}], 
             PointBox[{57.9, 227.78646508009797`}], 
             PointBox[{58., 226.76620268497055`}], 
             PointBox[{58.1, 227.85213113189008`}], 
             PointBox[{58.2, 227.7538021126088}], 
             PointBox[{58.3, 227.02533813472758`}], 
             PointBox[{58.4, 227.2922491801129}], 
             PointBox[{58.5, 227.77753152605933`}], 
             PointBox[{58.6, 225.69512925224043`}], 
             PointBox[{58.7, 226.00105288358088`}], 
             PointBox[{58.8, 226.47278923882797`}], 
             PointBox[{58.9, 225.89073940855457`}], 
             PointBox[{59., 225.01127507214474`}], 
             PointBox[{59.1, 226.6214507629925}], 
             PointBox[{59.2, 225.7954489752311}], 
             PointBox[{59.3, 225.4201506978534}], 
             PointBox[{59.4, 225.8927994364149}], 
             PointBox[{59.5, 225.84993248992495`}], 
             PointBox[{59.6, 223.78366629142045`}], 
             PointBox[{59.7, 224.6805879523389}], 
             PointBox[{59.8, 224.83593212669692`}], 
             PointBox[{59.9, 223.99450233262516`}], 
             PointBox[{60., 223.58676984301425`}], 
             PointBox[{60.1, 225.06955564050764`}], 
             PointBox[{60.2, 223.9855135129314}], 
             PointBox[{60.3, 223.94627512592385`}], 
             PointBox[{60.4, 224.50024296765275`}], 
             PointBox[{60.5, 223.7604871518577}], 
             PointBox[{60.6, 222.31215891883923`}], 
             PointBox[{60.7, 223.3433989119326}], 
             PointBox[{60.8, 223.1916434281982}], 
             PointBox[{60.9, 222.17909660116922`}], 
             PointBox[{61., 222.45549320906278`}], 
             PointBox[{61.1, 223.35652687459643`}], 
             PointBox[{61.2, 222.35263641817025`}], 
             PointBox[{61.3, 222.5906538543277}], 
             PointBox[{61.4, 223.07258212513935`}], 
             PointBox[{61.5, 221.751963999998}], 
             PointBox[{61.6, 221.09182251821227`}], 
             PointBox[{61.7, 222.01839072830134`}], 
             PointBox[{61.8, 221.59443076930435`}], 
             PointBox[{61.9, 220.52104453184648`}], 
             PointBox[{62., 221.46523187068814`}], 
             PointBox[{62.1, 221.67956595723982`}], 
             PointBox[{62.2, 220.8947398051838}], 
             PointBox[{62.3, 221.34171922874424`}], 
             PointBox[{62.4, 221.62402834306727`}], 
             PointBox[{62.5, 219.9584792136257}], 
             PointBox[{62.6, 219.9980910489557}], 
             PointBox[{62.7, 220.7482071752529}], 
             PointBox[{62.8, 220.09414166327426`}], 
             PointBox[{62.9, 219.0636491581815}], 
             PointBox[{63., 220.49189637732337`}], 
             PointBox[{63.1, 220.15159294445448`}], 
             PointBox[{63.2, 219.59498733156488`}], 
             PointBox[{63.3, 220.1888907817188}], 
             PointBox[{63.4, 220.2411012856932}], 
             PointBox[{63.5, 218.43842730926764`}], 
             PointBox[{63.6, 218.97552721974995`}], 
             PointBox[{63.7, 219.5632123769395}], 
             PointBox[{63.8, 218.7198964509164}], 
             PointBox[{63.9, 217.7962876210339}], 
             PointBox[{64., 219.5051583546697}], 
             PointBox[{64.1, 218.80178824819023`}], 
             PointBox[{64.2, 218.42120347314113`}], 
             PointBox[{64.3, 219.11605977175915`}], 
             PointBox[{64.4, 218.99578644725813`}], 
             PointBox[{64.5, 217.14239245763164`}], 
             PointBox[{64.6, 217.98371069905326`}], 
             PointBox[{64.7, 218.4612784220517}], 
             PointBox[{64.8, 217.46344743704466`}], 
             PointBox[{64.9, 216.65312672586344`}], 
             PointBox[{65., 218.51380007256085`}], 
             PointBox[{65.1, 217.600579422487}], 
             PointBox[{65.2, 217.31756775514117`}], 
             PointBox[{65.3, 218.08741482543095`}], 
             PointBox[{65.4, 217.85841782487833`}], 
             PointBox[{65.5, 215.95211735727443`}], 
             PointBox[{65.6, 216.95679878828085`}], 
             PointBox[{65.7, 217.394549506935}], 
             PointBox[{65.8, 216.26974482367703`}], 
             PointBox[{65.9, 215.52633271730997`}], 
             PointBox[{66., 217.4943149753221}], 
             PointBox[{66.1, 216.47552018775437`}], 
             PointBox[{66.2, 216.19806014077295`}], 
             PointBox[{66.3, 217.03284145420662`}], 
             PointBox[{66.4, 216.72857647579548`}], 
             PointBox[{66.5, 214.72483894563337`}], 
             PointBox[{66.6, 215.78605296571988`}], 
             PointBox[{66.7, 216.26564832387808`}], 
             PointBox[{66.8, 215.03860680083946`}], 
             PointBox[{66.9, 214.27988362140383`}], 
             PointBox[{67., 216.3587353301601}], 
             PointBox[{67.1, 215.3193067876895}], 
             PointBox[{67.2, 214.94478139333333`}], 
             PointBox[{67.3, 215.8395019090105}], 
             PointBox[{67.4, 215.47872545933868`}], 
             PointBox[{67.5, 213.310535653314}], 
             PointBox[{67.6, 214.32005766165918`}], 
             PointBox[{67.7, 214.9298660652628}], 
             PointBox[{67.8, 213.63046721243376`}], 
             PointBox[{67.9, 212.75840179994228`}], 
             PointBox[{68., 214.95641085671795`}], 
             PointBox[{68.1, 213.9963999357853}], 
             PointBox[{68.2, 213.41508201534273`}], 
             PointBox[{68.3, 214.35451526774548`}], 
             PointBox[{68.4, 213.97973980569256`}], 
             PointBox[{68.5, 211.56219902760546`}], 
             PointBox[{68.6, 212.37969261001322`}], 
             PointBox[{68.7, 213.20580550398725`}], 
             PointBox[{68.8, 211.88145264826727`}], 
             PointBox[{68.9, 210.7980264616986}], 
             PointBox[{69., 213.0928161691272}], 
             PointBox[{69.1, 212.34788158201633`}], 
             PointBox[{69.2, 211.45417466653572`}], 
             PointBox[{69.3, 212.39698709543066`}], 
             PointBox[{69.4, 212.11989239796694`}], 
             PointBox[{69.5, 209.34620759513848`}], 
             PointBox[{69.6, 209.7831791618397}], 
             PointBox[{69.7, 210.891497056504}], 
             PointBox[{69.8, 209.61693230903063`}], 
             PointBox[{69.9, 208.2413862754686}], 
             PointBox[{70., 210.55932422839604`}], 
             PointBox[{70.1, 210.19781143201487`}], 
             PointBox[{70.2, 208.9124672706175}], 
             PointBox[{70.3, 209.7798022330973}], 
             PointBox[{70.4, 209.78584512079968`}], 
             PointBox[{70.5, 206.559936659294}], 
             PointBox[{70.6, 206.38412413270535`}], 
             PointBox[{70.7, 207.79304878123452`}], 
             PointBox[{70.8, 206.67315575527456`}], 
             PointBox[{70.9, 204.96138596416975`}], 
             PointBox[{71., 207.17506591603774`}], 
             PointBox[{71.1, 207.36750332392856`}], 
             PointBox[{71.2, 205.669398211393}], 
             PointBox[{71.3, 206.3453728484807}], 
             PointBox[{71.4, 206.8044214897108}], 
             PointBox[{71.5, 203.16397199444228`}], 
             PointBox[{71.6, 202.1214558192936}], 
             PointBox[{71.7, 203.7733924662466}], 
             PointBox[{71.8, 202.93183416453613`}], 
             PointBox[{71.9, 200.89738616532938`}], 
             PointBox[{72., 202.84003520466092`}], 
             PointBox[{72.1, 203.71104140026142`}], 
             PointBox[{72.2, 201.66528136748488`}], 
             PointBox[{72.3, 202.01453952650667`}], 
             PointBox[{72.4, 202.96939106872807`}], 
             PointBox[{72.5, 199.2229493104452}], 
             PointBox[{72.6, 197.07355277783125`}], 
             PointBox[{72.7, 198.81839041540746`}], 
             PointBox[{72.8, 198.37084084559126`}], 
             PointBox[{72.9, 196.10043553744856`}], 
             PointBox[{73., 197.59389000799652`}], 
             PointBox[{73.1, 199.1779509915874}], 
             PointBox[{73.2, 196.9409672245477}], 
             PointBox[{73.3, 196.84164636562738`}], 
             PointBox[{73.4, 198.1896706074254}], 
             PointBox[{73.5, 194.90259652268367`}], 
             PointBox[{73.6, 191.49509227120205`}], 
             PointBox[{73.7, 193.09760981406234`}], 
             PointBox[{73.8, 193.1152511778455}], 
             PointBox[{73.9, 190.76837691950868`}], 
             PointBox[{74., 191.65843600636163`}], 
             PointBox[{74.1, 193.880458593418}], 
             PointBox[{74.2, 191.67130235933155`}], 
             PointBox[{74.3, 191.05471557789903`}], 
             PointBox[{74.4, 192.60089275265005`}], 
             PointBox[{74.5, 190.33291972603655`}], 
             PointBox[{74.6, 185.80021212997943`}], 
             PointBox[{74.7, 186.9762887700621}], 
             PointBox[{74.8, 187.4572096637201}], 
             PointBox[{74.9, 185.24024131365485`}], 
             PointBox[{75., 185.43535819380864`}], 
             PointBox[{75.1, 188.1238012473527}], 
             PointBox[{75.2, 186.16894269363732`}], 
             PointBox[{75.3, 185.04738035061976`}], 
             PointBox[{75.4, 186.56677552811206`}], 
             PointBox[{75.5, 185.5326663668928}], 
             PointBox[{75.6, 180.45565947834456`}], 
             PointBox[{75.7, 180.93584615169289`}], 
             PointBox[{75.8, 181.79917037391598`}], 
             PointBox[{75.9, 179.9133341293987}], 
             PointBox[{76., 179.41401166477854`}], 
             PointBox[{76.1, 182.33761056790442`}], 
             PointBox[{76.2, 180.81409261528003`}], 
             PointBox[{76.3, 179.28197433303657`}], 
             PointBox[{76.4, 180.57603236281977`}], 
             PointBox[{76.5, 180.64028616997496`}], 
             PointBox[{76.6, 175.8000651640402}], 
             PointBox[{76.7, 175.43089462782316`}], 
             PointBox[{76.8, 176.5371052582732}], 
             PointBox[{76.9, 175.12499413797835`}], 
             PointBox[{77., 174.03443994569227`}], 
             PointBox[{77.1, 176.94941784767948`}], 
             PointBox[{77.2, 175.95091498141286`}], 
             PointBox[{77.3, 174.15553991773996`}], 
             PointBox[{77.4, 175.0929555317088}], 
             PointBox[{77.5, 175.96558608823463`}], 
             PointBox[{77.6, 171.8946286756911}], 
             PointBox[{77.7, 170.76595062627828`}], 
             PointBox[{77.8, 171.9551229369429}], 
             PointBox[{77.9, 171.06671184497952`}], 
             PointBox[{78., 169.56858683718252`}], 
             PointBox[{78.1, 172.26344042251776`}], 
             PointBox[{78.2, 171.79568841966025`}], 
             PointBox[{78.3, 169.8936600598572}], 
             PointBox[{78.4, 170.42912312986041`}], 
             PointBox[{78.5, 171.79821076768872`}], 
             PointBox[{78.6, 168.6004691109152}], 
             PointBox[{78.7, 167.04858454692268`}], 
             PointBox[{78.8, 168.18101095863807`}], 
             PointBox[{78.9, 167.77700975529282`}], 
             PointBox[{79., 166.0849864288339}], 
             PointBox[{79.1, 168.41681225547464`}], 
             PointBox[{79.2, 168.4153402699086}], 
             PointBox[{79.3, 166.53489449486676`}], 
             PointBox[{79.4, 166.70077628210768`}], 
             PointBox[{79.5, 168.29860465161963`}], 
             PointBox[{79.6, 165.84292703231912`}], 
             PointBox[{79.7, 164.21819297813306`}], 
             PointBox[{79.8, 165.20602142781686`}], 
             PointBox[{79.9, 165.18887357003535`}], 
             PointBox[{80., 163.487194085626}], 
             PointBox[{80.1, 165.40119908282145`}], 
             PointBox[{80.2, 165.7579817056888}], 
             PointBox[{80.3, 163.98009741217746`}], 
             PointBox[{80.4, 163.8592761873227}], 
             PointBox[{80.5, 165.49435344942762`}], 
             PointBox[{80.6, 163.6210656477857}], 
             PointBox[{80.7, 162.1078584758165}], 
             PointBox[{80.8, 162.92790889409957`}], 
             PointBox[{80.9, 163.17748846567238`}], 
             PointBox[{81., 161.5837086968473}], 
             PointBox[{81.1, 163.11151442505056`}], 
             PointBox[{81.2, 163.6994724890833}], 
             PointBox[{81.3, 162.05794042919237`}], 
             PointBox[{81.4, 161.75124235432412`}], 
             PointBox[{81.5, 163.31728369624065`}], 
             PointBox[{81.6, 161.87121672621063`}], 
             PointBox[{81.7, 160.51303025637517`}], 
             PointBox[{81.8, 161.19452915915997`}], 
             PointBox[{81.9, 161.59707708031013`}], 
             PointBox[{82., 160.15211087814882`}], 
             PointBox[{82.1, 161.39221882724445`}], 
             PointBox[{82.2, 162.0816613981359}], 
             PointBox[{82.3, 160.57556835272308`}], 
             PointBox[{82.4, 160.18035446149534`}], 
             PointBox[{82.5, 161.6425131352029}], 
             PointBox[{82.6, 160.45963244630695`}], 
             PointBox[{82.7, 159.24261346952335`}], 
             PointBox[{82.8, 159.8380841404448}], 
             PointBox[{82.9, 160.29788848085082`}], 
             PointBox[{83., 158.98347663887108`}], 
             PointBox[{83.1, 160.07332739944874`}], 
             PointBox[{83.2, 160.7388976951412}], 
             PointBox[{83.3, 159.3497973776915}], 
             PointBox[{83.4, 158.94903934194028`}], 
             PointBox[{83.5, 160.31996514764649`}], 
             PointBox[{83.6, 159.2302669637581}], 
             PointBox[{83.7, 158.13718174656623`}], 
             PointBox[{83.8, 158.69882082208767`}], 
             PointBox[{83.9, 159.1387197045861}], 
             PointBox[{84., 157.90502097185623`}], 
             PointBox[{84.1, 158.99530701323457`}], 
             PointBox[{84.2, 159.51549978791138`}], 
             PointBox[{84.3, 158.2248413594793}], 
             PointBox[{84.4, 157.8875760539209}], 
             PointBox[{84.5, 159.19756536494333`}], 
             PointBox[{84.6, 158.03784494263985`}], 
             PointBox[{84.7, 157.07336309086682`}], 
             PointBox[{84.8, 157.6421371512803}], 
             PointBox[{84.9, 157.9968718430452}], 
             PointBox[{85., 156.79323096110747`}], 
             PointBox[{85.1, 158.02291293001633`}], 
             PointBox[{85.2, 158.2807852152382}], 
             PointBox[{85.3, 157.08427015034616`}], 
             PointBox[{85.4, 156.86981824355985`}], 
             PointBox[{85.5, 158.13802294785037`}], 
             PointBox[{85.6, 156.77190643341126`}], 
             PointBox[{85.7, 155.97189397071958`}], 
             PointBox[{85.8, 156.5676483747792}], 
             PointBox[{85.9, 156.77562278130685`}], 
             PointBox[{86., 155.58534502522795`}], 
             PointBox[{86.1, 157.04318245938853`}], 
             PointBox[{86.2, 156.94236694684614`}], 
             PointBox[{86.3, 155.85802678802912`}], 
             PointBox[{86.4, 155.8204605241631}], 
             PointBox[{86.5, 157.01775960035846`}], 
             PointBox[{86.6, 155.36759286657409`}], 
             PointBox[{86.7, 154.80394538420123`}], 
             PointBox[{86.8, 155.4102196262619}], 
             PointBox[{86.9, 155.40835755730555`}], 
             PointBox[{87., 154.2931963761931}], 
             PointBox[{87.1, 155.9544456708464}], 
             PointBox[{87.2, 155.4566190060061}], 
             PointBox[{87.3, 154.52413088503968`}], 
             PointBox[{87.4, 154.71333078215426`}], 
             PointBox[{87.5, 155.71272532913025`}], 
             PointBox[{87.6, 153.79408666275063`}], 
             PointBox[{87.7, 153.57359238380306`}], 
             PointBox[{87.8, 154.13282105683342`}], 
             PointBox[{87.9, 153.85818584964613`}], 
             PointBox[{88., 153.00456939264689`}], 
             PointBox[{88.1, 154.66305889581935`}], 
             PointBox[{88.2, 153.82805935167391`}], 
             PointBox[{88.3, 153.09959129831864`}], 
             PointBox[{88.4, 153.55409970204232`}], 
             PointBox[{88.5, 154.08931802337253`}], 
             PointBox[{88.6, 152.09231462846878`}], 
             PointBox[{88.7, 152.28618894508756`}], 
             PointBox[{88.8, 152.71517317595507`}], 
             PointBox[{88.9, 152.12096590318154`}], 
             PointBox[{89., 151.83634106246535`}], 
             PointBox[{89.1, 153.1133087617246}], 
             PointBox[{89.2, 152.09846752146447`}], 
             PointBox[{89.3, 151.62691060873257`}], 
             PointBox[{89.4, 152.3511748770928}], 
             PointBox[{89.5, 152.0670581067927}], 
             PointBox[{89.6, 150.43271419596434`}], 
             PointBox[{89.7, 150.93304715242627`}], 
             PointBox[{89.8, 151.14445216446734`}], 
             PointBox[{89.9, 150.24182838405616`}], 
             PointBox[{90., 150.8019773663852}], 
             PointBox[{90.1, 151.32407392960957`}], 
             PointBox[{90.2, 150.32767563126902`}], 
             PointBox[{90.3, 150.15622112414172`}], 
             PointBox[{90.4, 151.06491189912552`}], 
             PointBox[{90.5, 149.7477072390423}], 
             PointBox[{90.6, 148.9185379011189}], 
             PointBox[{90.7, 149.4946514401725}], 
             PointBox[{90.8, 149.4120917825528}], 
             PointBox[{90.9, 148.35233165767698`}], 
             PointBox[{91., 149.70647644359138`}], 
             PointBox[{91.1, 149.3840124059502}], 
             PointBox[{91.2, 148.5751355103035}], 
             PointBox[{91.3, 148.72794930964258`}], 
             PointBox[{91.4, 149.5491798358802}], 
             PointBox[{91.5, 147.42668994373764`}], 
             PointBox[{91.6, 147.49897372036466`}], 
             PointBox[{91.7, 147.94976855678843`}], 
             PointBox[{91.8, 147.5223384195797}], 
             PointBox[{91.9, 146.67759883091412`}], 
             PointBox[{92., 148.29160791413423`}], 
             PointBox[{92.1, 147.40528195564124`}], 
             PointBox[{92.2, 146.8876225220209}], 
             PointBox[{92.3, 147.35136023349546`}], 
             PointBox[{92.4, 147.5687583791337}], 
             PointBox[{92.5, 145.45958204861475`}], 
             PointBox[{92.6, 146.08239501809243`}], 
             PointBox[{92.7, 146.28225366659254`}], 
             PointBox[{92.8, 145.51260087569653`}], 
             PointBox[{92.9, 145.39691925079399`}], 
             PointBox[{93., 146.5013194302425}], 
             PointBox[{93.1, 145.47869703342332`}], 
             PointBox[{93.2, 145.29229622460502`}], 
             PointBox[{93.3, 145.9767382041223}], 
             PointBox[{93.4, 145.0731862368105}], 
             PointBox[{93.5, 143.88570504883404`}], 
             PointBox[{93.6, 144.6029147796072}], 
             PointBox[{93.7, 144.48809422053816`}], 
             PointBox[{93.8, 143.4873011523182}], 
             PointBox[{93.9, 144.3713038962237}], 
             PointBox[{94., 144.4958913924067}], 
             PointBox[{94.1, 143.65817714576832`}], 
             PointBox[{94.2, 143.79325125984016`}], 
             PointBox[{94.3, 144.46271231220106`}], 
             PointBox[{94.4, 142.5065000896772}], 
             PointBox[{94.5, 142.49939262608714`}], 
             PointBox[{94.6, 143.03057519576686`}], 
             PointBox[{94.7, 142.5835868742159}], 
             PointBox[{94.8, 141.62774872787514`}], 
             PointBox[{94.9, 143.1849297562972}], 
             PointBox[{95., 142.4721649243464}], 
             PointBox[{95.1, 141.96477059162837`}], 
             PointBox[{95.2, 142.36676309637366`}], 
             PointBox[{95.3, 142.6013361279499}], 
             PointBox[{95.4, 140.3954300471377}], 
             PointBox[{95.5, 141.13525725566524`}], 
             PointBox[{95.6, 141.36540578330468`}], 
             PointBox[{95.7, 140.61540273317829`}], 
             PointBox[{95.8, 140.11511188040248`}], 
             PointBox[{95.9, 141.60622234293277`}], 
             PointBox[{96., 140.553839318071}], 
             PointBox[{96.1, 140.3973459718501}], 
             PointBox[{96.2, 140.95612156109638`}], 
             PointBox[{96.3, 140.35420232758264`}], 
             PointBox[{96.4, 138.79315971806435`}], 
             PointBox[{96.5, 139.7265662655157}], 
             PointBox[{96.6, 139.63169909845485`}], 
             PointBox[{96.7, 138.66597962413502`}], 
             PointBox[{96.8, 138.9564378998321}], 
             PointBox[{96.9, 139.75930895652616`}], 
             PointBox[{97., 138.79060426246866`}], 
             PointBox[{97.1, 138.94178351564125`}], 
             PointBox[{97.2, 139.47607087574508`}], 
             PointBox[{97.3, 138.0299438546229}], 
             PointBox[{97.4, 137.47550534448615`}], 
             PointBox[{97.5, 138.27427123630594`}], 
             PointBox[{97.6, 137.8734662168565}], 
             PointBox[{97.7, 136.84149749876318`}], 
             PointBox[{97.8, 137.9345677743055}], 
             PointBox[{97.9, 137.87803196456534`}], 
             PointBox[{98., 137.1914350102682}], 
             PointBox[{98.1, 137.57841318065277`}], 
             PointBox[{98.2, 137.86512606463646`}], 
             PointBox[{98.3, 135.93860033015505`}], 
             PointBox[{98.4, 136.27000248028156`}], 
             PointBox[{98.5, 136.8151103112666}], 
             PointBox[{98.6, 136.1483150167112}], 
             PointBox[{98.7, 135.23640977672977`}], 
             PointBox[{98.8, 136.8254412288604}], 
             PointBox[{98.9, 136.11750122805066`}], 
             PointBox[{99., 135.7492987263577}], 
             PointBox[{99.1, 136.28853752092994`}], 
             PointBox[{99.2, 136.18806679784947`}], 
             PointBox[{99.3, 134.2280317252239}], 
             PointBox[{99.4, 135.11666008660066`}], 
             PointBox[{99.5, 135.39860050887393`}], 
             PointBox[{99.6, 134.515736159439}], 
             PointBox[{99.7, 133.8857430808062}], 
             PointBox[{99.8, 135.5930665203692}], 
             PointBox[{99.9, 134.53963497637093`}], 
             PointBox[{100., 134.45165442437795`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 360}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
             40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {
             0, -180}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
             PointBox[{0.1, 4.708959391589076}], 
             PointBox[{0.2, 4.1056018828487595`}], 
             PointBox[{0.3, 5.081084121166441}], 
             PointBox[{0.4, 8.439721564535489}], 
             PointBox[{0.5, 8.238564563747104}], 
             PointBox[{0.6, 7.409301150528677}], 
             PointBox[{0.7, 10.743050888478535`}], 
             PointBox[{0.8, 12.241720777719138`}], 
             PointBox[{0.9, 11.44569249760275}], 
             PointBox[{1., 14.766034903911645`}], 
             PointBox[{1.1, 20.419955503903793`}], 
             PointBox[{1.2, 20.257091203512914`}], 
             PointBox[{1.3, 20.719642760988904`}], 
             PointBox[{1.4, 23.846419589219863`}], 
             PointBox[{1.5, 24.32766594892223}], 
             PointBox[{1.6, 23.004107756771532`}], 
             PointBox[{1.7, 26.075032743037127`}], 
             PointBox[{1.8, 28.022067450012855`}], 
             PointBox[{1.9, 27.26337640012548}], 
             PointBox[{2., 29.2097531302976}], 
             PointBox[{2.1, 35.02549706170612}], 
             PointBox[{2.2, 35.49787197949672}], 
             PointBox[{2.3, 35.53256427539918}], 
             PointBox[{2.4, 38.210708731248815`}], 
             PointBox[{2.5, 39.32499799915513}], 
             PointBox[{2.6, 37.680943081965324`}], 
             PointBox[{2.7, 40.317193976501585`}], 
             PointBox[{2.8, 42.57043874275519}], 
             PointBox[{2.9, 42.01222886658911}], 
             PointBox[{3., 42.826034829427044`}], 
             PointBox[{3.1, 48.11944883788988}], 
             PointBox[{3.2, 49.271871146446756`}], 
             PointBox[{3.3, 49.00404584363605}], 
             PointBox[{3.4, 51.10316271245392}], 
             PointBox[{3.5, 52.70127587529714}], 
             PointBox[{3.6, 50.90979505126188}], 
             PointBox[{3.7, 53.02344932492724}], 
             PointBox[{3.8, 55.411057313320725`}], 
             PointBox[{3.9, 55.12421661758435}], 
             PointBox[{4., 55.09568038562975}], 
             PointBox[{4.1, 59.558293475331084`}], 
             PointBox[{4.2, 61.21180977543372}], 
             PointBox[{4.3, 60.76616993014795}], 
             PointBox[{4.4, 62.253704129970174`}], 
             PointBox[{4.5, 64.1250358736761}], 
             PointBox[{4.6, 62.32179295111837}], 
             PointBox[{4.7, 63.9016990793225}], 
             PointBox[{4.8, 66.26122016105319}], 
             PointBox[{4.9, 66.22681559310786}], 
             PointBox[{5., 65.62146918538292}], 
             PointBox[{5.1, 69.27351303234218}], 
             PointBox[{5.2, 71.10785889553563}], 
             PointBox[{5.3, 70.57424165047223}], 
             PointBox[{5.4, 71.49509738897268}], 
             PointBox[{5.5, 73.42247692953288}], 
             PointBox[{5.6, 71.68058436025603}], 
             PointBox[{5.7, 72.7721276618945}], 
             PointBox[{5.8, 74.97557776649228}], 
             PointBox[{5.9, 75.1092084560205}], 
             PointBox[{6., 74.13321994178523}], 
             PointBox[{6.1, 77.10815374376443}], 
             PointBox[{6.2, 78.85311022492488}], 
             PointBox[{6.3, 78.26839962173881}], 
             PointBox[{6.4, 78.70948668236178}], 
             PointBox[{6.5, 80.51741756281854}], 
             PointBox[{6.6, 78.83861358943523}], 
             PointBox[{6.7, 79.52245074584243}], 
             PointBox[{6.8, 81.48312494747734}], 
             PointBox[{6.9, 81.66802155611185}], 
             PointBox[{7., 80.45363213682776}], 
             PointBox[{7.1, 82.88238627626197}], 
             PointBox[{7.2, 84.39397947882208}], 
             PointBox[{7.3, 83.74306448638345}], 
             PointBox[{7.4, 83.80125102538022}], 
             PointBox[{7.5, 85.37922913288367}], 
             PointBox[{7.6, 83.70349962768432}], 
             PointBox[{7.7, 84.07796447569763}], 
             PointBox[{7.8, 85.7441846238662}], 
             PointBox[{7.9, 85.85784190953746}], 
             PointBox[{8., 84.4702748802465}], 
             PointBox[{8.1, 86.47619478004071}], 
             PointBox[{8.2, 87.6931760406078}], 
             PointBox[{8.3, 86.92619736457073}], 
             PointBox[{8.4, 86.69184466962543}], 
             PointBox[{8.5, 87.98696771684172}], 
             PointBox[{8.6, 86.2166230638868}], 
             PointBox[{8.7, 86.38688268449187}], 
             PointBox[{8.8, 87.72885366066112}], 
             PointBox[{8.9, 87.65860605098169}], 
             PointBox[{9., 86.12074913534616}], 
             PointBox[{9.1, 87.82716994547627}], 
             PointBox[{9.2, 88.71284473562628}], 
             PointBox[{9.3, 87.77051445817142}], 
             PointBox[{9.4, 87.3238280478945}], 
             PointBox[{9.5, 88.31858428058513}], 
             PointBox[{9.6, 86.35252815412059}], 
             PointBox[{9.7, 86.42101323976749}], 
             PointBox[{9.8, 87.41725825433059}], 
             PointBox[{9.9, 87.06585384508799}], 
             PointBox[{10., 85.39305986788622}], 
             PointBox[{10.1, 86.91487989448524}], 
             PointBox[{10.2, 87.41813923015343}], 
             PointBox[{10.3, 86.25706629023534}], 
             PointBox[{10.4, 85.67457303548508}], 
             PointBox[{10.5, 86.34822953452931}], 
             PointBox[{10.6, 84.12689588901776}], 
             PointBox[{10.7, 84.17888271191077}], 
             PointBox[{10.8, 84.80594206170463}], 
             PointBox[{10.9, 84.09353308183927}], 
             PointBox[{11., 82.33580921641533}], 
             PointBox[{11.1, 83.76000196389214}], 
             PointBox[{11.2, 83.79225516257884}], 
             PointBox[{11.3, 82.40775368248069}], 
             PointBox[{11.4, 81.7700177434208}], 
             PointBox[{11.5, 82.05665376034995}], 
             PointBox[{11.6, 79.61605590186173}], 
             PointBox[{11.7, 79.69562837760805}], 
             PointBox[{11.8, 79.9236966906019}], 
             PointBox[{11.9, 78.78740191070574}], 
             PointBox[{12., 77.0796176486192}], 
             PointBox[{12.1, 78.42976613198152}], 
             PointBox[{12.2, 77.86714964512976}], 
             PointBox[{12.3, 76.30649750644443}], 
             PointBox[{12.4, 75.6999670254645}], 
             PointBox[{12.5, 75.45000897833779}], 
             PointBox[{12.6, 72.96974553918335}], 
             PointBox[{12.7, 73.05421875481625}], 
             PointBox[{12.8, 72.8492137072135}], 
             PointBox[{12.9, 71.2504715206087}], 
             PointBox[{13., 69.84581861246988}], 
             PointBox[{13.1, 70.99003332390384}], 
             PointBox[{13.2, 69.7611080024617}], 
             PointBox[{13.3, 68.11745546709062}], 
             PointBox[{13.4, 67.62055314738427}], 
             PointBox[{13.5, 66.6073937074907}], 
             PointBox[{13.6, 64.39793234742865}], 
             PointBox[{13.7, 64.39374774476892}], 
             PointBox[{13.8, 63.723676414465444`}], 
             PointBox[{13.9, 61.670191902145234`}], 
             PointBox[{14., 60.898029949396005`}], 
             PointBox[{14.1, 61.47554776488505}], 
             PointBox[{14.2, 59.69652155840413}], 
             PointBox[{14.3, 58.09001194695338}], 
             PointBox[{14.4, 57.72951039023246}], 
             PointBox[{14.5, 55.775651019041106`}], 
             PointBox[{14.6, 54.13943835999453}], 
             PointBox[{14.7, 53.914756785738064`}], 
             PointBox[{14.8, 52.75713880432522}], 
             PointBox[{14.9, 50.35802414885802}], 
             PointBox[{15., 50.44758564741824}], 
             PointBox[{15.1, 50.05676562429289}], 
             PointBox[{15.2, 47.98902527967766}], 
             PointBox[{15.3, 46.54464284221285}], 
             PointBox[{15.4, 46.21321869397798}], 
             PointBox[{15.5, 43.426590288449006`}], 
             PointBox[{15.6, 42.44034041917985}], 
             PointBox[{15.7, 41.87563185976251}], 
             PointBox[{15.8, 40.227856487228564`}], 
             PointBox[{15.9, 37.78943159629125}], 
             PointBox[{16., 38.59648807057965}], 
             PointBox[{16.1, 37.11206136912551}], 
             PointBox[{16.2, 35.017077231579606`}], 
             PointBox[{16.3, 33.842794058900836`}], 
             PointBox[{16.4, 33.212919212419365`}], 
             PointBox[{16.5, 30.127320110666915`}], 
             PointBox[{16.6, 29.562452405551085`}], 
             PointBox[{16.7, 28.585161129893095`}], 
             PointBox[{16.8, 26.484114741682788`}], 
             PointBox[{16.9, 24.579417354598263`}], 
             PointBox[{17., 25.339346991344428`}], 
             PointBox[{17.1, 23.11469577592652}], 
             PointBox[{17.2, 21.189962233902406`}], 
             PointBox[{17.3, 20.3411010392374}], 
             PointBox[{17.4, 18.93414919483621}], 
             PointBox[{17.5, 16.30878607831619}], 
             PointBox[{17.6, 15.799158510551933`}], 
             PointBox[{17.7, 14.392638660456214`}], 
             PointBox[{17.8, 11.95945898260834}], 
             PointBox[{17.9, 11.21981874989433}], 
             PointBox[{18., 10.97560504097055}], 
             PointBox[{18.1, 8.542278519633328}], 
             PointBox[{18.2, 6.921095547642835}], 
             PointBox[{18.3, 6.336283303793607}], 
             PointBox[{18.4, 3.9003004885671544`}], 
             PointBox[{18.5, 2.223838769918075}], 
             PointBox[{18.6, 1.4852396372534713`}], 
             PointBox[{18.7, -0.3156273861586669}], 
             PointBox[{18.8, -2.7921407824687776`}], 
             PointBox[{18.9, -2.3171835822431603`}], 
             PointBox[{19., -3.883840723465255}], 
             PointBox[{19.1, -6.15388097471623}], 
             PointBox[{19.2, -7.3923851385170565`}], 
             PointBox[{19.3, -7.9649609902280645`}], 
             PointBox[{19.4, -11.077076595456674`}], 
             PointBox[{19.5, -11.916934111588489`}], 
             PointBox[{19.6, -13.00715349190068}], 
             PointBox[{19.7, -15.113928113134534`}], 
             PointBox[{19.8, -17.102080622760695`}], 
             PointBox[{19.9, -16.259967121293812`}], 
             PointBox[{20., -18.640441085346538`}], 
             PointBox[{20.1, -20.55340533441631}], 
             PointBox[{20.2, -21.38829455064115}], 
             PointBox[{20.3, -22.373727884618347`}], 
             PointBox[{20.4, -25.35745482585844}], 
             PointBox[{20.5, -25.840797317603574`}], 
             PointBox[{20.6, -27.276412455918035`}], 
             PointBox[{20.7, -29.528034265898896`}], 
             PointBox[{20.8, -30.428214777733956`}], 
             PointBox[{20.9, -30.274791972164167`}], 
             PointBox[{21., -32.79600719828704}], 
             PointBox[{21.1, -34.266813298530906`}], 
             PointBox[{21.2, -34.75205903362439}], 
             PointBox[{21.3, -36.51054999875487}], 
             PointBox[{21.4, -38.66700835233496}], 
             PointBox[{21.5, -39.2022061581647}], 
             PointBox[{21.6, -40.901194532481895`}], 
             PointBox[{21.7, -43.032566622081504`}], 
             PointBox[{21.8, -42.73387892462597}], 
             PointBox[{21.9, -43.69009880133672}], 
             PointBox[{22., -45.93426394052585}], 
             PointBox[{22.1, -46.93614505971345}], 
             PointBox[{22.2, -47.217004209804145`}], 
             PointBox[{22.3, -49.71945871947901}], 
             PointBox[{22.4, -50.85663415501767}], 
             PointBox[{22.5, -51.615051445805875`}], 
             PointBox[{22.6, -53.452620019008464`}], 
             PointBox[{22.7, -55.10074078341495}], 
             PointBox[{22.8, -54.10273258151028}], 
             PointBox[{22.9, -55.909085330151356`}], 
             PointBox[{23., -57.69871913024508}], 
             PointBox[{23.1, -58.24003134337727}], 
             PointBox[{23.2, -58.52891336488756}], 
             PointBox[{23.3, -61.34648033933445}], 
             PointBox[{23.4, -61.712455354219856`}], 
             PointBox[{23.5, -62.691262566568184`}], 
             PointBox[{23.6, -64.51617286890541}], 
             PointBox[{23.7, -65.37817013897802}], 
             PointBox[{23.8, -64.33394269405835}], 
             PointBox[{23.9, -66.49963921830931}], 
             PointBox[{24., -67.78663774744564}], 
             PointBox[{24.1, -67.90061037740088}], 
             PointBox[{24.2, -68.39725545401961}], 
             PointBox[{24.3, -71.01609494216609}], 
             PointBox[{24.4, -70.95710381293247}], 
             PointBox[{24.5, -72.0757050206048}], 
             PointBox[{24.6, -73.72716556259547}], 
             PointBox[{24.7, -73.78154699525112}], 
             PointBox[{24.8, -73.02093687851448}], 
             PointBox[{24.9, -75.15988268256478}], 
             PointBox[{25., -75.95281669878386}], 
             PointBox[{25.1, -75.68788049689829}], 
             PointBox[{25.2, -76.48676840537883}], 
             PointBox[{25.3, -78.58108562370762}], 
             PointBox[{25.4, -78.31584439724975}], 
             PointBox[{25.5, -79.47646318912302}], 
             PointBox[{25.6, -80.81650998077384}], 
             PointBox[{25.7, -80.22047224375274}], 
             PointBox[{25.8, -79.76718488186452}], 
             PointBox[{25.9, -81.68566172410283}], 
             PointBox[{26., -82.01697931310264}], 
             PointBox[{26.1, -81.42249609447026}], 
             PointBox[{26.2, -82.48795214097117}], 
             PointBox[{26.3, -83.97223711917468}], 
             PointBox[{26.4, -83.56959042137532}], 
             PointBox[{26.5, -84.6861462629895}], 
             PointBox[{26.6, -85.64331521353597}], 
             PointBox[{26.7, -84.55556997090025}], 
             PointBox[{26.8, -84.30345019892775}], 
             PointBox[{26.9, -85.95074499534894}], 
             PointBox[{27., -85.86488879004901}], 
             PointBox[{27.1, -84.97515755120912}], 
             PointBox[{27.2, -86.19379044232846}], 
             PointBox[{27.3, -87.14185011472364}], 
             PointBox[{27.4, -86.57697851409102}], 
             PointBox[{27.5, -87.58590693524093}], 
             PointBox[{27.6, -88.17363067052429}], 
             PointBox[{27.7, -86.69634798711559}], 
             PointBox[{27.8, -86.48461808755019}], 
             PointBox[{27.9, -87.89034935467498}], 
             PointBox[{28., -87.44081401761287}], 
             PointBox[{28.1, -86.26581273860938}], 
             PointBox[{28.2, -87.51142121564044}], 
             PointBox[{28.3, -88.06677937953282}], 
             PointBox[{28.4, -87.27233162237462}], 
             PointBox[{28.5, -88.13041014626651}], 
             PointBox[{28.6, -88.420901000296}], 
             PointBox[{28.7, -86.59424454161854}], 
             PointBox[{28.8, -86.2485754496629}], 
             PointBox[{28.9, -87.48164387792349}], 
             PointBox[{29., -86.73257745345109}], 
             PointBox[{29.1, -85.25965879292562}], 
             PointBox[{29.2, -86.42414134636783}], 
             PointBox[{29.3, -86.75313179105433}], 
             PointBox[{29.4, -85.64947398118238}], 
             PointBox[{29.5, -86.3223559460057}], 
             PointBox[{29.6, -86.4154800285105}], 
             PointBox[{29.7, -84.23762562838965}], 
             PointBox[{29.8, -83.58396747012375}], 
             PointBox[{29.9, -84.72512670419019}], 
             PointBox[{30., -83.7561274564141}], 
             PointBox[{30.1, -81.96100877624849}], 
             PointBox[{30.2, -82.95161407779233}], 
             PointBox[{30.3, -83.22895686454285}], 
             PointBox[{30.4, -81.74497017716203}], 
             PointBox[{30.5, -82.19155190756283}], 
             PointBox[{30.6, -82.2034174914661}], 
             PointBox[{30.7, -79.6519791719511}], 
             PointBox[{30.8, -78.5146829543628}], 
             PointBox[{30.9, -79.63251861147}], 
             PointBox[{31., -78.54368561944284}], 
             PointBox[{31.1, -76.40622565629383}], 
             PointBox[{31.2, -77.13091546380747}], 
             PointBox[{31.3, -77.53112848179808}], 
             PointBox[{31.4, -75.6265496678534}], 
             PointBox[{31.5, -75.7848109767765}], 
             PointBox[{31.6, -75.83944636682281}], 
             PointBox[{31.7, -72.90213398713604}], 
             PointBox[{31.8, -71.10184779010524}], 
             PointBox[{31.9, -72.2251407259646}], 
             PointBox[{32., -71.13893460044346}], 
             PointBox[{32.1, -68.66118197119431}], 
             PointBox[{32.2, -69.0188905904688}], 
             PointBox[{32.3, -69.6969361980191}], 
             PointBox[{32.4, -67.38910362016395}], 
             PointBox[{32.5, -67.17091247296412}], 
             PointBox[{32.6, -67.36771454415066}], 
             PointBox[{32.7, -64.10322697281663}], 
             PointBox[{32.8, -61.46032084773833}], 
             PointBox[{32.9, -62.549619572255324`}], 
             PointBox[{33., -61.60352125175996}], 
             PointBox[{33.1, -58.82810969740967}], 
             PointBox[{33.2, -58.71089865891554}], 
             PointBox[{33.3, -59.77117542756969}], 
             PointBox[{33.4, -57.158507286556414`}], 
             PointBox[{33.5, -56.45866111771102}], 
             PointBox[{33.6, -56.82708204373557}], 
             PointBox[{33.7, -53.455221544008964`}], 
             PointBox[{33.8, -49.78886957485156}], 
             PointBox[{33.9, -50.714751177703874`}], 
             PointBox[{34., -50.03967971891689}], 
             PointBox[{34.1, -47.06381440138284}], 
             PointBox[{34.2, -46.37268269309425}], 
             PointBox[{34.3, -47.83846798737068}], 
             PointBox[{34.4, -45.1048525998267}], 
             PointBox[{34.5, -43.82693572898279}], 
             PointBox[{34.6, -44.30899834701631}], 
             PointBox[{34.7, -41.259687952915556`}], 
             PointBox[{34.8, -36.40744791699399}], 
             PointBox[{34.9, -36.94772741794077}], 
             PointBox[{35., -36.63607174819481}], 
             PointBox[{35.1, -33.615733768241626`}], 
             PointBox[{35.2, -32.284986298025615`}], 
             PointBox[{35.3, -34.08416466318522}], 
             PointBox[{35.4, -31.472152655969694`}], 
             PointBox[{35.5, -29.566748514855135`}], 
             PointBox[{35.6, -30.033952068770304`}], 
             PointBox[{35.7, -27.80018774538621}], 
             PointBox[{35.8, -21.793973243529763`}], 
             PointBox[{35.9, -21.65519486505218}], 
             PointBox[{36., -21.727987758404197`}], 
             PointBox[{36.1, -18.86237956289915}], 
             PointBox[{36.2, -16.88877734394191}], 
             PointBox[{36.3, -18.863660748669645`}], 
             PointBox[{36.4, -16.620852889984235`}], 
             PointBox[{36.5, -14.121797666943166`}], 
             PointBox[{36.6, -14.413113154721941`}], 
             PointBox[{36.7, -13.233578914925602`}], 
             PointBox[{36.8, -6.5785330471953785`}], 
             PointBox[{36.9, -5.448212420353229}], 
             PointBox[{37., -5.839253766891488}], 
             PointBox[{37.1, -3.3334017012020922`}], 
             PointBox[{37.2, -0.7993195038434351}], 
             PointBox[{37.3, -2.7387918921704113`}], 
             PointBox[{37.4, -1.059385603723058}], 
             PointBox[{37.5, 1.9029719317913987`}], 
             PointBox[{37.6, 1.9367092492211668`}], 
             PointBox[{37.7, 2.1567770705078146`}], 
             PointBox[{37.8, 8.566072772271582}], 
             PointBox[{37.9, 10.913004443955288`}], 
             PointBox[{38., 10.34699864524373}], 
             PointBox[{38.1, 12.331840673879924`}], 
             PointBox[{38.2, 15.252068759582471`}], 
             PointBox[{38.3, 13.569132898122916`}], 
             PointBox[{38.4, 14.580762211477122`}], 
             PointBox[{38.5, 17.80160562381934}], 
             PointBox[{38.6, 18.25576591614299}], 
             PointBox[{38.7, 17.784160732335295`}], 
             PointBox[{38.8, 23.146156079117645`}], 
             PointBox[{38.9, 26.652487064977322`}], 
             PointBox[{39., 26.097033042860858`}], 
             PointBox[{39.1, 27.48220395511089}], 
             PointBox[{39.2, 30.546404389984673`}], 
             PointBox[{39.3, 29.302958250806114`}], 
             PointBox[{39.4, 29.638187784690672`}], 
             PointBox[{39.5, 32.887723662584904`}], 
             PointBox[{39.6, 33.77725586709494}], 
             PointBox[{39.7, 32.91425023263946}], 
             PointBox[{39.8, 36.920190713335614`}], 
             PointBox[{39.9, 41.126227437322086`}], 
             PointBox[{40., 40.76181570577319}], 
             PointBox[{40.1, 41.56050608872101}], 
             PointBox[{40.2, 44.508703605599294`}], 
             PointBox[{40.3, 43.80776626326406}], 
             PointBox[{40.4, 43.53354266176757}], 
             PointBox[{40.5, 46.60933311527697}], 
             PointBox[{40.6, 47.867224498339056`}], 
             PointBox[{40.7, 46.86922710681756}], 
             PointBox[{40.8, 49.606731919811864`}], 
             PointBox[{40.9, 53.90448265860323}], 
             PointBox[{41., 53.85414450599637}], 
             PointBox[{41.1, 54.14835719943221}], 
             PointBox[{41.2, 56.7622408063944}], 
             PointBox[{41.3, 56.60438405377499}], 
             PointBox[{41.4, 55.832341884684865`}], 
             PointBox[{41.5, 58.59304356098073}], 
             PointBox[{41.6, 60.09385680848209}], 
             PointBox[{41.7, 59.13267812961931}], 
             PointBox[{41.8, 60.808092730621865`}], 
             PointBox[{41.9, 64.773712250877}], 
             PointBox[{42., 65.05466783096199}], 
             PointBox[{42.1, 64.95586343168179}], 
             PointBox[{42.2, 67.10110095044365}], 
             PointBox[{42.3, 67.39030069537694}], 
             PointBox[{42.4, 66.24400585806507}], 
             PointBox[{42.5, 68.61785779154525}], 
             PointBox[{42.6, 70.2141162527987}], 
             PointBox[{42.7, 69.363504149871}], 
             PointBox[{42.8, 70.19592362814001}], 
             PointBox[{42.9, 73.66383269320795}], 
             PointBox[{43., 74.17327697343353}], 
             PointBox[{43.1, 73.7855213476978}], 
             PointBox[{43.2, 75.4194463261374}], 
             PointBox[{43.3, 75.99432293211794}], 
             PointBox[{43.4, 74.58206683376193}], 
             PointBox[{43.5, 76.55663837999964}], 
             PointBox[{43.6, 78.10870237720883}], 
             PointBox[{43.7, 77.35735928756912}], 
             PointBox[{43.8, 77.55536060764643}], 
             PointBox[{43.9, 80.53193984694008}], 
             PointBox[{44., 81.0992848788228}], 
             PointBox[{44.1, 80.49667513369059}], 
             PointBox[{44.2, 81.64968041177053}], 
             PointBox[{44.3, 82.32668760652086}], 
             PointBox[{44.4, 80.72712818218861}], 
             PointBox[{44.5, 82.33197036339334}], 
             PointBox[{44.6, 83.72539959296046}], 
             PointBox[{44.7, 83.00395910324005}], 
             PointBox[{44.8, 82.7520233914911}], 
             PointBox[{44.9, 85.30217743190951}], 
             PointBox[{45., 85.76789393429135}], 
             PointBox[{45.1, 84.9894619394654}], 
             PointBox[{45.2, 85.7345699882062}], 
             PointBox[{45.3, 86.34078312444399}], 
             PointBox[{45.4, 84.60286885871028}], 
             PointBox[{45.5, 85.89033738798389}], 
             PointBox[{45.6, 87.03825119775138}], 
             PointBox[{45.7, 86.24850604558378}], 
             PointBox[{45.8, 85.70308858283533}], 
             PointBox[{45.9, 87.88853118771658}], 
             PointBox[{46., 88.13467298868636}], 
             PointBox[{46.1, 87.1931545415573}], 
             PointBox[{46.2, 87.621563830784}], 
             PointBox[{46.3, 88.0054728688483}], 
             PointBox[{46.4, 86.16592915978981}], 
             PointBox[{46.5, 87.19299540638895}], 
             PointBox[{46.6, 88.03028789920063}], 
             PointBox[{46.7, 87.06883796270995}], 
             PointBox[{46.8, 86.37071419984568}], 
             PointBox[{46.9, 88.23503576411167}], 
             PointBox[{47., 88.16613997840614}], 
             PointBox[{47.1, 87.06590378731926}], 
             PointBox[{47.2, 87.27269181630982}], 
             PointBox[{47.3, 87.29330554382614}], 
             PointBox[{47.4, 85.40755500528758}], 
             PointBox[{47.5, 86.21841854814556}], 
             PointBox[{47.6, 86.69347369629395}], 
             PointBox[{47.7, 85.4667387179652}], 
             PointBox[{47.8, 84.76695338569698}], 
             PointBox[{47.9, 86.32375945066451}], 
             PointBox[{48., 85.84571507307555}], 
             PointBox[{48.1, 84.60267905056389}], 
             PointBox[{48.2, 84.67916889396292}], 
             PointBox[{48.3, 84.18798587327183}], 
             PointBox[{48.4, 82.3615332536283}], 
             PointBox[{48.5, 82.9713986019633}], 
             PointBox[{48.6, 83.03999493285664}], 
             PointBox[{48.7, 81.4779105732232}], 
             PointBox[{48.8, 80.95867612092843}], 
             PointBox[{48.9, 82.15723542084015}], 
             PointBox[{49., 81.19595081483567}], 
             PointBox[{49.1, 79.85276738197717}], 
             PointBox[{49.2, 79.87589158407354}], 
             PointBox[{49.3, 78.71781249122432}], 
             PointBox[{49.4, 77.11216041820444}], 
             PointBox[{49.5, 77.49751744839159}], 
             PointBox[{49.6, 77.12014570874453}], 
             PointBox[{49.7, 75.1958976876922}], 
             PointBox[{49.8, 75.05686723106191}], 
             PointBox[{49.9, 75.74133892944519}], 
             PointBox[{50., 74.30669624809525}], 
             PointBox[{50.1, 72.93750538244785}], 
             PointBox[{50.2, 72.94166019432305}], 
             PointBox[{50.3, 71.01335317850317}], 
             PointBox[{50.4, 69.79392188493512}], 
             PointBox[{50.5, 69.89709091882105}], 
             PointBox[{50.6, 69.03981750179082}], 
             PointBox[{50.7, 66.81121081641322}], 
             PointBox[{50.8, 67.19708784046816}], 
             PointBox[{50.9, 67.1405077071613}], 
             PointBox[{51., 65.35742545192625}], 
             PointBox[{51.1, 64.06113180870307}], 
             PointBox[{51.2, 63.97962312322488}], 
             PointBox[{51.3, 61.35765130716027}], 
             PointBox[{51.4, 60.585418238537386`}], 
             PointBox[{51.5, 60.33420289341302}], 
             PointBox[{51.6, 58.97471906667488}], 
             PointBox[{51.7, 56.65496051017544}], 
             PointBox[{51.8, 57.5365079459516}], 
             PointBox[{51.9, 56.559841701280675`}], 
             PointBox[{52., 54.6178390278219}], 
             PointBox[{52.1, 53.50088000026153}], 
             PointBox[{52.2, 53.092876299364434`}], 
             PointBox[{52.3, 50.15162898696144}], 
             PointBox[{52.4, 49.704846962522424`}], 
             PointBox[{52.5, 49.03735564449744}], 
             PointBox[{52.6, 47.177745915389096`}], 
             PointBox[{52.7, 45.20451984160172}], 
             PointBox[{52.8, 46.1558469636293}], 
             PointBox[{52.9, 44.343113065871876`}], 
             PointBox[{53., 42.43086725815374}], 
             PointBox[{53.1, 41.57538922286767}], 
             PointBox[{53.2, 40.44046729360707}], 
             PointBox[{53.3, 37.78933113334642}], 
             PointBox[{53.4, 37.411091020207095`}], 
             PointBox[{53.5, 36.292721155739855`}], 
             PointBox[{53.6, 33.99567865672725}], 
             PointBox[{53.7, 32.93870110135322}], 
             PointBox[{53.8, 33.16663319307554}], 
             PointBox[{53.9, 30.909137129900046`}], 
             PointBox[{54., 29.18350405631645}], 
             PointBox[{54.1, 28.58596776377817}], 
             PointBox[{54.2, 26.422181634625304`}], 
             PointBox[{54.3, 24.569956420375092`}], 
             PointBox[{54.4, 24.00415399223857}], 
             PointBox[{54.5, 22.43510855564091}], 
             PointBox[{54.6, 19.898605244809005`}], 
             PointBox[{54.7, 20.044178801843373`}], 
             PointBox[{54.8, 19.003687489377626`}], 
             PointBox[{54.9, 16.698854722133547`}], 
             PointBox[{55., 15.276891444147623`}], 
             PointBox[{55.1, 14.75518949180696}], 
             PointBox[{55.2, 11.74976426500507}], 
             PointBox[{55.3, 10.734746637892385`}], 
             PointBox[{55.4, 9.824196750851115}], 
             PointBox[{55.5, 7.847002058340877}], 
             PointBox[{55.6, 5.512198791613628}], 
             PointBox[{55.7, 6.350818648650602}], 
             PointBox[{55.8, 4.2405703645563335`}], 
             PointBox[{55.9, 2.148051242431393}], 
             PointBox[{56., 1.0967981760331895`}], 
             PointBox[{56.1, 0.23901942974771373`}], 
             PointBox[{56.2, -2.882226340312627}], 
             PointBox[{56.3, -3.4546867872340954`}], 
             PointBox[{56.4, -4.7552781884223805`}], 
             PointBox[{56.5, -7.035353144987312}], 
             PointBox[{56.6, -8.492478055864922}], 
             PointBox[{56.7, -8.06716599133506}], 
             PointBox[{56.8, -10.5899559636091}], 
             PointBox[{56.9, -12.327228864618519`}], 
             PointBox[{57., -13.017817582840507`}], 
             PointBox[{57.1, -14.67697153131303}], 
             PointBox[{57.2, -17.103251893568086`}], 
             PointBox[{57.3, -17.679348032121197`}], 
             PointBox[{57.4, -19.331870288624486`}], 
             PointBox[{57.5, -21.70081531481992}], 
             PointBox[{57.6, -21.839756797948212`}], 
             PointBox[{57.7, -22.612603617832065`}], 
             PointBox[{57.8, -25.02330706869543}], 
             PointBox[{57.9, -26.335837006525253`}], 
             PointBox[{58., -26.79367972289765}], 
             PointBox[{58.1, -29.355378852844296`}], 
             PointBox[{58.2, -30.74128648709302}], 
             PointBox[{58.3, -31.56743436421675}], 
             PointBox[{58.4, -33.47648599333479}], 
             PointBox[{58.5, -35.56043651559594}], 
             PointBox[{58.6, -34.74917897461273}], 
             PointBox[{58.7, -36.617004686522705`}], 
             PointBox[{58.8, -38.649535838987504`}], 
             PointBox[{58.9, -39.517582497603144`}], 
             PointBox[{59., -40.00338433821162}], 
             PointBox[{59.1, -43.012381589498546`}], 
             PointBox[{59.2, -43.59399365790159}], 
             PointBox[{59.3, -44.71750165299454}], 
             PointBox[{59.4, -46.73915249011043}], 
             PointBox[{59.5, -48.063403019819816`}], 
             PointBox[{59.6, -47.18210597871075}], 
             PointBox[{59.7, -49.54976678971434}], 
             PointBox[{59.8, -51.10312144704221}], 
             PointBox[{59.9, -51.55001405627263}], 
             PointBox[{60., -52.37718648790178}], 
             PointBox[{60.1, -55.143672005608096`}], 
             PointBox[{60.2, -55.36706118557777}], 
             PointBox[{60.3, -56.72374003351433}], 
             PointBox[{60.4, -58.665506706020096`}], 
             PointBox[{60.5, -58.980821720040694`}], 
             PointBox[{60.6, -58.67112351234391}], 
             PointBox[{60.7, -61.00888331852184}], 
             PointBox[{60.8, -62.0603888948026}], 
             PointBox[{60.9, -62.150773936649784`}], 
             PointBox[{61., -63.51235991388239}], 
             PointBox[{61.1, -65.54655076721247}], 
             PointBox[{61.2, -65.71967266332649}], 
             PointBox[{61.3, -67.2017597284721}], 
             PointBox[{61.4, -68.83671719770791}], 
             PointBox[{61.5, -68.27857772193238}], 
             PointBox[{61.6, -68.661048819813}], 
             PointBox[{61.7, -70.68538060432911}], 
             PointBox[{61.8, -71.24660949384997}], 
             PointBox[{61.9, -71.07192708072398}], 
             PointBox[{62., -72.92839409922453}], 
             PointBox[{62.1, -74.09692125388392}], 
             PointBox[{62.2, -74.32502849379671}], 
             PointBox[{62.3, -75.819273479603}], 
             PointBox[{62.4, -76.95230496906879}], 
             PointBox[{62.5, -75.81592522317806}], 
             PointBox[{62.6, -76.73334190425521}], 
             PointBox[{62.7, -78.34740885146311}], 
             PointBox[{62.8, -78.44500724624231}], 
             PointBox[{62.9, -78.0948688611461}], 
             PointBox[{63., -80.23877870236174}], 
             PointBox[{63.1, -80.6522929182538}], 
             PointBox[{63.2, -80.91425067311502}], 
             PointBox[{63.3, -82.32416698278394}], 
             PointBox[{63.4, -82.88695445162739}], 
             PointBox[{63.5, -81.42114675058838}], 
             PointBox[{63.6, -82.62836155157856}], 
             PointBox[{63.7, -83.83539896724687}], 
             PointBox[{63.8, -83.50281246842496}], 
             PointBox[{63.9, -83.03221486246184}], 
             PointBox[{64., -85.24137813023845}], 
             PointBox[{64.1, -85.07656643769587}], 
             PointBox[{64.2, -85.29894287737989}], 
             PointBox[{64.3, -86.56057523363415}], 
             PointBox[{64.4, -86.61809246201301}], 
             PointBox[{64.5, -84.91733434099297}], 
             PointBox[{64.6, -86.20256944821449}], 
             PointBox[{64.7, -87.05553273868281}], 
             PointBox[{64.8, -86.32829048785061}], 
             PointBox[{64.9, -85.7405692650209}], 
             PointBox[{65., -87.87595004290051}], 
             PointBox[{65.1, -87.27818426081649}], 
             PointBox[{65.2, -87.3729866013382}], 
             PointBox[{65.3, -88.46157125740865}], 
             PointBox[{65.4, -88.11615268806054}], 
             PointBox[{65.5, -86.1666117673376}], 
             PointBox[{65.6, -87.38762251198932}], 
             PointBox[{65.7, -87.96674054120376}], 
             PointBox[{65.8, -86.8809380907478}], 
             PointBox[{65.9, -86.13339244770759}], 
             PointBox[{66., -88.14931314172281}], 
             PointBox[{66.1, -87.22253652317886}], 
             PointBox[{66.2, -87.09919118199468}], 
             PointBox[{66.3, -88.02231427924562}], 
             PointBox[{66.4, -87.3562917260424}], 
             PointBox[{66.5, -85.1002026587521}], 
             PointBox[{66.6, -86.16003646296303}], 
             PointBox[{66.7, -86.56431767453614}], 
             PointBox[{66.8, -85.16019755640446}], 
             PointBox[{66.9, -84.18102971206827}], 
             PointBox[{67., -86.0878579268392}], 
             PointBox[{67.1, -84.92359413334634}], 
             PointBox[{67.2, -84.48898944556277}], 
             PointBox[{67.3, -85.26840893252665}], 
             PointBox[{67.4, -84.35264992943121}], 
             PointBox[{67.5, -81.71427059629787}], 
             PointBox[{67.6, -82.5210180070062}], 
             PointBox[{67.7, -82.86148355232581}], 
             PointBox[{67.8, -81.19010425706074}], 
             PointBox[{67.9, -79.89792692573246}], 
             PointBox[{68., -81.7173581438692}], 
             PointBox[{68.1, -80.4279861615214}], 
             PointBox[{68.2, -79.58674077781325}], 
             PointBox[{68.3, -80.23506753165566}], 
             PointBox[{68.4, -79.16778998295922}], 
             PointBox[{68.5, -76.05870376784878}], 
             PointBox[{68.6, -76.49120747015695}], 
             PointBox[{68.7, -76.88024559374753}], 
             PointBox[{68.8, -75.01486606043909}], 
             PointBox[{68.9, -73.3339759862356}], 
             PointBox[{69., -75.0625259431763}], 
             PointBox[{69.1, -73.80075950654282}], 
             PointBox[{69.2, -72.46431975453015}], 
             PointBox[{69.3, -72.96421977793943}], 
             PointBox[{69.4, -71.91288203480508}], 
             PointBox[{69.5, -68.23183946485369}], 
             PointBox[{69.6, -68.12028367057792}], 
             PointBox[{69.7, -68.65196691562596}], 
             PointBox[{69.8, -66.69664471256692}], 
             PointBox[{69.9, -64.57335370849614}], 
             PointBox[{70., -66.16100026083586}], 
             PointBox[{70.1, -65.11616699409205}], 
             PointBox[{70.2, -63.224259936469025`}], 
             PointBox[{70.3, -63.51623536564148}], 
             PointBox[{70.4, -62.70949948429188}], 
             PointBox[{70.5, -58.386924687816645`}], 
             PointBox[{70.6, -57.513660056793015`}], 
             PointBox[{70.7, -58.23478958016494}], 
             PointBox[{70.8, -56.326018380095775`}], 
             PointBox[{70.9, -53.747106421913486`}], 
             PointBox[{71., -55.09445036406396}], 
             PointBox[{71.1, -54.46169008901052}], 
             PointBox[{71.2, -52.01433242287021}], 
             PointBox[{71.3, -51.99923661144567}], 
             PointBox[{71.4, -51.62703400901228}], 
             PointBox[{71.5, -46.758755757640756`}], 
             PointBox[{71.6, -44.87600640147866}], 
             PointBox[{71.7, -45.75591101851023}], 
             PointBox[{71.8, -44.04992375570873}], 
             PointBox[{71.9, -41.06260094777099}], 
             PointBox[{72., -42.034604064065206`}], 
             PointBox[{72.1, -41.96664008317748}], 
             PointBox[{72.2, -39.05280166781449}], 
             PointBox[{72.3, -38.61208603285195}], 
             PointBox[{72.4, -38.719408762452076`}], 
             PointBox[{72.5, -33.699828610122495`}], 
             PointBox[{72.6, -30.561556359294627`}], 
             PointBox[{72.7, -31.473716163178324`}], 
             PointBox[{72.8, -30.118262735079043`}], 
             PointBox[{72.9, -26.844345400451857`}], 
             PointBox[{73., -27.29748283544177}], 
             PointBox[{73.1, -27.86013616253331}], 
             PointBox[{73.2, -24.663236567583226`}], 
             PointBox[{73.3, -23.694022881769342`}], 
             PointBox[{73.4, -24.176640174431668`}], 
             PointBox[{73.5, -19.66370039871981}], 
             PointBox[{73.6, -15.108544062946748`}], 
             PointBox[{73.7, -15.835831851203693`}], 
             PointBox[{73.8, -14.932255150517449`}], 
             PointBox[{73.9, -11.56630322347337}], 
             PointBox[{74., -11.382616415670782`}], 
             PointBox[{74.1, -12.534690979271545`}], 
             PointBox[{74.2, -9.303733877568447}], 
             PointBox[{74.3, -7.759402742951352}], 
             PointBox[{74.4, -8.425736909674015}], 
             PointBox[{74.5, -5.03931724310678}], 
             PointBox[{74.6, 0.7796146801338182}], 
             PointBox[{74.7, 0.5111743062807363}], 
             PointBox[{74.8, 0.937780172956991}], 
             PointBox[{74.9, 4.155513135905494}], 
             PointBox[{75., 5.030805919348495}], 
             PointBox[{75.1, 3.424795470382378}], 
             PointBox[{75.2, 6.430339239333989}], 
             PointBox[{75.3, 8.511515975631482}], 
             PointBox[{75.4, 7.875534531784069}], 
             PointBox[{75.5, 9.914155923572253}], 
             PointBox[{75.6, 16.33990316346899}], 
             PointBox[{75.7, 16.799913316383027`}], 
             PointBox[{75.8, 16.80728201039892}], 
             PointBox[{75.9, 19.643949029341456`}], 
             PointBox[{76., 21.174552393444174`}], 
             PointBox[{76.1, 19.30920500974753}], 
             PointBox[{76.2, 21.87730918147281}], 
             PointBox[{76.3, 24.371668404761294`}], 
             PointBox[{76.4, 23.94714476099034}], 
             PointBox[{76.5, 24.78829520959698}], 
             PointBox[{76.6, 30.935909435211215`}], 
             PointBox[{76.7, 32.2878736427956}], 
             PointBox[{76.8, 31.996846479065425`}], 
             PointBox[{76.9, 34.28129126793647}], 
             PointBox[{77., 36.33006152973394}], 
             PointBox[{77.1, 34.4129544929674}], 
             PointBox[{77.2, 36.41384623470367}], 
             PointBox[{77.3, 39.142126974256826`}], 
             PointBox[{77.4, 39.03740900943376}], 
             PointBox[{77.5, 38.97723051444336}], 
             PointBox[{77.6, 44.22055926048051}], 
             PointBox[{77.7, 46.38130164986069}], 
             PointBox[{77.8, 45.93733375177544}], 
             PointBox[{77.9, 47.59426394703769}], 
             PointBox[{78., 49.946403481917514`}], 
             PointBox[{78.1, 48.154753647671896`}], 
             PointBox[{78.2, 49.54681522025203}], 
             PointBox[{78.3, 52.318912994727725`}], 
             PointBox[{78.4, 52.55231782262854}], 
             PointBox[{78.5, 51.895881869320874`}], 
             PointBox[{78.6, 56.07583986209647}], 
             PointBox[{78.7, 58.68550041766866}], 
             PointBox[{78.8, 58.21677506648848}], 
             PointBox[{78.9, 59.26320435219532}], 
             PointBox[{79., 61.676985291429446`}], 
             PointBox[{79.1, 60.122202345883125`}], 
             PointBox[{79.2, 60.93552407245443}], 
             PointBox[{79.3, 63.58943204804382}], 
             PointBox[{79.4, 64.0989848280733}], 
             PointBox[{79.5, 63.097807476791786`}], 
             PointBox[{79.6, 66.33195174665889}], 
             PointBox[{79.7, 68.98007425346441}], 
             PointBox[{79.8, 68.56273809693812}], 
             PointBox[{79.9, 69.07623389107903}], 
             PointBox[{80., 71.34258682732616}], 
             PointBox[{80.1, 70.05150323878479}], 
             PointBox[{80.2, 70.36257719259447}], 
             PointBox[{80.3, 72.78475176409847}], 
             PointBox[{80.4, 73.45704217811726}], 
             PointBox[{80.5, 72.28095767627383}], 
             PointBox[{80.6, 74.73125267326395}], 
             PointBox[{80.7, 77.16385105221707}], 
             PointBox[{80.8, 76.80418057343195}], 
             PointBox[{80.9, 76.88595256872213}], 
             PointBox[{81., 78.86576794715802}], 
             PointBox[{81.1, 77.78260722998675}], 
             PointBox[{81.2, 77.69079318122385}], 
             PointBox[{81.3, 79.81727156120178}], 
             PointBox[{81.4, 80.52139174248441}], 
             PointBox[{81.5, 79.25243234017398}], 
             PointBox[{81.6, 81.07376965701405}], 
             PointBox[{81.7, 83.1913755430287}], 
             PointBox[{81.8, 82.83298932117759}], 
             PointBox[{81.9, 82.5779515192844}], 
             PointBox[{82., 84.2121208025128}], 
             PointBox[{82.1, 83.21830329227669}], 
             PointBox[{82.2, 82.83038829971338}], 
             PointBox[{82.3, 84.63554987313546}], 
             PointBox[{82.4, 85.24615672670916}], 
             PointBox[{82.5, 83.8946557631134}], 
             PointBox[{82.6, 85.24617453373503}], 
             PointBox[{82.7, 87.02591150418448}], 
             PointBox[{82.8, 86.5779614079438}], 
             PointBox[{82.9, 86.06303337056306}], 
             PointBox[{83., 87.35555883373308}], 
             PointBox[{83.1, 86.29812654935085}], 
             PointBox[{83.2, 85.72218919832085}], 
             PointBox[{83.3, 87.2025539872484}], 
             PointBox[{83.4, 87.61216200036142}], 
             PointBox[{83.5, 86.1429175206431}], 
             PointBox[{83.6, 87.1893803762141}], 
             PointBox[{83.7, 88.62541610465269}], 
             PointBox[{83.8, 87.99157821646804}], 
             PointBox[{83.9, 87.27700687110337}], 
             PointBox[{84., 88.26843460027885}], 
             PointBox[{84.1, 86.9864240844181}], 
             PointBox[{84.2, 86.33306035579153}], 
             PointBox[{84.3, 87.49067074922641}], 
             PointBox[{84.4, 87.61055981381651}], 
             PointBox[{84.5, 85.9751130236109}], 
             PointBox[{84.6, 86.87979113996698}], 
             PointBox[{84.7, 87.94750459663192}], 
             PointBox[{84.8, 87.04755038744042}], 
             PointBox[{84.9, 86.18772166500275}], 
             PointBox[{85., 86.92635220049851}], 
             PointBox[{85.1, 85.27712597817299}], 
             PointBox[{85.2, 84.65967925774748}], 
             PointBox[{85.3, 85.48875341186795}], 
             PointBox[{85.4, 85.24638781088288}], 
             PointBox[{85.5, 83.41458339508972}], 
             PointBox[{85.6, 84.32594422891998}], 
             PointBox[{85.7, 84.96137995222671}], 
             PointBox[{85.8, 83.75343539095775}], 
             PointBox[{85.9, 82.80983878677216}], 
             PointBox[{86., 83.31854267528979}], 
             PointBox[{86.1, 81.21772756113205}], 
             PointBox[{86.2, 80.73638336671866}], 
             PointBox[{86.3, 81.21588976879138}], 
             PointBox[{86.4, 80.55182755450369}], 
             PointBox[{86.5, 78.55243399434403}], 
             PointBox[{86.6, 79.57708502919559}], 
             PointBox[{86.7, 79.66686654028308}], 
             PointBox[{86.8, 78.1712503690942}], 
             PointBox[{86.9, 77.22075352064712}], 
             PointBox[{87., 77.45254577241576}], 
             PointBox[{87.1, 74.93837351338152}], 
             PointBox[{87.2, 74.64156346012896}], 
             PointBox[{87.3, 74.73612697925273}], 
             PointBox[{87.4, 73.60400570681668}], 
             PointBox[{87.5, 71.57875872904697}], 
             PointBox[{87.6, 72.73811860134447}], 
             PointBox[{87.7, 72.13546633419901}], 
             PointBox[{87.8, 70.43904979635408}], 
             PointBox[{87.9, 69.5720157816395}], 
             PointBox[{88., 69.3616179590681}], 
             PointBox[{88.1, 66.66333820581349}], 
             PointBox[{88.2, 66.5055989560351}], 
             PointBox[{88.3, 66.17462735049776}], 
             PointBox[{88.4, 64.5492331997084}], 
             PointBox[{88.5, 62.80030650997651}], 
             PointBox[{88.6, 63.90824498410075}], 
             PointBox[{88.7, 62.54987058287952}], 
             PointBox[{88.8, 60.78255209416966}], 
             PointBox[{88.9, 60.083173639803135`}], 
             PointBox[{89., 59.14688074027072}], 
             PointBox[{89.1, 56.67377250406571}], 
             PointBox[{89.2, 56.51436606593779}], 
             PointBox[{89.3, 55.723212415745365`}], 
             PointBox[{89.4, 53.624250026572554`}], 
             PointBox[{89.5, 52.571432246637414`}], 
             PointBox[{89.6, 53.134365831210744`}], 
             PointBox[{89.7, 51.202974704770895`}], 
             PointBox[{89.8, 49.5067127753282}], 
             PointBox[{89.9, 49.00513116169168}], 
             PointBox[{90., 47.092126970346726`}], 
             PointBox[{90.1, 45.24976145830442}], 
             PointBox[{90.2, 44.909078589269484`}], 
             PointBox[{90.3, 43.63916968758713}], 
             PointBox[{90.4, 41.18989501368924}], 
             PointBox[{90.5, 41.13853291957639}], 
             PointBox[{90.6, 40.64471890737332}], 
             PointBox[{90.7, 38.46605016911781}], 
             PointBox[{90.8, 36.97265413424611}], 
             PointBox[{90.9, 36.55588787038141}], 
             PointBox[{91., 33.746163691168476`}], 
             PointBox[{91.1, 32.650416798693186`}], 
             PointBox[{91.2, 31.98150201592216}], 
             PointBox[{91.3, 30.240096635825466`}], 
             PointBox[{91.4, 27.7708053868555}], 
             PointBox[{91.5, 28.53935409313999}], 
             PointBox[{91.6, 26.89208789888653}], 
             PointBox[{91.7, 24.750155662099132`}], 
             PointBox[{91.8, 23.562001433907426`}], 
             PointBox[{91.9, 22.887057706000633`}], 
             PointBox[{92., 19.75087521300884}], 
             PointBox[{92.1, 19.13883380747575}], 
             PointBox[{92.2, 18.06526782309811}], 
             PointBox[{92.3, 15.905771999285207`}], 
             PointBox[{92.4, 14.023455862610717`}], 
             PointBox[{92.5, 14.731486716264044`}], 
             PointBox[{92.6, 12.38937793642981}], 
             PointBox[{92.7, 10.476934772959794`}], 
             PointBox[{92.8, 9.635834950619028}], 
             PointBox[{92.9, 8.208124206692446}], 
             PointBox[{93., 5.553949941138853}], 
             PointBox[{93.1, 5.014270462750574}], 
             PointBox[{93.2, 3.530091582928435}], 
             PointBox[{93.3, 1.0957175437361002`}], 
             PointBox[{93.4, 0.4361454416648485}], 
             PointBox[{93.5, 0.09298899385612458}], 
             PointBox[{93.6, -2.376160098152468}], 
             PointBox[{93.7, -3.9413225070165936`}], 
             PointBox[{93.8, -4.511350700064213}], 
             PointBox[{93.9, -6.943588894500863}], 
             PointBox[{94., -8.613558356519206}], 
             PointBox[{94.1, -9.379179945171927}], 
             PointBox[{94.2, -11.221971190432669`}], 
             PointBox[{94.3, -13.621843407890992`}], 
             PointBox[{94.4, -13.083284266598639`}], 
             PointBox[{94.5, -14.723097323483671`}], 
             PointBox[{94.6, -16.95972929627169}], 
             PointBox[{94.7, -18.116413280848064`}], 
             PointBox[{94.8, -18.66655892280687}], 
             PointBox[{94.9, -21.747680964763276`}], 
             PointBox[{95., -22.554945643612882`}], 
             PointBox[{95.1, -23.658694215249852`}], 
             PointBox[{95.2, -25.753419895510888`}], 
             PointBox[{95.3, -27.59400733676739}], 
             PointBox[{95.4, -26.732374201747007`}], 
             PointBox[{95.5, -29.120802446836024`}], 
             PointBox[{95.6, -30.95385167223867}], 
             PointBox[{95.7, -31.695939255325356`}], 
             PointBox[{95.8, -32.61960036121309}], 
             PointBox[{95.9, -35.57221460832807}], 
             PointBox[{96., -35.99590884640929}], 
             PointBox[{96.1, -37.41547052831447}], 
             PointBox[{96.2, -39.587759082511184`}], 
             PointBox[{96.3, -40.35083482024493}], 
             PointBox[{96.4, -40.13562787391129}], 
             PointBox[{96.5, -42.62133022068883}], 
             PointBox[{96.6, -43.9849992939271}], 
             PointBox[{96.7, -44.37138838370447}], 
             PointBox[{96.8, -45.986917936155805`}], 
             PointBox[{96.9, -48.151284758292604`}], 
             PointBox[{97., -48.58781223098049}], 
             PointBox[{97.1, -50.2297033881332}], 
             PointBox[{97.2, -52.2194336989196}], 
             PointBox[{97.3, -51.87063945343834}], 
             PointBox[{97.4, -52.64273147865606}], 
             PointBox[{97.5, -54.83396982126578}], 
             PointBox[{97.6, -55.71485039898835}], 
             PointBox[{97.7, -55.87204841393395}], 
             PointBox[{97.8, -58.16743901094014}], 
             PointBox[{97.9, -59.34137183110579}], 
             PointBox[{98., -59.95279225950071}], 
             PointBox[{98.1, -61.6908431250049}], 
             PointBox[{98.2, -63.18307205416204}], 
             PointBox[{98.3, -62.148574523685966`}], 
             PointBox[{98.4, -63.697823404407245`}], 
             PointBox[{98.5, -65.43483996475697}], 
             PointBox[{98.6, -65.8475646727602}], 
             PointBox[{98.7, -65.94279496376112}], 
             PointBox[{98.8, -68.58063818384835}], 
             PointBox[{98.9, -68.94650656619342}], 
             PointBox[{99., -69.72851319692563}], 
             PointBox[{99.1, -71.42527238656476}], 
             PointBox[{99.2, -72.19922458662768}], 
             PointBox[{99.3, -70.986122123737}], 
             PointBox[{99.4, -72.91377991062473}], 
             PointBox[{99.5, -74.16123153734952}], 
             PointBox[{99.6, -74.13682160257304}], 
             PointBox[{99.7, -74.31529490067624}], 
             PointBox[{99.8, -76.88728089860524}], 
             PointBox[{99.9, -76.72755864882492}], 
             PointBox[{100., -77.6044705388922}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {-180, 180}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-328., 0}},
       PlotRangePadding->{6, 5}], {570, -176.}, ImageScaled[{0.5, 0.5}], {360, 312.},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {
     InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
            {Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
            {RGBColor[0.368417, 0.506779, 0.709798], 
             PointBox[{0, 0.6378370000000001}], 
             PointBox[{0.1, 0.6368821941042105}], 
             PointBox[{0.2, 0.6377376120620503}], 
             PointBox[{0.3, 0.6396055726512849}], 
             PointBox[{0.4, 0.6415525161395735}], 
             PointBox[{0.5, 0.6426191389595117}], 
             PointBox[{0.6, 0.6421590516526469}], 
             PointBox[{0.7, 0.6405839236206406}], 
             PointBox[{0.8, 0.638625423643196}], 
             PointBox[{0.9, 0.6370250314374283}], 
             PointBox[{1., 0.6372895105942552}], 
             PointBox[{1.1, 0.6371783567680237}], 
             PointBox[{1.2, 0.63698513254673}], 
             PointBox[{1.3, 0.6384229416194981}], 
             PointBox[{1.4, 0.6405201594590314}], 
             PointBox[{1.5, 0.6421756607824674}], 
             PointBox[{1.6, 0.6423266992496549}], 
             PointBox[{1.7, 0.6412091475334563}], 
             PointBox[{1.8, 0.6394453866905508}], 
             PointBox[{1.9, 0.6374799772506322}], 
             PointBox[{2., 0.6365833894925275}], 
             PointBox[{2.1, 0.6375619397472995}], 
             PointBox[{2.2, 0.636533499314694}], 
             PointBox[{2.3, 0.6372393393555231}], 
             PointBox[{2.4, 0.6391552119769092}], 
             PointBox[{2.5, 0.6412892917115302}], 
             PointBox[{2.6, 0.6420822917462217}], 
             PointBox[{2.7, 0.6414284911208689}], 
             PointBox[{2.8, 0.6400101071223698}], 
             PointBox[{2.9, 0.6380484245494241}], 
             PointBox[{3., 0.6363010865542043}], 
             PointBox[{3.1, 0.6369622029248629}], 
             PointBox[{3.2, 0.6364825903520982}], 
             PointBox[{3.3, 0.6362317377132519}], 
             PointBox[{3.4, 0.6376386975028734}], 
             PointBox[{3.5, 0.6399876350053509}], 
             PointBox[{3.6, 0.641455840289929}], 
             PointBox[{3.7, 0.6412654671930236}], 
             PointBox[{3.8, 0.6402156970466175}], 
             PointBox[{3.9, 0.6385188526645547}], 
             PointBox[{4., 0.6363543410812561}], 
             PointBox[{4.1, 0.6358262831735159}], 
             PointBox[{4.2, 0.6366646408431473}], 
             PointBox[{4.3, 0.6355093233282294}], 
             PointBox[{4.4, 0.636176038723186}], 
             PointBox[{4.5, 0.638366738255963}], 
             PointBox[{4.6, 0.6404708872978255}], 
             PointBox[{4.7, 0.6407769817733724}], 
             PointBox[{4.8, 0.6400553374157109}], 
             PointBox[{4.9, 0.6387234362017401}], 
             PointBox[{5., 0.6365561151353738}], 
             PointBox[{5.1, 0.6349672124954112}], 
             PointBox[{5.2, 0.6362649388308609}], 
             PointBox[{5.3, 0.6351132855392743}], 
             PointBox[{5.4, 0.6349119354127855}], 
             PointBox[{5.5, 0.6365997451500864}], 
             PointBox[{5.6, 0.6391528793870231}], 
             PointBox[{5.7, 0.6400221368720591}], 
             PointBox[{5.8, 0.639583377928648}], 
             PointBox[{5.9, 0.6385919033921716}], 
             PointBox[{6., 0.6367099279964682}], 
             PointBox[{6.1, 0.634436731686783}], 
             PointBox[{6.2, 0.6349969605687896}], 
             PointBox[{6.3, 0.6349731226359135}], 
             PointBox[{6.4, 0.6338984882086304}], 
             PointBox[{6.5, 0.6348792523611835}], 
             PointBox[{6.6, 0.6375554785636276}], 
             PointBox[{6.7, 0.6390493255937324}], 
             PointBox[{6.8, 0.6388723050344823}], 
             PointBox[{6.9, 0.6381426048880458}], 
             PointBox[{7., 0.6366554936403538}], 
             PointBox[{7.1, 0.6341122510641799}], 
             PointBox[{7.2, 0.6335967860454036}], 
             PointBox[{7.3, 0.6347658855736237}], 
             PointBox[{7.4, 0.6331133181506099}], 
             PointBox[{7.5, 0.6333308304827215}], 
             PointBox[{7.6, 0.6357753256265269}], 
             PointBox[{7.7, 0.6378929388234724}], 
             PointBox[{7.8, 0.6379842757382002}], 
             PointBox[{7.9, 0.6374359023020705}], 
             PointBox[{8., 0.6363146267550683}], 
             PointBox[{8.1, 0.6338499936668787}], 
             PointBox[{8.2, 0.6323752251955996}], 
             PointBox[{8.3, 0.634041618306399}], 
             PointBox[{8.4, 0.6324769331842103}], 
             PointBox[{8.5, 0.6319744101042133}], 
             PointBox[{8.6, 0.6339364150834332}], 
             PointBox[{8.7, 0.6365780686253828}], 
             PointBox[{8.8, 0.6369603705727558}], 
             PointBox[{8.9, 0.6365286443269608}], 
             PointBox[{9., 0.6356833877928625}], 
             PointBox[{9.1, 0.6335022768864375}], 
             PointBox[{9.2, 0.6312986934798596}], 
             PointBox[{9.3, 0.6327886256504655}], 
             PointBox[{9.4, 0.6318573219133189}], 
             PointBox[{9.5, 0.6307484940175435}], 
             PointBox[{9.6, 0.6321376864356851}], 
             PointBox[{9.7, 0.6351288757122315}], 
             PointBox[{9.8, 0.6358184607230162}], 
             PointBox[{9.9, 0.6354535010340084}], 
             PointBox[{10., 0.634788493633718}], 
             PointBox[{10.1, 0.6329462229030746}], 
             PointBox[{10.2, 0.6302628040228243}], 
             PointBox[{10.3, 0.6313126964088105}], 
             PointBox[{10.4, 0.6310882014802937}], 
             PointBox[{10.5, 0.6295462064243879}], 
             PointBox[{10.6, 0.630409947768004}], 
             PointBox[{10.7, 0.6335737581736183}], 
             PointBox[{10.8, 0.6345546782089312}], 
             PointBox[{10.9, 0.634212796812633}], 
             PointBox[{11., 0.6336485137926294}], 
             PointBox[{11.1, 0.6320990388973408}], 
             PointBox[{11.2, 0.6291446918868412}], 
             PointBox[{11.3, 0.6297812251336906}], 
             PointBox[{11.4, 0.6300228756209993}], 
             PointBox[{11.5, 0.6282456933260367}], 
             PointBox[{11.6, 0.6287183736489472}], 
             PointBox[{11.7, 0.6319460475190027}], 
             PointBox[{11.8, 0.6331479169407643}], 
             PointBox[{11.9, 0.6327822078500893}], 
             PointBox[{12., 0.6322580006825529}], 
             PointBox[{12.1, 0.6309085710392573}], 
             PointBox[{12.2, 0.6278114437555318}], 
             PointBox[{12.3, 0.628208923901719}], 
             PointBox[{12.4, 0.6285649578332296}], 
             PointBox[{12.5, 0.6267329536846631}], 
             PointBox[{12.6, 0.6270019296056918}], 
             PointBox[{12.7, 0.6302866513434161}], 
             PointBox[{12.8, 0.6315664624640235}], 
             PointBox[{12.9, 0.631123408653517}], 
             PointBox[{13., 0.6305941498753396}], 
             PointBox[{13.1, 0.6293356037036151}], 
             PointBox[{13.2, 0.6261391497335607}], 
             PointBox[{13.3, 0.6265683036275512}], 
             PointBox[{13.4, 0.6266565075400478}], 
             PointBox[{13.5, 0.6249501986245575}], 
             PointBox[{13.6, 0.6252316845291926}], 
             PointBox[{13.7, 0.6286542933712179}], 
             PointBox[{13.8, 0.6297794226180365}], 
             PointBox[{13.9, 0.6292067749787863}], 
             PointBox[{14., 0.6286397752789761}], 
             PointBox[{14.1, 0.6273505292955187}], 
             PointBox[{14.2, 0.6240587135005852}], 
             PointBox[{14.3, 0.624832035367987}], 
             PointBox[{14.4, 0.6243146626465939}], 
             PointBox[{14.5, 0.6229470353703107}], 
             PointBox[{14.6, 0.6234811665856057}], 
             PointBox[{14.7, 0.6271310365991609}], 
             PointBox[{14.8, 0.6277804082534083}], 
             PointBox[{14.9, 0.6270515539592055}], 
             PointBox[{15., 0.6264216020933094}], 
             PointBox[{15.1, 0.6249483383599362}], 
             PointBox[{15.2, 0.6216545012039392}], 
             PointBox[{15.3, 0.6228666005952181}], 
             PointBox[{15.4, 0.6217608100673785}], 
             PointBox[{15.5, 0.6209199716835341}], 
             PointBox[{15.6, 0.6219770715864787}], 
             PointBox[{15.7, 0.6257512437785998}], 
             PointBox[{15.8, 0.6256157027561816}], 
             PointBox[{15.9, 0.6247535504235039}], 
             PointBox[{16., 0.6240306691939398}], 
             PointBox[{16.1, 0.6221563277592578}], 
             PointBox[{16.2, 0.6193083629716057}], 
             PointBox[{16.3, 0.620414031126556}], 
             PointBox[{16.4, 0.6194046916112294}], 
             PointBox[{16.5, 0.6191665096766554}], 
             PointBox[{16.6, 0.6210703785379106}], 
             PointBox[{16.7, 0.6243725709402126}], 
             PointBox[{16.8, 0.6233969636139172}], 
             PointBox[{16.9, 0.6224622937983968}], 
             PointBox[{17., 0.6215869027088534}], 
             PointBox[{17.1, 0.6190475941380634}], 
             PointBox[{17.2, 0.6175839804650461}], 
             PointBox[{17.3, 0.6179561725570162}], 
             PointBox[{17.4, 0.617599854439743}], 
             PointBox[{17.5, 0.6179865729085741}], 
             PointBox[{17.6, 0.6210191393796223}], 
             PointBox[{17.7, 0.6227455567432026}], 
             PointBox[{17.8, 0.6212663983615246}], 
             PointBox[{17.9, 0.6203079524056976}], 
             PointBox[{18., 0.6191524552067988}], 
             PointBox[{18.1, 0.6159550231363021}], 
             PointBox[{18.2, 0.6161706092158742}], 
             PointBox[{18.3, 0.6162735015077652}], 
             PointBox[{18.4, 0.6165022994091028}], 
             PointBox[{18.5, 0.6176232877742577}], 
             PointBox[{18.6, 0.6214554158155183}], 
             PointBox[{18.7, 0.6208721996777812}], 
             PointBox[{18.8, 0.6193363031137407}], 
             PointBox[{18.9, 0.6183487173158067}], 
             PointBox[{19., 0.616689533131884}], 
             PointBox[{19.1, 0.6139250076602342}], 
             PointBox[{19.2, 0.6149157028127455}], 
             PointBox[{19.3, 0.6154661276242641}], 
             PointBox[{19.4, 0.6161380093724372}], 
             PointBox[{19.5, 0.6182437235981768}], 
             PointBox[{19.6, 0.6211830307672834}], 
             PointBox[{19.7, 0.6190228707254108}], 
             PointBox[{19.8, 0.6176635946826896}], 
             PointBox[{19.9, 0.6165760410590962}], 
             PointBox[{20., 0.6142287124140207}], 
             PointBox[{20.1, 0.6133250812340196}], 
             PointBox[{20.2, 0.6145512469010037}], 
             PointBox[{20.3, 0.6153759400471794}], 
             PointBox[{20.4, 0.6164983779093506}], 
             PointBox[{20.5, 0.6196543050474951}], 
             PointBox[{20.6, 0.6197377427464078}], 
             PointBox[{20.7, 0.6174363603929506}], 
             PointBox[{20.8, 0.6162715766437855}], 
             PointBox[{20.9, 0.6149653143180662}], 
             PointBox[{21., 0.6124887028201554}], 
             PointBox[{21.1, 0.6134596225958567}], 
             PointBox[{21.2, 0.6148955602634975}], 
             PointBox[{21.3, 0.6158666722635813}], 
             PointBox[{21.4, 0.6175777139853992}], 
             PointBox[{21.5, 0.6206047688118673}], 
             PointBox[{21.6, 0.6179972356845798}], 
             PointBox[{21.7, 0.6162240141388672}], 
             PointBox[{21.8, 0.6151859594853734}], 
             PointBox[{21.9, 0.6135929837249562}], 
             PointBox[{22., 0.612289866515077}], 
             PointBox[{22.1, 0.6144303962139882}], 
             PointBox[{22.2, 0.6157129322097263}], 
             PointBox[{22.3, 0.6168556707921634}], 
             PointBox[{22.4, 0.6192349638801022}], 
             PointBox[{22.5, 0.6198023521738403}], 
             PointBox[{22.6, 0.6166853113302654}], 
             PointBox[{22.7, 0.6154441083570595}], 
             PointBox[{22.8, 0.614478367981673}], 
             PointBox[{22.9, 0.6129150952507539}], 
             PointBox[{23., 0.6135056138835905}], 
             PointBox[{23.1, 0.6157812007282744}], 
             PointBox[{23.2, 0.6168923406061074}], 
             PointBox[{23.3, 0.6182847898854879}], 
             PointBox[{23.4, 0.6207678591110273}], 
             PointBox[{23.5, 0.6182344078778645}], 
             PointBox[{23.6, 0.6160064283898941}], 
             PointBox[{23.7, 0.6151686025736026}], 
             PointBox[{23.8, 0.6143370434002834}], 
             PointBox[{23.9, 0.6131826942877895}], 
             PointBox[{24., 0.6156586221464937}], 
             PointBox[{24.1, 0.6173472358055971}], 
             PointBox[{24.2, 0.6183853022341417}], 
             PointBox[{24.3, 0.6200479945907551}], 
             PointBox[{24.4, 0.6210393629987}], 
             PointBox[{24.5, 0.6172764133145954}], 
             PointBox[{24.6, 0.6159965648249256}], 
             PointBox[{24.7, 0.615523070656417}], 
             PointBox[{24.8, 0.6150621954280004}], 
             PointBox[{24.9, 0.6148187035840136}], 
             PointBox[{25., 0.6179218317912846}], 
             PointBox[{25.1, 0.6191205048027516}], 
             PointBox[{25.2, 0.6201623642498845}], 
             PointBox[{25.3, 0.6218717039915572}], 
             PointBox[{25.4, 0.6202890688393069}], 
             PointBox[{25.5, 0.6172601106630388}], 
             PointBox[{25.6, 0.6166915148754303}], 
             PointBox[{25.7, 0.6166991602696309}], 
             PointBox[{25.8, 0.616230592791863}], 
             PointBox[{25.9, 0.6177534744953066}], 
             PointBox[{26., 0.6201933986858891}], 
             PointBox[{26.1, 0.6211137471922494}], 
             PointBox[{26.2, 0.6221730541647531}], 
             PointBox[{26.3, 0.6233466649247787}], 
             PointBox[{26.4, 0.6199217538024048}], 
             PointBox[{26.5, 0.6180972833631686}], 
             PointBox[{26.6, 0.6181332103983136}], 
             PointBox[{26.7, 0.6187796887048004}], 
             PointBox[{26.8, 0.6177770754410141}], 
             PointBox[{26.9, 0.6208205476152391}], 
             PointBox[{27., 0.6225320461201436}], 
             PointBox[{27.1, 0.6233037473783215}], 
             PointBox[{27.2, 0.6243183078261875}], 
             PointBox[{27.3, 0.6243805943933868}], 
             PointBox[{27.4, 0.6205125304057065}], 
             PointBox[{27.5, 0.6196259373105256}], 
             PointBox[{27.6, 0.6202899864291422}], 
             PointBox[{27.7, 0.6211100997706543}], 
             PointBox[{27.8, 0.6202575107921079}], 
             PointBox[{27.9, 0.6236596111533891}], 
             PointBox[{28., 0.6249193673572453}], 
             PointBox[{28.1, 0.6255993337272274}], 
             PointBox[{28.2, 0.6264618792809796}], 
             PointBox[{28.3, 0.6253789820197578}], 
             PointBox[{28.4, 0.6218650562660589}], 
             PointBox[{28.5, 0.6216152938170858}], 
             PointBox[{28.6, 0.622911449204978}], 
             PointBox[{28.7, 0.623011911928395}], 
             PointBox[{28.8, 0.622993589496773}], 
             PointBox[{28.9, 0.6262183533775482}], 
             PointBox[{29., 0.6272456108910276}], 
             PointBox[{29.1, 0.6278527364983864}], 
             PointBox[{29.2, 0.6284902884103422}], 
             PointBox[{29.3, 0.6266669901533393}], 
             PointBox[{29.4, 0.6236062280017496}], 
             PointBox[{29.5, 0.6237595415219227}], 
             PointBox[{29.6, 0.6255159599168516}], 
             PointBox[{29.7, 0.6247854034432705}], 
             PointBox[{29.8, 0.6254267972415296}], 
             PointBox[{29.9, 0.628446807519961}], 
             PointBox[{30., 0.6293810583672595}], 
             PointBox[{30.1, 0.6299251966647923}], 
             PointBox[{30.2, 0.6303498785031469}], 
             PointBox[{30.3, 0.6282274812502258}], 
             PointBox[{30.4, 0.6254273523376522}], 
             PointBox[{30.5, 0.625768886536013}], 
             PointBox[{30.6, 0.6277278381507403}], 
             PointBox[{30.7, 0.6265170193981321}], 
             PointBox[{30.8, 0.6273795762977129}], 
             PointBox[{30.9, 0.6303082625072424}], 
             PointBox[{31., 0.6312494814668236}], 
             PointBox[{31.1, 0.631748788526517}], 
             PointBox[{31.2, 0.6320323666937845}], 
             PointBox[{31.3, 0.6299230514069473}], 
             PointBox[{31.4, 0.6271658569056597}], 
             PointBox[{31.5, 0.6274799065760456}], 
             PointBox[{31.6, 0.6294895551793358}], 
             PointBox[{31.7, 0.6281469428829469}], 
             PointBox[{31.8, 0.6288756071867547}], 
             PointBox[{31.9, 0.6318032700555837}], 
             PointBox[{32., 0.6328421722265926}], 
             PointBox[{32.1, 0.6333270766239799}], 
             PointBox[{32.2, 0.6335519570365602}], 
             PointBox[{32.3, 0.6316557000368958}], 
             PointBox[{32.4, 0.6287993075705528}], 
             PointBox[{32.5, 0.628879405058549}], 
             PointBox[{32.6, 0.6308634051068065}], 
             PointBox[{32.7, 0.6296828132684388}], 
             PointBox[{32.8, 0.6300182868787623}], 
             PointBox[{32.9, 0.632953236247122}], 
             PointBox[{33., 0.6341847103004981}], 
             PointBox[{33.1, 0.6346976056967016}], 
             PointBox[{33.2, 0.6349288097113828}], 
             PointBox[{33.3, 0.6333739021426958}], 
             PointBox[{33.4, 0.6303900616849893}], 
             PointBox[{33.5, 0.6300520893973324}], 
             PointBox[{33.6, 0.6318746959350477}], 
             PointBox[{33.7, 0.631182946280805}], 
             PointBox[{33.8, 0.6309369164035161}], 
             PointBox[{33.9, 0.6337804257021297}], 
             PointBox[{34., 0.6353013492991334}], 
             PointBox[{34.1, 0.6358981727685175}], 
             PointBox[{34.2, 0.6361820548569637}], 
             PointBox[{34.3, 0.6350366502320451}], 
             PointBox[{34.4, 0.6320249356520862}], 
             PointBox[{34.5, 0.6311236963085813}], 
             PointBox[{34.6, 0.6325581716992518}], 
             PointBox[{34.7, 0.6326926224973746}], 
             PointBox[{34.8, 0.6317682763000914}], 
             PointBox[{34.9, 0.6343109969350901}], 
             PointBox[{35., 0.6361942847576672}], 
             PointBox[{35.1, 0.6369482655330473}], 
             PointBox[{35.2, 0.6373216105020106}], 
             PointBox[{35.3, 0.6365995744523057}], 
             PointBox[{35.4, 0.6337632654703677}], 
             PointBox[{35.5, 0.6322227790827037}], 
             PointBox[{35.6, 0.6330450700092046}], 
             PointBox[{35.7, 0.6341286495692459}], 
             PointBox[{35.8, 0.6326416587716004}], 
             PointBox[{35.9, 0.6345979778354794}], 
             PointBox[{36., 0.6368386966615867}], 
             PointBox[{36.1, 0.6378411259085458}], 
             PointBox[{36.2, 0.6383435557782804}], 
             PointBox[{36.3, 0.6380146092533807}], 
             PointBox[{36.4, 0.6355941631526417}], 
             PointBox[{36.5, 0.6334582154934756}], 
             PointBox[{36.6, 0.6335332320897111}], 
             PointBox[{36.7, 0.6351368348816813}], 
             PointBox[{36.8, 0.6336694095274271}], 
             PointBox[{36.9, 0.6347451200848907}], 
             PointBox[{37., 0.6371955677912002}], 
             PointBox[{37.1, 0.638540089445982}], 
             PointBox[{37.2, 0.63922654820628}], 
             PointBox[{37.3, 0.6392457176465545}], 
             PointBox[{37.4, 0.6374220447369005}], 
             PointBox[{37.5, 0.6348973341548657}], 
             PointBox[{37.6, 0.6341816919760118}], 
             PointBox[{37.7, 0.6354463983903414}], 
             PointBox[{37.8, 0.6349295324394134}], 
             PointBox[{37.9, 0.6349013408729771}], 
             PointBox[{38., 0.6372484699667414}], 
             PointBox[{38.1, 0.6389847312344596}], 
             PointBox[{38.2, 0.6399270872590209}], 
             PointBox[{38.3, 0.6402639201519699}], 
             PointBox[{38.4, 0.6390994853701027}], 
             PointBox[{38.5, 0.6365336148966472}], 
             PointBox[{38.6, 0.6350740376758458}], 
             PointBox[{38.7, 0.6354788925978204}], 
             PointBox[{38.8, 0.636273266270047}], 
             PointBox[{38.9, 0.6352275381949717}], 
             PointBox[{39., 0.637051892886152}], 
             PointBox[{39.1, 0.639110345165442}], 
             PointBox[{39.2, 0.640383190838676}], 
             PointBox[{39.3, 0.6410379761774212}], 
             PointBox[{39.4, 0.6404987151211072}], 
             PointBox[{39.5, 0.638257205708057}], 
             PointBox[{39.6, 0.6362298828113223}], 
             PointBox[{39.7, 0.6357286351840571}], 
             PointBox[{39.8, 0.6369393492742829}], 
             PointBox[{39.9, 0.6358695747552646}], 
             PointBox[{40., 0.6367523396436002}], 
             PointBox[{40.1, 0.6388886752829568}], 
             PointBox[{40.2, 0.6405234818307917}], 
             PointBox[{40.3, 0.6415264917966994}], 
             PointBox[{40.4, 0.6415441737412626}], 
             PointBox[{40.5, 0.6398775541760579}], 
             PointBox[{40.6, 0.6376002830727461}], 
             PointBox[{40.7, 0.6363255815234335}], 
             PointBox[{40.8, 0.636751575505583}], 
             PointBox[{40.9, 0.6368754729402816}], 
             PointBox[{41., 0.636549763830339}], 
             PointBox[{41.1, 0.6383767329200146}], 
             PointBox[{41.2, 0.6402920988940312}], 
             PointBox[{41.3, 0.6416769294427644}], 
             PointBox[{41.4, 0.6422057570799408}], 
             PointBox[{41.5, 0.6412032089222057}], 
             PointBox[{41.6, 0.6390482965209855}], 
             PointBox[{41.7, 0.6372278248143594}], 
             PointBox[{41.8, 0.6366509059699997}], 
             PointBox[{41.9, 0.6376574838968551}], 
             PointBox[{42., 0.6366430826236974}], 
             PointBox[{42.1, 0.6377314534840016}], 
             PointBox[{42.2, 0.6396903931940052}], 
             PointBox[{42.3, 0.6414365037291045}], 
             PointBox[{42.4, 0.6424661734385851}], 
             PointBox[{42.5, 0.6421181038782303}], 
             PointBox[{42.6, 0.6403719529465174}], 
             PointBox[{42.7, 0.6383238774353593}], 
             PointBox[{42.8, 0.6369645318901149}], 
             PointBox[{42.9, 0.6373561142529185}], 
             PointBox[{43., 0.637171422201385}], 
             PointBox[{43.1, 0.637162151529185}], 
             PointBox[{43.2, 0.6388149740613346}], 
             PointBox[{43.3, 0.6407810840327663}], 
             PointBox[{43.4, 0.6423038063383877}], 
             PointBox[{43.5, 0.6425851040992602}], 
             PointBox[{43.6, 0.6413844889372831}], 
             PointBox[{43.7, 0.6394387372829989}], 
             PointBox[{43.8, 0.6376076497669084}], 
             PointBox[{43.9, 0.636900112168161}], 
             PointBox[{44., 0.6377947625038568}], 
             PointBox[{44.1, 0.6368684957344224}], 
             PointBox[{44.2, 0.6378484446118399}], 
             PointBox[{44.3, 0.6397584639291961}], 
             PointBox[{44.4, 0.6416977263044971}], 
             PointBox[{44.5, 0.6426070065050732}], 
             PointBox[{44.6, 0.6419826334050757}], 
             PointBox[{44.7, 0.6403697064885825}], 
             PointBox[{44.8, 0.6384128666180499}], 
             PointBox[{44.9, 0.6368789027354883}], 
             PointBox[{45., 0.637404955319589}], 
             PointBox[{45.1, 0.6369977999284565}], 
             PointBox[{45.2, 0.6369934759136593}], 
             PointBox[{45.3, 0.6385120782279383}], 
             PointBox[{45.4, 0.6406570577711739}], 
             PointBox[{45.5, 0.6421910196785392}], 
             PointBox[{45.6, 0.6421494184454538}], 
             PointBox[{45.7, 0.6409619921638724}], 
             PointBox[{45.8, 0.639175633469927}], 
             PointBox[{45.9, 0.6372054751849825}], 
             PointBox[{46., 0.636550184307351}], 
             PointBox[{46.1, 0.6373816850281375}], 
             PointBox[{46.2, 0.6364123038694907}], 
             PointBox[{46.3, 0.6372428628541283}], 
             PointBox[{46.4, 0.6392622419666455}], 
             PointBox[{46.5, 0.6413415758429246}], 
             PointBox[{46.6, 0.6419144808023586}], 
             PointBox[{46.7, 0.6411571149398431}], 
             PointBox[{46.8, 0.6397040126708143}], 
             PointBox[{46.9, 0.6376874487532309}], 
             PointBox[{47., 0.6360648864859145}], 
             PointBox[{47.1, 0.6370181559825492}], 
             PointBox[{47.2, 0.6362087810296904}], 
             PointBox[{47.3, 0.636132200858116}], 
             PointBox[{47.4, 0.6376848808830179}], 
             PointBox[{47.5, 0.6400800055174716}], 
             PointBox[{47.6, 0.6413173505191707}], 
             PointBox[{47.7, 0.6409773509930071}], 
             PointBox[{47.8, 0.6398851137999391}], 
             PointBox[{47.9, 0.6381106132910229}], 
             PointBox[{48., 0.6359461392471233}], 
             PointBox[{48.1, 0.6358328792728429}], 
             PointBox[{48.2, 0.6363158225249067}], 
             PointBox[{48.3, 0.6352876888882187}], 
             PointBox[{48.4, 0.6361328152070016}], 
             PointBox[{48.5, 0.6384808316214261}], 
             PointBox[{48.6, 0.6403889702575069}], 
             PointBox[{48.7, 0.6404824735302876}], 
             PointBox[{48.8, 0.6397058708152129}], 
             PointBox[{48.9, 0.6382987071122211}], 
             PointBox[{49., 0.6360260649130874}], 
             PointBox[{49.1, 0.6347655956487276}], 
             PointBox[{49.2, 0.6361369800069203}], 
             PointBox[{49.3, 0.6347475400729612}], 
             PointBox[{49.4, 0.6347610526270657}], 
             PointBox[{49.5, 0.6366939826104583}], 
             PointBox[{49.6, 0.6391560927174302}], 
             PointBox[{49.7, 0.6397371973347242}], 
             PointBox[{49.8, 0.6392184377940677}], 
             PointBox[{49.9, 0.638165109488192}], 
             PointBox[{50., 0.6361168584065714}], 
             PointBox[{50.1, 0.6340170361166845}], 
             PointBox[{50.2, 0.6350728855190758}], 
             PointBox[{50.3, 0.6344685938330574}], 
             PointBox[{50.4, 0.6336276396226329}], 
             PointBox[{50.5, 0.6349052617335533}], 
             PointBox[{50.6, 0.6376574420042707}], 
             PointBox[{50.7, 0.6387951003105564}], 
             PointBox[{50.8, 0.6384947293900597}], 
             PointBox[{50.9, 0.6377158815898365}], 
             PointBox[{51., 0.6360499787943298}], 
             PointBox[{51.1, 0.6334959860025249}], 
             PointBox[{51.2, 0.6336143020216917}], 
             PointBox[{51.3, 0.6342480660681247}], 
             PointBox[{51.4, 0.6327078108459221}], 
             PointBox[{51.5, 0.633253006944641}], 
             PointBox[{51.6, 0.635960138101597}], 
             PointBox[{51.7, 0.6376930224301931}], 
             PointBox[{51.8, 0.6375953266689331}], 
             PointBox[{51.9, 0.6370037432403755}], 
             PointBox[{52., 0.635722574047019}], 
             PointBox[{52.1, 0.6330757401101257}], 
             PointBox[{52.2, 0.6322307845962115}], 
             PointBox[{52.3, 0.6337288277788116}], 
             PointBox[{52.4, 0.6319229690313225}], 
             PointBox[{52.5, 0.6317746781494995}], 
             PointBox[{52.6, 0.6341592804753045}], 
             PointBox[{52.7, 0.6364550431207606}], 
             PointBox[{52.8, 0.6365587020395159}], 
             PointBox[{52.9, 0.6360814272636147}], 
             PointBox[{53., 0.635106174902607}], 
             PointBox[{53.1, 0.632618509937603}], 
             PointBox[{53.2, 0.6309687687533064}], 
             PointBox[{53.3, 0.6327268043782986}], 
             PointBox[{53.4, 0.6311517182280066}], 
             PointBox[{53.5, 0.6304202347016228}], 
             PointBox[{53.6, 0.632343530699691}], 
             PointBox[{53.7, 0.6350967601112513}], 
             PointBox[{53.8, 0.6353970441573401}], 
             PointBox[{53.9, 0.634976971662526}], 
             PointBox[{54., 0.6342100157760138}], 
             PointBox[{54.1, 0.6319900445630712}], 
             PointBox[{54.2, 0.6297407253257211}], 
             PointBox[{54.3, 0.6313869105912506}], 
             PointBox[{54.4, 0.6302447106066554}], 
             PointBox[{54.5, 0.6290880992762131}], 
             PointBox[{54.6, 0.6305577690136076}], 
             PointBox[{54.7, 0.6336322625727064}], 
             PointBox[{54.8, 0.6340986322464919}], 
             PointBox[{54.9, 0.6336884953984327}], 
             PointBox[{55., 0.6330436363938228}], 
             PointBox[{55.1, 0.6310820232902464}], 
             PointBox[{55.2, 0.6284319690054089}], 
             PointBox[{55.3, 0.6298910423136845}], 
             PointBox[{55.4, 0.6290559952015061}], 
             PointBox[{55.5, 0.6276628237622026}], 
             PointBox[{55.6, 0.6287947567489443}], 
             PointBox[{55.7, 0.6320807037377227}], 
             PointBox[{55.8, 0.632633596156152}], 
             PointBox[{55.9, 0.6321893029331156}], 
             PointBox[{56., 0.6315989143038508}], 
             PointBox[{56.1, 0.6298129751308962}], 
             PointBox[{56.2, 0.6269244775015973}], 
             PointBox[{56.3, 0.6282996556481185}], 
             PointBox[{56.4, 0.6274758562496601}], 
             PointBox[{56.5, 0.6260479038366829}], 
             PointBox[{56.6, 0.6270314106592997}], 
             PointBox[{56.7, 0.6304689247447928}], 
             PointBox[{56.8, 0.6309625520213042}], 
             PointBox[{56.9, 0.6304429444873648}], 
             PointBox[{57., 0.6298551600582332}], 
             PointBox[{57.1, 0.6281201225636622}], 
             PointBox[{57.2, 0.6251277283363732}], 
             PointBox[{57.3, 0.6265749917659558}], 
             PointBox[{57.4, 0.6254646171385632}], 
             PointBox[{57.5, 0.624213306058185}], 
             PointBox[{57.6, 0.6252864631049925}], 
             PointBox[{57.7, 0.62883455343814}], 
             PointBox[{57.8, 0.6290576132730119}], 
             PointBox[{57.9, 0.6284335419640698}], 
             PointBox[{58., 0.6278060572574864}], 
             PointBox[{58.1, 0.6259595231862323}], 
             PointBox[{58.2, 0.6230514036718161}], 
             PointBox[{58.3, 0.6245654985620246}], 
             PointBox[{58.4, 0.6231229411244326}], 
             PointBox[{58.5, 0.6222501006725392}], 
             PointBox[{58.6, 0.6236986988953941}], 
             PointBox[{58.7, 0.6272049359585601}], 
             PointBox[{58.8, 0.626936952853292}], 
             PointBox[{58.9, 0.6262054843810264}], 
             PointBox[{59., 0.6254943808019762}], 
             PointBox[{59.1, 0.6233237827360981}], 
             PointBox[{59.2, 0.6209161862800888}], 
             PointBox[{59.3, 0.6220631343132715}], 
             PointBox[{59.4, 0.6207414743169101}], 
             PointBox[{59.5, 0.6203884410726306}], 
             PointBox[{59.6, 0.6225447707377053}], 
             PointBox[{59.7, 0.6255384937885694}], 
             PointBox[{59.8, 0.6246910766366028}], 
             PointBox[{59.9, 0.6238778147565397}], 
             PointBox[{60., 0.6230152774916031}], 
             PointBox[{60.1, 0.620283451522961}], 
             PointBox[{60.2, 0.6191173511747001}], 
             PointBox[{60.3, 0.6193822056484993}], 
             PointBox[{60.4, 0.6186880911934678}], 
             PointBox[{60.5, 0.6189443363670019}], 
             PointBox[{60.6, 0.6220848305541293}], 
             PointBox[{60.7, 0.623728598866389}], 
             PointBox[{60.8, 0.622464797805608}], 
             PointBox[{60.9, 0.6215986947689455}], 
             PointBox[{61., 0.6204551441733911}], 
             PointBox[{61.1, 0.6171619799257618}], 
             PointBox[{61.2, 0.6174937923555097}], 
             PointBox[{61.3, 0.6172692988147196}], 
             PointBox[{61.4, 0.6172312611587739}], 
             PointBox[{61.5, 0.6182328741051644}], 
             PointBox[{61.6, 0.6221073058867588}], 
             PointBox[{61.7, 0.6217715712886479}], 
             PointBox[{61.8, 0.6203922844294569}], 
             PointBox[{61.9, 0.6194676139749653}], 
             PointBox[{62., 0.6178145633650792}], 
             PointBox[{62.1, 0.6148793053474398}], 
             PointBox[{62.2, 0.6157902007200693}], 
             PointBox[{62.3, 0.616008365130824}], 
             PointBox[{62.4, 0.616490842916268}], 
             PointBox[{62.5, 0.6185016746241215}], 
             PointBox[{62.6, 0.6216809944300736}], 
             PointBox[{62.7, 0.6198381727578102}], 
             PointBox[{62.8, 0.6185505395720023}], 
             PointBox[{62.9, 0.6175015633882782}], 
             PointBox[{63., 0.6151020350474663}], 
             PointBox[{63.1, 0.6139834859166987}], 
             PointBox[{63.2, 0.6148931844711453}], 
             PointBox[{63.3, 0.615525531299884}], 
             PointBox[{63.4, 0.6165114687054888}], 
             PointBox[{63.5, 0.619677589289325}], 
             PointBox[{63.6, 0.6202748485693714}], 
             PointBox[{63.7, 0.6181182777919598}], 
             PointBox[{63.8, 0.6169662859700096}], 
             PointBox[{63.9, 0.6156623807715591}], 
             PointBox[{64., 0.6129179092703946}], 
             PointBox[{64.1, 0.6136273200757559}], 
             PointBox[{64.2, 0.6148284227690455}], 
             PointBox[{64.3, 0.6156969195680461}], 
             PointBox[{64.4, 0.6173244119202066}], 
             PointBox[{64.5, 0.6206624125017585}], 
             PointBox[{64.6, 0.6184950850589948}], 
             PointBox[{64.7, 0.6167182927741274}], 
             PointBox[{64.8, 0.6156490083549953}], 
             PointBox[{64.9, 0.6139583698427461}], 
             PointBox[{65., 0.6123373899901547}], 
             PointBox[{65.1, 0.6141366513812059}], 
             PointBox[{65.2, 0.6153429218615797}], 
             PointBox[{65.3, 0.616435763474868}], 
             PointBox[{65.4, 0.6188501673875167}], 
             PointBox[{65.5, 0.6200078266326134}], 
             PointBox[{65.6, 0.6170106036386289}], 
             PointBox[{65.7, 0.6156929788549638}], 
             PointBox[{65.8, 0.6146349330944099}], 
             PointBox[{65.9, 0.6127664813413247}], 
             PointBox[{66., 0.6130525103698241}], 
             PointBox[{66.1, 0.6151838603510478}], 
             PointBox[{66.2, 0.6162889277201636}], 
             PointBox[{66.3, 0.6176863228454036}], 
             PointBox[{66.4, 0.6204440913864504}], 
             PointBox[{66.5, 0.6183673577560147}], 
             PointBox[{66.6, 0.6160655202348227}], 
             PointBox[{66.7, 0.6151010853204174}], 
             PointBox[{66.8, 0.614056259801669}], 
             PointBox[{66.9, 0.6126734147018649}], 
             PointBox[{67., 0.6148351024368095}], 
             PointBox[{67.1, 0.6165249281734627}], 
             PointBox[{67.2, 0.6175937123598205}], 
             PointBox[{67.3, 0.619354943394009}], 
             PointBox[{67.4, 0.6207782922284671}], 
             PointBox[{67.5, 0.6171386430583732}], 
             PointBox[{67.6, 0.6157204867182408}], 
             PointBox[{67.7, 0.6150484323951448}], 
             PointBox[{67.8, 0.6142325362799271}], 
             PointBox[{67.9, 0.6138932867692933}], 
             PointBox[{68., 0.61686731870824}], 
             PointBox[{68.1, 0.6181052000776688}], 
             PointBox[{68.2, 0.6192162796947116}], 
             PointBox[{68.3, 0.6211512282168951}], 
             PointBox[{68.4, 0.6198107486898364}], 
             PointBox[{68.5, 0.6167711031070957}], 
             PointBox[{68.6, 0.6160265262718172}], 
             PointBox[{68.7, 0.6157247645908349}], 
             PointBox[{68.8, 0.6150949836751248}], 
             PointBox[{68.9, 0.6165796296220635}], 
             PointBox[{69., 0.6189513378974673}], 
             PointBox[{69.1, 0.6199239477594214}], 
             PointBox[{69.2, 0.6211042341331646}], 
             PointBox[{69.3, 0.6225162952516479}], 
             PointBox[{69.4, 0.6190683877084351}], 
             PointBox[{69.5, 0.6172457882123781}], 
             PointBox[{69.6, 0.6170614346471318}], 
             PointBox[{69.7, 0.6173292688520919}], 
             PointBox[{69.8, 0.6164062888599082}], 
             PointBox[{69.9, 0.6195156241485255}], 
             PointBox[{70., 0.6211371400030412}], 
             PointBox[{70.1, 0.6219737594662353}], 
             PointBox[{70.2, 0.6231554175813165}], 
             PointBox[{70.3, 0.6231921056122933}], 
             PointBox[{70.4, 0.619317107810477}], 
             PointBox[{70.5, 0.6184710806838607}], 
             PointBox[{70.6, 0.6188894165460097}], 
             PointBox[{70.7, 0.61943640246527}], 
             PointBox[{70.8, 0.6189302570809639}], 
             PointBox[{70.9, 0.6222963040927648}], 
             PointBox[{71., 0.6234431918592606}], 
             PointBox[{71.1, 0.6241998369011008}], 
             PointBox[{71.2, 0.6252203760084544}], 
             PointBox[{71.3, 0.6237288105584731}], 
             PointBox[{71.4, 0.6204506943022685}], 
             PointBox[{71.5, 0.6203062984222119}], 
             PointBox[{71.6, 0.6214055016510817}], 
             PointBox[{71.7, 0.6212266790154354}], 
             PointBox[{71.8, 0.6219264696099595}], 
             PointBox[{71.9, 0.6249042431501155}], 
             PointBox[{72., 0.6257962974090693}], 
             PointBox[{72.1, 0.6264814970907013}], 
             PointBox[{72.2, 0.6271855792886538}], 
             PointBox[{72.3, 0.624692141366193}], 
             PointBox[{72.4, 0.6221287211852486}], 
             PointBox[{72.5, 0.6225035820604817}], 
             PointBox[{72.6, 0.6241406416426288}], 
             PointBox[{72.7, 0.6230466026959545}], 
             PointBox[{72.8, 0.624686050718392}], 
             PointBox[{72.9, 0.6272934699935783}], 
             PointBox[{73., 0.6280587690967132}], 
             PointBox[{73.1, 0.6286655764168}], 
             PointBox[{73.2, 0.6290235848188666}], 
             PointBox[{73.3, 0.6261142383744236}], 
             PointBox[{73.4, 0.6240069580341409}], 
             PointBox[{73.5, 0.6247334881581631}], 
             PointBox[{73.6, 0.6265350693233747}], 
             PointBox[{73.7, 0.6249405807240812}], 
             PointBox[{73.8, 0.6269608027442988}], 
             PointBox[{73.9, 0.6293892686577852}], 
             PointBox[{74., 0.6301077393121599}], 
             PointBox[{74.1, 0.6306389944045616}], 
             PointBox[{74.2, 0.6307461576319581}], 
             PointBox[{74.3, 0.6277847309893247}], 
             PointBox[{74.4, 0.625834296896295}], 
             PointBox[{74.5, 0.6267160603639366}], 
             PointBox[{74.6, 0.6284748748426968}], 
             PointBox[{74.7, 0.6267114282210512}], 
             PointBox[{74.8, 0.628727312430454}], 
             PointBox[{74.9, 0.6311519729508497}], 
             PointBox[{75., 0.631888823445289}], 
             PointBox[{75.1, 0.6323646539927936}], 
             PointBox[{75.2, 0.6323559572084426}], 
             PointBox[{75.3, 0.629542191221899}], 
             PointBox[{75.4, 0.6275031104535976}], 
             PointBox[{75.5, 0.6283291230150431}], 
             PointBox[{75.6, 0.6300981961272766}], 
             PointBox[{75.7, 0.6282955184998829}], 
             PointBox[{75.8, 0.6300462514684476}], 
             PointBox[{75.9, 0.6325850271638648}], 
             PointBox[{76., 0.6334100903150192}], 
             PointBox[{76.1, 0.6338639654186147}], 
             PointBox[{76.2, 0.633851061005872}], 
             PointBox[{76.3, 0.6313230161287506}], 
             PointBox[{76.4, 0.6290306267577407}], 
             PointBox[{76.5, 0.629597434759128}], 
             PointBox[{76.6, 0.6314725226348583}], 
             PointBox[{76.7, 0.6297424830878923}], 
             PointBox[{76.8, 0.6310131516198819}], 
             PointBox[{76.9, 0.6337079315479549}], 
             PointBox[{77., 0.6347040440996662}], 
             PointBox[{77.1, 0.6351784110606484}], 
             PointBox[{77.2, 0.6352323485594594}], 
             PointBox[{77.3, 0.633107660830462}], 
             PointBox[{77.4, 0.630503164013555}], 
             PointBox[{77.5, 0.6306288661399558}], 
             PointBox[{77.6, 0.6325459091348933}], 
             PointBox[{77.7, 0.6311449447469752}], 
             PointBox[{77.8, 0.6317457601453894}], 
             PointBox[{77.9, 0.6345316520192243}], 
             PointBox[{78., 0.6357944787429495}], 
             PointBox[{78.1, 0.636342228409115}], 
             PointBox[{78.2, 0.636501922409696}], 
             PointBox[{78.3, 0.6348670171140156}], 
             PointBox[{78.4, 0.6320237405268796}], 
             PointBox[{78.5, 0.6315612102079725}], 
             PointBox[{78.6, 0.6332428579434137}], 
             PointBox[{78.7, 0.6325899668468484}], 
             PointBox[{78.8, 0.6323766119155679}], 
             PointBox[{78.9, 0.6350616188630661}], 
             PointBox[{79., 0.6366804389991508}], 
             PointBox[{79.1, 0.6373691104497761}], 
             PointBox[{79.2, 0.6376583858427721}], 
             PointBox[{79.3, 0.6365455561997014}], 
             PointBox[{79.4, 0.6336708285476512}], 
             PointBox[{79.5, 0.6325291442431697}], 
             PointBox[{79.6, 0.633641393237391}], 
             PointBox[{79.7, 0.6340836782821397}], 
             PointBox[{79.8, 0.6330383052780334}], 
             PointBox[{79.9, 0.6353219727878717}], 
             PointBox[{80., 0.6373314036909631}], 
             PointBox[{80.1, 0.6382459949514765}], 
             PointBox[{80.2, 0.6386911705917839}], 
             PointBox[{80.3, 0.6380744910795785}], 
             PointBox[{80.4, 0.635455250533694}], 
             PointBox[{80.5, 0.633641985815052}], 
             PointBox[{80.6, 0.6339846838514116}], 
             PointBox[{80.7, 0.6353506487652262}], 
             PointBox[{80.8, 0.6338533956476387}], 
             PointBox[{80.9, 0.6353900761888647}], 
             PointBox[{81., 0.6376992485822347}], 
             PointBox[{81.1, 0.6389328878021302}], 
             PointBox[{81.2, 0.6395749878035527}], 
             PointBox[{81.3, 0.6393967255656862}], 
             PointBox[{81.4, 0.6372917458851127}], 
             PointBox[{81.5, 0.634968185614164}], 
             PointBox[{81.6, 0.6344896983026574}], 
             PointBox[{81.7, 0.635875634605228}], 
             PointBox[{81.8, 0.6349238087917948}], 
             PointBox[{81.9, 0.6354074365421196}], 
             PointBox[{82., 0.6377515353675379}], 
             PointBox[{82.1, 0.6393661819752386}], 
             PointBox[{82.2, 0.6402666703515023}], 
             PointBox[{82.3, 0.6404735947407916}], 
             PointBox[{82.4, 0.6390230925715373}], 
             PointBox[{82.5, 0.6365101219769395}], 
             PointBox[{82.6, 0.635257254211871}], 
             PointBox[{82.7, 0.6358544457961407}], 
             PointBox[{82.8, 0.6362227032744976}], 
             PointBox[{82.9, 0.6355459159440576}], 
             PointBox[{83., 0.6375220438547957}], 
             PointBox[{83.1, 0.6394780344480798}], 
             PointBox[{83.2, 0.6407050646634413}], 
             PointBox[{83.3, 0.6412758004924488}], 
             PointBox[{83.4, 0.6404904837757429}], 
             PointBox[{83.5, 0.6381719625758848}], 
             PointBox[{83.6, 0.6363036446356259}], 
             PointBox[{83.7, 0.6359573144644407}], 
             PointBox[{83.8, 0.6371294771084706}], 
             PointBox[{83.9, 0.635973329200516}], 
             PointBox[{84., 0.6371412286001181}], 
             PointBox[{84.1, 0.6392333684413586}], 
             PointBox[{84.2, 0.6408208425696208}], 
             PointBox[{84.3, 0.6417688622251329}], 
             PointBox[{84.4, 0.6415938984983496}], 
             PointBox[{84.5, 0.6397685341078182}], 
             PointBox[{84.6, 0.637578596442137}], 
             PointBox[{84.7, 0.6364220866922911}], 
             PointBox[{84.8, 0.6370173783997172}], 
             PointBox[{84.9, 0.6367992104795945}], 
             PointBox[{85., 0.636807542208487}], 
             PointBox[{85.1, 0.6386787245832115}], 
             PointBox[{85.2, 0.6405583540360076}], 
             PointBox[{85.3, 0.6419083136122301}], 
             PointBox[{85.4, 0.6422907588129906}], 
             PointBox[{85.5, 0.6410986624022186}], 
             PointBox[{85.6, 0.638950504747522}], 
             PointBox[{85.7, 0.6372151905872367}], 
             PointBox[{85.8, 0.636772698092298}], 
             PointBox[{85.9, 0.6376716394513826}], 
             PointBox[{86., 0.6367279321691953}], 
             PointBox[{86.1, 0.637961653197283}], 
             PointBox[{86.2, 0.63991587467198}], 
             PointBox[{86.3, 0.6416477972916304}], 
             PointBox[{86.4, 0.6425699571594625}], 
             PointBox[{86.5, 0.6420285362842804}], 
             PointBox[{86.6, 0.6402220980993919}], 
             PointBox[{86.7, 0.6382207540629439}], 
             PointBox[{86.8, 0.6369384487676862}], 
             PointBox[{86.9, 0.6375240120582208}], 
             PointBox[{87., 0.6370692522823754}], 
             PointBox[{87.1, 0.6372879109984717}], 
             PointBox[{87.2, 0.6389833266816624}], 
             PointBox[{87.3, 0.6409636653653153}], 
             PointBox[{87.4, 0.642417364555821}], 
             PointBox[{87.5, 0.6425109175967048}], 
             PointBox[{87.6, 0.6412029278045778}], 
             PointBox[{87.7, 0.639264575964907}], 
             PointBox[{87.8, 0.6374642384371728}], 
             PointBox[{87.9, 0.6369310559184949}], 
             PointBox[{88., 0.6376818169015335}], 
             PointBox[{88.1, 0.6368565477029873}], 
             PointBox[{88.2, 0.6379393080288986}], 
             PointBox[{88.3, 0.639898005950035}], 
             PointBox[{88.4, 0.641817109608077}], 
             PointBox[{88.5, 0.6425485950557415}], 
             PointBox[{88.6, 0.6417811146626986}], 
             PointBox[{88.7, 0.6401427137862067}], 
             PointBox[{88.8, 0.6381801711762369}], 
             PointBox[{88.9, 0.6367305872731673}], 
             PointBox[{89., 0.637496452235681}], 
             PointBox[{89.1, 0.6368216623629112}], 
             PointBox[{89.2, 0.636985755903062}], 
             PointBox[{89.3, 0.6385882622941441}], 
             PointBox[{89.4, 0.6407756259016336}], 
             PointBox[{89.5, 0.6421580346091865}], 
             PointBox[{89.6, 0.6419370731148307}], 
             PointBox[{89.7, 0.6406972259341992}], 
             PointBox[{89.8, 0.6388822116854546}], 
             PointBox[{89.9, 0.6369131991804526}], 
             PointBox[{90., 0.6365473848617792}], 
             PointBox[{90.1, 0.6371371845357082}], 
             PointBox[{90.2, 0.6362832018628269}], 
             PointBox[{90.3, 0.6372349194383509}], 
             PointBox[{90.4, 0.6393625059615659}], 
             PointBox[{90.5, 0.6413490365410882}], 
             PointBox[{90.6, 0.6417023789156684}], 
             PointBox[{90.7, 0.6408630098157261}], 
             PointBox[{90.8, 0.6393721455673191}], 
             PointBox[{90.9, 0.6372938792476569}], 
             PointBox[{91., 0.6358507818206423}], 
             PointBox[{91.1, 0.6370022426785987}], 
             PointBox[{91.2, 0.6359317119530221}], 
             PointBox[{91.3, 0.6360224444995443}], 
             PointBox[{91.4, 0.6377340771421001}], 
             PointBox[{91.5, 0.6401389590232847}], 
             PointBox[{91.6, 0.6411241521053623}], 
             PointBox[{91.7, 0.6406607950028493}], 
             PointBox[{91.8, 0.639528277512298}], 
             PointBox[{91.9, 0.6376606525648074}], 
             PointBox[{92., 0.63553836537125}], 
             PointBox[{92.1, 0.635875885801886}], 
             PointBox[{92.2, 0.6359194046305953}], 
             PointBox[{92.3, 0.6350602930868295}], 
             PointBox[{92.4, 0.6360983750762229}], 
             PointBox[{92.5, 0.6385838942652025}], 
             PointBox[{92.6, 0.6402430407487006}], 
             PointBox[{92.7, 0.6401525365659358}], 
             PointBox[{92.8, 0.6393304136838025}], 
             PointBox[{92.9, 0.6378288246526309}], 
             PointBox[{93., 0.635468232883581}], 
             PointBox[{93.1, 0.6346303430184912}], 
             PointBox[{93.2, 0.6358625147383079}], 
             PointBox[{93.3, 0.6343812499779738}], 
             PointBox[{93.4, 0.6346205338446568}], 
             PointBox[{93.5, 0.6368059986498851}], 
             PointBox[{93.6, 0.6390905037746943}], 
             PointBox[{93.7, 0.6394070349129594}], 
             PointBox[{93.8, 0.6388273058272749}], 
             PointBox[{93.9, 0.6376949458298106}], 
             PointBox[{94., 0.6354677452987193}], 
             PointBox[{94.1, 0.6336605354302007}], 
             PointBox[{94.2, 0.6350833255725009}], 
             PointBox[{94.3, 0.6339506549087213}], 
             PointBox[{94.4, 0.6333674747152469}], 
             PointBox[{94.5, 0.6349734375244991}], 
             PointBox[{94.6, 0.6376978039010395}], 
             PointBox[{94.7, 0.6384806651991586}], 
             PointBox[{94.8, 0.6380883576556198}], 
             PointBox[{94.9, 0.6372491519033414}], 
             PointBox[{95., 0.6353673268327998}], 
             PointBox[{95.1, 0.6329236783836871}], 
             PointBox[{95.2, 0.6336901909747908}], 
             PointBox[{95.3, 0.6336338826816738}], 
             PointBox[{95.4, 0.6323167020920935}], 
             PointBox[{95.5, 0.6332303259703195}], 
             PointBox[{95.6, 0.6361097911726068}], 
             PointBox[{95.7, 0.6374116568297561}], 
             PointBox[{95.8, 0.637172298426611}], 
             PointBox[{95.9, 0.6365337160913089}], 
             PointBox[{96., 0.6350430977437914}], 
             PointBox[{96.1, 0.6323084528560451}], 
             PointBox[{96.2, 0.6322053989237528}], 
             PointBox[{96.3, 0.6331794968158238}], 
             PointBox[{96.4, 0.6313873278436702}], 
             PointBox[{96.5, 0.63163460628562}], 
             PointBox[{96.6, 0.634391532073983}], 
             PointBox[{96.7, 0.6362217977357572}], 
             PointBox[{96.8, 0.6361137575319804}], 
             PointBox[{96.9, 0.6355953767928738}], 
             PointBox[{97., 0.6344375170284379}], 
             PointBox[{97.1, 0.631688132979722}], 
             PointBox[{97.2, 0.6307924994446342}], 
             PointBox[{97.3, 0.6323696765151704}], 
             PointBox[{97.4, 0.6304612745711687}], 
             PointBox[{97.5, 0.6301511912217765}], 
             PointBox[{97.6, 0.6326122894923325}], 
             PointBox[{97.7, 0.6349190123276333}], 
             PointBox[{97.8, 0.6349180092132016}], 
             PointBox[{97.9, 0.6344574963132739}], 
             PointBox[{98., 0.6335376338109047}], 
             PointBox[{98.1, 0.6309273847854739}], 
             PointBox[{98.2, 0.6294042903722729}], 
             PointBox[{98.3, 0.6311935621453851}], 
             PointBox[{98.4, 0.629399928489}], 
             PointBox[{98.5, 0.6286898706528021}], 
             PointBox[{98.6, 0.630823351290312}], 
             PointBox[{98.7, 0.6335054665512064}], 
             PointBox[{98.8, 0.6335668781853484}], 
             PointBox[{98.9, 0.6331148482500881}], 
             PointBox[{99., 0.6323404042084055}], 
             PointBox[{99.1, 0.6298990160700971}], 
             PointBox[{99.2, 0.6279448992740599}], 
             PointBox[{99.3, 0.6297516521457492}], 
             PointBox[{99.4, 0.6280682590042924}], 
             PointBox[{99.5, 0.6271464894671375}], 
             PointBox[{99.6, 0.6290434914467866}], 
             PointBox[{99.7, 0.6319816072927127}], 
             PointBox[{99.8, 0.6320236940705573}], 
             PointBox[{99.9, 0.6315394393358367}], 
             PointBox[{100., 0.6308326084552227}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0.6, 0.65}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], 
             PointBox[{0, 0.012286199999996425`}], 
             PointBox[{0.1, 0.014787000935964018`}], 
             PointBox[{0.2, 0.015758757134471127`}], 
             PointBox[{0.3, 0.013220342337240785`}], 
             PointBox[{0.4, 0.014916472581743535`}], 
             PointBox[{0.5, 0.017402449620990183`}], 
             PointBox[{0.6, 0.014615852932436809`}], 
             PointBox[{0.7, 0.013169144880059986`}], 
             PointBox[{0.8, 0.01601778900751362}], 
             PointBox[{0.9, 0.015558588608091043`}], 
             PointBox[{1., 0.014585015707782966`}], 
             PointBox[{1.1, 0.020183758480863588`}], 
             PointBox[{1.2, 0.022762541552241045`}], 
             PointBox[{1.3, 0.020595731817565032`}], 
             PointBox[{1.4, 0.02153004036211773}], 
             PointBox[{1.5, 0.024415737907588383`}], 
             PointBox[{1.6, 0.02187934917001051}], 
             PointBox[{1.7, 0.019991307691023336`}], 
             PointBox[{1.8, 0.022839293833118737`}], 
             PointBox[{1.9, 0.02322146399511602}], 
             PointBox[{2., 0.021344857243563123`}], 
             PointBox[{2.1, 0.027021430944021565`}], 
             PointBox[{2.2, 0.032041889636579814`}], 
             PointBox[{2.3, 0.030895873933331437`}], 
             PointBox[{2.4, 0.03031385807736529}], 
             PointBox[{2.5, 0.033705207284158295`}], 
             PointBox[{2.6, 0.03229658678526866}], 
             PointBox[{2.7, 0.029452155122776286`}], 
             PointBox[{2.8, 0.0316090894135311}], 
             PointBox[{2.9, 0.033354079425395894`}], 
             PointBox[{3., 0.0309219808368337}], 
             PointBox[{3.1, 0.034184402810716774`}], 
             PointBox[{3.2, 0.041054629993700534`}], 
             PointBox[{3.3, 0.041943878876912845`}], 
             PointBox[{3.4, 0.040182888960564836`}], 
             PointBox[{3.5, 0.04308713175694771}], 
             PointBox[{3.6, 0.04348479534377358}], 
             PointBox[{3.7, 0.04003060860941067}], 
             PointBox[{3.8, 0.04084750677536632}], 
             PointBox[{3.9, 0.04364362834032953}], 
             PointBox[{4., 0.04190255804861852}], 
             PointBox[{4.1, 0.042275818483904305`}], 
             PointBox[{4.2, 0.04910631780975129}], 
             PointBox[{4.3, 0.05264362236029244}], 
             PointBox[{4.4, 0.050834714268826506`}], 
             PointBox[{4.5, 0.05214991498829536}], 
             PointBox[{4.6, 0.05443368992256077}], 
             PointBox[{4.7, 0.05111066845832089}], 
             PointBox[{4.8, 0.05038755208919629}], 
             PointBox[{4.9, 0.05337777005384061}], 
             PointBox[{5., 0.05325362268800581}], 
             PointBox[{5.1, 0.05136889347458902}], 
             PointBox[{5.2, 0.05674575781270671}], 
             PointBox[{5.3, 0.062378764736355015`}], 
             PointBox[{5.4, 0.06174882160169131}], 
             PointBox[{5.5, 0.061206501208447964`}], 
             PointBox[{5.6, 0.06461520491716205}], 
             PointBox[{5.7, 0.06225088756480133}], 
             PointBox[{5.8, 0.06019459844389849}], 
             PointBox[{5.9, 0.06257845359768315}], 
             PointBox[{6., 0.0641496962772639}], 
             PointBox[{6.1, 0.06127390172322786}], 
             PointBox[{6.2, 0.06472459299483406}], 
             PointBox[{6.3, 0.07097261111939449}], 
             PointBox[{6.4, 0.07233569340950408}], 
             PointBox[{6.5, 0.07061398593762593}], 
             PointBox[{6.6, 0.07386712756251491}], 
             PointBox[{6.7, 0.07311438458846593}], 
             PointBox[{6.8, 0.07014609471879471}], 
             PointBox[{6.9, 0.07150221797411149}], 
             PointBox[{7., 0.07417401291213978}], 
             PointBox[{7.1, 0.07168114012983628}], 
             PointBox[{7.2, 0.07297117093429119}], 
             PointBox[{7.3, 0.0787942710394368}], 
             PointBox[{7.4, 0.08223414813994678}], 
             PointBox[{7.5, 0.0803793055241188}], 
             PointBox[{7.6, 0.08240684399252379}], 
             PointBox[{7.7, 0.08349061473170137}], 
             PointBox[{7.8, 0.08009953970728463}], 
             PointBox[{7.9, 0.08036062478028336}], 
             PointBox[{8., 0.0833816317393297}], 
             PointBox[{8.1, 0.08216224845811988}], 
             PointBox[{8.2, 0.08138920263572337}], 
             PointBox[{8.3, 0.08657567630405742}], 
             PointBox[{8.4, 0.09140311455712237}], 
             PointBox[{8.5, 0.09026436340167283}], 
             PointBox[{8.6, 0.09070656106606909}], 
             PointBox[{8.7, 0.09332465116800581}], 
             PointBox[{8.8, 0.0899745873490283}], 
             PointBox[{8.9, 0.08927749381360185}], 
             PointBox[{9., 0.09210724416757729}], 
             PointBox[{9.1, 0.09235774735742214}], 
             PointBox[{9.2, 0.09005038689865234}], 
             PointBox[{9.3, 0.09468909135072835}], 
             PointBox[{9.4, 0.10008642558120516`}], 
             PointBox[{9.5, 0.10009143487832936`}], 
             PointBox[{9.6, 0.09923065706358823}], 
             PointBox[{9.7, 0.10274211653270099`}], 
             PointBox[{9.8, 0.09979072822351942}], 
             PointBox[{9.9, 0.09835141199444876}], 
             PointBox[{10., 0.10074484110080817`}], 
             PointBox[{10.1, 0.10217666475345359`}], 
             PointBox[{10.2, 0.09904857220098423}], 
             PointBox[{10.3, 0.10313280207431341`}], 
             PointBox[{10.4, 0.10871568031922113`}], 
             PointBox[{10.5, 0.10988883343025932`}], 
             PointBox[{10.6, 0.10826286034062958`}], 
             PointBox[{10.7, 0.11203811184563327`}], 
             PointBox[{10.8, 0.10966098748025264`}], 
             PointBox[{10.9, 0.10770753684330583`}], 
             PointBox[{11., 0.10964540464797891`}], 
             PointBox[{11.1, 0.11181782176645445`}], 
             PointBox[{11.2, 0.10845249587972879`}], 
             PointBox[{11.3, 0.1120005153439257}], 
             PointBox[{11.4, 0.11776495994842938`}], 
             PointBox[{11.5, 0.11985006629392421`}], 
             PointBox[{11.6, 0.1179236039301713}], 
             PointBox[{11.7, 0.1216052083966143}], 
             PointBox[{11.8, 0.1197499022558104}], 
             PointBox[{11.9, 0.11749784061861578`}], 
             PointBox[{12., 0.11909552012320175`}], 
             PointBox[{12.1, 0.12163242295417677`}], 
             PointBox[{12.2, 0.11831181102699785`}], 
             PointBox[{12.3, 0.12153184546278498`}], 
             PointBox[{12.4, 0.1276218723963391}], 
             PointBox[{12.5, 0.13020296345571725`}], 
             PointBox[{12.6, 0.12823301873357626`}], 
             PointBox[{12.7, 0.13179987454718264`}], 
             PointBox[{12.8, 0.13018746706867063`}], 
             PointBox[{12.9, 0.1278459308626852}], 
             PointBox[{13., 0.12928866541352949`}], 
             PointBox[{13.1, 0.13193488518492194`}], 
             PointBox[{13.2, 0.12864410934897383`}], 
             PointBox[{13.3, 0.13198429491214994`}], 
             PointBox[{13.4, 0.13847643922213218`}], 
             PointBox[{13.5, 0.14101227856184703`}], 
             PointBox[{13.6, 0.13908554235991963`}], 
             PointBox[{13.7, 0.14276346599227924`}], 
             PointBox[{13.8, 0.14093270460982413`}], 
             PointBox[{13.9, 0.13873792382022387`}], 
             PointBox[{14., 0.14023730856235758`}], 
             PointBox[{14.1, 0.1428058786305943}], 
             PointBox[{14.2, 0.13937345318704322`}], 
             PointBox[{14.3, 0.14348823711914652`}], 
             PointBox[{14.4, 0.15011128531857396`}], 
             PointBox[{14.5, 0.1519830214170256}], 
             PointBox[{14.6, 0.15015781931417452`}], 
             PointBox[{14.7, 0.15421169164825466`}], 
             PointBox[{14.8, 0.15164452422058536`}], 
             PointBox[{14.9, 0.14989757150230854`}], 
             PointBox[{15., 0.15164946154053627`}], 
             PointBox[{15.1, 0.15389661857287784`}], 
             PointBox[{15.2, 0.1503052095842225}], 
             PointBox[{15.3, 0.155832958327706}], 
             PointBox[{15.4, 0.161679783100971}], 
             PointBox[{15.5, 0.1624038420823059}], 
             PointBox[{15.6, 0.16095178555057946`}], 
             PointBox[{15.7, 0.16524964746258555`}], 
             PointBox[{15.8, 0.1617227023576954}], 
             PointBox[{15.9, 0.1607646730541953}], 
             PointBox[{16., 0.16288882598357635`}], 
             PointBox[{16.1, 0.16432108562894054`}], 
             PointBox[{16.2, 0.1612998206679979}], 
             PointBox[{16.3, 0.1680547462128602}], 
             PointBox[{16.4, 0.17196010478587062`}], 
             PointBox[{16.5, 0.17143434973934862`}], 
             PointBox[{16.6, 0.17111670761139244`}], 
             PointBox[{16.7, 0.17451246257609232`}], 
             PointBox[{16.8, 0.17061288338210268`}], 
             PointBox[{16.9, 0.17069071673447955`}], 
             PointBox[{17., 0.17314118771650153`}], 
             PointBox[{17.1, 0.17286051261971458`}], 
             PointBox[{17.2, 0.17230710674101363`}], 
             PointBox[{17.3, 0.17842725883637015`}], 
             PointBox[{17.4, 0.18003723246234735`}], 
             PointBox[{17.5, 0.1786012088396726}], 
             PointBox[{17.6, 0.1806007572715888}], 
             PointBox[{17.7, 0.18106531399296016`}], 
             PointBox[{17.8, 0.17809147943403064`}], 
             PointBox[{17.9, 0.17921163948116375`}], 
             PointBox[{18., 0.18163591907986074`}], 
             PointBox[{18.1, 0.1789023338989095}], 
             PointBox[{18.2, 0.18225990428161315`}], 
             PointBox[{18.3, 0.18588394414572626`}], 
             PointBox[{18.4, 0.18565390143751453`}], 
             PointBox[{18.5, 0.184150376311276}], 
             PointBox[{18.6, 0.18858671505048935`}], 
             PointBox[{18.7, 0.1853420408773845}], 
             PointBox[{18.8, 0.18421126368968632`}], 
             PointBox[{18.9, 0.18610693680765064`}], 
             PointBox[{19., 0.1876169349654971}], 
             PointBox[{19.1, 0.1840754944493684}], 
             PointBox[{19.2, 0.18938634533464963`}], 
             PointBox[{19.3, 0.19045722905460824`}], 
             PointBox[{19.4, 0.18909230780345793`}], 
             PointBox[{19.5, 0.18904941423600038`}], 
             PointBox[{19.6, 0.19279539296246662`}], 
             PointBox[{19.7, 0.18844780333776298`}], 
             PointBox[{19.8, 0.18906157790535552`}], 
             PointBox[{19.9, 0.19121089074707515`}], 
             PointBox[{20., 0.19035020001770184`}], 
             PointBox[{20.1, 0.18976725973844372`}], 
             PointBox[{20.2, 0.19337307728994932`}], 
             PointBox[{20.3, 0.19261964789605546`}], 
             PointBox[{20.4, 0.1910046267376383}], 
             PointBox[{20.5, 0.1940272661701583}], 
             PointBox[{20.6, 0.1931796294140818}], 
             PointBox[{20.7, 0.190949854972125}], 
             PointBox[{20.8, 0.19260175180867978`}], 
             PointBox[{20.9, 0.194157839752513}], 
             PointBox[{21., 0.19057140637754139`}], 
             PointBox[{21.1, 0.19378557636183608`}], 
             PointBox[{21.2, 0.19462906330093896`}], 
             PointBox[{21.3, 0.19294268349569962`}], 
             PointBox[{21.4, 0.1923143172252475}], 
             PointBox[{21.5, 0.1970580132971545}], 
             PointBox[{21.6, 0.19247614027478402`}], 
             PointBox[{21.7, 0.1927497647840589}], 
             PointBox[{21.8, 0.1945979133037493}], 
             PointBox[{21.9, 0.19432735006343216`}], 
             PointBox[{22., 0.1910845077689603}], 
             PointBox[{22.1, 0.19493690654306417`}], 
             PointBox[{22.2, 0.19374680751932868`}], 
             PointBox[{22.3, 0.19200918291681304`}], 
             PointBox[{22.4, 0.19381971686204089`}], 
             PointBox[{22.5, 0.19533318569219452`}], 
             PointBox[{22.6, 0.19190133608059615`}], 
             PointBox[{22.7, 0.19343665553938452`}], 
             PointBox[{22.8, 0.19460785990889376`}], 
             PointBox[{22.9, 0.19155368644281828`}], 
             PointBox[{23., 0.1919394514028749}], 
             PointBox[{23.1, 0.19326478938208488`}], 
             PointBox[{23.2, 0.19123854359511985`}], 
             PointBox[{23.3, 0.19036760992739438`}], 
             PointBox[{23.4, 0.1946733812420728}], 
             PointBox[{23.5, 0.19124368039712522`}], 
             PointBox[{23.6, 0.19092879899248905`}], 
             PointBox[{23.7, 0.19249209256923666`}], 
             PointBox[{23.8, 0.19204092819195748`}], 
             PointBox[{23.9, 0.18711975822488514`}], 
             PointBox[{24., 0.1906025259552461}], 
             PointBox[{24.1, 0.189383673037627}], 
             PointBox[{24.2, 0.18744573873471643`}], 
             PointBox[{24.3, 0.18833673732058687`}], 
             PointBox[{24.4, 0.19185464051945686`}], 
             PointBox[{24.5, 0.18729195095432158`}], 
             PointBox[{24.6, 0.18869011131771882`}], 
             PointBox[{24.7, 0.18935088131835778`}], 
             PointBox[{24.8, 0.18643200683621014`}], 
             PointBox[{24.9, 0.1832224699490941}], 
             PointBox[{25., 0.1860219795825033}], 
             PointBox[{25.1, 0.18372480879142}], 
             PointBox[{25.2, 0.18251729850415857`}], 
             PointBox[{25.3, 0.18549923885895392`}], 
             PointBox[{25.4, 0.18498063677020815`}], 
             PointBox[{25.5, 0.1829772678461347}], 
             PointBox[{25.6, 0.18446927822586615`}], 
             PointBox[{25.7, 0.18345592255850526`}], 
             PointBox[{25.8, 0.1778661912517493}], 
             PointBox[{25.9, 0.1787150064610272}], 
             PointBox[{26., 0.1788203819013063}], 
             PointBox[{26.1, 0.176460558045601}], 
             PointBox[{26.2, 0.17639779170173994`}], 
             PointBox[{26.3, 0.18045279026736397`}], 
             PointBox[{26.4, 0.1766778851615381}], 
             PointBox[{26.5, 0.17719397256932817`}], 
             PointBox[{26.6, 0.17778786832184815`}], 
             PointBox[{26.7, 0.1744731986339002}], 
             PointBox[{26.8, 0.16799410188452907`}], 
             PointBox[{26.9, 0.171373290526378}], 
             PointBox[{27., 0.16963166579504024`}], 
             PointBox[{27.1, 0.16767716108351913`}], 
             PointBox[{27.2, 0.16887539596208728`}], 
             PointBox[{27.3, 0.17217036673321295`}], 
             PointBox[{27.4, 0.1677781440930858}], 
             PointBox[{27.5, 0.16938904128271068`}], 
             PointBox[{27.6, 0.16854405341764442`}], 
             PointBox[{27.7, 0.16293598450060431`}], 
             PointBox[{27.8, 0.15809701367362652`}], 
             PointBox[{27.9, 0.16155543858785115`}], 
             PointBox[{28., 0.15902030086611238`}], 
             PointBox[{28.1, 0.15760269148033126`}], 
             PointBox[{28.2, 0.15983143728062751`}], 
             PointBox[{28.3, 0.16142561495217117`}], 
             PointBox[{28.4, 0.15793534864770412`}], 
             PointBox[{28.5, 0.15971037170473873`}], 
             PointBox[{28.6, 0.157285052778762}], 
             PointBox[{28.7, 0.1504986512815395}], 
             PointBox[{28.8, 0.14781245287532557`}], 
             PointBox[{28.9, 0.15048739241999817`}], 
             PointBox[{29., 0.147686435847533}], 
             PointBox[{29.1, 0.14673225196538986`}], 
             PointBox[{29.2, 0.14957054865166355`}], 
             PointBox[{29.3, 0.1497747414838962}], 
             PointBox[{29.4, 0.14724399064423688`}], 
             PointBox[{29.5, 0.1488913170906387}], 
             PointBox[{29.6, 0.14524785753842762`}], 
             PointBox[{29.7, 0.1384970183510035}], 
             PointBox[{29.8, 0.13715274231498062`}], 
             PointBox[{29.9, 0.13926539200688384`}], 
             PointBox[{30., 0.13637536385795787`}], 
             PointBox[{30.1, 0.13569377838505173`}], 
             PointBox[{30.2, 0.13877630512918296`}], 
             PointBox[{30.3, 0.1383393229535151}], 
             PointBox[{30.4, 0.13625563654432463`}], 
             PointBox[{30.5, 0.13784867595628697`}], 
             PointBox[{30.6, 0.1336821569125034}], 
             PointBox[{30.7, 0.127432390208176}], 
             PointBox[{30.8, 0.12652377629913267`}], 
             PointBox[{30.9, 0.12855222786806775`}], 
             PointBox[{31., 0.1256144383752204}], 
             PointBox[{31.1, 0.1249669958171441}], 
             PointBox[{31.2, 0.12807109399040686`}], 
             PointBox[{31.3, 0.12766552831342298`}], 
             PointBox[{31.4, 0.1254915441612767}], 
             PointBox[{31.5, 0.12720776466392467`}], 
             PointBox[{31.6, 0.12315477801601643`}], 
             PointBox[{31.7, 0.1173560609017546}], 
             PointBox[{31.8, 0.11618968674613532`}], 
             PointBox[{31.9, 0.11853432144855539`}], 
             PointBox[{32., 0.11559739672922222`}], 
             PointBox[{32.1, 0.11474511876142163`}], 
             PointBox[{32.2, 0.11772353201130865`}], 
             PointBox[{32.3, 0.11785755408326504`}], 
             PointBox[{32.4, 0.11520183508966937`}], 
             PointBox[{32.5, 0.11712417063848161`}], 
             PointBox[{32.6, 0.11365174890749317`}], 
             PointBox[{32.7, 0.10810263568656134`}], 
             PointBox[{32.8, 0.10619531795555719`}], 
             PointBox[{32.9, 0.10904523308725984`}], 
             PointBox[{33., 0.10626283303496087`}], 
             PointBox[{33.1, 0.10499287748127697`}], 
             PointBox[{33.2, 0.1076905096522726}], 
             PointBox[{33.3, 0.10870664987382937`}], 
             PointBox[{33.4, 0.10542955481982579`}], 
             PointBox[{33.5, 0.10741612009487456`}], 
             PointBox[{33.6, 0.10493198270285246`}], 
             PointBox[{33.7, 0.09941941191138512}], 
             PointBox[{33.8, 0.09650666854141454}], 
             PointBox[{33.9, 0.09972336347977905}], 
             PointBox[{34., 0.09741982075973597}], 
             PointBox[{34.1, 0.09557403445661047}], 
             PointBox[{34.2, 0.09779131212308924}], 
             PointBox[{34.3, 0.0998170300589659}], 
             PointBox[{34.4, 0.09615610713356873}], 
             PointBox[{34.5, 0.09777836446029109}], 
             PointBox[{34.6, 0.09663875845980625}], 
             PointBox[{34.7, 0.09105972300664}], 
             PointBox[{34.8, 0.08712037042319859}], 
             PointBox[{34.9, 0.09015781917402967}], 
             PointBox[{35., 0.08882067363770951}], 
             PointBox[{35.1, 0.08635058537920379}], 
             PointBox[{35.2, 0.08784479027418293}], 
             PointBox[{35.3, 0.09074513578129186}], 
             PointBox[{35.4, 0.08735125178479046}], 
             PointBox[{35.5, 0.08795976589771082}], 
             PointBox[{35.6, 0.08829171311312911}], 
             PointBox[{35.7, 0.08289761191961655}], 
             PointBox[{35.8, 0.07806221293297705}], 
             PointBox[{35.9, 0.08005467276843183}], 
             PointBox[{36., 0.08017122163353885}], 
             PointBox[{36.1, 0.07723123459114387}], 
             PointBox[{36.2, 0.07774725076786072}], 
             PointBox[{36.3, 0.08113879758485915}], 
             PointBox[{36.4, 0.07888331705605212}], 
             PointBox[{36.5, 0.07789618230863113}], 
             PointBox[{36.6, 0.07940237631227855}], 
             PointBox[{36.7, 0.07501777409735445}], 
             PointBox[{36.8, 0.06933341921693438}], 
             PointBox[{36.9, 0.06941650379619405}], 
             PointBox[{37., 0.07112134263329242}], 
             PointBox[{37.1, 0.06817083683308024}], 
             PointBox[{37.2, 0.06750361761912164}], 
             PointBox[{37.3, 0.07084491853247354}], 
             PointBox[{37.4, 0.07039577203390007}], 
             PointBox[{37.5, 0.06777166263527078}], 
             PointBox[{37.6, 0.06967333979450477}], 
             PointBox[{37.7, 0.06730880853882848}], 
             PointBox[{37.8, 0.06090213516134258}], 
             PointBox[{37.9, 0.058604534901392204`}], 
             PointBox[{38., 0.061322282671438244`}], 
             PointBox[{38.1, 0.05911462503137242}], 
             PointBox[{38.2, 0.057231094529781666`}], 
             PointBox[{38.3, 0.05992850603218033}], 
             PointBox[{38.4, 0.0613858972157638}], 
             PointBox[{38.5, 0.057927468901456544`}], 
             PointBox[{38.6, 0.05911325879161353}], 
             PointBox[{38.7, 0.05902087853321212}], 
             PointBox[{38.8, 0.05281011426207489}], 
             PointBox[{38.9, 0.0481759314378577}], 
             PointBox[{39., 0.05062823635390864}], 
             PointBox[{39.1, 0.0499209725067467}], 
             PointBox[{39.2, 0.04712473994614763}], 
             PointBox[{39.3, 0.04863831987911058}], 
             PointBox[{39.4, 0.051517198575136695`}], 
             PointBox[{39.5, 0.04855685259162459}], 
             PointBox[{39.6, 0.048068213390637604`}], 
             PointBox[{39.7, 0.04959363056595072}], 
             PointBox[{39.8, 0.045167101524996575`}], 
             PointBox[{39.9, 0.038624247284860774`}], 
             PointBox[{40., 0.03934956597262157}], 
             PointBox[{40.1, 0.040373770015264446`}], 
             PointBox[{40.2, 0.03738261328417949}], 
             PointBox[{40.3, 0.037369219553676586`}], 
             PointBox[{40.4, 0.040864530788833814`}], 
             PointBox[{40.5, 0.03946654389731416}], 
             PointBox[{40.6, 0.03716233986006866}], 
             PointBox[{40.7, 0.03914411766285407}], 
             PointBox[{40.8, 0.03740436651079744}], 
             PointBox[{40.9, 0.030294704781825096`}], 
             PointBox[{41., 0.02831394502288187}], 
             PointBox[{41.1, 0.03045860363611976}], 
             PointBox[{41.2, 0.02814848437907246}], 
             PointBox[{41.3, 0.02666414026018149}], 
             PointBox[{41.4, 0.029994045845538456`}], 
             PointBox[{41.5, 0.03037090077738822}], 
             PointBox[{41.6, 0.027071753315289174`}], 
             PointBox[{41.7, 0.028333747438490927`}], 
             PointBox[{41.8, 0.028874238355513695`}], 
             PointBox[{41.9, 0.02328022799604693}], 
             PointBox[{42., 0.01879288990342271}], 
             PointBox[{42.1, 0.02101851875623559}], 
             PointBox[{42.2, 0.019793600391209747`}], 
             PointBox[{42.3, 0.017412018588259148`}], 
             PointBox[{42.4, 0.02020854771020833}], 
             PointBox[{42.5, 0.021749718134469045`}], 
             PointBox[{42.6, 0.018424337076903895`}], 
             PointBox[{42.7, 0.018514636391975023`}], 
             PointBox[{42.8, 0.020384512174564603`}], 
             PointBox[{42.9, 0.017086343560312113`}], 
             PointBox[{43., 0.012938494154222985`}], 
             PointBox[{43.1, 0.015068073893918994`}], 
             PointBox[{43.2, 0.01446161079502193}], 
             PointBox[{43.3, 0.012037618103180138`}], 
             PointBox[{43.4, 0.01475538579888077}], 
             PointBox[{43.5, 0.016347803077341024`}], 
             PointBox[{43.6, 0.013064893228452685`}], 
             PointBox[{43.7, 0.012812944322348509`}], 
             PointBox[{43.8, 0.01524121207545076}], 
             PointBox[{43.9, 0.01337093571467299}], 
             PointBox[{44., 0.013070465547275248`}], 
             PointBox[{44.1, 0.01687647355378358}], 
             PointBox[{44.2, 0.016857155319880242`}], 
             PointBox[{44.3, 0.014707790634664864`}], 
             PointBox[{44.4, 0.017438732651398472`}], 
             PointBox[{44.5, 0.018774650212871388`}], 
             PointBox[{44.6, 0.01534620423768085}], 
             PointBox[{44.7, 0.015326536991162171`}], 
             PointBox[{44.8, 0.018058224122578972`}], 
             PointBox[{44.9, 0.016682450761590795`}], 
             PointBox[{45., 0.017277969456826563`}], 
             PointBox[{45.1, 0.023555530223125443`}], 
             PointBox[{45.2, 0.02527909170632638}], 
             PointBox[{45.3, 0.023081200231448426`}], 
             PointBox[{45.4, 0.024920036388806376`}], 
             PointBox[{45.5, 0.02708296182924948}], 
             PointBox[{45.6, 0.02388429258010669}], 
             PointBox[{45.7, 0.023014905200259162`}], 
             PointBox[{45.8, 0.026013450845685807`}], 
             PointBox[{45.9, 0.025559325732726193`}], 
             PointBox[{46., 0.024406011954622223`}], 
             PointBox[{46.1, 0.030903154892961315`}], 
             PointBox[{46.2, 0.035181581092819374`}], 
             PointBox[{46.3, 0.03358635323597091}], 
             PointBox[{46.4, 0.03377044600972511}], 
             PointBox[{46.5, 0.036963411513395626`}], 
             PointBox[{46.6, 0.03466503562399853}], 
             PointBox[{46.7, 0.03250572139618382}], 
             PointBox[{46.8, 0.03513855122767177}], 
             PointBox[{46.9, 0.036205589287670016`}], 
             PointBox[{47., 0.033785758021127946`}], 
             PointBox[{47.1, 0.038200847800350414`}], 
             PointBox[{47.2, 0.04463670647331273}], 
             PointBox[{47.3, 0.04474217308477766}], 
             PointBox[{47.4, 0.043377659594781216`}], 
             PointBox[{47.5, 0.04667940251626539}], 
             PointBox[{47.6, 0.04603041107621999}], 
             PointBox[{47.7, 0.04287915344678215}], 
             PointBox[{47.8, 0.044404199702115524`}], 
             PointBox[{47.9, 0.04683862680938987}], 
             PointBox[{48., 0.04452579330709855}], 
             PointBox[{48.1, 0.04612503387474444}], 
             PointBox[{48.2, 0.05302056921416156}], 
             PointBox[{48.3, 0.05561842715760164}], 
             PointBox[{48.4, 0.053700544753352716`}], 
             PointBox[{48.5, 0.05582592472649508}], 
             PointBox[{48.6, 0.05718646750301762}], 
             PointBox[{48.7, 0.05370471329214837}], 
             PointBox[{48.8, 0.05377520973661878}], 
             PointBox[{48.9, 0.05679366268055411}], 
             PointBox[{49., 0.055801115112363284`}], 
             PointBox[{49.1, 0.054827295292288664`}], 
             PointBox[{49.2, 0.06071208496470988}], 
             PointBox[{49.3, 0.06562178075320677}], 
             PointBox[{49.4, 0.0643962936555266}], 
             PointBox[{49.5, 0.0646693072783306}], 
             PointBox[{49.6, 0.0676515244248592}], 
             PointBox[{49.7, 0.06462219501133608}], 
             PointBox[{49.8, 0.06330781017588245}], 
             PointBox[{49.9, 0.06606199114087402}], 
             PointBox[{50., 0.06682205942973472}], 
             PointBox[{50.1, 0.06420354715100078}], 
             PointBox[{50.2, 0.06858774094041238}], 
             PointBox[{50.3, 0.07453870345980948}], 
             PointBox[{50.4, 0.07493749442438312}], 
             PointBox[{50.5, 0.07366650060176022}], 
             PointBox[{50.6, 0.07721171374419913}], 
             PointBox[{50.7, 0.07534741287847167}], 
             PointBox[{50.8, 0.07295508666544492}], 
             PointBox[{50.9, 0.07491733839129897}], 
             PointBox[{51., 0.07707920719502251}], 
             PointBox[{51.1, 0.07410292660292679}], 
             PointBox[{51.2, 0.07673684737388342}], 
             PointBox[{51.3, 0.08259198556732905}], 
             PointBox[{51.4, 0.08495323126984092}], 
             PointBox[{51.5, 0.08302574943329918}], 
             PointBox[{51.6, 0.0859699347237027}], 
             PointBox[{51.7, 0.08570928062857709}], 
             PointBox[{51.8, 0.0826291677559168}], 
             PointBox[{51.9, 0.08363269098401446}], 
             PointBox[{52., 0.08651260149015194}], 
             PointBox[{52.1, 0.08426196135846231}], 
             PointBox[{52.2, 0.08499483450028233}], 
             PointBox[{52.3, 0.09038752566283009}], 
             PointBox[{52.4, 0.09437361327064034}], 
             PointBox[{52.5, 0.09265847573862783}], 
             PointBox[{52.6, 0.09431380096290805}], 
             PointBox[{52.7, 0.0956773609172017}], 
             PointBox[{52.8, 0.09228938340740087}], 
             PointBox[{52.9, 0.09240313476949773}], 
             PointBox[{53., 0.09540871614822734}], 
             PointBox[{53.1, 0.09439814464709627}], 
             PointBox[{53.2, 0.0934228983576371}], 
             PointBox[{53.3, 0.09845905695580025}], 
             PointBox[{53.4, 0.10340278629896253`}], 
             PointBox[{53.5, 0.10242858460814148`}], 
             PointBox[{53.6, 0.10273517409066811`}], 
             PointBox[{53.7, 0.10537102619971922`}], 
             PointBox[{53.8, 0.10197999178717948`}], 
             PointBox[{53.9, 0.10138363017856837`}], 
             PointBox[{54., 0.10418091394154219`}], 
             PointBox[{54.1, 0.10438140366230685`}], 
             PointBox[{54.2, 0.10217328626603879`}], 
             PointBox[{54.3, 0.10698930944870823`}], 
             PointBox[{54.4, 0.11242437955445836`}], 
             PointBox[{54.5, 0.11233480840250878`}], 
             PointBox[{54.6, 0.11163440849993506`}], 
             PointBox[{54.7, 0.11504530026783799`}], 
             PointBox[{54.8, 0.11182300369558647`}], 
             PointBox[{54.9, 0.11073415733441354`}], 
             PointBox[{55., 0.11322561199599392`}], 
             PointBox[{55.1, 0.11431487118934036`}], 
             PointBox[{55.2, 0.11139633389217554`}], 
             PointBox[{55.3, 0.11609354969734294`}], 
             PointBox[{55.4, 0.12187584779777559`}], 
             PointBox[{55.5, 0.12250862665237025`}], 
             PointBox[{55.6, 0.12123912720340038`}], 
             PointBox[{55.7, 0.12502482887084884`}], 
             PointBox[{55.8, 0.12196943692270742`}], 
             PointBox[{55.9, 0.12061791090211056`}], 
             PointBox[{56., 0.12286167942830035`}], 
             PointBox[{56.1, 0.12445059553659259`}], 
             PointBox[{56.2, 0.12121065785671833`}], 
             PointBox[{56.3, 0.12598898274834125`}], 
             PointBox[{56.4, 0.13210024480443008`}], 
             PointBox[{56.5, 0.13308406959013008`}], 
             PointBox[{56.6, 0.1316095591009265}], 
             PointBox[{56.7, 0.13556378003220534`}], 
             PointBox[{56.8, 0.13250463333441584`}], 
             PointBox[{56.9, 0.13113525499627512`}], 
             PointBox[{57., 0.1332727996991876}], 
             PointBox[{57.1, 0.13499844534493707`}], 
             PointBox[{57.2, 0.13167743599977305`}], 
             PointBox[{57.3, 0.136903598467437}], 
             PointBox[{57.4, 0.1431611289477792}], 
             PointBox[{57.5, 0.14399853869767076`}], 
             PointBox[{57.6, 0.14261405614462827`}], 
             PointBox[{57.7, 0.14663469979738736`}], 
             PointBox[{57.8, 0.14331903359699955`}], 
             PointBox[{57.9, 0.14220574648391723`}], 
             PointBox[{58., 0.14440359999595725`}], 
             PointBox[{58.1, 0.14588982306530837`}], 
             PointBox[{58.2, 0.14276806541782078`}], 
             PointBox[{58.3, 0.14886705899164887`}], 
             PointBox[{58.4, 0.15462088479122613`}], 
             PointBox[{58.5, 0.1548228676969858}], 
             PointBox[{58.6, 0.15390649021935765`}], 
             PointBox[{58.7, 0.1576949913224292}], 
             PointBox[{58.8, 0.1540159127548864}], 
             PointBox[{58.9, 0.15345438794714292`}], 
             PointBox[{59., 0.15584256405057764`}], 
             PointBox[{59.1, 0.15656733895612174`}], 
             PointBox[{59.2, 0.15436153431726649`}], 
             PointBox[{59.3, 0.16129625244655083`}], 
             PointBox[{59.4, 0.16551023382539803`}], 
             PointBox[{59.5, 0.16481222583696037`}], 
             PointBox[{59.6, 0.1650410323242386}], 
             PointBox[{59.7, 0.16768453889924861`}], 
             PointBox[{59.8, 0.16400652730394608`}], 
             PointBox[{59.9, 0.16424466867067944`}], 
             PointBox[{60., 0.16682860854406012`}], 
             PointBox[{60.1, 0.1660240313822702}], 
             PointBox[{60.2, 0.166194501031108}], 
             PointBox[{60.3, 0.17267754516395664`}], 
             PointBox[{60.4, 0.17475890298632127`}], 
             PointBox[{60.5, 0.17329435218680608`}], 
             PointBox[{60.6, 0.17559416140466091`}], 
             PointBox[{60.7, 0.1756162704649354}], 
             PointBox[{60.8, 0.172796766868995}], 
             PointBox[{60.9, 0.17392488930119304`}], 
             PointBox[{61., 0.1764396988269094}], 
             PointBox[{61.1, 0.17355804072410574`}], 
             PointBox[{61.2, 0.1773013763035264}], 
             PointBox[{61.3, 0.18157422581496}], 
             PointBox[{61.4, 0.18174230978479808`}], 
             PointBox[{61.5, 0.18018365393643007`}], 
             PointBox[{61.6, 0.18458179734672037`}], 
             PointBox[{61.7, 0.18140971996876648`}], 
             PointBox[{61.8, 0.18018303586996068`}], 
             PointBox[{61.9, 0.1820631036566612}], 
             PointBox[{62., 0.1837349762548506}], 
             PointBox[{62.1, 0.18020345667613716`}], 
             PointBox[{62.2, 0.18591297620777536`}], 
             PointBox[{62.3, 0.1875980172335851}], 
             PointBox[{62.4, 0.1864573429136182}], 
             PointBox[{62.5, 0.18620053345269738`}], 
             PointBox[{62.6, 0.19004464926314485`}], 
             PointBox[{62.7, 0.18575468427016023`}], 
             PointBox[{62.8, 0.18617002406256014`}], 
             PointBox[{62.9, 0.18840250917669854`}], 
             PointBox[{63., 0.18784743439330095`}], 
             PointBox[{63.1, 0.1872080747044175}], 
             PointBox[{63.2, 0.19134321115232722`}], 
             PointBox[{63.3, 0.19104030903099484`}], 
             PointBox[{63.4, 0.18941359760895768`}], 
             PointBox[{63.5, 0.19211919430001217`}], 
             PointBox[{63.6, 0.1917322148604633}], 
             PointBox[{63.7, 0.18922383628347594`}], 
             PointBox[{63.8, 0.1907675301046144}], 
             PointBox[{63.9, 0.19259975126742593`}], 
             PointBox[{64., 0.18923281947468715`}], 
             PointBox[{64.1, 0.19250561278174197`}], 
             PointBox[{64.2, 0.19389304688501952`}], 
             PointBox[{64.3, 0.19242911198883042`}], 
             PointBox[{64.4, 0.19152810031187148`}], 
             PointBox[{64.5, 0.1963157863961414}], 
             PointBox[{64.6, 0.19195593694696056`}], 
             PointBox[{64.7, 0.1919008439885672}], 
             PointBox[{64.8, 0.19384047598357443`}], 
             PointBox[{64.9, 0.19404596737179572`}], 
             PointBox[{65., 0.1908146340332118}], 
             PointBox[{65.1, 0.1949262264543234}], 
             PointBox[{65.2, 0.19413657576624319`}], 
             PointBox[{65.3, 0.19237688092512145`}], 
             PointBox[{65.4, 0.1937940248090395}], 
             PointBox[{65.5, 0.19585987291299353`}], 
             PointBox[{65.6, 0.19212369417388847`}], 
             PointBox[{65.7, 0.19353173883879857`}], 
             PointBox[{65.8, 0.19503060215836743`}], 
             PointBox[{65.9, 0.19244472383528546`}], 
             PointBox[{66., 0.1927170237899694}], 
             PointBox[{66.1, 0.19448469353438028`}], 
             PointBox[{66.2, 0.19263061998383801`}], 
             PointBox[{66.3, 0.19153633582015867`}], 
             PointBox[{66.4, 0.19574014380843346`}], 
             PointBox[{66.5, 0.19267201555629115`}], 
             PointBox[{66.6, 0.19199631522561372`}], 
             PointBox[{66.7, 0.19369128490943743`}], 
             PointBox[{66.8, 0.19376795992262807`}], 
             PointBox[{66.9, 0.18921018942916118`}], 
             PointBox[{67., 0.1926541290675369}], 
             PointBox[{67.1, 0.19176533135045248`}], 
             PointBox[{67.2, 0.18980988865593953`}], 
             PointBox[{67.3, 0.19043581079033364`}], 
             PointBox[{67.4, 0.19423310791424736`}], 
             PointBox[{67.5, 0.18956255338147415`}], 
             PointBox[{67.6, 0.1908241272447556}], 
             PointBox[{67.7, 0.19185342100427946`}], 
             PointBox[{67.8, 0.18954582076352638`}], 
             PointBox[{67.9, 0.1864832596718383}], 
             PointBox[{68., 0.18940973907913972`}], 
             PointBox[{68.1, 0.1872647950276359}], 
             PointBox[{68.2, 0.18594862547770374`}], 
             PointBox[{68.3, 0.18888017041071428`}], 
             PointBox[{68.4, 0.18844228709922126`}], 
             PointBox[{68.5, 0.18633340330271558`}], 
             PointBox[{68.6, 0.18789427164776912`}], 
             PointBox[{68.7, 0.18743792770979606`}], 
             PointBox[{68.8, 0.1824043464598249}], 
             PointBox[{68.9, 0.183418155222453}], 
             PointBox[{69., 0.18350759977060005`}], 
             PointBox[{69.1, 0.18121696226378636`}], 
             PointBox[{69.2, 0.18110160020200688`}], 
             PointBox[{69.3, 0.18529352004723565`}], 
             PointBox[{69.4, 0.1812937659589564}], 
             PointBox[{69.5, 0.1818607177097455}], 
             PointBox[{69.6, 0.18263001385158126`}], 
             PointBox[{69.7, 0.17995783571120857`}], 
             PointBox[{69.8, 0.1738372621355673}], 
             PointBox[{69.9, 0.17738647758692536`}], 
             PointBox[{70., 0.1755313401345718}], 
             PointBox[{70.1, 0.1736774638723654}], 
             PointBox[{70.2, 0.1750303938426384}], 
             PointBox[{70.3, 0.17808117908683246`}], 
             PointBox[{70.4, 0.1737526683586989}], 
             PointBox[{70.5, 0.17538461109851947`}], 
             PointBox[{70.6, 0.17467552007273332`}], 
             PointBox[{70.7, 0.16948972508575208`}], 
             PointBox[{70.8, 0.16539341502100108`}], 
             PointBox[{70.9, 0.16848039803247597`}], 
             PointBox[{71., 0.16588135610885893`}], 
             PointBox[{71.1, 0.1646995304631994}], 
             PointBox[{71.2, 0.1673209083500322}], 
             PointBox[{71.3, 0.1679010367405408}], 
             PointBox[{71.4, 0.16515259767223472`}], 
             PointBox[{71.5, 0.1667304707033252}], 
             PointBox[{71.6, 0.1641664574490896}], 
             PointBox[{71.7, 0.1573670666254787}], 
             PointBox[{71.8, 0.15616221941540842`}], 
             PointBox[{71.9, 0.15779176391447813`}], 
             PointBox[{72., 0.15504620837570782`}], 
             PointBox[{72.1, 0.15453556107878313`}], 
             PointBox[{72.2, 0.15786879603627815`}], 
             PointBox[{72.3, 0.15644946335902105`}], 
             PointBox[{72.4, 0.15524056409883624`}], 
             PointBox[{72.5, 0.15635546909136774`}], 
             PointBox[{72.6, 0.1520864380712026}], 
             PointBox[{72.7, 0.14518269224073233`}], 
             PointBox[{72.8, 0.1458569204531001}], 
             PointBox[{72.9, 0.14642819130608306`}], 
             PointBox[{73., 0.14370930526546385`}], 
             PointBox[{73.1, 0.1437040290693433}], 
             PointBox[{73.2, 0.14724293287587972`}], 
             PointBox[{73.3, 0.14483393254400076`}], 
             PointBox[{73.4, 0.1444711644856482}], 
             PointBox[{73.5, 0.1451912539868982}], 
             PointBox[{73.6, 0.1399572378397447}], 
             PointBox[{73.7, 0.13366502633064228`}], 
             PointBox[{73.8, 0.13511740197151698`}], 
             PointBox[{73.9, 0.13526647408329218`}], 
             PointBox[{74., 0.13254913878381316`}], 
             PointBox[{74.1, 0.1327993658856325}], 
             PointBox[{74.2, 0.13632011139613232`}], 
             PointBox[{74.3, 0.13367413160333688`}], 
             PointBox[{74.4, 0.13352659828252714`}], 
             PointBox[{74.5, 0.1341666007456107}], 
             PointBox[{74.6, 0.12874971647661163`}], 
             PointBox[{74.7, 0.1230243853518742}], 
             PointBox[{74.8, 0.1245146101344971}], 
             PointBox[{74.9, 0.12478138283769794`}], 
             PointBox[{75., 0.12198262448672882`}], 
             PointBox[{75.1, 0.12222293900553347`}], 
             PointBox[{75.2, 0.12569092962727177`}], 
             PointBox[{75.3, 0.12330585874954754`}], 
             PointBox[{75.4, 0.12286823247767201`}], 
             PointBox[{75.5, 0.12377476147196667`}], 
             PointBox[{75.6, 0.11863145887374656`}], 
             PointBox[{75.7, 0.11323692131968299`}], 
             PointBox[{75.8, 0.11422279916696687`}], 
             PointBox[{75.9, 0.1150444672650219}], 
             PointBox[{76., 0.11211476620271435`}], 
             PointBox[{76.1, 0.112094834808797}], 
             PointBox[{76.2, 0.11549305359491836`}], 
             PointBox[{76.3, 0.1137900826803231}], 
             PointBox[{76.4, 0.11263330459002585`}], 
             PointBox[{76.5, 0.11402294287792093`}], 
             PointBox[{76.6, 0.10942802740036972`}], 
             PointBox[{76.7, 0.1041547705918655}], 
             PointBox[{76.8, 0.1041619704107719}], 
             PointBox[{76.9, 0.10584636623457028`}], 
             PointBox[{77., 0.10284801208106949`}], 
             PointBox[{77.1, 0.1023412443374602}], 
             PointBox[{77.2, 0.10557399308654972`}], 
             PointBox[{77.3, 0.10494558055648062`}], 
             PointBox[{77.4, 0.10277811207983878`}], 
             PointBox[{77.5, 0.10462419008493486`}], 
             PointBox[{77.6, 0.10092204505142248`}], 
             PointBox[{77.7, 0.09556913388007578}], 
             PointBox[{77.8, 0.09422595765262073}], 
             PointBox[{77.9, 0.09681946943483888}], 
             PointBox[{78., 0.09400053340734775}], 
             PointBox[{78.1, 0.09281806769421277}], 
             PointBox[{78.2, 0.09569159873677782}], 
             PointBox[{78.3, 0.09640164107630411}], 
             PointBox[{78.4, 0.09325276177896791}], 
             PointBox[{78.5, 0.09520411059286621}], 
             PointBox[{78.6, 0.09286286838850176}], 
             PointBox[{78.7, 0.08725977265959041}], 
             PointBox[{78.8, 0.0844198464846972}], 
             PointBox[{78.9, 0.08753417155873243}], 
             PointBox[{79., 0.08536673107326831}], 
             PointBox[{79.1, 0.08340286862634788}], 
             PointBox[{79.2, 0.08564600728388023}], 
             PointBox[{79.3, 0.08768765902585655}], 
             PointBox[{79.4, 0.08408262147600508}], 
             PointBox[{79.5, 0.08546351242265923}], 
             PointBox[{79.6, 0.08482003502900863}], 
             PointBox[{79.7, 0.07907544783280646}], 
             PointBox[{79.8, 0.07486036356807485}], 
             PointBox[{79.9, 0.07762663432793616}], 
             PointBox[{80., 0.07671439620185778}], 
             PointBox[{80.1, 0.0740380483305253}], 
             PointBox[{80.2, 0.07534327853324885}], 
             PointBox[{80.3, 0.0783835226077365}], 
             PointBox[{80.4, 0.07528624979633404}], 
             PointBox[{80.5, 0.0753007869072696}], 
             PointBox[{80.6, 0.07623508973184621}], 
             PointBox[{80.7, 0.07107589338606694}], 
             PointBox[{80.8, 0.06568121091015947}], 
             PointBox[{80.9, 0.0669908949207511}], 
             PointBox[{81., 0.06775335214925386}], 
             PointBox[{81.1, 0.06472886571580655}], 
             PointBox[{81.2, 0.0648170953457835}], 
             PointBox[{81.3, 0.06827385189107267}], 
             PointBox[{81.4, 0.06667520028516033}], 
             PointBox[{81.5, 0.06488857906833531}], 
             PointBox[{81.6, 0.06672658604423239}], 
             PointBox[{81.7, 0.0633698588200575}], 
             PointBox[{81.8, 0.05694717341383419}], 
             PointBox[{81.9, 0.055924649353027954`}], 
             PointBox[{82., 0.05815070594773051}], 
             PointBox[{82.1, 0.05548876394816972}], 
             PointBox[{82.2, 0.05422254848238405}], 
             PointBox[{82.3, 0.0574071383124481}], 
             PointBox[{82.4, 0.05780046404479981}], 
             PointBox[{82.5, 0.05463030351525565}], 
             PointBox[{82.6, 0.05626390505017136}], 
             PointBox[{82.7, 0.05535152717508528}], 
             PointBox[{82.8, 0.04870244547320932}], 
             PointBox[{82.9, 0.04504761562044801}], 
             PointBox[{83., 0.04770235179039449}], 
             PointBox[{83.1, 0.04625160387950994}], 
             PointBox[{83.2, 0.043807833816768435`}], 
             PointBox[{83.3, 0.046062909218229475`}], 
             PointBox[{83.4, 0.04823341671100865}], 
             PointBox[{83.5, 0.04489227801227676}], 
             PointBox[{83.6, 0.04517815299936308}], 
             PointBox[{83.7, 0.04626637761161176}], 
             PointBox[{83.8, 0.0410345069862577}], 
             PointBox[{83.9, 0.035028160037405096`}], 
             PointBox[{84., 0.03662345988277659}], 
             PointBox[{84.1, 0.03685966325086279}], 
             PointBox[{84.2, 0.03384874728563678}], 
             PointBox[{84.3, 0.03470257502874327}], 
             PointBox[{84.4, 0.03794636698146819}], 
             PointBox[{84.5, 0.03568207963508326}], 
             PointBox[{84.6, 0.03411792524617717}], 
             PointBox[{84.7, 0.036142104035400274`}], 
             PointBox[{84.8, 0.03352212381500957}], 
             PointBox[{84.9, 0.026420646658373445`}], 
             PointBox[{85., 0.02575035766051844}], 
             PointBox[{85.1, 0.0273537245383559}], 
             PointBox[{85.2, 0.024624891710767826`}], 
             PointBox[{85.3, 0.024012621332157952`}], 
             PointBox[{85.4, 0.027541986709401733`}], 
             PointBox[{85.5, 0.026827638008202804`}], 
             PointBox[{85.6, 0.023909435934968252`}], 
             PointBox[{85.7, 0.02572100366888235}], 
             PointBox[{85.8, 0.025517385007254013`}], 
             PointBox[{85.9, 0.019613375407652126`}], 
             PointBox[{86., 0.016699222141335467`}], 
             PointBox[{86.1, 0.018837264312591077`}], 
             PointBox[{86.2, 0.016832641379815008`}], 
             PointBox[{86.3, 0.015325748154323074`}], 
             PointBox[{86.4, 0.018728859372524477`}], 
             PointBox[{86.5, 0.018996918341655032`}], 
             PointBox[{86.6, 0.015620790574512954`}], 
             PointBox[{86.7, 0.016775835451762446`}], 
             PointBox[{86.8, 0.018050952657431885`}], 
             PointBox[{86.9, 0.01439879628103916}], 
             PointBox[{87., 0.012600967961240411`}], 
             PointBox[{87.1, 0.015157437306113082`}], 
             PointBox[{87.2, 0.013545871081095569`}], 
             PointBox[{87.3, 0.012195984547760438`}], 
             PointBox[{87.4, 0.015603440953809364`}], 
             PointBox[{87.5, 0.01563965361080594}], 
             PointBox[{87.6, 0.012198840118245307`}], 
             PointBox[{87.7, 0.01348085712752431}], 
             PointBox[{87.8, 0.015279231150114606`}], 
             PointBox[{87.9, 0.012927824109100287`}], 
             PointBox[{88., 0.015206417321790889`}], 
             PointBox[{88.1, 0.019402501424369813`}], 
             PointBox[{88.2, 0.01850504248631687}], 
             PointBox[{88.3, 0.017100347889771148`}], 
             PointBox[{88.4, 0.020385279595481025`}], 
             PointBox[{88.5, 0.02042997503952156}], 
             PointBox[{88.6, 0.016957833124003775`}], 
             PointBox[{88.7, 0.018188974708111517`}], 
             PointBox[{88.8, 0.020450128438581676`}], 
             PointBox[{88.9, 0.018437743254144257`}], 
             PointBox[{89., 0.02070774354113703}], 
             PointBox[{89.1, 0.027130131043712667`}], 
             PointBox[{89.2, 0.027988554024962753`}], 
             PointBox[{89.3, 0.025993096673035856`}], 
             PointBox[{89.4, 0.028570937787306544`}], 
             PointBox[{89.5, 0.029802734731360393`}], 
             PointBox[{89.6, 0.026296841977876663`}], 
             PointBox[{89.7, 0.026433955444985585`}], 
             PointBox[{89.8, 0.029336147005801085`}], 
             PointBox[{89.9, 0.028103311255667254`}], 
             PointBox[{90., 0.02797160999749307}], 
             PointBox[{90.1, 0.03495261000964974}], 
             PointBox[{90.2, 0.038388941795518834`}], 
             PointBox[{90.3, 0.03651162035425187}], 
             PointBox[{90.4, 0.03750523981101211}], 
             PointBox[{90.5, 0.04021406191320265}], 
             PointBox[{90.6, 0.03723576247372308}], 
             PointBox[{90.7, 0.03588529424877985}], 
             PointBox[{90.8, 0.038806356313909225`}], 
             PointBox[{90.9, 0.03911001391200793}], 
             PointBox[{91., 0.03703371298312899}], 
             PointBox[{91.1, 0.04239663396422245}], 
             PointBox[{91.2, 0.04824143606309025}], 
             PointBox[{91.3, 0.04766086570000169}], 
             PointBox[{91.4, 0.04685947617975366}], 
             PointBox[{91.5, 0.05029611384740081}], 
             PointBox[{91.6, 0.048647555463258337`}], 
             PointBox[{91.7, 0.046017776275095054`}], 
             PointBox[{91.8, 0.04813353162238952}], 
             PointBox[{91.9, 0.05004447548441918}], 
             PointBox[{92., 0.04738745230642094}], 
             PointBox[{92.1, 0.05021853095714831}], 
             PointBox[{92.2, 0.056976822195957094`}], 
             PointBox[{92.3, 0.05863075761685538}], 
             PointBox[{92.4, 0.05680017927166886}], 
             PointBox[{92.5, 0.059630213278609595`}], 
             PointBox[{92.6, 0.05990128817516686}], 
             PointBox[{92.7, 0.056545061330414655`}], 
             PointBox[{92.8, 0.05737207244490815}], 
             PointBox[{92.9, 0.06024221196510319}], 
             PointBox[{93., 0.05842184257716119}], 
             PointBox[{93.1, 0.05862751086339722}], 
             PointBox[{93.2, 0.06479951035727627}], 
             PointBox[{93.3, 0.06884378647421233}], 
             PointBox[{93.4, 0.06718664166603554}], 
             PointBox[{93.5, 0.06838911486988179}], 
             PointBox[{93.6, 0.0705725816197102}], 
             PointBox[{93.7, 0.06718137739888197}], 
             PointBox[{93.8, 0.06665716126591849}], 
             PointBox[{93.9, 0.06963145173354628}], 
             PointBox[{94., 0.06943938955664698}], 
             PointBox[{94.1, 0.06753194235732636}], 
             PointBox[{94.2, 0.07257232008027001}], 
             PointBox[{94.3, 0.07806288344891332}], 
             PointBox[{94.4, 0.0775913387652515}], 
             PointBox[{94.5, 0.07704875462799798}], 
             PointBox[{94.6, 0.08043544283319845}], 
             PointBox[{94.7, 0.077692452080176}], 
             PointBox[{94.8, 0.07601858146745312}], 
             PointBox[{94.9, 0.07847914051688006}], 
             PointBox[{95., 0.07988253880972747}], 
             PointBox[{95.1, 0.0768864989012318}], 
             PointBox[{95.2, 0.08065044895101206}], 
             PointBox[{95.3, 0.08642105546715874}], 
             PointBox[{95.4, 0.08765204437267575}], 
             PointBox[{95.5, 0.08598785992703775}], 
             PointBox[{95.6, 0.08951537876862825}], 
             PointBox[{95.7, 0.08794767803092961}], 
             PointBox[{95.8, 0.08542888090582504}], 
             PointBox[{95.9, 0.08711014353058096}], 
             PointBox[{96., 0.08957508716847247}], 
             PointBox[{96.1, 0.08658842408451181}], 
             PointBox[{96.2, 0.08886376386722893}], 
             PointBox[{96.3, 0.09438617456631704}], 
             PointBox[{96.4, 0.0972721577299354}], 
             PointBox[{96.5, 0.09530024836916583}], 
             PointBox[{96.6, 0.09810156265922408}], 
             PointBox[{96.7, 0.09794298849975493}], 
             PointBox[{96.8, 0.09488906404010278}], 
             PointBox[{96.9, 0.0957886514920565}], 
             PointBox[{97., 0.09872064216763066}], 
             PointBox[{97.1, 0.0964807434167081}], 
             PointBox[{97.2, 0.09722546074572355}], 
             PointBox[{97.3, 0.10251306931033527`}], 
             PointBox[{97.4, 0.10661906444698252`}], 
             PointBox[{97.5, 0.10493456575541572`}], 
             PointBox[{97.6, 0.10664979526856906`}], 
             PointBox[{97.7, 0.10780199165886102`}], 
             PointBox[{97.8, 0.10447190716764079`}], 
             PointBox[{97.9, 0.10472890791505099`}], 
             PointBox[{98., 0.10771966603099292`}], 
             PointBox[{98.1, 0.10645972197880237`}], 
             PointBox[{98.2, 0.10591455241169012`}], 
             PointBox[{98.3, 0.11115941842500174`}], 
             PointBox[{98.4, 0.11602955605908272`}], 
             PointBox[{98.5, 0.11488216546245553`}], 
             PointBox[{98.6, 0.11561597572220789`}], 
             PointBox[{98.7, 0.11774701366864226`}], 
             PointBox[{98.8, 0.1143094561039241}], 
             PointBox[{98.9, 0.11412737023966807`}], 
             PointBox[{99., 0.11699390369979751`}], 
             PointBox[{99.1, 0.1165603326761839}], 
             PointBox[{99.2, 0.11514686407572228`}], 
             PointBox[{99.3, 0.12053992496943}], 
             PointBox[{99.4, 0.12588136527191857`}], 
             PointBox[{99.5, 0.1252121181597005}], 
             PointBox[{99.6, 0.12531796285952634`}], 
             PointBox[{99.7, 0.1280236710018842}], 
             PointBox[{99.8, 0.12453987801020146`}], 
             PointBox[{99.9, 0.12415261689549269`}], 
             PointBox[{100., 0.12687957515267503`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 0.2}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
             PointBox[{0.1, 338.5526545001986}], 
             PointBox[{0.2, 345.62861482478456`}], 
             PointBox[{0.3, 343.7686697530962}], 
             PointBox[{0.4, 332.70849517431327`}], 
             PointBox[{0.5, 341.77583172292987`}], 
             PointBox[{0.6, 349.8647532870555}], 
             PointBox[{0.7, 337.53713387668205`}], 
             PointBox[{0.8, 335.9777714510052}], 
             PointBox[{0.9, 344.25812439299733`}], 
             PointBox[{1., 332.13742247816407`}], 
             PointBox[{1.1, 317.6257089673661}], 
             PointBox[{1.2, 321.278310632163}], 
             PointBox[{1.3, 322.08234949355005`}], 
             PointBox[{1.4, 314.3922577621723}], 
             PointBox[{1.5, 319.4323402665269}], 
             PointBox[{1.6, 325.7898515046204}], 
             PointBox[{1.7, 318.1156635770443}], 
             PointBox[{1.8, 315.2284590313473}], 
             PointBox[{1.9, 321.8133611072529}], 
             PointBox[{2., 318.25407453804246`}], 
             PointBox[{2.1, 312.00471503764965`}], 
             PointBox[{2.2, 313.14269974122044`}], 
             PointBox[{2.3, 316.0352908862424}], 
             PointBox[{2.4, 311.247512726406}], 
             PointBox[{2.5, 312.11398555665767`}], 
             PointBox[{2.6, 317.9405036007586}], 
             PointBox[{2.7, 314.3931707361264}], 
             PointBox[{2.8, 310.1429179435668}], 
             PointBox[{2.9, 314.2375480113187}], 
             PointBox[{3., 315.1287220259906}], 
             PointBox[{3.1, 310.8692808328134}], 
             PointBox[{3.2, 312.17330607491226`}], 
             PointBox[{3.3, 315.5778445825711}], 
             PointBox[{3.4, 313.7836742305379}], 
             PointBox[{3.5, 311.8589362352788}], 
             PointBox[{3.6, 316.68340456045604`}], 
             PointBox[{3.7, 316.07905013732744`}], 
             PointBox[{3.8, 311.7441020143225}], 
             PointBox[{3.9, 313.2441778503115}], 
             PointBox[{4., 316.2167902681447}], 
             PointBox[{4.1, 312.6544362052688}], 
             PointBox[{4.2, 314.44050384946996`}], 
             PointBox[{4.3, 317.4850671122611}], 
             PointBox[{4.4, 318.0868520157372}], 
             PointBox[{4.5, 315.236632709521}], 
             PointBox[{4.6, 318.31397615044614`}], 
             PointBox[{4.7, 319.68607046838474`}], 
             PointBox[{4.8, 316.16873183607754`}], 
             PointBox[{4.9, 315.6276456651999}], 
             PointBox[{5., 318.8842850039732}], 
             PointBox[{5.1, 317.02148978226313`}], 
             PointBox[{5.2, 317.7218974326525}], 
             PointBox[{5.3, 320.73077926558494`}], 
             PointBox[{5.4, 322.7637748062376}], 
             PointBox[{5.5, 320.5577170514002}], 
             PointBox[{5.6, 321.55255969638637`}], 
             PointBox[{5.7, 324.05682004004757`}], 
             PointBox[{5.8, 321.7111218358661}], 
             PointBox[{5.9, 319.98441268184126`}], 
             PointBox[{6., 322.407283309019}], 
             PointBox[{6.1, 322.5163626016444}], 
             PointBox[{6.2, 321.5051132907465}], 
             PointBox[{6.3, 324.8310181561044}], 
             PointBox[{6.4, 327.47833535401446`}], 
             PointBox[{6.5, 326.62779019039385`}], 
             PointBox[{6.6, 325.89869389954043`}], 
             PointBox[{6.7, 328.75150433261285`}], 
             PointBox[{6.8, 327.58388916984103`}], 
             PointBox[{6.9, 325.4206068740295}], 
             PointBox[{7., 326.64043650635585`}], 
             PointBox[{7.1, 328.17344028458524`}], 
             PointBox[{7.2, 326.2904528385218}], 
             PointBox[{7.3, 329.3725030555123}], 
             PointBox[{7.4, 332.2115005327045}], 
             PointBox[{7.5, 332.6643247804405}], 
             PointBox[{7.6, 331.048501681105}], 
             PointBox[{7.7, 333.57254155224354`}], 
             PointBox[{7.8, 333.4259954571858}], 
             PointBox[{7.9, 331.29995787144577`}], 
             PointBox[{8., 331.46519317901}], 
             PointBox[{8.1, 333.59613902689716`}], 
             PointBox[{8.2, 331.82636670256466`}], 
             PointBox[{8.3, 334.0104077937923}], 
             PointBox[{8.4, 336.96149441157917`}], 
             PointBox[{8.5, 338.32727530138277`}], 
             PointBox[{8.6, 336.6523999316457}], 
             PointBox[{8.7, 338.4085800387088}], 
             PointBox[{8.8, 339.05750490942427`}], 
             PointBox[{8.9, 337.1955003489866}], 
             PointBox[{9., 336.6494654752179}], 
             PointBox[{9.1, 338.7196210319698}], 
             PointBox[{9.2, 337.6060915136173}], 
             PointBox[{9.3, 338.6803466666717}], 
             PointBox[{9.4, 341.675938717158}], 
             PointBox[{9.5, 343.5410140573505}], 
             PointBox[{9.6, 342.29378776499397`}], 
             PointBox[{9.7, 343.1686104096034}], 
             PointBox[{9.8, 344.36322877775154`}], 
             PointBox[{9.9, 342.829675309579}], 
             PointBox[{10., 341.89788320621625`}], 
             PointBox[{10.1, 343.58020646288685`}], 
             PointBox[{10.2, 343.2240148685888}], 
             PointBox[{10.3, 343.3910122254858}], 
             PointBox[{10.4, 346.25401201255556`}], 
             PointBox[{10.5, 348.2949913065549}], 
             PointBox[{10.6, 347.5917474643463}], 
             PointBox[{10.7, 347.7388709684623}], 
             PointBox[{10.8, 349.2401625181292}], 
             PointBox[{10.9, 348.0061090579571}], 
             PointBox[{11., 346.9208699820704}], 
             PointBox[{11.1, 348.1648783756001}], 
             PointBox[{11.2, 348.39869910332806`}], 
             PointBox[{11.3, 347.9945025169088}], 
             PointBox[{11.4, 350.5550681997518}], 
             PointBox[{11.5, 352.5422895368902}], 
             PointBox[{11.6, 352.267094731464}], 
             PointBox[{11.7, 351.9568527185836}], 
             PointBox[{11.8, 353.57068905288975`}], 
             PointBox[{11.9, 352.5558436519882}], 
             PointBox[{12., 351.4597179231591}], 
             PointBox[{12.1, 352.3660199020079}], 
             PointBox[{12.2, 352.93025448407155`}], 
             PointBox[{12.3, 352.2518144038428}], 
             PointBox[{12.4, 354.3963197563445}], 
             PointBox[{12.5, 356.17485454617446`}], 
             PointBox[{12.6, 356.11863932921284`}], 
             PointBox[{12.7, 355.61654299012554`}], 
             PointBox[{12.8, 357.20757859345224`}], 
             PointBox[{12.9, 356.3083650784446}], 
             PointBox[{13., 355.2836208943844}], 
             PointBox[{13.1, 356.0064214475878}], 
             PointBox[{13.2, 356.6469122303966}], 
             PointBox[{13.3, 355.9110986834416}], 
             PointBox[{13.4, 357.55274328714626`}], 
             PointBox[{13.5, 359.036164215011}], 
             PointBox[{13.6, 358.9836573604348}], 
             PointBox[{13.7, 358.51677638360303`}], 
             PointBox[{13.8, 359.98121393644084`}], 
             PointBox[{13.9, 359.0976378378395}], 
             PointBox[{14., 358.19762248618645`}], 
             PointBox[{14.1, 358.894361784728}], 
             PointBox[{14.2, 359.3721203461653}], 
             PointBox[{14.3, 358.73484723875686`}], 
             PointBox[{14.4, 359.8073056391245}], 
             PointBox[{14.5, 0.9786278912442506}], 
             PointBox[{14.6, 0.7426364778083259}], 
             PointBox[{14.7, 0.5420813965896559}], 
             PointBox[{14.8, 1.7399169622313164`}], 
             PointBox[{14.9, 0.8110974668922086}], 
             PointBox[{15., 0.08561334801710876}], 
             PointBox[{15.1, 0.8950219274640341}], 
             PointBox[{15.2, 0.9498986136521861}], 
             PointBox[{15.3, 0.48230919067542716`}], 
             PointBox[{15.4, 1.072463308084407}], 
             PointBox[{15.5, 1.9426285557956366`}], 
             PointBox[{15.6, 1.3849271905975704`}], 
             PointBox[{15.7, 1.7229949550293475`}], 
             PointBox[{15.8, 2.4293044624820492`}], 
             PointBox[{15.9, 1.4694399596614673`}], 
             PointBox[{16., 0.9812528854356397}], 
             PointBox[{16.1, 1.9894365132728635`}], 
             PointBox[{16.2, 1.3710375067475309`}], 
             PointBox[{16.3, 1.0001197472879388`}], 
             PointBox[{16.4, 1.457442309991157}], 
             PointBox[{16.5, 1.9982597094012355`}], 
             PointBox[{16.6, 1.0946062772009912`}], 
             PointBox[{16.7, 2.1545764128247726`}], 
             PointBox[{16.8, 2.1616615157496595`}], 
             PointBox[{16.9, 1.2650329506278435`}], 
             PointBox[{17., 1.0961506608745832`}], 
             PointBox[{17.1, 2.219185759619754}], 
             PointBox[{17.2, 0.9095962875590502}], 
             PointBox[{17.3, 0.6582381268424182}], 
             PointBox[{17.4, 1.170486266706702}], 
             PointBox[{17.5, 1.292399875820517}], 
             PointBox[{17.6, 0.3308923657896414}], 
             PointBox[{17.7, 1.830344346909269}], 
             PointBox[{17.8, 1.201901673217691}], 
             PointBox[{17.9, 0.5009715886618865}], 
             PointBox[{18., 0.7428559473661203}], 
             PointBox[{18.1, 1.4830396649574527`}], 
             PointBox[{18.2, 359.84349986984216`}], 
             PointBox[{18.3, 359.9680375913033}], 
             PointBox[{18.4, 0.38656058963126383`}], 
             PointBox[{18.5, 359.98299339282374`}], 
             PointBox[{18.6, 359.71850483243077`}], 
             PointBox[{18.7, 0.7584648465594854}], 
             PointBox[{18.8, 359.8658405683141}], 
             PointBox[{18.9, 359.4815235726439}], 
             PointBox[{19., 0.16844201231621392`}], 
             PointBox[{19.1, 359.69884280193844`}], 
             PointBox[{19.2, 358.6081818743664}], 
             PointBox[{19.3, 359.07293176624364`}], 
             PointBox[{19.4, 359.1994471165915}], 
             PointBox[{19.5, 358.31317165163495`}], 
             PointBox[{19.6, 359.2923114273921}], 
             PointBox[{19.7, 359.1833699236601}], 
             PointBox[{19.8, 358.41950174667426`}], 
             PointBox[{19.9, 358.4375482461248}], 
             PointBox[{20., 359.30115568818496`}], 
             PointBox[{20.1, 357.52786437753656`}], 
             PointBox[{20.2, 357.5613825931165}], 
             PointBox[{20.3, 357.9614788543681}], 
             PointBox[{20.4, 357.6533074286533}], 
             PointBox[{20.5, 356.84993949138624`}], 
             PointBox[{20.6, 358.3142971472267}], 
             PointBox[{20.7, 357.45659051034426`}], 
             PointBox[{20.8, 357.04021424096527`}], 
             PointBox[{20.9, 357.4795153158018}], 
             PointBox[{21., 357.5755019002714}], 
             PointBox[{21.1, 355.9017273882846}], 
             PointBox[{21.2, 356.5200277902887}], 
             PointBox[{21.3, 356.60769875794006`}], 
             PointBox[{21.4, 355.843749730826}], 
             PointBox[{21.5, 356.1543203561273}], 
             PointBox[{21.6, 356.6518420229571}], 
             PointBox[{21.7, 355.8259440741911}], 
             PointBox[{21.8, 355.8178012929925}], 
             PointBox[{21.9, 356.4967986218916}], 
             PointBox[{22., 355.0130432056336}], 
             PointBox[{22.1, 354.8436393704603}], 
             PointBox[{22.2, 355.3331158223607}], 
             PointBox[{22.3, 355.01390199841154`}], 
             PointBox[{22.4, 354.1057472511891}], 
             PointBox[{22.5, 355.5233083260591}], 
             PointBox[{22.6, 354.81845592410446`}], 
             PointBox[{22.7, 354.40210104073594`}], 
             PointBox[{22.8, 354.75250304529254`}], 
             PointBox[{22.9, 355.0014552140895}], 
             PointBox[{23., 353.0862699380063}], 
             PointBox[{23.1, 353.8632722282562}], 
             PointBox[{23.2, 353.9642498141608}], 
             PointBox[{23.3, 353.25809169276255`}], 
             PointBox[{23.4, 353.01380409053274`}], 
             PointBox[{23.5, 354.1007838399893}], 
             PointBox[{23.6, 353.181475141801}], 
             PointBox[{23.7, 353.20629336185004`}], 
             PointBox[{23.8, 353.71655611860274`}], 
             PointBox[{23.9, 352.7339458958873}], 
             PointBox[{24., 352.076456962336}], 
             PointBox[{24.1, 352.7724682700864}], 
             PointBox[{24.2, 352.4620625059002}], 
             PointBox[{24.3, 351.5635719664409}], 
             PointBox[{24.4, 352.5381289384066}], 
             PointBox[{24.5, 352.3420551658544}], 
             PointBox[{24.6, 351.8583979742351}], 
             PointBox[{24.7, 352.2084670457564}], 
             PointBox[{24.8, 352.4401203242034}], 
             PointBox[{24.9, 350.6841053797698}], 
             PointBox[{25., 351.3519089735577}], 
             PointBox[{25.1, 351.61361357760893`}], 
             PointBox[{25.2, 350.95888047109895`}], 
             PointBox[{25.3, 350.30428812279234`}], 
             PointBox[{25.4, 351.7934957223722}], 
             PointBox[{25.5, 350.8399284553725}], 
             PointBox[{25.6, 350.87675243891834`}], 
             PointBox[{25.7, 351.3513511734708}], 
             PointBox[{25.8, 351.0067637024716}], 
             PointBox[{25.9, 349.66841160893796`}], 
             PointBox[{26., 350.72243232695206`}], 
             PointBox[{26.1, 350.55474097469573`}], 
             PointBox[{26.2, 349.68261582821515`}], 
             PointBox[{26.3, 349.75883166792613`}], 
             PointBox[{26.4, 350.67875846425744`}], 
             PointBox[{26.5, 349.83602400789204`}], 
             PointBox[{26.6, 350.2823593004947}], 
             PointBox[{26.7, 350.64860308076146`}], 
             PointBox[{26.8, 349.92887274430836`}], 
             PointBox[{26.9, 349.51811652746693`}], 
             PointBox[{27., 350.36495475733005`}], 
             PointBox[{27.1, 349.8551860091271}], 
             PointBox[{27.2, 348.9384306386041}], 
             PointBox[{27.3, 349.84712266200944`}], 
             PointBox[{27.4, 349.85249510744313`}], 
             PointBox[{27.5, 349.46031716118017`}], 
             PointBox[{27.6, 350.19713786220893`}], 
             PointBox[{27.7, 350.52513058566984`}], 
             PointBox[{27.8, 349.60592661214224`}], 
             PointBox[{27.9, 350.05990281030057`}], 
             PointBox[{28., 350.5925916914892}], 
             PointBox[{28.1, 349.82778169786855`}], 
             PointBox[{28.2, 349.02576069320935`}], 
             PointBox[{28.3, 350.45583443270465`}], 
             PointBox[{28.4, 349.81634255782285`}], 
             PointBox[{28.5, 349.86599944348575`}], 
             PointBox[{28.6, 350.8402730495595}], 
             PointBox[{28.7, 351.5372186743534}], 
             PointBox[{28.8, 350.4305337815573}], 
             PointBox[{28.9, 351.4069022389698}], 
             PointBox[{29., 351.7022046605493}], 
             PointBox[{29.1, 350.7495017968687}], 
             PointBox[{29.2, 350.127730993537}], 
             PointBox[{29.3, 351.7635709947743}], 
             PointBox[{29.4, 350.811917752474}], 
             PointBox[{29.5, 351.19390768598396`}], 
             PointBox[{29.6, 352.4505058686964}], 
             PointBox[{29.7, 353.66204617547555`}], 
             PointBox[{29.8, 352.4381132836819}], 
             PointBox[{29.9, 353.6742097898797}], 
             PointBox[{30., 353.85348619642355`}], 
             PointBox[{30.1, 352.7551295325714}], 
             PointBox[{30.2, 352.2637439490241}], 
             PointBox[{30.3, 353.98843683470386`}], 
             PointBox[{30.4, 352.90480484298644`}], 
             PointBox[{30.5, 353.4781205386582}], 
             PointBox[{30.6, 355.08750774125116`}], 
             PointBox[{30.7, 356.76476252457815`}], 
             PointBox[{30.8, 355.4828592888042}], 
             PointBox[{30.9, 356.8287362556638}], 
             PointBox[{31., 357.0308472805204}], 
             PointBox[{31.1, 355.8097479302033}], 
             PointBox[{31.2, 355.3261916635366}], 
             PointBox[{31.3, 357.14988360547756`}], 
             PointBox[{31.4, 356.0307804495957}], 
             PointBox[{31.5, 356.617453822952}], 
             PointBox[{31.6, 358.5720848996682}], 
             PointBox[{31.7, 0.6850143302414708}], 
             PointBox[{31.8, 359.3921990921696}], 
             PointBox[{31.9, 0.7085599928051398}], 
             PointBox[{32., 1.0945505203950137`}], 
             PointBox[{32.1, 359.77282969822187`}], 
             PointBox[{32.2, 359.1503305850503}], 
             PointBox[{32.3, 1.0850316014010182`}], 
             PointBox[{32.4, 0.06216560195531042}], 
             PointBox[{32.5, 0.4385346702859992}], 
             PointBox[{32.6, 2.6464672333756045`}], 
             PointBox[{32.7, 5.199086265425768}], 
             PointBox[{32.8, 4.022632303317456}], 
             PointBox[{32.9, 5.096350762249187}], 
             PointBox[{33., 5.848795915443493}], 
             PointBox[{33.1, 4.475964577950928}], 
             PointBox[{33.2, 3.573636604333539}], 
             PointBox[{33.3, 5.5467013113580474`}], 
             PointBox[{33.4, 4.86461247294714}], 
             PointBox[{33.5, 4.776224097494727}], 
             PointBox[{33.6, 7.095804032902548}], 
             PointBox[{33.7, 10.041390200154583`}], 
             PointBox[{33.8, 9.259017099328748}], 
             PointBox[{33.9, 9.780363708964442}], 
             PointBox[{34., 11.07229014091877}], 
             PointBox[{34.1, 9.760555051724353}], 
             PointBox[{34.2, 8.461671861413656}], 
             PointBox[{34.3, 10.283566816825438`}], 
             PointBox[{34.4, 10.294647597818393`}], 
             PointBox[{34.5, 9.519235998166296}], 
             PointBox[{34.6, 11.75700759830768}], 
             PointBox[{34.7, 14.92810104213699}], 
             PointBox[{34.8, 14.965831835743847`}], 
             PointBox[{34.9, 14.606006893048963`}], 
             PointBox[{35., 16.510911847188734`}], 
             PointBox[{35.1, 15.474669950411053`}], 
             PointBox[{35.2, 13.708764231415197`}], 
             PointBox[{35.3, 15.090918461676512`}], 
             PointBox[{35.4, 16.133529191251885`}], 
             PointBox[{35.5, 14.6226704851938}], 
             PointBox[{35.6, 16.487987550738808`}], 
             PointBox[{35.7, 19.62640722280159}], 
             PointBox[{35.8, 20.909844508870147`}], 
             PointBox[{35.9, 19.52037637806357}], 
             PointBox[{36., 21.85800991288945}], 
             PointBox[{36.1, 21.44029706421213}], 
             PointBox[{36.2, 19.22157803170459}], 
             PointBox[{36.3, 19.829837541938083`}], 
             PointBox[{36.4, 22.010222467155653`}], 
             PointBox[{36.5, 20.094294006019762`}], 
             PointBox[{36.6, 21.160480957328616`}], 
             PointBox[{36.7, 24.126194315842454`}], 
             PointBox[{36.8, 26.692461184492196`}], 
             PointBox[{36.9, 24.57155801110531}], 
             PointBox[{37., 26.759774812907462`}], 
             PointBox[{37.1, 27.394640398651063`}], 
             PointBox[{37.2, 24.892652251095335`}], 
             PointBox[{37.3, 24.396574752099543`}], 
             PointBox[{37.4, 27.420419005954383`}], 
             PointBox[{37.5, 25.920873221316082`}], 
             PointBox[{37.6, 25.679274338549394`}], 
             PointBox[{37.7, 28.529472651948424`}], 
             PointBox[{37.8, 31.721875933098634`}], 
             PointBox[{37.9, 29.78612738538953}], 
             PointBox[{38., 30.86994290683783}], 
             PointBox[{38.1, 32.90192481512562}], 
             PointBox[{38.2, 30.550352298186034`}], 
             PointBox[{38.3, 28.661413911383544`}], 
             PointBox[{38.4, 31.856955393556706`}], 
             PointBox[{38.5, 31.869373194215715`}], 
             PointBox[{38.6, 29.992170969082235`}], 
             PointBox[{38.7, 32.48988161945913}], 
             PointBox[{38.8, 35.45083888775973}], 
             PointBox[{38.9, 34.90185964369635}], 
             PointBox[{39., 33.907954035275495`}], 
             PointBox[{39.1, 37.25073162507371}], 
             PointBox[{39.2, 35.83297332137038}], 
             PointBox[{39.3, 32.37407789753281}], 
             PointBox[{39.4, 34.85720404430819}], 
             PointBox[{39.5, 37.20204825429349}], 
             PointBox[{39.6, 34.03395277334429}], 
             PointBox[{39.7, 35.37685879402019}], 
             PointBox[{39.8, 38.23536149750786}], 
             PointBox[{39.9, 39.00229297704488}], 
             PointBox[{40., 35.526216376709876`}], 
             PointBox[{40.1, 39.32593461215183}], 
             PointBox[{40.2, 39.889134937626636`}], 
             PointBox[{40.3, 34.949520896141074`}], 
             PointBox[{40.4, 35.73100313653676}], 
             PointBox[{40.5, 40.52884191711949}], 
             PointBox[{40.6, 37.43506092527481}], 
             PointBox[{40.7, 36.43942841131894}], 
             PointBox[{40.8, 40.03236938903285}], 
             PointBox[{40.9, 40.25592552223458}], 
             PointBox[{41., 34.63635104166659}], 
             PointBox[{41.1, 37.19595471813796}], 
             PointBox[{41.2, 40.67809297485974}], 
             PointBox[{41.3, 34.80362819144174}], 
             PointBox[{41.4, 32.74698693175748}], 
             PointBox[{41.5, 39.6145418387355}], 
             PointBox[{41.6, 38.62719830161447}], 
             PointBox[{41.7, 34.111786410331604`}], 
             PointBox[{41.8, 38.01619185864995}], 
             PointBox[{41.9, 37.156761116790115`}], 
             PointBox[{42., 27.51952140260628}], 
             PointBox[{42.1, 26.36178029903237}], 
             PointBox[{42.2, 33.11576026071885}], 
             PointBox[{42.3, 27.019546346540295`}], 
             PointBox[{42.4, 20.926638418640017`}], 
             PointBox[{42.5, 29.87808617070194}], 
             PointBox[{42.6, 32.60219159016376}], 
             PointBox[{42.7, 23.64519099274706}], 
             PointBox[{42.8, 26.74808646003538}], 
             PointBox[{42.9, 27.968538223011823`}], 
             PointBox[{43., 5.6974680620247105`}], 
             PointBox[{43.1, 357.52190388607323`}], 
             PointBox[{43.2, 6.358942326695789}], 
             PointBox[{43.3, 359.21267932843097`}], 
             PointBox[{43.4, 350.5912477706484}], 
             PointBox[{43.5, 2.533717331476049}], 
             PointBox[{43.6, 7.466846440029781}], 
             PointBox[{43.7, 353.66270296529814`}], 
             PointBox[{43.8, 356.5656563072148}], 
             PointBox[{43.9, 1.2846490122360217`}], 
             PointBox[{44., 334.4829607463659}], 
             PointBox[{44.1, 321.77069968803966`}], 
             PointBox[{44.2, 328.81458679288096`}], 
             PointBox[{44.3, 323.2218460069501}], 
             PointBox[{44.4, 316.77434427454267`}], 
             PointBox[{44.5, 327.34958846895773`}], 
             PointBox[{44.6, 330.4473232158383}], 
             PointBox[{44.7, 318.29370046714854`}], 
             PointBox[{44.8, 320.8534975045253}], 
             PointBox[{44.9, 326.9503202401974}], 
             PointBox[{45., 314.1538590197996}], 
             PointBox[{45.1, 305.8771882909125}], 
             PointBox[{45.2, 310.41886866863706`}], 
             PointBox[{45.3, 309.3336283289594}], 
             PointBox[{45.4, 303.4552168394007}], 
             PointBox[{45.5, 309.72788702582574`}], 
             PointBox[{45.6, 313.36522153624077`}], 
             PointBox[{45.7, 305.539610101796}], 
             PointBox[{45.8, 305.10152750160427`}], 
             PointBox[{45.9, 310.9084934325928}], 
             PointBox[{46., 305.9111660299913}], 
             PointBox[{46.1, 302.4754754180733}], 
             PointBox[{46.2, 304.84885644730855`}], 
             PointBox[{46.3, 306.67586200289014`}], 
             PointBox[{46.4, 302.0298197392914}], 
             PointBox[{46.5, 304.3821694282783}], 
             PointBox[{46.6, 308.87117523132395`}], 
             PointBox[{46.7, 304.4640983266161}], 
             PointBox[{46.8, 301.74106074730565`}], 
             PointBox[{46.9, 306.0671227854039}], 
             PointBox[{47., 305.4295005086509}], 
             PointBox[{47.1, 302.7698185141393}], 
             PointBox[{47.2, 304.7602350630246}], 
             PointBox[{47.3, 307.76216603677165`}], 
             PointBox[{47.4, 305.364895419001}], 
             PointBox[{47.5, 304.66503153484405`}], 
             PointBox[{47.6, 309.1330309491502}], 
             PointBox[{47.7, 307.41652492276734`}], 
             PointBox[{47.8, 303.84630022572946`}], 
             PointBox[{47.9, 306.0662911878397}], 
             PointBox[{48., 308.03365960778564`}], 
             PointBox[{48.1, 304.89165861640186`}], 
             PointBox[{48.2, 307.35551290329477`}], 
             PointBox[{48.3, 310.4259323039403}], 
             PointBox[{48.4, 310.2990261204912}], 
             PointBox[{48.5, 308.00990834322255`}], 
             PointBox[{48.6, 311.50018090439005`}], 
             PointBox[{48.7, 311.7985242844254}], 
             PointBox[{48.8, 308.45311574684047`}], 
             PointBox[{48.9, 308.71674680493675`}], 
             PointBox[{49., 311.6450979914746}], 
             PointBox[{49.1, 309.24784368365647`}], 
             PointBox[{49.2, 311.0148139135819}], 
             PointBox[{49.3, 314.0176906689782}], 
             PointBox[{49.4, 315.49620894448066`}], 
             PointBox[{49.5, 313.17583249433795`}], 
             PointBox[{49.6, 315.03501452644906`}], 
             PointBox[{49.7, 316.69796734381686`}], 
             PointBox[{49.8, 314.1149646568712}], 
             PointBox[{49.9, 313.04539459501194`}], 
             PointBox[{50., 315.67710034994343`}], 
             PointBox[{50.1, 314.85415985377983`}], 
             PointBox[{50.2, 314.95576892648216`}], 
             PointBox[{50.3, 318.2445690807411}], 
             PointBox[{50.4, 320.57426118658395`}], 
             PointBox[{50.5, 319.20291805953946`}], 
             PointBox[{50.6, 319.3667053735501}], 
             PointBox[{50.7, 321.75966626913737`}], 
             PointBox[{50.8, 320.0939463838228}], 
             PointBox[{50.9, 318.36201818238936`}], 
             PointBox[{51., 320.08009783285354`}], 
             PointBox[{51.1, 320.77107917020345`}], 
             PointBox[{51.2, 319.5352808293659}], 
             PointBox[{51.3, 322.85118742447406`}], 
             PointBox[{51.4, 325.51301770492586`}], 
             PointBox[{51.5, 325.3265170474801}], 
             PointBox[{51.6, 324.2901554292807}], 
             PointBox[{51.7, 326.8166310995332}], 
             PointBox[{51.8, 326.02022182604054`}], 
             PointBox[{51.9, 324.11059506633114`}], 
             PointBox[{52., 324.8523914653671}], 
             PointBox[{52.1, 326.4914589271851}], 
             PointBox[{52.2, 324.77073771978456`}], 
             PointBox[{52.3, 327.57497527883396`}], 
             PointBox[{52.4, 330.3376110581022}], 
             PointBox[{52.5, 331.11298016815255`}], 
             PointBox[{52.6, 329.57761712938475`}], 
             PointBox[{52.7, 331.76742827474794`}], 
             PointBox[{52.8, 331.69837309704906`}], 
             PointBox[{52.9, 329.8801930357492}], 
             PointBox[{53., 329.8694772973579}], 
             PointBox[{53.1, 331.8336251712626}], 
             PointBox[{53.2, 330.2779906881834}], 
             PointBox[{53.3, 332.26049441521656`}], 
             PointBox[{53.4, 335.0243222975029}], 
             PointBox[{53.5, 336.40192283014295`}], 
             PointBox[{53.6, 334.91718741799093`}], 
             PointBox[{53.7, 336.524672019419}], 
             PointBox[{53.8, 336.9994437735174}], 
             PointBox[{53.9, 335.3822336403461}], 
             PointBox[{54., 334.9035404026776}], 
             PointBox[{54.1, 336.7741335475301}], 
             PointBox[{54.2, 335.67288472107214`}], 
             PointBox[{54.3, 336.8551302459938}], 
             PointBox[{54.4, 339.4910746709544}], 
             PointBox[{54.5, 341.14267061865735`}], 
             PointBox[{54.6, 339.9626132322108}], 
             PointBox[{54.7, 340.98453965599936`}], 
             PointBox[{54.8, 341.8068275224187}], 
             PointBox[{54.9, 340.4022450795739}], 
             PointBox[{55., 339.69176815065896`}], 
             PointBox[{55.1, 341.3001896067435}], 
             PointBox[{55.2, 340.65061553829594`}], 
             PointBox[{55.3, 341.24902872624625`}], 
             PointBox[{55.4, 343.60114143968656`}], 
             PointBox[{55.5, 345.27501560611495`}], 
             PointBox[{55.6, 344.4052901018046}], 
             PointBox[{55.7, 345.0070808468435}], 
             PointBox[{55.8, 345.987750241437}], 
             PointBox[{55.9, 344.75441151271957`}], 
             PointBox[{56., 343.97797074322574`}], 
             PointBox[{56.1, 345.3342979379887}], 
             PointBox[{56.2, 344.96669319948074`}], 
             PointBox[{56.3, 345.2402683987557}], 
             PointBox[{56.4, 347.16729991831727`}], 
             PointBox[{56.5, 348.68885264630296`}], 
             PointBox[{56.6, 347.9966731547806}], 
             PointBox[{56.7, 348.418816148153}], 
             PointBox[{56.8, 349.38248037336234`}], 
             PointBox[{56.9, 348.25879910911016`}], 
             PointBox[{57., 347.5277966417938}], 
             PointBox[{57.1, 348.7309845520979}], 
             PointBox[{57.2, 348.4078460624952}], 
             PointBox[{57.3, 348.5729469052285}], 
             PointBox[{57.4, 349.97465884523035`}], 
             PointBox[{57.5, 351.23899742519313`}], 
             PointBox[{57.6, 350.5509328036559}], 
             PointBox[{57.7, 351.0527069636155}], 
             PointBox[{57.8, 351.82304336941314`}], 
             PointBox[{57.9, 350.75803099750476`}], 
             PointBox[{58., 350.1548358909774}], 
             PointBox[{58.1, 351.3245221725094}], 
             PointBox[{58.2, 350.7957939327705}], 
             PointBox[{58.3, 350.9529848554211}], 
             PointBox[{58.4, 351.85445832163066`}], 
             PointBox[{58.5, 352.80761723282365`}], 
             PointBox[{58.6, 351.9773315292044}], 
             PointBox[{58.7, 352.8065870150258}], 
             PointBox[{58.8, 353.19275460845154`}], 
             PointBox[{58.9, 352.17654712078036`}], 
             PointBox[{59., 351.77732287578334`}], 
             PointBox[{59.1, 352.99116241638376`}], 
             PointBox[{59.2, 352.06073391775516`}], 
             PointBox[{59.3, 352.1401472795636}], 
             PointBox[{59.4, 352.78167655741663`}], 
             PointBox[{59.5, 353.37908246721855`}], 
             PointBox[{59.6, 352.37331743662725`}], 
             PointBox[{59.7, 353.661759581892}], 
             PointBox[{59.8, 353.51329167942714`}], 
             PointBox[{59.9, 352.59387188896596`}], 
             PointBox[{60., 352.4839159225938}], 
             PointBox[{60.1, 353.6658126561721}], 
             PointBox[{60.2, 352.3377482957347}], 
             PointBox[{60.3, 352.29412860245833`}], 
             PointBox[{60.4, 352.8882540500063}], 
             PointBox[{60.5, 353.0542263977505}], 
             PointBox[{60.6, 352.11630060153755`}], 
             PointBox[{60.7, 353.6327062703468}], 
             PointBox[{60.8, 352.98218249922803`}], 
             PointBox[{60.9, 352.25206383177573`}], 
             PointBox[{61., 352.52552599144514`}], 
             PointBox[{61.1, 353.25960728419733`}], 
             PointBox[{61.2, 351.7813899749887}], 
             PointBox[{61.3, 351.8716291565362}], 
             PointBox[{61.4, 352.36165009105304`}], 
             PointBox[{61.5, 352.0010326554874}], 
             PointBox[{61.6, 351.75744432685684`}], 
             PointBox[{61.7, 352.7935179393258}], 
             PointBox[{61.8, 351.9042586092967}], 
             PointBox[{61.9, 351.46903460170216`}], 
             PointBox[{62., 352.1755598073383}], 
             PointBox[{62.1, 351.78658095479494`}], 
             PointBox[{62.2, 350.7124315455266}], 
             PointBox[{62.3, 351.12560954920406`}], 
             PointBox[{62.4, 351.34288577891846`}], 
             PointBox[{62.5, 350.4804294293685}], 
             PointBox[{62.6, 351.4104780728905}], 
             PointBox[{62.7, 351.38030370481823`}], 
             PointBox[{62.8, 350.57828040701474`}], 
             PointBox[{62.9, 350.53169703546297`}], 
             PointBox[{63., 351.4588317796674}], 
             PointBox[{63.1, 349.82628456732476`}], 
             PointBox[{63.2, 349.68724088787627`}], 
             PointBox[{63.3, 350.1169912929109}], 
             PointBox[{63.4, 349.9078795142145}], 
             PointBox[{63.5, 349.0451953539178}], 
             PointBox[{63.6, 350.52721477119735`}], 
             PointBox[{63.7, 349.72358490671246`}], 
             PointBox[{63.8, 349.22864016020867`}], 
             PointBox[{63.9, 349.6201053166765}], 
             PointBox[{64., 349.9132151669198}], 
             PointBox[{64.1, 348.1447280223525}], 
             PointBox[{64.2, 348.67431288406476`}], 
             PointBox[{64.3, 348.8443011466099}], 
             PointBox[{64.4, 348.1473557821219}], 
             PointBox[{64.5, 348.31072153891137`}], 
             PointBox[{64.6, 348.9513687331994}], 
             PointBox[{64.7, 348.0877156387904}], 
             PointBox[{64.8, 347.9911302074624}], 
             PointBox[{64.9, 348.70299790638376`}], 
             PointBox[{65., 347.42772170488433`}], 
             PointBox[{65.1, 347.0123899925306}], 
             PointBox[{65.2, 347.5292671060693}], 
             PointBox[{65.3, 347.30460181004446`}], 
             PointBox[{65.4, 346.36833069481594`}], 
             PointBox[{65.5, 347.72610096318726`}], 
             PointBox[{65.6, 347.1244740578946}], 
             PointBox[{65.7, 346.6156856659577}], 
             PointBox[{65.8, 346.9086656308217}], 
             PointBox[{65.9, 347.34224776906996`}], 
             PointBox[{66., 345.3468982819362}], 
             PointBox[{66.1, 346.01515152408876`}], 
             PointBox[{66.2, 346.1914259121207}], 
             PointBox[{66.3, 345.5501128279202}], 
             PointBox[{66.4, 345.1826242272747}], 
             PointBox[{66.5, 346.36367252877585`}], 
             PointBox[{66.6, 345.42661075464775`}], 
             PointBox[{66.7, 345.3551066612298}], 
             PointBox[{66.8, 345.89064683196733`}], 
             PointBox[{66.9, 345.069469427039}], 
             PointBox[{67., 344.2099015256048}], 
             PointBox[{67.1, 344.9101475989162}], 
             PointBox[{67.2, 344.6762116109538}], 
             PointBox[{67.3, 343.7782207820214}], 
             PointBox[{67.4, 344.6748835379488}], 
             PointBox[{67.5, 344.56379557378546`}], 
             PointBox[{67.6, 344.0021410881285}], 
             PointBox[{67.7, 344.2871710309721}], 
             PointBox[{67.8, 344.6428468641978}], 
             PointBox[{67.9, 342.815159192383}], 
             PointBox[{68., 343.3859502011938}], 
             PointBox[{68.1, 343.6809434659664}], 
             PointBox[{68.2, 343.07729973122724`}], 
             PointBox[{68.3, 342.3822817139011}], 
             PointBox[{68.4, 343.868872573584}], 
             PointBox[{68.5, 342.9302535103903}], 
             PointBox[{68.6, 342.8783544179778}], 
             PointBox[{68.7, 343.33615780951106`}], 
             PointBox[{68.8, 342.9921985242066}], 
             PointBox[{68.9, 341.5888422460312}], 
             PointBox[{69., 342.5814594740011}], 
             PointBox[{69.1, 342.43828505307687`}], 
             PointBox[{69.2, 341.5872731261211}], 
             PointBox[{69.3, 341.6934234734516}], 
             PointBox[{69.4, 342.52837183509587`}], 
             PointBox[{69.5, 341.7128158275353}], 
             PointBox[{69.6, 342.06722537323645`}], 
             PointBox[{69.7, 342.41644355705057`}], 
             PointBox[{69.8, 341.44021044202356`}], 
             PointBox[{69.9, 341.1565193794116}], 
             PointBox[{70., 341.8904156867589}], 
             PointBox[{70.1, 341.38686838860957`}], 
             PointBox[{70.2, 340.4963405669856}], 
             PointBox[{70.3, 341.541394885502}], 
             PointBox[{70.4, 341.3243585150543}], 
             PointBox[{70.5, 341.01287286691917`}], 
             PointBox[{70.6, 341.6281383030204}], 
             PointBox[{70.7, 341.777279698528}], 
             PointBox[{70.8, 340.54118917211383`}], 
             PointBox[{70.9, 341.2367707994254}], 
             PointBox[{71., 341.58202171029586`}], 
             PointBox[{71.1, 340.8113159158823}], 
             PointBox[{71.2, 340.11777822053097`}], 
             PointBox[{71.3, 341.6397751936616}], 
             PointBox[{71.4, 340.7681307480413}], 
             PointBox[{71.5, 340.9565717639347}], 
             PointBox[{71.6, 341.72932848253777`}], 
             PointBox[{71.7, 342.059055158893}], 
             PointBox[{71.8, 340.76570303482083`}], 
             PointBox[{71.9, 341.95351022687277`}], 
             PointBox[{72., 341.97923496903707`}], 
             PointBox[{72.1, 341.023831885282}], 
             PointBox[{72.2, 340.66588454662434`}], 
             PointBox[{72.3, 342.2001209001596}], 
             PointBox[{72.4, 341.1178974226251}], 
             PointBox[{72.5, 341.7131695307623}], 
             PointBox[{72.6, 342.67937873501256`}], 
             PointBox[{72.7, 343.37779806535656`}], 
             PointBox[{72.8, 342.15340777507623`}], 
             PointBox[{72.9, 343.5326446701002}], 
             PointBox[{73., 343.3425376909535}], 
             PointBox[{73.1, 342.25734976006186`}], 
             PointBox[{73.2, 342.2101412759885}], 
             PointBox[{73.3, 343.6229191071248}], 
             PointBox[{73.4, 342.50172723243213`}], 
             PointBox[{73.5, 343.4092410511584}], 
             PointBox[{73.6, 344.729102689489}], 
             PointBox[{73.7, 345.7371306844332}], 
             PointBox[{73.8, 344.58149661179965`}], 
             PointBox[{73.9, 346.07409575296737`}], 
             PointBox[{74., 345.7745730190776}], 
             PointBox[{74.1, 344.57779073863526`}], 
             PointBox[{74.2, 344.70502044196553`}], 
             PointBox[{74.3, 346.0970541677184}], 
             PointBox[{74.4, 344.92403437940175`}], 
             PointBox[{74.5, 346.0356384712894}], 
             PointBox[{74.6, 347.7954571351832}], 
             PointBox[{74.7, 349.0943937343114}], 
             PointBox[{74.8, 347.8936749115482}], 
             PointBox[{74.9, 349.5056968335714}], 
             PointBox[{75., 349.21487367698705`}], 
             PointBox[{75.1, 347.89694191689955`}], 
             PointBox[{75.2, 348.02447715691676`}], 
             PointBox[{75.3, 349.56575163740257`}], 
             PointBox[{75.4, 348.285678045408}], 
             PointBox[{75.5, 349.44901639729335`}], 
             PointBox[{75.6, 351.5955660765583}], 
             PointBox[{75.7, 353.28559566997603`}], 
             PointBox[{75.8, 351.9323051834922}], 
             PointBox[{75.9, 353.6410805499848}], 
             PointBox[{76., 353.5072288802803}], 
             PointBox[{76.1, 352.05463539612185`}], 
             PointBox[{76.2, 352.00455451246836`}], 
             PointBox[{76.3, 353.82463645451656`}], 
             PointBox[{76.4, 352.45389494795245`}], 
             PointBox[{76.5, 353.4546920253476}], 
             PointBox[{76.6, 355.86468371119645`}], 
             PointBox[{76.7, 358.0786581271111}], 
             PointBox[{76.8, 356.5771012268821}], 
             PointBox[{76.9, 358.2459269722558}], 
             PointBox[{77., 358.460425693261}], 
             PointBox[{77.1, 356.88633278733744`}], 
             PointBox[{77.2, 356.48861028096553`}], 
             PointBox[{77.3, 358.59767176990874`}], 
             PointBox[{77.4, 357.3169715117393}], 
             PointBox[{77.5, 357.8807133060701}], 
             PointBox[{77.6, 0.4162557542663802}], 
             PointBox[{77.7, 3.200266763421785}], 
             PointBox[{77.8, 1.7577179067568287`}], 
             PointBox[{77.9, 3.07999482128119}], 
             PointBox[{78., 3.86614449750026}], 
             PointBox[{78.1, 2.2470962732827546`}], 
             PointBox[{78.2, 1.3502786834749398`}], 
             PointBox[{78.3, 3.5881107209129692`}], 
             PointBox[{78.4, 2.782657533620745}], 
             PointBox[{78.5, 2.6109598160310887`}], 
             PointBox[{78.6, 5.125364279124538}], 
             PointBox[{78.7, 8.335888111882502}], 
             PointBox[{78.8, 7.40856100062832}], 
             PointBox[{78.9, 7.9366914130861135`}], 
             PointBox[{79., 9.479705687654496}], 
             PointBox[{79.1, 8.001847994193087}], 
             PointBox[{79.2, 6.490988273176167}], 
             PointBox[{79.3, 8.531094129150791}], 
             PointBox[{79.4, 8.706695005473922}], 
             PointBox[{79.5, 7.5931254921935105`}], 
             PointBox[{79.6, 9.862865990570196}], 
             PointBox[{79.7, 13.16167845638184}], 
             PointBox[{79.8, 13.37420586141533}], 
             PointBox[{79.9, 12.697015447982134`}], 
             PointBox[{80., 14.985568559345975`}], 
             PointBox[{80.1, 13.991074004933921`}], 
             PointBox[{80.2, 11.82180431051698}], 
             PointBox[{80.3, 13.234966211642833`}], 
             PointBox[{80.4, 14.774553861092992`}], 
             PointBox[{80.5, 12.835791334706322`}], 
             PointBox[{80.6, 14.463298076642786`}], 
             PointBox[{80.7, 17.54525533729764}], 
             PointBox[{80.8, 19.299194227542774`}], 
             PointBox[{80.9, 17.36803921811281}], 
             PointBox[{81., 19.980246405044667`}], 
             PointBox[{81.1, 19.968199578833037`}], 
             PointBox[{81.2, 17.237620117566316`}], 
             PointBox[{81.3, 17.56498492391947}], 
             PointBox[{81.4, 20.43799359843115}], 
             PointBox[{81.5, 18.361232423716856`}], 
             PointBox[{81.6, 18.767805251598872`}], 
             PointBox[{81.7, 21.721798310138947`}], 
             PointBox[{81.8, 24.548838927774845`}], 
             PointBox[{81.9, 22.010444042971656`}], 
             PointBox[{82., 24.001205175153924`}], 
             PointBox[{82.1, 25.492495804447987`}], 
             PointBox[{82.2, 22.56228396075279}], 
             PointBox[{82.3, 21.360234923753055`}], 
             PointBox[{82.4, 25.022588847380792`}], 
             PointBox[{82.5, 24.02996109100725}], 
             PointBox[{82.6, 22.648411956899842`}], 
             PointBox[{82.7, 25.506249657649622`}], 
             PointBox[{82.8, 28.311097352511542`}], 
             PointBox[{82.9, 26.470850992960337`}], 
             PointBox[{83., 26.571811009621673`}], 
             PointBox[{83.1, 29.776465654924245`}], 
             PointBox[{83.2, 27.414604891547196`}], 
             PointBox[{83.3, 24.28937804570817}], 
             PointBox[{83.4, 27.842145728540142`}], 
             PointBox[{83.5, 29.185689522786443`}], 
             PointBox[{83.6, 25.94340755276702}], 
             PointBox[{83.7, 28.01359687093575}], 
             PointBox[{83.8, 30.52293328937515}], 
             PointBox[{83.9, 29.900827430855568`}], 
             PointBox[{84., 27.030435603267307`}], 
             PointBox[{84.1, 31.445986631706273`}], 
             PointBox[{84.2, 30.83147081437192}], 
             PointBox[{84.3, 25.531443988780314`}], 
             PointBox[{84.4, 27.92184561113972}], 
             PointBox[{84.5, 32.27802041209653}], 
             PointBox[{84.6, 28.131261990485264`}], 
             PointBox[{84.7, 28.105252768422076`}], 
             PointBox[{84.8, 31.59008208700855}], 
             PointBox[{84.9, 30.12920366699636}], 
             PointBox[{85., 23.629987341166757`}], 
             PointBox[{85.1, 27.882915819963138`}], 
             PointBox[{85.2, 30.273954226431385`}], 
             PointBox[{85.3, 22.790295002309634`}], 
             PointBox[{85.4, 22.916409550577725`}], 
             PointBox[{85.5, 30.39543628253423}], 
             PointBox[{85.6, 27.203210700735273`}], 
             PointBox[{85.7, 23.44713772702528}], 
             PointBox[{85.8, 28.19594464053142}], 
             PointBox[{85.9, 24.13602983693683}], 
             PointBox[{86., 10.862950597066082`}], 
             PointBox[{86.1, 12.920078147419982`}], 
             PointBox[{86.2, 18.86249617623048}], 
             PointBox[{86.3, 8.981994785542845}], 
             PointBox[{86.4, 6.384652565272091}], 
             PointBox[{86.5, 17.350284009794745`}], 
             PointBox[{86.6, 16.352568931886253`}], 
             PointBox[{86.7, 7.291166561189672}], 
             PointBox[{86.8, 12.869241770542361`}], 
             PointBox[{86.9, 9.205818217949917}], 
             PointBox[{87., 340.4200418353689}], 
             PointBox[{87.1, 338.4641369600258}], 
             PointBox[{87.2, 345.5080029123958}], 
             PointBox[{87.3, 333.5866388312697}], 
             PointBox[{87.4, 331.6257481349621}], 
             PointBox[{87.5, 344.90228867966476`}], 
             PointBox[{87.6, 343.29245486664195`}], 
             PointBox[{87.7, 330.9003276076208}], 
             PointBox[{87.8, 337.7683042712462}], 
             PointBox[{87.9, 337.63846498417024`}], 
             PointBox[{88., 312.225322880652}], 
             PointBox[{88.1, 307.1982784294033}], 
             PointBox[{88.2, 312.78845532152366`}], 
             PointBox[{88.3, 305.3111327400761}], 
             PointBox[{88.4, 303.28795400263374`}], 
             PointBox[{88.5, 313.447490633967}], 
             PointBox[{88.6, 311.95148541627685`}], 
             PointBox[{88.7, 302.35897432918983`}], 
             PointBox[{88.8, 307.2462391732381}], 
             PointBox[{88.9, 310.4652360591452}], 
             PointBox[{89., 299.37185037054303`}], 
             PointBox[{89.1, 295.4689266240677}], 
             PointBox[{89.2, 299.99325191927846`}], 
             PointBox[{89.3, 297.50299083812683`}], 
             PointBox[{89.4, 293.617743818763}], 
             PointBox[{89.5, 300.2887114280195}], 
             PointBox[{89.6, 301.39636552721015`}], 
             PointBox[{89.7, 294.32536784649596`}], 
             PointBox[{89.8, 295.65789093576325`}], 
             PointBox[{89.9, 300.29923416596654`}], 
             PointBox[{90., 294.8118839251573}], 
             PointBox[{90.1, 293.58820286113973`}], 
             PointBox[{90.2, 296.6628356135477}], 
             PointBox[{90.3, 297.45233039269215`}], 
             PointBox[{90.4, 293.2973612918357}], 
             PointBox[{90.5, 296.7447352701826}], 
             PointBox[{90.6, 299.73636523887245`}], 
             PointBox[{90.7, 295.0121022366037}], 
             PointBox[{90.8, 293.65867570194774`}], 
             PointBox[{90.9, 297.8942422804133}], 
             PointBox[{91., 295.99608128870887`}], 
             PointBox[{91.1, 294.96038498033965`}], 
             PointBox[{91.2, 297.40919870162725`}], 
             PointBox[{91.3, 299.86456881083365`}], 
             PointBox[{91.4, 297.0872958318807}], 
             PointBox[{91.5, 297.58825252468336`}], 
             PointBox[{91.6, 301.37360823838407`}], 
             PointBox[{91.7, 298.8540914719224}], 
             PointBox[{91.8, 296.13502454964635`}], 
             PointBox[{91.9, 298.8636830915466}], 
             PointBox[{92., 299.7169195079587}], 
             PointBox[{92.1, 297.43275387519304`}], 
             PointBox[{92.2, 300.29961506132764`}], 
             PointBox[{92.3, 303.2438581005668}], 
             PointBox[{92.4, 302.4397573151766}], 
             PointBox[{92.5, 300.92591385586724`}], 
             PointBox[{92.6, 304.4792153939022}], 
             PointBox[{92.7, 303.8208065605191}], 
             PointBox[{92.8, 300.83036685342523`}], 
             PointBox[{92.9, 301.8113599121095}], 
             PointBox[{93., 304.16726174456613`}], 
             PointBox[{93.1, 301.6588214438996}], 
             PointBox[{93.2, 304.2263133833753}], 
             PointBox[{93.3, 307.1959565360637}], 
             PointBox[{93.4, 308.0576762589022}], 
             PointBox[{93.5, 305.8781757552843}], 
             PointBox[{93.6, 308.3803762005228}], 
             PointBox[{93.7, 309.14431875890756`}], 
             PointBox[{93.8, 306.5271547782015}], 
             PointBox[{93.9, 306.12517353338126`}], 
             PointBox[{94., 308.74373676426944`}], 
             PointBox[{94.1, 307.1781651630743}], 
             PointBox[{94.2, 308.4030432610679}], 
             PointBox[{94.3, 311.5675026954155}], 
             PointBox[{94.4, 313.4702845487747}], 
             PointBox[{94.5, 311.7343487659178}], 
             PointBox[{94.6, 312.7985667681324}], 
             PointBox[{94.7, 314.51363439608826`}], 
             PointBox[{94.8, 312.53720433665717`}], 
             PointBox[{94.9, 311.30833234993554`}], 
             PointBox[{95., 313.3920592396992}], 
             PointBox[{95.1, 313.1640134748954}], 
             PointBox[{95.2, 312.88912970130053`}], 
             PointBox[{95.3, 316.2127909983828}], 
             PointBox[{95.4, 318.6145044412583}], 
             PointBox[{95.5, 317.82008723088757`}], 
             PointBox[{95.6, 317.5853459172397}], 
             PointBox[{95.7, 319.7781241590471}], 
             PointBox[{95.8, 318.48333719284204`}], 
             PointBox[{95.9, 316.89595994048716`}], 
             PointBox[{96., 318.1724180204963}], 
             PointBox[{96.1, 319.05889434730875`}], 
             PointBox[{96.2, 317.84820641144245`}], 
             PointBox[{96.3, 320.956681038151}], 
             PointBox[{96.4, 323.51987722557504`}], 
             PointBox[{96.5, 323.64626956658935`}], 
             PointBox[{96.6, 322.5892934541723}], 
             PointBox[{96.7, 324.83983185173975`}], 
             PointBox[{96.8, 324.1516897482221}], 
             PointBox[{96.9, 322.50226372382207`}], 
             PointBox[{97., 323.0504697428669}], 
             PointBox[{97.1, 324.57906221736926`}], 
             PointBox[{97.2, 323.04738603609974`}], 
             PointBox[{97.3, 325.6381384634434}], 
             PointBox[{97.4, 328.1799152083448}], 
             PointBox[{97.5, 328.9644441527912}], 
             PointBox[{97.6, 327.58985106599744`}], 
             PointBox[{97.7, 329.6106678927735}], 
             PointBox[{97.8, 329.3965146857588}], 
             PointBox[{97.9, 327.83369281366816`}], 
             PointBox[{98., 327.8703176232495}], 
             PointBox[{98.1, 329.6142174772229}], 
             PointBox[{98.2, 328.1484842086459}], 
             PointBox[{98.3, 330.14125641816236`}], 
             PointBox[{98.4, 332.52434305438084`}], 
             PointBox[{98.5, 333.66266311915115`}], 
             PointBox[{98.6, 332.30004115332724`}], 
             PointBox[{98.7, 333.98615002464123`}], 
             PointBox[{98.8, 334.08413761451715`}], 
             PointBox[{98.9, 332.65929515620786`}], 
             PointBox[{99., 332.4064155959281}], 
             PointBox[{99.1, 334.1120541474273}], 
             PointBox[{99.2, 332.8457368798582}], 
             PointBox[{99.3, 334.3349933836846}], 
             PointBox[{99.4, 336.420714642439}], 
             PointBox[{99.5, 337.652356569928}], 
             PointBox[{99.6, 336.4208456485026}], 
             PointBox[{99.7, 337.8321420070034}], 
             PointBox[{99.8, 338.06679695018465`}], 
             PointBox[{99.9, 336.7780184041859}], 
             PointBox[{100., 336.4148323527695}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 360}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
             40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {
             0, -180}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
             PointBox[{0.1, 23.372580148747716`}], 
             PointBox[{0.2, 17.811804317847418`}], 
             PointBox[{0.3, 21.179838754361526`}], 
             PointBox[{0.4, 33.832666149175566`}], 
             PointBox[{0.5, 26.428315243664997`}], 
             PointBox[{0.6, 20.018612565170656`}], 
             PointBox[{0.7, 33.97836615081712}], 
             PointBox[{0.8, 37.081379644872186`}], 
             PointBox[{0.9, 30.286789769341112`}], 
             PointBox[{1., 44.0662169679257}], 
             PointBox[{1.1, 60.67593938296733}], 
             PointBox[{1.2, 58.62707215127887}], 
             PointBox[{1.3, 59.28680254354185}], 
             PointBox[{1.4, 68.4998025326089}], 
             PointBox[{1.5, 65.06447009943099}], 
             PointBox[{1.6, 60.35731725929395}], 
             PointBox[{1.7, 69.66549398567565}], 
             PointBox[{1.8, 74.11006679078912}], 
             PointBox[{1.9, 68.99577505302113}], 
             PointBox[{2., 74.05147363093602}], 
             PointBox[{2.1, 82.25833865521008}], 
             PointBox[{2.2, 82.92487366346995}], 
             PointBox[{2.3, 81.46459215008372}], 
             PointBox[{2.4, 87.68505814858122}], 
             PointBox[{2.5, 88.3301572466903}], 
             PointBox[{2.6, 84.08155033477351}], 
             PointBox[{2.7, 89.22319964831422}], 
             PointBox[{2.8, 95.01424745598433}], 
             PointBox[{2.9, 92.36694635784124}], 
             PointBox[{3., 92.87635175271112}], 
             PointBox[{3.1, 98.7788724280972}], 
             PointBox[{3.2, 99.46924618195408}], 
             PointBox[{3.3, 97.51524084125072}], 
             PointBox[{3.4, 100.64408145904713`}], 
             PointBox[{3.5, 103.96121320773136`}], 
             PointBox[{3.6, 100.60438828426186`}], 
             PointBox[{3.7, 102.72187509676769`}], 
             PointBox[{3.8, 108.54605319170423`}], 
             PointBox[{3.9, 108.4505166837398}], 
             PointBox[{4., 106.80050007229147`}], 
             PointBox[{4.1, 111.76054746850741`}], 
             PointBox[{4.2, 111.89636525621017`}], 
             PointBox[{4.3, 110.41840695653855`}], 
             PointBox[{4.4, 111.06297609611192`}], 
             PointBox[{4.5, 115.16977601072222`}], 
             PointBox[{4.6, 113.42100835707424`}], 
             PointBox[{4.7, 113.44314304900854`}], 
             PointBox[{4.8, 118.36229261398012`}], 
             PointBox[{4.9, 120.23948443191239`}], 
             PointBox[{5., 118.22334988780949`}], 
             PointBox[{5.1, 121.31473891002088`}], 
             PointBox[{5.2, 122.22606932159988`}], 
             PointBox[{5.3, 120.96026706770044`}], 
             PointBox[{5.4, 120.1189345148523}], 
             PointBox[{5.5, 123.43844586210616`}], 
             PointBox[{5.6, 123.61396154749127`}], 
             PointBox[{5.7, 122.35393613954511`}], 
             PointBox[{5.8, 125.98075826036938`}], 
             PointBox[{5.9, 128.9471470492672}], 
             PointBox[{6., 127.66950589101089`}], 
             PointBox[{6.1, 128.64732426155706`}], 
             PointBox[{6.2, 130.94060279056475`}], 
             PointBox[{6.3, 129.39713233500743`}], 
             PointBox[{6.4, 127.94745758851786`}], 
             PointBox[{6.5, 129.77128529871243`}], 
             PointBox[{6.6, 131.50124676526957`}], 
             PointBox[{6.7, 129.71999323720775`}], 
             PointBox[{6.8, 132.0195123338044}], 
             PointBox[{6.9, 135.29885863830896`}], 
             PointBox[{7., 135.11146690886835`}], 
             PointBox[{7.1, 134.5267276370496}], 
             PointBox[{7.2, 137.43659698246302`}], 
             PointBox[{7.3, 135.95440383929053`}], 
             PointBox[{7.4, 134.3844818074649}], 
             PointBox[{7.5, 134.77737795886242`}], 
             PointBox[{7.6, 137.21778339070988`}], 
             PointBox[{7.7, 135.57782101771772`}], 
             PointBox[{7.8, 136.68361671826915`}], 
             PointBox[{7.9, 139.77745650029374`}], 
             PointBox[{8., 140.5120079622502}], 
             PointBox[{8.1, 139.18386578865739`}], 
             PointBox[{8.2, 141.77090686365227`}], 
             PointBox[{8.3, 140.87169701523453`}], 
             PointBox[{8.4, 139.26323536634482`}], 
             PointBox[{8.5, 138.6326666373834}], 
             PointBox[{8.6, 140.9503465106318}], 
             PointBox[{8.7, 139.88081763044556`}], 
             PointBox[{8.8, 139.99899758492302`}], 
             PointBox[{8.9, 142.6582454964564}], 
             PointBox[{9., 143.94987697252054`}], 
             PointBox[{9.1, 142.5247792064929}], 
             PointBox[{9.2, 144.2597832377296}], 
             PointBox[{9.3, 144.14273235769087`}], 
             PointBox[{9.4, 142.4743354837874}], 
             PointBox[{9.5, 141.24431777136215`}], 
             PointBox[{9.6, 142.94510995656856`}], 
             PointBox[{9.7, 142.5498026065252}], 
             PointBox[{9.8, 141.91236414002014`}], 
             PointBox[{9.9, 144.05094022320827`}], 
             PointBox[{10., 145.55056390501704`}], 
             PointBox[{10.1, 144.33757644888192`}], 
             PointBox[{10.2, 145.11486076499568`}], 
             PointBox[{10.3, 145.61168651939715`}], 
             PointBox[{10.4, 143.94795929636257`}], 
             PointBox[{10.5, 142.42907634144285`}], 
             PointBox[{10.6, 143.38261111790416`}], 
             PointBox[{10.7, 143.49354913749903`}], 
             PointBox[{10.8, 142.32037716896866`}], 
             PointBox[{10.9, 143.94356497118042`}], 
             PointBox[{11., 145.39164485390575`}], 
             PointBox[{11.1, 144.41593236788685`}], 
             PointBox[{11.2, 144.38595440403242`}], 
             PointBox[{11.3, 145.18636849240193`}], 
             PointBox[{11.4, 143.6146097784058}], 
             PointBox[{11.5, 141.98722649012416`}], 
             PointBox[{11.6, 142.28375195234548`}], 
             PointBox[{11.7, 142.60839031000887`}], 
             PointBox[{11.8, 141.07010280394206`}], 
             PointBox[{11.9, 142.22992295663062`}], 
             PointBox[{12., 143.45089734689827`}], 
             PointBox[{12.1, 142.57770575498762`}], 
             PointBox[{12.2, 141.97259968115395`}], 
             PointBox[{12.3, 142.7870579106766}], 
             PointBox[{12.4, 141.3662029551706}], 
             PointBox[{12.5, 139.69919287534685`}], 
             PointBox[{12.6, 139.50839401001576`}], 
             PointBox[{12.7, 139.75034580779538`}], 
             PointBox[{12.8, 137.9532275593665}], 
             PointBox[{12.9, 138.71950137964086`}], 
             PointBox[{13., 139.59143150390082`}], 
             PointBox[{13.1, 138.62354520121517`}], 
             PointBox[{13.2, 137.66125057505815`}], 
             PointBox[{13.3, 138.27003951240295`}], 
             PointBox[{13.4, 137.02814886411215`}], 
             PointBox[{13.5, 135.301857321203}], 
             PointBox[{13.6, 134.79155116743277`}], 
             PointBox[{13.7, 134.6884557780977}], 
             PointBox[{13.8, 132.70486489596624`}], 
             PointBox[{13.9, 133.14077366361016`}], 
             PointBox[{14., 133.56643524659012`}], 
             PointBox[{14.1, 132.29805614113866`}], 
             PointBox[{14.2, 131.1787789001246}], 
             PointBox[{14.3, 131.42827532766387`}], 
             PointBox[{14.4, 130.3285576684757}], 
             PointBox[{14.5, 128.46940063142938`}], 
             PointBox[{14.6, 127.78835056825301`}], 
             PointBox[{14.7, 127.0797377578383}], 
             PointBox[{14.8, 125.02618263861586`}], 
             PointBox[{14.9, 125.16092381519593`}], 
             PointBox[{15., 125.05115842093255`}], 
             PointBox[{15.1, 123.30000057104371`}], 
             PointBox[{15.2, 122.25826213435721`}], 
             PointBox[{15.3, 122.09272536205935`}], 
             PointBox[{15.4, 120.89580871825092`}], 
             PointBox[{15.5, 118.86236784293033`}], 
             PointBox[{15.6, 118.14161485748264`}], 
             PointBox[{15.7, 116.54607947453405`}], 
             PointBox[{15.8, 114.64569229455446`}], 
             PointBox[{15.9, 114.44994386380313`}], 
             PointBox[{16., 113.72023997467295`}], 
             PointBox[{16.1, 111.37771883594905`}], 
             PointBox[{16.2, 110.67813904089417`}], 
             PointBox[{16.3, 110.1341294966096}], 
             PointBox[{16.4, 108.40901177880005`}], 
             PointBox[{16.5, 106.27556256376192`}], 
             PointBox[{16.6, 105.57381812969834`}], 
             PointBox[{16.7, 102.92986698495042`}], 
             PointBox[{16.8, 101.41514856382855`}], 
             PointBox[{16.9, 100.80335489958998`}], 
             PointBox[{17., 99.37726468402616}], 
             PointBox[{17.1, 96.5435589002227}], 
             PointBox[{17.2, 96.28919479783872}], 
             PointBox[{17.3, 95.18072367504465}], 
             PointBox[{17.4, 92.85761321948303}], 
             PointBox[{17.5, 90.81132085042918}], 
             PointBox[{17.6, 89.90163248106546}], 
             PointBox[{17.7, 86.54569618656751}], 
             PointBox[{17.8, 85.39090323786513}], 
             PointBox[{17.9, 84.26042092087482}], 
             PointBox[{18., 82.07883392554322}], 
             PointBox[{18.1, 79.32306076549685}], 
             PointBox[{18.2, 79.25211909604695}], 
             PointBox[{18.3, 77.20587238180087}], 
             PointBox[{18.4, 74.62668127356483}], 
             PointBox[{18.5, 72.88661882010638}], 
             PointBox[{18.6, 71.07204743320108}], 
             PointBox[{18.7, 67.97792818720882}], 
             PointBox[{18.8, 66.84748051459792}], 
             PointBox[{18.9, 65.1203183241123}], 
             PointBox[{19., 62.20462425097685}], 
             PointBox[{19.1, 60.49941773024693}], 
             PointBox[{19.2, 59.62456496156665}], 
             PointBox[{19.3, 56.84422446174358}], 
             PointBox[{19.4, 54.367109432963844`}], 
             PointBox[{19.5, 52.98897236525954}], 
             PointBox[{19.6, 49.77205204679012}], 
             PointBox[{19.7, 47.69259156324006}], 
             PointBox[{19.8, 46.227548054783256`}], 
             PointBox[{19.9, 43.869755912246546`}], 
             PointBox[{20., 40.5781753599731}], 
             PointBox[{20.1, 40.18462105278377}], 
             PointBox[{20.2, 37.809857189618924`}], 
             PointBox[{20.3, 34.92276975606546}], 
             PointBox[{20.4, 32.80934154559145}], 
             PointBox[{20.5, 31.28885453820112}], 
             PointBox[{20.6, 27.491522276084652`}], 
             PointBox[{20.7, 26.052059298725}], 
             PointBox[{20.8, 24.07457997614074}], 
             PointBox[{20.9, 21.132860317817176`}], 
             PointBox[{21., 18.57213415793194}], 
             PointBox[{21.1, 18.00009632691217}], 
             PointBox[{21.2, 14.835129010885794`}], 
             PointBox[{21.3, 12.231607004654506`}], 
             PointBox[{21.4, 10.586966701748679`}], 
             PointBox[{21.5, 7.9145234185380104`}], 
             PointBox[{21.6, 5.057694415469086}], 
             PointBox[{21.7, 3.4924353921524016`}], 
             PointBox[{21.8, 0.9972829362668563}], 
             PointBox[{21.9, -2.248583820695785}], 
             PointBox[{22., -3.068014132193639}], 
             PointBox[{22.1, -5.354748637380908}], 
             PointBox[{22.2, -8.394145697928252}], 
             PointBox[{22.3, -10.526824653261428`}], 
             PointBox[{22.4, -11.96550989635216}], 
             PointBox[{22.5, -15.752474499744494`}], 
             PointBox[{22.6, -17.39932875160048}], 
             PointBox[{22.7, -19.429259002572508`}], 
             PointBox[{22.8, -22.313032348620254`}], 
             PointBox[{22.9, -25.019402970867304`}], 
             PointBox[{23., -25.323299659959957`}], 
             PointBox[{23.1, -28.604723354384987`}], 
             PointBox[{23.2, -31.14331822985332}], 
             PointBox[{23.3, -32.76174507809992}], 
             PointBox[{23.4, -34.78620683246663}], 
             PointBox[{23.5, -38.18492266508838}], 
             PointBox[{23.6, -39.59614138292454}], 
             PointBox[{23.7, -42.05148971618837}], 
             PointBox[{23.8, -45.00414810704751}], 
             PointBox[{23.9, -46.15842555562631}], 
             PointBox[{24., -47.77311893636579}], 
             PointBox[{24.1, -50.83458474015424}], 
             PointBox[{24.2, -52.77609443426991}], 
             PointBox[{24.3, -54.03177345279255}], 
             PointBox[{24.4, -57.179879534396605`}], 
             PointBox[{24.5, -59.17653136028821}], 
             PointBox[{24.6, -60.9543428544639}], 
             PointBox[{24.7, -63.61455095529527}], 
             PointBox[{24.8, -65.99947184488701}], 
             PointBox[{24.9, -66.12584768033048}], 
             PointBox[{25., -68.98134258606296}], 
             PointBox[{25.1, -71.36608482079464}], 
             PointBox[{25.2, -72.72254346459886}], 
             PointBox[{25.3, -74.02098600471436}], 
             PointBox[{25.4, -77.53079453303872}], 
             PointBox[{25.5, -78.60902662690933}], 
             PointBox[{25.6, -80.74812985623066}], 
             PointBox[{25.7, -83.26495529109161}], 
             PointBox[{25.8, -84.57059828955244}], 
             PointBox[{25.9, -85.00316893443232}], 
             PointBox[{26., -87.98832285576282}], 
             PointBox[{26.1, -89.63649156226165}], 
             PointBox[{26.2, -90.48871986657468}], 
             PointBox[{26.3, -92.28507984548924}], 
             PointBox[{26.4, -94.99459787505839}], 
             PointBox[{26.5, -95.967588908974}], 
             PointBox[{26.6, -98.24028216001534}], 
             PointBox[{26.7, -100.17906971243065`}], 
             PointBox[{26.8, -100.6670168114506}], 
             PointBox[{26.9, -101.8294975494864}], 
             PointBox[{27., -104.25659403902682`}], 
             PointBox[{27.1, -105.21036738357725`}], 
             PointBox[{27.2, -105.69292008243065`}], 
             PointBox[{27.3, -108.04474412938725`}], 
             PointBox[{27.4, -109.54425398238891`}], 
             PointBox[{27.5, -110.67623576666665`}], 
             PointBox[{27.6, -112.8392719817275}], 
             PointBox[{27.7, -114.09194852185828`}], 
             PointBox[{27.8, -114.10814928024774`}], 
             PointBox[{27.9, -115.81727869728638`}], 
             PointBox[{28., -117.54006300173569`}], 
             PointBox[{28.1, -117.86183645135316`}], 
             PointBox[{28.2, -118.10933878221476`}], 
             PointBox[{28.3, -120.66081907043917`}], 
             PointBox[{28.4, -121.18018274525457`}], 
             PointBox[{28.5, -122.39825979171292`}], 
             PointBox[{28.6, -124.29988191367738`}], 
             PointBox[{28.7, -125.31586148785937`}], 
             PointBox[{28.8, -124.90510856082983`}], 
             PointBox[{28.9, -126.7753171571785}], 
             PointBox[{29., -127.87199184311976`}], 
             PointBox[{29.1, -127.63088463277745`}], 
             PointBox[{29.2, -127.70511420534604`}], 
             PointBox[{29.3, -130.11984089391626`}], 
             PointBox[{29.4, -129.9798327599674}], 
             PointBox[{29.5, -131.15121762334456`}], 
             PointBox[{29.6, -132.81208944864557`}], 
             PointBox[{29.7, -133.90399943815282`}], 
             PointBox[{29.8, -133.10064043526654`}], 
             PointBox[{29.9, -134.88055666209402`}], 
             PointBox[{30., -135.50364494810492`}], 
             PointBox[{30.1, -134.76873020770654`}], 
             PointBox[{30.2, -134.63807123391234`}], 
             PointBox[{30.3, -136.80900932880832`}], 
             PointBox[{30.4, -136.20538487374142`}], 
             PointBox[{30.5, -137.2124435440819}], 
             PointBox[{30.6, -138.77296089660376`}], 
             PointBox[{30.7, -140.0052136460763}], 
             PointBox[{30.8, -138.8637400025509}], 
             PointBox[{30.9, -140.4413269441975}], 
             PointBox[{31., -140.77569834153473`}], 
             PointBox[{31.1, -139.61030889819085`}], 
             PointBox[{31.2, -139.1841010045864}], 
             PointBox[{31.3, -141.1498789787256}], 
             PointBox[{31.4, -140.2118455773416}], 
             PointBox[{31.5, -140.9281855341942}], 
             PointBox[{31.6, -142.5015542698784}], 
             PointBox[{31.7, -143.88690759824385`}], 
             PointBox[{31.8, -142.46972291835846`}], 
             PointBox[{31.9, -143.7485206654419}], 
             PointBox[{32., -144.00216661751256`}], 
             PointBox[{32.1, -142.4701877731095}], 
             PointBox[{32.2, -141.63632676561974`}], 
             PointBox[{32.3, -143.44084992596981`}], 
             PointBox[{32.4, -142.33573933749722`}], 
             PointBox[{32.5, -142.59190740308986`}], 
             PointBox[{32.6, -144.20626347833968`}], 
             PointBox[{32.7, -145.7618724323729}], 
             PointBox[{32.8, -144.21070445119403`}], 
             PointBox[{32.9, -145.01409065574626`}], 
             PointBox[{33., -145.41013045481304`}], 
             PointBox[{33.1, -143.59761690242885`}], 
             PointBox[{33.2, -142.24605220005833`}], 
             PointBox[{33.3, -143.84376798692392`}], 
             PointBox[{33.4, -142.84553272349513`}], 
             PointBox[{33.5, -142.42742483093025`}], 
             PointBox[{33.6, -144.03467190067022`}], 
             PointBox[{33.7, -145.73578814377106`}], 
             PointBox[{33.8, -144.32969834404867`}], 
             PointBox[{33.9, -144.3747723076085}], 
             PointBox[{34., -145.11843837660126`}], 
             PointBox[{34.1, -143.16777632354933`}], 
             PointBox[{34.2, -141.20745422394248`}], 
             PointBox[{34.3, -142.42953503677927`}], 
             PointBox[{34.4, -141.9110242067618}], 
             PointBox[{34.5, -140.61914883042482`}], 
             PointBox[{34.6, -142.07822597553604`}], 
             PointBox[{34.7, -143.82088355227097`}], 
             PointBox[{34.8, -142.9656525021055}], 
             PointBox[{34.9, -141.94077451730845`}], 
             PointBox[{35., -143.13016088069708`}], 
             PointBox[{35.1, -141.2812198384854}], 
             PointBox[{35.2, -138.6636481403657}], 
             PointBox[{35.3, -139.23813640888693`}], 
             PointBox[{35.4, -139.55061536036737`}], 
             PointBox[{35.5, -137.34622424578993`}], 
             PointBox[{35.6, -138.3744753220526}], 
             PointBox[{35.7, -140.01997342963296`}], 
             PointBox[{35.8, -140.09764646133408`}], 
             PointBox[{35.9, -137.86160606453632`}], 
             PointBox[{36., -139.33484481950654`}], 
             PointBox[{36.1, -137.95372853607114`}], 
             PointBox[{36.2, -134.71407943134545`}], 
             PointBox[{36.3, -134.3231049023525}], 
             PointBox[{36.4, -135.58128554453288`}], 
             PointBox[{36.5, -132.79835913468196`}], 
             PointBox[{36.6, -132.94831024769155`}], 
             PointBox[{36.7, -134.490129138263}], 
             PointBox[{36.8, -135.5080094576042}], 
             PointBox[{36.9, -132.35200750263175`}], 
             PointBox[{37., -133.5404742090941}], 
             PointBox[{37.1, -133.08356655075477`}], 
             PointBox[{37.2, -129.41392467626065`}], 
             PointBox[{37.3, -127.74613918473915`}], 
             PointBox[{37.4, -129.66446609776904`}], 
             PointBox[{37.5, -127.12766791189279`}], 
             PointBox[{37.6, -125.86333729790567`}], 
             PointBox[{37.7, -127.40210876179117`}], 
             PointBox[{37.8, -128.78795564704342`}], 
             PointBox[{37.9, -125.59470765731385`}], 
             PointBox[{38., -125.55237583769122`}], 
             PointBox[{38.1, -126.38601019463749`}], 
             PointBox[{38.2, -122.74576569936835`}], 
             PointBox[{38.3, -119.53674840426902`}], 
             PointBox[{38.4, -121.45733229460166`}], 
             PointBox[{38.5, -120.26841779129609`}], 
             PointBox[{38.6, -117.24222049572563`}], 
             PointBox[{38.7, -118.47765087069638`}], 
             PointBox[{38.8, -119.5977474496176}], 
             PointBox[{38.9, -117.4945086446678}], 
             PointBox[{39., -115.24925835177055`}], 
             PointBox[{39.1, -117.30717757270395`}], 
             PointBox[{39.2, -114.50858378630073`}], 
             PointBox[{39.3, -109.61101586302539`}], 
             PointBox[{39.4, -110.67207145058637`}], 
             PointBox[{39.5, -111.66286731888977`}], 
             PointBox[{39.6, -107.21232799453355`}], 
             PointBox[{39.7, -107.26641908685633`}], 
             PointBox[{39.8, -108.45409406640829`}], 
             PointBox[{39.9, -107.3325019412332}], 
             PointBox[{40., -102.4615003310173}], 
             PointBox[{40.1, -104.9059177324707}], 
             PointBox[{40.2, -104.02619624427825`}], 
             PointBox[{40.3, -97.56412729325893}], 
             PointBox[{40.4, -96.80777900955945}], 
             PointBox[{40.5, -100.11798901950533`}], 
             PointBox[{40.6, -95.61355600791649}], 
             PointBox[{40.7, -93.25859893482993}], 
             PointBox[{40.8, -95.33864912580611}], 
             PointBox[{40.9, -93.52570654149531}], 
             PointBox[{41., -86.30448096232067}], 
             PointBox[{41.1, -87.44611048826482}], 
             PointBox[{41.2, -89.4511997497575}], 
             PointBox[{41.3, -82.00803186419216}], 
             PointBox[{41.4, -78.33634761099529}], 
             PointBox[{41.5, -83.61140103750586}], 
             PointBox[{41.6, -81.10122266215694}], 
             PointBox[{41.7, -75.1409972570109}], 
             PointBox[{41.8, -77.58300431666066}], 
             PointBox[{41.9, -74.83521848319288}], 
             PointBox[{42., -63.29570399327713}], 
             PointBox[{42.1, -60.64623239816865}], 
             PointBox[{42.2, -65.91108888229064}], 
             PointBox[{42.3, -58.23660407239731}], 
             PointBox[{42.4, -50.49400998182682}], 
             PointBox[{42.5, -57.785862353972334`}], 
             PointBox[{42.6, -58.90066515633225}], 
             PointBox[{42.7, -48.41856468262267}], 
             PointBox[{42.8, -50.04774208946037}], 
             PointBox[{42.9, -49.61239964180277}], 
             PointBox[{43., -25.238520127753873`}], 
             PointBox[{43.1, -15.44409678768352}], 
             PointBox[{43.2, -22.791250738999224`}], 
             PointBox[{43.3, -14.089167566602555`}], 
             PointBox[{43.4, -3.826034097597585}], 
             PointBox[{43.5, -14.085581313727744`}], 
             PointBox[{43.6, -17.35752047819915}], 
             PointBox[{43.7, -1.9670019748118648`}], 
             PointBox[{43.8, -3.3661758847629244`}], 
             PointBox[{43.9, -6.553241783651174}], 
             PointBox[{44., 22.236928335394623`}], 
             PointBox[{44.1, 36.803814075541595`}], 
             PointBox[{44.2, 31.259165417170152`}], 
             PointBox[{44.3, 38.36159622095511}], 
             PointBox[{44.4, 46.40428967498883}], 
             PointBox[{44.5, 37.48996172720217}], 
             PointBox[{44.6, 36.06388684249396}], 
             PointBox[{44.7, 49.83606368955225}], 
             PointBox[{44.8, 48.804456996560475`}], 
             PointBox[{44.9, 44.18807607749477}], 
             PointBox[{45., 58.689302819384466`}], 
             PointBox[{45.1, 69.03664646954712}], 
             PointBox[{45.2, 66.05085706913087}], 
             PointBox[{45.3, 68.58831634256421}], 
             PointBox[{45.4, 75.98425974052952}], 
             PointBox[{45.5, 71.30821206127439}], 
             PointBox[{45.6, 69.30839216094319}], 
             PointBox[{45.7, 78.74825499979488}], 
             PointBox[{45.8, 80.71911873297722}], 
             PointBox[{45.9, 76.36200889161773}], 
             PointBox[{46., 82.86346628956744}], 
             PointBox[{46.1, 88.29934069643059}], 
             PointBox[{46.2, 87.64331318561017}], 
             PointBox[{46.3, 87.21869177917688}], 
             PointBox[{46.4, 93.28284980888566}], 
             PointBox[{46.5, 92.42748534258135}], 
             PointBox[{46.6, 89.49850245547714}], 
             PointBox[{46.7, 95.47515206745447}], 
             PointBox[{46.8, 99.70715390083205}], 
             PointBox[{46.9, 96.79581734532985}], 
             PointBox[{47., 98.81700351143081}], 
             PointBox[{47.1, 103.16974413371645`}], 
             PointBox[{47.2, 103.10667599790031`}], 
             PointBox[{47.3, 101.49630283928855`}], 
             PointBox[{47.4, 105.20217536335258`}], 
             PointBox[{47.5, 107.27321385622781`}], 
             PointBox[{47.6, 104.25000635466131`}], 
             PointBox[{47.7, 107.45113836661767`}], 
             PointBox[{47.8, 112.47326308570337`}], 
             PointBox[{47.9, 111.6159427548555}], 
             PointBox[{48., 110.93746375128103`}], 
             PointBox[{48.1, 115.48795340432116`}], 
             PointBox[{48.2, 114.9561979598584}], 
             PointBox[{48.3, 113.3499186012923}], 
             PointBox[{48.4, 114.6809970509712}], 
             PointBox[{48.5, 118.19840587177168`}], 
             PointBox[{48.6, 116.00862606103328`}], 
             PointBox[{48.7, 117.07325481894804`}], 
             PointBox[{48.8, 121.77939011665876`}], 
             PointBox[{48.9, 122.80325633662869`}], 
             PointBox[{49., 121.06920391623134`}], 
             PointBox[{49.1, 124.67629804642638`}], 
             PointBox[{49.2, 124.58156492835406`}], 
             PointBox[{49.3, 123.20076461931603`}], 
             PointBox[{49.4, 122.846761918845}], 
             PointBox[{49.5, 126.24387066895724`}], 
             PointBox[{49.6, 125.52168133025407`}], 
             PointBox[{49.7, 125.0695422753779}], 
             PointBox[{49.8, 128.89044746856234`}], 
             PointBox[{49.9, 131.14654000700102`}], 
             PointBox[{50., 129.60423483059276`}], 
             PointBox[{50.1, 131.47675431607058`}], 
             PointBox[{50.2, 132.69970439777535`}], 
             PointBox[{50.3, 131.1281589297214}], 
             PointBox[{50.4, 129.88967577790754`}], 
             PointBox[{50.5, 132.18565850360028`}], 
             PointBox[{50.6, 132.98409654847637`}], 
             PointBox[{50.7, 131.62684180931683`}], 
             PointBox[{50.8, 134.38037173043267`}], 
             PointBox[{50.9, 137.17231615562196`}], 
             PointBox[{51., 136.4237425554602}], 
             PointBox[{51.1, 136.63043176020437`}], 
             PointBox[{51.2, 138.89972472826776`}], 
             PointBox[{51.3, 137.20210096927622`}], 
             PointBox[{51.4, 135.6539357798174}], 
             PointBox[{51.5, 136.6193855618767}], 
             PointBox[{51.6, 138.4359705691968}], 
             PointBox[{51.7, 136.75405554319877`}], 
             PointBox[{51.8, 138.46533080101653`}], 
             PointBox[{51.9, 141.28461244670325`}], 
             PointBox[{52., 141.37436858995352`}], 
             PointBox[{52.1, 140.47644236689666`}], 
             PointBox[{52.2, 142.99514883390657`}], 
             PointBox[{52.3, 141.5518474173732}], 
             PointBox[{52.4, 139.94884361523873`}], 
             PointBox[{52.5, 139.8153549309136}], 
             PointBox[{52.6, 141.9418962185955}], 
             PointBox[{52.7, 140.39389755798038`}], 
             PointBox[{52.8, 141.1850724172109}], 
             PointBox[{52.9, 143.74021265986084`}], 
             PointBox[{53., 144.42370900738752`}], 
             PointBox[{53.1, 143.03270522853563`}], 
             PointBox[{53.2, 145.17335162506788`}], 
             PointBox[{53.3, 144.23694165431516`}], 
             PointBox[{53.4, 142.6311517186332}], 
             PointBox[{53.5, 141.75964327090333`}], 
             PointBox[{53.6, 143.6361113429448}], 
             PointBox[{53.7, 142.45603447488247`}], 
             PointBox[{53.8, 142.49138510612102`}], 
             PointBox[{53.9, 144.65006589731638`}], 
             PointBox[{54., 145.61842409502424`}], 
             PointBox[{54.1, 144.13481810003577`}], 
             PointBox[{54.2, 145.60765002833068`}], 
             PointBox[{54.3, 145.1668564229767}], 
             PointBox[{54.4, 143.59288801016373`}], 
             PointBox[{54.5, 142.29298009729973`}], 
             PointBox[{54.6, 143.6476860007897}], 
             PointBox[{54.7, 142.82238215147663`}], 
             PointBox[{54.8, 142.27659721308737`}], 
             PointBox[{54.9, 144.00125741377997`}], 
             PointBox[{55., 144.98890211675462`}], 
             PointBox[{55.1, 143.55485680509446`}], 
             PointBox[{55.2, 144.34701813541324`}], 
             PointBox[{55.3, 144.20951385171065`}], 
             PointBox[{55.4, 142.7269371040602}], 
             PointBox[{55.5, 141.20214319481602`}], 
             PointBox[{55.6, 142.00134512237855`}], 
             PointBox[{55.7, 141.34117944378522`}], 
             PointBox[{55.8, 140.37718526140088`}], 
             PointBox[{55.9, 141.67802555402886`}], 
             PointBox[{56., 142.4831428299076}], 
             PointBox[{56.1, 141.05251855172537`}], 
             PointBox[{56.2, 141.30688928155723`}], 
             PointBox[{56.3, 141.22973395069857`}], 
             PointBox[{56.4, 139.8886659637501}], 
             PointBox[{56.5, 138.23723533681186`}], 
             PointBox[{56.6, 138.57547972143948`}], 
             PointBox[{56.7, 137.80791605587}], 
             PointBox[{56.8, 136.5702780912252}], 
             PointBox[{56.9, 137.47208398926887`}], 
             PointBox[{57., 137.94053497557616`}], 
             PointBox[{57.1, 136.36948831334303`}], 
             PointBox[{57.2, 136.28969128522294`}], 
             PointBox[{57.3, 136.06630180752836`}], 
             PointBox[{57.4, 134.85759852602496`}], 
             PointBox[{57.5, 133.09862741864345`}], 
             PointBox[{57.6, 133.10842678491463`}], 
             PointBox[{57.7, 131.93995876878034`}], 
             PointBox[{57.8, 130.5744714689572}], 
             PointBox[{57.9, 131.0898262613191}], 
             PointBox[{58., 131.094117288063}], 
             PointBox[{58.1, 129.2151035380375}], 
             PointBox[{58.2, 129.02061838946247`}], 
             PointBox[{58.3, 128.55469310563785`}], 
             PointBox[{58.4, 127.31314219305204`}], 
             PointBox[{58.5, 125.44008695930097`}], 
             PointBox[{58.6, 125.24137624417199`}], 
             PointBox[{58.7, 123.40007162735856`}], 
             PointBox[{58.8, 122.07842259564495`}], 
             PointBox[{58.9, 122.1870846424863}], 
             PointBox[{59., 121.61427898313559`}], 
             PointBox[{59.1, 119.31241155918542`}], 
             PointBox[{59.2, 119.19394990854926`}], 
             PointBox[{59.3, 118.51038549521763`}], 
             PointBox[{59.4, 116.8949777775706}], 
             PointBox[{59.5, 114.94960122373595`}], 
             PointBox[{59.6, 114.58117936584313`}], 
             PointBox[{59.7, 111.93710744869895`}], 
             PointBox[{59.8, 110.81270071070321`}], 
             PointBox[{59.9, 110.45665388429916`}], 
             PointBox[{60., 109.20652526082267`}], 
             PointBox[{60.1, 106.55159626611567`}], 
             PointBox[{60.2, 106.55755066723214`}], 
             PointBox[{60.3, 105.54733524336916`}], 
             PointBox[{60.4, 103.39904643193586`}], 
             PointBox[{60.5, 101.51576428891713`}], 
             PointBox[{60.6, 100.77282832274068`}], 
             PointBox[{60.7, 97.59419876759057}], 
             PointBox[{60.8, 96.65860135804542}], 
             PointBox[{60.9, 95.76057882048917}], 
             PointBox[{61., 93.7534865061316}], 
             PointBox[{61.1, 91.20755457917403}], 
             PointBox[{61.2, 91.17940526659368}], 
             PointBox[{61.3, 89.43499877955037}], 
             PointBox[{61.4, 86.97085248368239}], 
             PointBox[{61.5, 85.34044159569021}], 
             PointBox[{61.6, 83.64857846740051}], 
             PointBox[{61.7, 80.70913898763683}], 
             PointBox[{61.8, 79.7329841370447}], 
             PointBox[{61.9, 78.22289817170531}], 
             PointBox[{62., 75.45274910442822}], 
             PointBox[{62.1, 73.80909059452824}], 
             PointBox[{62.2, 73.11467565991916}], 
             PointBox[{62.3, 70.55701694250456}], 
             PointBox[{62.4, 68.10606042052677}], 
             PointBox[{62.5, 66.80291687733552}], 
             PointBox[{62.6, 63.73663950761693}], 
             PointBox[{62.7, 61.686664717126405`}], 
             PointBox[{62.8, 60.380582973935816`}], 
             PointBox[{62.9, 58.21276063625555}], 
             PointBox[{63., 54.970049129893596`}], 
             PointBox[{63.1, 54.519794949970674`}], 
             PointBox[{63.2, 52.47593132353359}], 
             PointBox[{63.3, 49.64491814542998}], 
             PointBox[{63.4, 47.49043552259536}], 
             PointBox[{63.5, 46.08463241436402}], 
             PointBox[{63.6, 42.33259111299412}], 
             PointBox[{63.7, 40.91302340560651}], 
             PointBox[{63.8, 39.09819409032934}], 
             PointBox[{63.9, 36.283412077515095`}], 
             PointBox[{64., 33.56449713152688}], 
             PointBox[{64.1, 33.168167700845515`}], 
             PointBox[{64.2, 30.154586931981612`}], 
             PointBox[{64.3, 27.490627626117202`}], 
             PointBox[{64.4, 25.790792902073008`}], 
             PointBox[{64.5, 23.287667087330192`}], 
             PointBox[{64.6, 20.315790879743872`}], 
             PointBox[{64.7, 18.83086180008104}], 
             PointBox[{64.8, 16.4668705405129}], 
             PointBox[{64.9, 13.20854861967382}], 
             PointBox[{65., 12.155598917554016`}], 
             PointBox[{65.1, 10.164395198102284`}], 
             PointBox[{65.2, 7.086808163810929}], 
             PointBox[{65.3, 4.832629774406087}], 
             PointBox[{65.4, 3.3991846952412743`}], 
             PointBox[{65.5, -0.33832442847051425`}], 
             PointBox[{65.6, -2.090136258950224}], 
             PointBox[{65.7, -4.022375375643605}], 
             PointBox[{65.8, -6.857507074404566}], 
             PointBox[{65.9, -9.811310987206525}], 
             PointBox[{66., -10.06155056211719}], 
             PointBox[{66.1, -13.270238066936145`}], 
             PointBox[{66.2, -15.948324316479557`}], 
             PointBox[{66.3, -17.697420871641953`}], 
             PointBox[{66.4, -19.65111325038015}], 
             PointBox[{66.5, -23.188909353986674`}], 
             PointBox[{66.6, -24.617785438029387`}], 
             PointBox[{66.7, -27.019906973182515`}], 
             PointBox[{66.8, -30.07575996250671}], 
             PointBox[{66.9, -31.524664028147527`}], 
             PointBox[{67., -32.99263081313984}], 
             PointBox[{67.1, -36.15831403872289}], 
             PointBox[{67.2, -38.28378833845636}], 
             PointBox[{67.3, -39.63988491056807}], 
             PointBox[{67.4, -42.797343339872896`}], 
             PointBox[{67.5, -44.960062174723134`}], 
             PointBox[{67.6, -46.741028543045104`}], 
             PointBox[{67.7, -49.44165018381318}], 
             PointBox[{67.8, -52.12405322527047}], 
             PointBox[{67.9, -52.31867475992476}], 
             PointBox[{68., -55.209157783137925`}], 
             PointBox[{68.1, -57.7760241104188}], 
             PointBox[{68.2, -59.33015577232436}], 
             PointBox[{68.3, -60.723953415072174`}], 
             PointBox[{68.4, -64.35985895800695}], 
             PointBox[{68.5, -65.57743243336154}], 
             PointBox[{68.6, -67.7661747300881}], 
             PointBox[{68.7, -70.44999003256089}], 
             PointBox[{68.8, -72.00600624433719}], 
             PointBox[{68.9, -72.5406678954314}], 
             PointBox[{69., -75.6519528847275}], 
             PointBox[{69.1, -77.51486444997863}], 
             PointBox[{69.2, -78.57258176129835}], 
             PointBox[{69.3, -80.57722652265511}], 
             PointBox[{69.4, -83.37287843888043}], 
             PointBox[{69.5, -84.54877553674305}], 
             PointBox[{69.6, -86.92988786708156}], 
             PointBox[{69.7, -89.12257770158612}], 
             PointBox[{69.8, -89.61606227716402}], 
             PointBox[{69.9, -91.13174963270285}], 
             PointBox[{70., -93.6703090008159}], 
             PointBox[{70.1, -94.85420918047748}], 
             PointBox[{70.2, -95.58251090610429}], 
             PointBox[{70.3, -98.29227863541018}], 
             PointBox[{70.4, -99.7799150278006}], 
             PointBox[{70.5, -101.21501019038988`}], 
             PointBox[{70.6, -103.50774148066557`}], 
             PointBox[{70.7, -104.9002155811686}], 
             PointBox[{70.8, -104.8744592805233}], 
             PointBox[{70.9, -107.08082489026128`}], 
             PointBox[{71., -108.85893932069303`}], 
             PointBox[{71.1, -109.41882837296725`}], 
             PointBox[{71.2, -110.02023247613397`}], 
             PointBox[{71.3, -112.91443806597817`}], 
             PointBox[{71.4, -113.4407704890109}], 
             PointBox[{71.5, -115.04394592763128`}], 
             PointBox[{71.6, -117.00559029207216`}], 
             PointBox[{71.7, -117.96874735093297`}], 
             PointBox[{71.8, -117.66203846547432`}], 
             PointBox[{71.9, -119.99708933634247`}], 
             PointBox[{72., -121.06377758175222`}], 
             PointBox[{72.1, -121.06481578657986`}], 
             PointBox[{72.2, -121.65694164659362`}], 
             PointBox[{72.3, -124.22759354889422`}], 
             PointBox[{72.4, -124.20348900422687`}], 
             PointBox[{72.5, -125.82346465722367`}], 
             PointBox[{72.6, -127.40122698801133`}], 
             PointBox[{72.7, -128.29667879998306`}], 
             PointBox[{72.8, -127.77272600713331`}], 
             PointBox[{72.9, -129.9252858022155}], 
             PointBox[{73., -130.39684230334387`}], 
             PointBox[{73.1, -129.90304670009937`}], 
             PointBox[{73.2, -130.46084517597046`}], 
             PointBox[{73.3, -132.56504629073606`}], 
             PointBox[{73.4, -132.1560475025326}], 
             PointBox[{73.5, -133.6919343735426}], 
             PointBox[{73.6, -135.07408214554016`}], 
             PointBox[{73.7, -135.97185686607554`}], 
             PointBox[{73.8, -135.21248211351485`}], 
             PointBox[{73.9, -137.13402227882034`}], 
             PointBox[{74., -137.15335414400033`}], 
             PointBox[{74.1, -136.21359723508067`}], 
             PointBox[{74.2, -136.6211391286488}], 
             PointBox[{74.3, -138.3791968896985}], 
             PointBox[{74.4, -137.59432663708867`}], 
             PointBox[{74.5, -138.98102792252757`}], 
             PointBox[{74.6, -140.3733105841602}], 
             PointBox[{74.7, -141.29517866179958`}], 
             PointBox[{74.8, -140.20461785195948`}], 
             PointBox[{74.9, -141.94631203560857`}], 
             PointBox[{75., -141.67790627485374`}], 
             PointBox[{75.1, -140.3228679011445}], 
             PointBox[{75.2, -140.43763711330394`}], 
             PointBox[{75.3, -142.05196540051838`}], 
             PointBox[{75.4, -140.87234094880114`}], 
             PointBox[{75.5, -142.02414386198507`}], 
             PointBox[{75.6, -143.506706266322}], 
             PointBox[{75.7, -144.5505108725847}], 
             PointBox[{75.8, -143.048269384788}], 
             PointBox[{75.9, -144.63153640328528`}], 
             PointBox[{76., -144.26832145123626`}], 
             PointBox[{76.1, -142.5236002441452}], 
             PointBox[{76.2, -142.20006976885634`}], 
             PointBox[{76.3, -143.83191477649234`}], 
             PointBox[{76.4, -142.3097822909549}], 
             PointBox[{76.5, -143.07392973183596`}], 
             PointBox[{76.6, -144.6408517125019}], 
             PointBox[{76.7, -145.92587323057523`}], 
             PointBox[{76.8, -144.03729111052235`}], 
             PointBox[{76.9, -145.36091812762606`}], 
             PointBox[{77., -145.1318974113383}], 
             PointBox[{77.1, -143.0439255289166}], 
             PointBox[{77.2, -142.14006701120525`}], 
             PointBox[{77.3, -143.82431559934048`}], 
             PointBox[{77.4, -142.16805452724657`}], 
             PointBox[{77.5, -142.3107151266231}], 
             PointBox[{77.6, -143.92194963325164`}], 
             PointBox[{77.7, -145.49009315463627`}], 
             PointBox[{77.8, -143.43018001270684`}], 
             PointBox[{77.9, -144.21312653535279`}], 
             PointBox[{78., -144.37178360174585`}], 
             PointBox[{78.1, -142.04462046024855`}], 
             PointBox[{78.2, -140.43225998566777`}], 
             PointBox[{78.3, -142.02646281915804`}], 
             PointBox[{78.4, -140.63977501876798`}], 
             PointBox[{78.5, -139.88135088642593`}], 
             PointBox[{78.6, -141.4525041369052}], 
             PointBox[{78.7, -143.19872331321676`}], 
             PointBox[{78.8, -141.4112424292689}], 
             PointBox[{78.9, -141.22266809391294`}], 
             PointBox[{79., -141.97813150043658`}], 
             PointBox[{79.1, -139.6217931054125}], 
             PointBox[{79.2, -137.20648345109657`}], 
             PointBox[{79.3, -138.3981181440031}], 
             PointBox[{79.4, -137.7981601880092}], 
             PointBox[{79.5, -135.93625086527027`}], 
             PointBox[{79.6, -137.25258253811626`}], 
             PointBox[{79.7, -138.950921156189}], 
             PointBox[{79.8, -138.01993702570326`}], 
             PointBox[{79.9, -136.45744787080184`}], 
             PointBox[{80., -137.81748133780638`}], 
             PointBox[{80.1, -135.7968762089513}], 
             PointBox[{80.2, -132.55486198197468`}], 
             PointBox[{80.3, -132.92923696400248`}], 
             PointBox[{80.4, -133.506622580775}], 
             PointBox[{80.5, -130.65649302668317`}], 
             PointBox[{80.6, -131.28904620748654`}], 
             PointBox[{80.7, -132.80060818923812`}], 
             PointBox[{80.8, -133.07158871978027`}], 
             PointBox[{80.9, -130.08461834710033`}], 
             PointBox[{81., -131.6424966169725}], 
             PointBox[{81.1, -130.4799237491534}], 
             PointBox[{81.2, -126.531355552288}], 
             PointBox[{81.3, -125.64818575619574`}], 
             PointBox[{81.4, -127.38051522129535`}], 
             PointBox[{81.5, -124.2294107034977}], 
             PointBox[{81.6, -123.55969646340964`}], 
             PointBox[{81.7, -125.07948893715366`}], 
             PointBox[{81.8, -126.10889286721795`}], 
             PointBox[{81.9, -122.32076454190246`}], 
             PointBox[{82., -123.14263727531943`}], 
             PointBox[{82.1, -123.38271882884874`}], 
             PointBox[{82.2, -119.11623701237113`}], 
             PointBox[{82.3, -116.55655238912004`}], 
             PointBox[{82.4, -118.9130675703127}], 
             PointBox[{82.5, -116.68805956123106`}], 
             PointBox[{82.6, -114.12029209213506`}], 
             PointBox[{82.7, -115.63861764089233`}], 
             PointBox[{82.8, -116.53109802481777`}], 
             PointBox[{82.9, -113.18251650522143`}], 
             PointBox[{83., -112.0048726541063}], 
             PointBox[{83.1, -113.88028896605829`}], 
             PointBox[{83.2, -110.0944653052502}], 
             PointBox[{83.3, -105.4955417159872}], 
             PointBox[{83.4, -107.59928772514104`}], 
             PointBox[{83.5, -107.56373897845333`}], 
             PointBox[{83.6, -103.01305215560569`}], 
             PointBox[{83.7, -103.74926826966112`}], 
             PointBox[{83.8, -104.48440395210491`}], 
             PointBox[{83.9, -102.02121284255554`}], 
             PointBox[{84., -97.75128470975324}], 
             PointBox[{84.1, -100.77848608740169`}], 
             PointBox[{84.2, -98.68444789245405}], 
             PointBox[{84.3, -91.83108077655197}], 
             PointBox[{84.4, -92.66076538922789}], 
             PointBox[{84.5, -95.51046245249017}], 
             PointBox[{84.6, -89.93591277403902}], 
             PointBox[{84.7, -88.52549522605841}], 
             PointBox[{84.8, -90.42979154286877}], 
             PointBox[{84.9, -86.91388893824478}], 
             PointBox[{85., -78.84421115033183}], 
             PointBox[{85.1, -81.66078498142451}], 
             PointBox[{85.2, -82.54690352962643}], 
             PointBox[{85.3, -73.4693551634191}], 
             PointBox[{85.4, -71.96233177286194}], 
             PointBox[{85.5, -77.83620080747642}], 
             PointBox[{85.6, -73.11186057055602}], 
             PointBox[{85.7, -67.89989547088771}], 
             PointBox[{85.8, -71.15447457676783}], 
             PointBox[{85.9, -65.13031290104118}], 
             PointBox[{86., -50.01499048245023}], 
             PointBox[{86.1, -50.58221973056061}], 
             PointBox[{86.2, -55.01861808860849}], 
             PointBox[{86.3, -43.541875999362674`}], 
             PointBox[{86.4, -39.2823186831738}], 
             PointBox[{86.5, -48.581784676258394`}], 
             PointBox[{86.6, -45.97284770887927}], 
             PointBox[{86.7, -35.38625822704489}], 
             PointBox[{86.8, -39.481164094751875`}], 
             PointBox[{86.9, -34.10487550263497}], 
             PointBox[{87., -3.232341173250461}], 
             PointBox[{87.1, 0.308967324817786}], 
             PointBox[{87.2, -5.241886461444665}], 
             PointBox[{87.3, 8.244580717859208}], 
             PointBox[{87.4, 11.853263700999378`}], 
             PointBox[{87.5, 0.26016850678570336`}], 
             PointBox[{87.6, 3.5262663847461226`}], 
             PointBox[{87.7, 17.495596997810935`}], 
             PointBox[{87.8, 12.12531667829171}], 
             PointBox[{87.9, 13.805996806833718`}], 
             PointBox[{88., 41.25831641802506}], 
             PointBox[{88.1, 48.06861805777589}], 
             PointBox[{88.2, 43.96228802874248}], 
             PointBox[{88.3, 52.94828594288265}], 
             PointBox[{88.4, 56.565504468431755`}], 
             PointBox[{88.5, 48.06120789430861}], 
             PointBox[{88.6, 51.2176371078458}], 
             PointBox[{88.7, 62.41145589280495}], 
             PointBox[{88.8, 59.03405349314562}], 
             PointBox[{88.9, 57.289628552076465`}], 
             PointBox[{89., 70.13938280393631}], 
             PointBox[{89.1, 76.06470190587424}], 
             PointBox[{89.2, 73.05223036314419}], 
             PointBox[{89.3, 76.98108630516799}], 
             PointBox[{89.4, 82.37481339686201}], 
             PointBox[{89.5, 77.28845087438822}], 
             PointBox[{89.6, 77.80155123666191}], 
             PointBox[{89.7, 86.46289906023594}], 
             PointBox[{89.8, 86.63500826634845}], 
             PointBox[{89.9, 83.42082206576742}], 
             PointBox[{90., 90.4242880201491}], 
             PointBox[{90.1, 93.6724925586459}], 
             PointBox[{90.2, 92.22986918087554}], 
             PointBox[{90.3, 92.81228549811203}], 
             PointBox[{90.4, 98.36759960627387}], 
             PointBox[{90.5, 96.39869312012888}], 
             PointBox[{90.6, 94.94532800970046}], 
             PointBox[{90.7, 101.20993238455412`}], 
             PointBox[{90.8, 104.0362518050897}], 
             PointBox[{90.9, 101.17979423397628`}], 
             PointBox[{91., 104.44536111660273`}], 
             PointBox[{91.1, 107.22874581180076`}], 
             PointBox[{91.2, 106.6186203557736}], 
             PointBox[{91.3, 105.49836491203314`}], 
             PointBox[{91.4, 109.5558318766416}], 
             PointBox[{91.5, 110.40093487055128`}], 
             PointBox[{91.6, 108.03377281245776`}], 
             PointBox[{91.7, 112.00471265074157`}], 
             PointBox[{91.8, 116.133638670668}], 
             PointBox[{91.9, 114.72194402685273`}], 
             PointBox[{92., 115.12304606837279`}], 
             PointBox[{92.1, 118.83641072150203`}], 
             PointBox[{92.2, 117.88280061240948`}], 
             PointBox[{92.3, 116.30504606314935`}], 
             PointBox[{92.4, 118.27044428870431`}], 
             PointBox[{92.5, 120.98083883183426`}], 
             PointBox[{92.6, 118.69653644434584`}], 
             PointBox[{92.7, 120.68205211588065`}], 
             PointBox[{92.8, 124.98705075525504`}], 
             PointBox[{92.9, 125.2403426728124}], 
             PointBox[{93., 124.03058370255167`}], 
             PointBox[{93.1, 127.73551793229126`}], 
             PointBox[{93.2, 126.8915221636853}], 
             PointBox[{93.3, 125.40938963385997`}], 
             PointBox[{93.4, 125.60738920251606`}], 
             PointBox[{93.5, 128.8244405118603}], 
             PointBox[{93.6, 127.42255605396349`}], 
             PointBox[{93.7, 127.83183020328579`}], 
             PointBox[{93.8, 131.63827688718447`}], 
             PointBox[{93.9, 133.16848423275223`}], 
             PointBox[{94., 131.5804667493503}], 
             PointBox[{94.1, 134.1607397964981}], 
             PointBox[{94.2, 134.3193789452489}], 
             PointBox[{94.3, 132.76426681506564`}], 
             PointBox[{94.4, 131.85343888073112`}], 
             PointBox[{94.5, 134.46468617024948`}], 
             PointBox[{94.6, 134.32060654142697`}], 
             PointBox[{94.7, 133.60189787330455`}], 
             PointBox[{94.8, 136.616296939319}], 
             PointBox[{94.9, 138.84342206915608`}], 
             PointBox[{95., 137.6620251567365}], 
             PointBox[{95.1, 138.7381796000991}], 
             PointBox[{95.2, 140.07300327785197`}], 
             PointBox[{95.3, 138.3370883558091}], 
             PointBox[{95.4, 136.90152853824839`}], 
             PointBox[{95.5, 138.4103695675003}], 
             PointBox[{95.6, 139.37754267694254`}], 
             PointBox[{95.7, 137.98712628497742`}], 
             PointBox[{95.8, 140.14626085446798`}], 
             PointBox[{95.9, 142.57880055559508`}], 
             PointBox[{96., 142.0601293896325}], 
             PointBox[{96.1, 141.85330590813828`}], 
             PointBox[{96.2, 143.85791647140286`}], 
             PointBox[{96.3, 142.1550883736927}], 
             PointBox[{96.4, 140.55697059172962`}], 
             PointBox[{96.5, 140.98571232199902`}], 
             PointBox[{96.6, 142.57927251709043`}], 
             PointBox[{96.7, 140.92339748048107`}], 
             PointBox[{96.8, 142.2820471419691}], 
             PointBox[{96.9, 144.60081741883187`}], 
             PointBox[{97., 144.64556367511977`}], 
             PointBox[{97.1, 143.61717445455724`}], 
             PointBox[{97.2, 145.70852198947978`}], 
             PointBox[{97.3, 144.25191361589532`}], 
             PointBox[{97.4, 142.64983993234637`}], 
             PointBox[{97.5, 142.25495990646596`}], 
             PointBox[{97.6, 143.95752920601808`}], 
             PointBox[{97.7, 142.30938559579954`}], 
             PointBox[{97.8, 142.9793381713098}], 
             PointBox[{97.9, 145.0112559315894}], 
             PointBox[{98., 145.3774171107798}], 
             PointBox[{98.1, 143.93543816107558`}], 
             PointBox[{98.2, 145.73214241309324`}], 
             PointBox[{98.3, 144.58186963789922`}], 
             PointBox[{98.4, 143.03747523060883`}], 
             PointBox[{98.5, 142.0998646945518}], 
             PointBox[{98.6, 143.56142676276795`}], 
             PointBox[{98.7, 142.00700887906714`}], 
             PointBox[{98.8, 142.12609539326513`}], 
             PointBox[{98.9, 143.79131122044055`}], 
             PointBox[{99., 144.2251233577117}], 
             PointBox[{99.1, 142.59525502545875`}], 
             PointBox[{99.2, 143.95154923654627`}], 
             PointBox[{99.3, 143.0247320675844}], 
             PointBox[{99.4, 141.57346456166124`}], 
             PointBox[{99.5, 140.30675801847246`}], 
             PointBox[{99.6, 141.3783130574011}], 
             PointBox[{99.7, 139.8313579196256}], 
             PointBox[{99.8, 139.54611225993722`}], 
             PointBox[{99.9, 140.8120850916457}], 
             PointBox[{100., 141.09516458128928`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {-180, 180}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-328., 0}},
       PlotRangePadding->{6, 5}], {190, -528.}, ImageScaled[{0.5, 0.5}], {360, 312.},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
            {Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
            {RGBColor[0.368417, 0.506779, 0.709798], 
             PointBox[{0, 0.6367050000000001}], 
             PointBox[{0.1, 0.6350092605023289}], 
             PointBox[{0.2, 0.6353004364442035}], 
             PointBox[{0.3, 0.6377817112031924}], 
             PointBox[{0.4, 0.6395947951698812}], 
             PointBox[{0.5, 0.6400942952636646}], 
             PointBox[{0.6, 0.639901678974486}], 
             PointBox[{0.7, 0.6386740514285693}], 
             PointBox[{0.8, 0.6361235554255612}], 
             PointBox[{0.9, 0.6347721259106133}], 
             PointBox[{1., 0.6362134486072962}], 
             PointBox[{1.1, 0.635708824648922}], 
             PointBox[{1.2, 0.6348603734366041}], 
             PointBox[{1.3, 0.6367817422024687}], 
             PointBox[{1.4, 0.6391187089187318}], 
             PointBox[{1.5, 0.6400283073365283}], 
             PointBox[{1.6, 0.6400930158221213}], 
             PointBox[{1.7, 0.6393634968169988}], 
             PointBox[{1.8, 0.6371759867829101}], 
             PointBox[{1.9, 0.6350112845402167}], 
             PointBox[{2., 0.6354114173649766}], 
             PointBox[{2.1, 0.6365684728591865}], 
             PointBox[{2.2, 0.6348779364680401}], 
             PointBox[{2.3, 0.6358671847535954}], 
             PointBox[{2.4, 0.6384305752476532}], 
             PointBox[{2.5, 0.6398699005128076}], 
             PointBox[{2.6, 0.6402055616931487}], 
             PointBox[{2.7, 0.6398534052472269}], 
             PointBox[{2.8, 0.6382457022062125}], 
             PointBox[{2.9, 0.6356906584787828}], 
             PointBox[{3., 0.6349683404321692}], 
             PointBox[{3.1, 0.636703280084763}], 
             PointBox[{3.2, 0.6353828179605941}], 
             PointBox[{3.3, 0.635242049179769}], 
             PointBox[{3.4, 0.6375536274188583}], 
             PointBox[{3.5, 0.639568055547136}], 
             PointBox[{3.6, 0.640249128789902}], 
             PointBox[{3.7, 0.6401905912658623}], 
             PointBox[{3.8, 0.6391610793719337}], 
             PointBox[{3.9, 0.6367116343058997}], 
             PointBox[{4., 0.6350129308440805}], 
             PointBox[{4.1, 0.6360033414207804}], 
             PointBox[{4.2, 0.6362935804360188}], 
             PointBox[{4.3, 0.6350370636863896}], 
             PointBox[{4.4, 0.636624122703736}], 
             PointBox[{4.5, 0.6390628191653028}], 
             PointBox[{4.6, 0.6402056861770162}], 
             PointBox[{4.7, 0.6404185649848402}], 
             PointBox[{4.8, 0.6398584805871099}], 
             PointBox[{4.9, 0.6378853485702995}], 
             PointBox[{5., 0.6355307409709158}], 
             PointBox[{5.1, 0.6353869540462587}], 
             PointBox[{5.2, 0.6369900156519912}], 
             PointBox[{5.3, 0.6353162806107456}], 
             PointBox[{5.4, 0.635855145102574}], 
             PointBox[{5.5, 0.6383282603311301}], 
             PointBox[{5.6, 0.6400297801803619}], 
             PointBox[{5.7, 0.6405570662632886}], 
             PointBox[{5.8, 0.6403568374127758}], 
             PointBox[{5.9, 0.6389925343170602}], 
             PointBox[{6., 0.6364608227323832}], 
             PointBox[{6.1, 0.6352457523045916}], 
             PointBox[{6.2, 0.6366482598046072}], 
             PointBox[{6.3, 0.6360934733021741}], 
             PointBox[{6.4, 0.6354381886785722}], 
             PointBox[{6.5, 0.6374369825234081}], 
             PointBox[{6.6, 0.6396570649806084}], 
             PointBox[{6.7, 0.6405971188186597}], 
             PointBox[{6.8, 0.6407002102503668}], 
             PointBox[{6.9, 0.6398910419671865}], 
             PointBox[{7., 0.6376536758081902}], 
             PointBox[{7.1, 0.6356053332531285}], 
             PointBox[{7.2, 0.6359327711889031}], 
             PointBox[{7.3, 0.6370634675885509}], 
             PointBox[{7.4, 0.6354859820227413}], 
             PointBox[{7.5, 0.6365785180596097}], 
             PointBox[{7.6, 0.6390366708585392}], 
             PointBox[{7.7, 0.6405003097856902}], 
             PointBox[{7.8, 0.6409187249826703}], 
             PointBox[{7.9, 0.640550128220211}], 
             PointBox[{8., 0.6388804482579862}], 
             PointBox[{8.1, 0.6364198678878035}], 
             PointBox[{8.2, 0.6356149115677713}], 
             PointBox[{8.3, 0.6372041896137665}], 
             PointBox[{8.4, 0.636057841521243}], 
             PointBox[{8.5, 0.6359788330460152}], 
             PointBox[{8.6, 0.6381934337822145}], 
             PointBox[{8.7, 0.640203892624574}], 
             PointBox[{8.8, 0.6410133726956067}], 
             PointBox[{8.9, 0.6410010594492023}], 
             PointBox[{9., 0.639936046639441}], 
             PointBox[{9.1, 0.6375698402021175}], 
             PointBox[{9.2, 0.6358241030501801}], 
             PointBox[{9.3, 0.6365026453255405}], 
             PointBox[{9.4, 0.637047253500587}], 
             PointBox[{9.5, 0.6358056555421203}], 
             PointBox[{9.6, 0.637280078127473}], 
             PointBox[{9.7, 0.6396459136365823}], 
             PointBox[{9.8, 0.640953908364837}], 
             PointBox[{9.9, 0.6412808706294624}], 
             PointBox[{10., 0.6407285434137238}], 
             PointBox[{10.1, 0.6388366966135456}], 
             PointBox[{10.2, 0.6365180704728498}], 
             PointBox[{10.3, 0.6360209269907801}], 
             PointBox[{10.4, 0.6375914365919316}], 
             PointBox[{10.5, 0.6361543066945926}], 
             PointBox[{10.6, 0.6365331019525321}], 
             PointBox[{10.7, 0.6388240889626644}], 
             PointBox[{10.8, 0.6406821162231523}], 
             PointBox[{10.9, 0.6414018917571728}], 
             PointBox[{11., 0.6412634048308603}], 
             PointBox[{11.1, 0.6399791419984386}], 
             PointBox[{11.2, 0.6375898807749996}], 
             PointBox[{11.3, 0.6360816195286709}], 
             PointBox[{11.4, 0.6370080870759294}], 
             PointBox[{11.5, 0.6370239113910938}], 
             PointBox[{11.6, 0.6361605906112554}], 
             PointBox[{11.7, 0.6378609517365138}], 
             PointBox[{11.8, 0.6401340827239984}], 
             PointBox[{11.9, 0.641344172847682}], 
             PointBox[{12., 0.6415790523748394}], 
             PointBox[{12.1, 0.6408524756593059}], 
             PointBox[{12.2, 0.6388326859229929}], 
             PointBox[{12.3, 0.6366528566297726}], 
             PointBox[{12.4, 0.6363790771123831}], 
             PointBox[{12.5, 0.637800390668904}], 
             PointBox[{12.6, 0.6362942767899629}], 
             PointBox[{12.7, 0.6369904455689986}], 
             PointBox[{12.8, 0.6392949219851162}], 
             PointBox[{12.9, 0.6410577145995568}], 
             PointBox[{13., 0.6417000496875226}], 
             PointBox[{13.1, 0.6414321505312277}], 
             PointBox[{13.2, 0.6399911375618021}], 
             PointBox[{13.3, 0.6376269212950342}], 
             PointBox[{13.4, 0.6362867118059684}], 
             PointBox[{13.5, 0.6373936266275528}], 
             PointBox[{13.6, 0.636989176737318}], 
             PointBox[{13.7, 0.6364465172940522}], 
             PointBox[{13.8, 0.6382701586311316}], 
             PointBox[{13.9, 0.6404820806906473}], 
             PointBox[{14., 0.6416193115284599}], 
             PointBox[{14.1, 0.6417540427078021}], 
             PointBox[{14.2, 0.6408848105658553}], 
             PointBox[{14.3, 0.6388043359211769}], 
             PointBox[{14.4, 0.6367271117910237}], 
             PointBox[{14.5, 0.63663604988301}], 
             PointBox[{14.6, 0.6378476705068635}], 
             PointBox[{14.7, 0.6363865934245031}], 
             PointBox[{14.8, 0.6372882066765083}], 
             PointBox[{14.9, 0.6395980370420117}], 
             PointBox[{15., 0.6412977325004331}], 
             PointBox[{15.1, 0.6418537615726306}], 
             PointBox[{15.2, 0.6414656286898308}], 
             PointBox[{15.3, 0.639925633722048}], 
             PointBox[{15.4, 0.6375891449086477}], 
             PointBox[{15.5, 0.6363787910304218}], 
             PointBox[{15.6, 0.63763749060127}], 
             PointBox[{15.7, 0.6368961606298916}], 
             PointBox[{15.8, 0.636597696808407}], 
             PointBox[{15.9, 0.6385020479619195}], 
             PointBox[{16., 0.6406819500247813}], 
             PointBox[{16.1, 0.6417391681601999}], 
             PointBox[{16.2, 0.6417668771714828}], 
             PointBox[{16.3, 0.6407929902126949}], 
             PointBox[{16.4, 0.6386786516318753}], 
             PointBox[{16.5, 0.6366731955869149}], 
             PointBox[{16.6, 0.636777385408561}], 
             PointBox[{16.7, 0.6377417195810269}], 
             PointBox[{16.8, 0.6363699431166749}], 
             PointBox[{16.9, 0.6374177145787099}], 
             PointBox[{17., 0.6397514845298546}], 
             PointBox[{17.1, 0.6413848185375763}], 
             PointBox[{17.2, 0.6418342838453002}], 
             PointBox[{17.3, 0.6413435920135595}], 
             PointBox[{17.4, 0.6397367650591473}], 
             PointBox[{17.5, 0.637408757383328}], 
             PointBox[{17.6, 0.6363394378619194}], 
             PointBox[{17.7, 0.6377423220729849}], 
             PointBox[{17.8, 0.6367028139225271}], 
             PointBox[{17.9, 0.6365996109702504}], 
             PointBox[{18., 0.6385910719946903}], 
             PointBox[{18.1, 0.6407447297992046}], 
             PointBox[{18.2, 0.6416901624826896}], 
             PointBox[{18.3, 0.64160953640234}], 
             PointBox[{18.4, 0.6405575115045437}], 
             PointBox[{18.5, 0.6383994689184908}], 
             PointBox[{18.6, 0.6364643680486103}], 
             PointBox[{18.7, 0.636826559544134}], 
             PointBox[{18.8, 0.6374806450363293}], 
             PointBox[{18.9, 0.636225297357509}], 
             PointBox[{19., 0.6374168175110473}], 
             PointBox[{19.1, 0.6397943137012596}], 
             PointBox[{19.2, 0.6413234176544937}], 
             PointBox[{19.3, 0.6416455859845042}], 
             PointBox[{19.4, 0.6410693155324935}], 
             PointBox[{19.5, 0.639392958262966}], 
             PointBox[{19.6, 0.6370541773628496}], 
             PointBox[{19.7, 0.6361945680897493}], 
             PointBox[{19.8, 0.6377130919332121}], 
             PointBox[{19.9, 0.6363932244259443}], 
             PointBox[{20., 0.6364852784406002}], 
             PointBox[{20.1, 0.6386006516492823}], 
             PointBox[{20.2, 0.6406973327243352}], 
             PointBox[{20.3, 0.6414881954981432}], 
             PointBox[{20.4, 0.6413044349116402}], 
             PointBox[{20.5, 0.6401770500363503}], 
             PointBox[{20.6, 0.6379414857343384}], 
             PointBox[{20.7, 0.6361242398183548}], 
             PointBox[{20.8, 0.6368364347813277}], 
             PointBox[{20.9, 0.6370682138437216}], 
             PointBox[{21., 0.6359785809632891}], 
             PointBox[{21.1, 0.6373604225436245}], 
             PointBox[{21.2, 0.6397801225610594}], 
             PointBox[{21.3, 0.6411403092850695}], 
             PointBox[{21.4, 0.6413246879338061}], 
             PointBox[{21.5, 0.6406692162420208}], 
             PointBox[{21.6, 0.6388860103594994}], 
             PointBox[{21.7, 0.6365443652322017}], 
             PointBox[{21.8, 0.6360152884673713}], 
             PointBox[{21.9, 0.6375405149640928}], 
             PointBox[{22., 0.6359903055892715}], 
             PointBox[{22.1, 0.6363285173234176}], 
             PointBox[{22.2, 0.6386091160782652}], 
             PointBox[{22.3, 0.6405747792708456}], 
             PointBox[{22.4, 0.6411774002050589}], 
             PointBox[{22.5, 0.6408979261154386}], 
             PointBox[{22.6, 0.6396663627232668}], 
             PointBox[{22.7, 0.6373172098784416}], 
             PointBox[{22.8, 0.6357268140595878}], 
             PointBox[{22.9, 0.6368635478204917}], 
             PointBox[{23., 0.6365311280435977}], 
             PointBox[{23.1, 0.6356947398698172}], 
             PointBox[{23.2, 0.6373442168496906}], 
             PointBox[{23.3, 0.6397537752056572}], 
             PointBox[{23.4, 0.6408784030290133}], 
             PointBox[{23.5, 0.6409292602352513}], 
             PointBox[{23.6, 0.6401802312611283}], 
             PointBox[{23.7, 0.6382274345621585}], 
             PointBox[{23.8, 0.6359488541041303}], 
             PointBox[{23.9, 0.6358980934361919}], 
             PointBox[{24., 0.6371926605135205}], 
             PointBox[{24.1, 0.6355520979900825}], 
             PointBox[{24.2, 0.6362280713967632}], 
             PointBox[{24.3, 0.6386787933239064}], 
             PointBox[{24.4, 0.6404118678799143}], 
             PointBox[{24.5, 0.6408184177829371}], 
             PointBox[{24.6, 0.6404438859889862}], 
             PointBox[{24.7, 0.6390464337272983}], 
             PointBox[{24.8, 0.6365818424036509}], 
             PointBox[{24.9, 0.6353826290875549}], 
             PointBox[{25., 0.636918558806029}], 
             PointBox[{25.1, 0.6359316996879592}], 
             PointBox[{25.2, 0.6354673498055006}], 
             PointBox[{25.3, 0.6374526032461525}], 
             PointBox[{25.4, 0.6397393635459806}], 
             PointBox[{25.5, 0.6405917993066261}], 
             PointBox[{25.6, 0.6405218315679854}], 
             PointBox[{25.7, 0.6396371898918447}], 
             PointBox[{25.8, 0.6374540415062412}], 
             PointBox[{25.9, 0.635383494290101}], 
             PointBox[{26., 0.6359355731847061}], 
             PointBox[{26.1, 0.636661343961369}], 
             PointBox[{26.2, 0.6351673851996693}], 
             PointBox[{26.3, 0.6362865907175687}], 
             PointBox[{26.4, 0.6388316496804356}], 
             PointBox[{26.5, 0.6402448610615287}], 
             PointBox[{26.6, 0.6404745375155194}], 
             PointBox[{26.7, 0.6399877247223378}], 
             PointBox[{26.8, 0.6383386861136092}], 
             PointBox[{26.9, 0.6358391099113984}], 
             PointBox[{27., 0.635207368626817}], 
             PointBox[{27.1, 0.6369129246077548}], 
             PointBox[{27.2, 0.6353665774961671}], 
             PointBox[{27.3, 0.6354016321191108}], 
             PointBox[{27.4, 0.6377260844526453}], 
             PointBox[{27.5, 0.6397444642175364}], 
             PointBox[{27.6, 0.6403359797563765}], 
             PointBox[{27.7, 0.6401529500195735}], 
             PointBox[{27.8, 0.6390583867154296}], 
             PointBox[{27.9, 0.6366336860491963}], 
             PointBox[{28., 0.6349761541292676}], 
             PointBox[{28.1, 0.6361615275321291}], 
             PointBox[{28.2, 0.6360236385517908}], 
             PointBox[{28.3, 0.6349360254746503}], 
             PointBox[{28.4, 0.6365711638510948}], 
             PointBox[{28.5, 0.6390464406969133}], 
             PointBox[{28.6, 0.6401121802678879}], 
             PointBox[{28.7, 0.6401954117178662}], 
             PointBox[{28.8, 0.6395516539760712}], 
             PointBox[{28.9, 0.6375742576490738}], 
             PointBox[{29., 0.6352229300703371}], 
             PointBox[{29.1, 0.6352828136357646}], 
             PointBox[{29.2, 0.6366965585549976}], 
             PointBox[{29.3, 0.6349432176716653}], 
             PointBox[{29.4, 0.6355847687624336}], 
             PointBox[{29.5, 0.6381335637843772}], 
             PointBox[{29.6, 0.6397795178436009}], 
             PointBox[{29.7, 0.6401567382761836}], 
             PointBox[{29.8, 0.6398488934674513}], 
             PointBox[{29.9, 0.6384500839597763}], 
             PointBox[{30., 0.6358821562997892}], 
             PointBox[{30.1, 0.6348248857490734}], 
             PointBox[{30.2, 0.6364876210416204}], 
             PointBox[{30.3, 0.6354331562405795}], 
             PointBox[{30.4, 0.6349486027163366}], 
             PointBox[{30.5, 0.6370753277741151}], 
             PointBox[{30.6, 0.6392927842223008}], 
             PointBox[{30.7, 0.6400512603914633}], 
             PointBox[{30.8, 0.6400092716394385}], 
             PointBox[{30.9, 0.6391340186508802}], 
             PointBox[{31., 0.6368191961926238}], 
             PointBox[{31.1, 0.634850241951286}], 
             PointBox[{31.2, 0.6356263763300627}], 
             PointBox[{31.3, 0.6362536601770273}], 
             PointBox[{31.4, 0.6347545503939223}], 
             PointBox[{31.5, 0.6360463224231505}], 
             PointBox[{31.6, 0.6386056199261891}], 
             PointBox[{31.7, 0.6398667362749979}], 
             PointBox[{31.8, 0.6400818401701274}], 
             PointBox[{31.9, 0.639609072231279}], 
             PointBox[{32., 0.6378297455765984}], 
             PointBox[{32.1, 0.6353285600258467}], 
             PointBox[{32.2, 0.6349677567159291}], 
             PointBox[{32.3, 0.6366936734780985}], 
             PointBox[{32.4, 0.6350366053127202}], 
             PointBox[{32.5, 0.6352567361262424}], 
             PointBox[{32.6, 0.6377180366759992}], 
             PointBox[{32.7, 0.6395641587540781}], 
             PointBox[{32.8, 0.6400900334056119}], 
             PointBox[{32.9, 0.6399193700503097}], 
             PointBox[{33., 0.638725083792805}], 
             PointBox[{33.1, 0.6361842276801624}], 
             PointBox[{33.2, 0.6347760680107135}], 
             PointBox[{33.3, 0.6361580458923712}], 
             PointBox[{33.4, 0.6357747970627483}], 
             PointBox[{33.5, 0.6348568984710393}], 
             PointBox[{33.6, 0.6367317009876551}], 
             PointBox[{33.7, 0.6390890209618855}], 
             PointBox[{33.8, 0.6400314187425763}], 
             PointBox[{33.9, 0.6401180504196481}], 
             PointBox[{34., 0.6394162266843475}], 
             PointBox[{34.1, 0.6372581822501161}], 
             PointBox[{34.2, 0.6350589148897162}], 
             PointBox[{34.3, 0.6353798232904886}], 
             PointBox[{34.4, 0.636627231258674}], 
             PointBox[{34.5, 0.6349167692529448}], 
             PointBox[{34.6, 0.6358417003072969}], 
             PointBox[{34.7, 0.638399203791385}], 
             PointBox[{34.8, 0.639876124229211}], 
             PointBox[{34.9, 0.6402379696157785}], 
             PointBox[{35., 0.6399091357165873}], 
             PointBox[{35.1, 0.63833680465594}], 
             PointBox[{35.2, 0.6357777778430236}], 
             PointBox[{35.3, 0.6349824887727554}], 
             PointBox[{35.4, 0.6366917799350178}], 
             PointBox[{35.5, 0.6354648929544162}], 
             PointBox[{35.6, 0.6352496945470918}], 
             PointBox[{35.7, 0.6375235524653693}], 
             PointBox[{35.8, 0.6395705578492055}], 
             PointBox[{35.9, 0.6402859432258431}], 
             PointBox[{36., 0.6402502497350613}], 
             PointBox[{36.1, 0.6392533329307317}], 
             PointBox[{36.2, 0.6368285671637827}], 
             PointBox[{36.3, 0.6350743073657228}], 
             PointBox[{36.4, 0.6359751314322093}], 
             PointBox[{36.5, 0.6363998495377732}], 
             PointBox[{36.6, 0.6350826854930791}], 
             PointBox[{36.7, 0.6366051464187324}], 
             PointBox[{36.8, 0.6390543708077516}], 
             PointBox[{36.9, 0.6402408195177507}], 
             PointBox[{37., 0.6404807709814399}], 
             PointBox[{37.1, 0.6399485279128316}], 
             PointBox[{37.2, 0.6380161432876599}], 
             PointBox[{37.3, 0.6356375147555832}], 
             PointBox[{37.4, 0.6353989290335283}], 
             PointBox[{37.5, 0.6370383279522656}], 
             PointBox[{37.6, 0.6354050491199865}], 
             PointBox[{37.7, 0.635861233734417}], 
             PointBox[{37.8, 0.6383080509052114}], 
             PointBox[{37.9, 0.6400548732803473}], 
             PointBox[{38., 0.6406186163045094}], 
             PointBox[{38.1, 0.6404443743086128}], 
             PointBox[{38.2, 0.6391224606242146}], 
             PointBox[{38.3, 0.636605123653648}], 
             PointBox[{38.4, 0.6353094348709232}], 
             PointBox[{38.5, 0.6366245057279248}], 
             PointBox[{38.6, 0.6362226993167401}], 
             PointBox[{38.7, 0.6354795334193517}], 
             PointBox[{38.8, 0.6374135730163231}], 
             PointBox[{38.9, 0.6396625398206809}], 
             PointBox[{39., 0.6406512937312443}], 
             PointBox[{39.1, 0.6407836371858722}], 
             PointBox[{39.2, 0.6400112567499052}], 
             PointBox[{39.3, 0.6378177208724288}], 
             PointBox[{39.4, 0.6357200937570124}], 
             PointBox[{39.5, 0.6359297977363003}], 
             PointBox[{39.6, 0.6371696216285418}], 
             PointBox[{39.7, 0.6355694443866188}], 
             PointBox[{39.8, 0.6365685399511702}], 
             PointBox[{39.9, 0.6390168847695505}], 
             PointBox[{40., 0.6405371263390035}], 
             PointBox[{40.1, 0.6409941281338807}], 
             PointBox[{40.2, 0.6406576582744493}], 
             PointBox[{40.3, 0.639041850135465}], 
             PointBox[{40.4, 0.6365783355664287}], 
             PointBox[{40.5, 0.63566632113758}], 
             PointBox[{40.6, 0.6371951188912691}], 
             PointBox[{40.7, 0.6361881884351519}], 
             PointBox[{40.8, 0.6359994061986042}], 
             PointBox[{40.9, 0.6381544808430348}], 
             PointBox[{41., 0.6402113488221279}], 
             PointBox[{41.1, 0.6410735148924739}], 
             PointBox[{41.2, 0.641094059003449}], 
             PointBox[{41.3, 0.640078209088567}], 
             PointBox[{41.4, 0.6377527161367473}], 
             PointBox[{41.5, 0.6359307869658644}], 
             PointBox[{41.6, 0.6364742478654363}], 
             PointBox[{41.7, 0.6371868220434274}], 
             PointBox[{41.8, 0.6358674738430391}], 
             PointBox[{41.9, 0.6372416075259096}], 
             PointBox[{42., 0.6396155724013108}], 
             PointBox[{42.1, 0.6409879324061861}], 
             PointBox[{42.2, 0.6413557578042529}], 
             PointBox[{42.3, 0.6408443972223494}], 
             PointBox[{42.4, 0.6390146270214452}], 
             PointBox[{42.5, 0.636672021729086}], 
             PointBox[{42.6, 0.6360450598773788}], 
             PointBox[{42.7, 0.6376060543700832}], 
             PointBox[{42.8, 0.6362655093215829}], 
             PointBox[{42.9, 0.6365180107092255}], 
             PointBox[{43., 0.6387598269417596}], 
             PointBox[{43.1, 0.6406775031455071}], 
             PointBox[{43.2, 0.6414524196486424}], 
             PointBox[{43.3, 0.6413515871628931}], 
             PointBox[{43.4, 0.6401289201484228}], 
             PointBox[{43.5, 0.6377709416823851}], 
             PointBox[{43.6, 0.6361639217320338}], 
             PointBox[{43.7, 0.6369495087367563}], 
             PointBox[{43.8, 0.6371663501226076}], 
             PointBox[{43.9, 0.6361855129202785}], 
             PointBox[{44., 0.6377841990859755}], 
             PointBox[{44.1, 0.6400816008571985}], 
             PointBox[{44.2, 0.6413609110784946}], 
             PointBox[{44.3, 0.6416384756162338}], 
             PointBox[{44.4, 0.640962594541782}], 
             PointBox[{44.5, 0.6390084339581268}], 
             PointBox[{44.6, 0.6367841449792944}], 
             PointBox[{44.7, 0.636364860693693}], 
             PointBox[{44.8, 0.6378375656354699}], 
             PointBox[{44.9, 0.6363701188334699}], 
             PointBox[{45., 0.636930318753104}], 
             PointBox[{45.1, 0.6391982573662113}], 
             PointBox[{45.2, 0.6410297041163046}], 
             PointBox[{45.3, 0.641727250135273}], 
             PointBox[{45.4, 0.6415022067564528}], 
             PointBox[{45.5, 0.6401314870374157}], 
             PointBox[{45.6, 0.637786553076461}], 
             PointBox[{45.7, 0.6363319845144166}], 
             PointBox[{45.8, 0.6373072763678364}], 
             PointBox[{45.9, 0.6371102781088253}], 
             PointBox[{46., 0.6364256346715699}], 
             PointBox[{46.1, 0.6381521065130342}], 
             PointBox[{46.2, 0.640401380460854}], 
             PointBox[{46.3, 0.6416086291778162}], 
             PointBox[{46.4, 0.6417865795147717}], 
             PointBox[{46.5, 0.640976274703426}], 
             PointBox[{46.6, 0.6389590713023916}], 
             PointBox[{46.7, 0.6368217381396388}], 
             PointBox[{46.8, 0.6365786812724056}], 
             PointBox[{46.9, 0.6378982940774148}], 
             PointBox[{47., 0.636418422049522}], 
             PointBox[{47.1, 0.6371824208402922}], 
             PointBox[{47.2, 0.6394689402288748}], 
             PointBox[{47.3, 0.6412414562391427}], 
             PointBox[{47.4, 0.6418500205646169}], 
             PointBox[{47.5, 0.6415087257201761}], 
             PointBox[{47.6, 0.6400428251487078}], 
             PointBox[{47.7, 0.6377130302808355}], 
             PointBox[{47.8, 0.6363798111940723}], 
             PointBox[{47.9, 0.6375322026718266}], 
             PointBox[{48., 0.6369814285896963}], 
             PointBox[{48.1, 0.6365301543958369}], 
             PointBox[{48.2, 0.6383470029284541}], 
             PointBox[{48.3, 0.6405735959773917}], 
             PointBox[{48.4, 0.6416971168386623}], 
             PointBox[{48.5, 0.6417668970366313}], 
             PointBox[{48.6, 0.6408565099849469}], 
             PointBox[{48.7, 0.6387986431175696}], 
             PointBox[{48.8, 0.6367218195249089}], 
             PointBox[{48.9, 0.6366774300732411}], 
             PointBox[{49., 0.6377931416610727}], 
             PointBox[{49.1, 0.6363550929524112}], 
             PointBox[{49.2, 0.6372716137677144}], 
             PointBox[{49.3, 0.6395957272044024}], 
             PointBox[{49.4, 0.6413010601834572}], 
             PointBox[{49.5, 0.6417973928910882}], 
             PointBox[{49.6, 0.6413553646063719}], 
             PointBox[{49.7, 0.6398213465171793}], 
             PointBox[{49.8, 0.6374868244806915}], 
             PointBox[{49.9, 0.6362938827036084}], 
             PointBox[{50., 0.637631253616218}], 
             PointBox[{50.1, 0.6367447150572442}], 
             PointBox[{50.2, 0.6364909761118844}], 
             PointBox[{50.3, 0.6384097048928634}], 
             PointBox[{50.4, 0.6406164444265667}], 
             PointBox[{50.5, 0.641619604454342}], 
             PointBox[{50.6, 0.6415784949042}], 
             PointBox[{50.7, 0.6405906248910054}], 
             PointBox[{50.8, 0.6384781619205222}], 
             PointBox[{50.9, 0.6364645700758764}], 
             PointBox[{51., 0.6366927446973512}], 
             PointBox[{51.1, 0.6375226162140757}], 
             PointBox[{51.2, 0.6361685990085819}], 
             PointBox[{51.3, 0.6372430582239378}], 
             PointBox[{51.4, 0.6396254806384178}], 
             PointBox[{51.5, 0.6412198812357653}], 
             PointBox[{51.6, 0.641581378828122}], 
             PointBox[{51.7, 0.6410533129770647}], 
             PointBox[{51.8, 0.6394432844937001}], 
             PointBox[{51.9, 0.6370845104502295}], 
             PointBox[{52., 0.6361084662368236}], 
             PointBox[{52.1, 0.6376150007051292}], 
             PointBox[{52.2, 0.636392880360084}], 
             PointBox[{52.3, 0.636347454723779}], 
             PointBox[{52.4, 0.6384101059126607}], 
             PointBox[{52.5, 0.640561180274171}], 
             PointBox[{52.6, 0.641397983082743}], 
             PointBox[{52.7, 0.6412503860430747}], 
             PointBox[{52.8, 0.6401836228336084}], 
             PointBox[{52.9, 0.6379792485811799}], 
             PointBox[{53., 0.636081184727281}], 
             PointBox[{53.1, 0.6366845060640866}], 
             PointBox[{53.2, 0.6370926814475091}], 
             PointBox[{53.3, 0.6358899877266974}], 
             PointBox[{53.4, 0.6371764301530675}], 
             PointBox[{53.5, 0.6396152751319838}], 
             PointBox[{53.6, 0.6410285839319281}], 
             PointBox[{53.7, 0.6412446427740777}], 
             PointBox[{53.8, 0.6406346927336524}], 
             PointBox[{53.9, 0.6389067082400918}], 
             PointBox[{54., 0.6365324794470298}], 
             PointBox[{54.1, 0.6359013191378746}], 
             PointBox[{54.2, 0.6374719701063903}], 
             PointBox[{54.3, 0.6359545619036326}], 
             PointBox[{54.4, 0.6361770951858504}], 
             PointBox[{54.5, 0.6384283471081087}], 
             PointBox[{54.6, 0.6404442085894293}], 
             PointBox[{54.7, 0.6410802972173335}], 
             PointBox[{54.8, 0.6408335351198402}], 
             PointBox[{54.9, 0.6396554784857849}], 
             PointBox[{55., 0.6373200418309274}], 
             PointBox[{55.1, 0.6356529747186366}], 
             PointBox[{55.2, 0.6367163544116744}], 
             PointBox[{55.3, 0.6365333362714095}], 
             PointBox[{55.4, 0.6355883881641571}], 
             PointBox[{55.5, 0.6371695210776617}], 
             PointBox[{55.6, 0.6396078659939144}], 
             PointBox[{55.7, 0.6407707313592239}], 
             PointBox[{55.8, 0.6408469046742893}], 
             PointBox[{55.9, 0.6401394926417208}], 
             PointBox[{56., 0.6382268852635802}], 
             PointBox[{56.1, 0.6359061460845734}], 
             PointBox[{56.2, 0.635774094126588}], 
             PointBox[{56.3, 0.6371579528169155}], 
             PointBox[{56.4, 0.6354932675932372}], 
             PointBox[{56.5, 0.6360812999714257}], 
             PointBox[{56.6, 0.6385254526429645}], 
             PointBox[{56.7, 0.6402978616382318}], 
             PointBox[{56.8, 0.6407278190832718}], 
             PointBox[{56.9, 0.6403825367403909}], 
             PointBox[{57., 0.6390287892890693}], 
             PointBox[{57.1, 0.6365600266394608}], 
             PointBox[{57.2, 0.6352960730082796}], 
             PointBox[{57.3, 0.6368018675436528}], 
             PointBox[{57.4, 0.635913976802434}], 
             PointBox[{57.5, 0.6353599366874663}], 
             PointBox[{57.6, 0.6373060344833994}], 
             PointBox[{57.7, 0.639622054300243}], 
             PointBox[{57.8, 0.6404996223369652}], 
             PointBox[{57.9, 0.6404507449609219}], 
             PointBox[{58., 0.6396015660737386}], 
             PointBox[{58.1, 0.6374402998482058}], 
             PointBox[{58.2, 0.6353273812138347}], 
             PointBox[{58.3, 0.6358203362697585}], 
             PointBox[{58.4, 0.6366492112083654}], 
             PointBox[{58.5, 0.6351011677106907}], 
             PointBox[{58.6, 0.6361617822487838}], 
             PointBox[{58.7, 0.6387152610587911}], 
             PointBox[{58.8, 0.6401550438998234}], 
             PointBox[{58.9, 0.6404021086992292}], 
             PointBox[{59., 0.6399408785310013}], 
             PointBox[{59.1, 0.638323010278377}], 
             PointBox[{59.2, 0.6358069420826432}], 
             PointBox[{59.3, 0.6351250851259603}], 
             PointBox[{59.4, 0.6368454593161519}], 
             PointBox[{59.5, 0.6353383765246213}], 
             PointBox[{59.6, 0.6353087836538583}], 
             PointBox[{59.7, 0.6376174815089458}], 
             PointBox[{59.8, 0.6396596323178144}], 
             PointBox[{59.9, 0.6402679818617192}], 
             PointBox[{60., 0.6401032193752609}], 
             PointBox[{60.1, 0.6390367028584959}], 
             PointBox[{60.2, 0.6366179923917061}], 
             PointBox[{60.3, 0.6349237040619512}], 
             PointBox[{60.4, 0.6360710846216358}], 
             PointBox[{60.5, 0.6360201607494533}], 
             PointBox[{60.6, 0.6348775019655172}], 
             PointBox[{60.7, 0.6364792075207926}], 
             PointBox[{60.8, 0.6389677220222264}], 
             PointBox[{60.9, 0.6400510273682674}], 
             PointBox[{61., 0.640148813323998}], 
             PointBox[{61.1, 0.6395264559969634}], 
             PointBox[{61.2, 0.6375672313215509}], 
             PointBox[{61.3, 0.6351953716871822}], 
             PointBox[{61.4, 0.6352162843551011}], 
             PointBox[{61.5, 0.6366779408017432}], 
             PointBox[{61.6, 0.6349177017145791}], 
             PointBox[{61.7, 0.6355175444354282}], 
             PointBox[{61.8, 0.6380639386061425}], 
             PointBox[{61.9, 0.6397269858666778}], 
             PointBox[{62., 0.6401175513535082}], 
             PointBox[{62.1, 0.6398256111140874}], 
             PointBox[{62.2, 0.6384470454272324}], 
             PointBox[{62.3, 0.635875464613787}], 
             PointBox[{62.4, 0.6347876761009636}], 
             PointBox[{62.5, 0.63643469338087}], 
             PointBox[{62.6, 0.6354366295734314}], 
             PointBox[{62.7, 0.6349094133316429}], 
             PointBox[{62.8, 0.6370192005570048}], 
             PointBox[{62.9, 0.6392490337801371}], 
             PointBox[{63., 0.6400215561787652}], 
             PointBox[{63.1, 0.6399925238583939}], 
             PointBox[{63.2, 0.6391345326779562}], 
             PointBox[{63.3, 0.6368284727841903}], 
             PointBox[{63.4, 0.6348394660978394}], 
             PointBox[{63.5, 0.6355806326689395}], 
             PointBox[{63.6, 0.6362695289612447}], 
             PointBox[{63.7, 0.6347434605873679}], 
             PointBox[{63.8, 0.6360088184495314}], 
             PointBox[{63.9, 0.6385705561246703}], 
             PointBox[{64., 0.6398465660345692}], 
             PointBox[{64.1, 0.6400742762674569}], 
             PointBox[{64.2, 0.639615534225953}], 
             PointBox[{64.3, 0.6378504189949179}], 
             PointBox[{64.4, 0.6353417123726885}], 
             PointBox[{64.5, 0.6349489110939515}], 
             PointBox[{64.6, 0.6366865768162895}], 
             PointBox[{64.7, 0.6350530701305931}], 
             PointBox[{64.8, 0.6352412933504026}], 
             PointBox[{64.9, 0.637692555776697}], 
             PointBox[{65., 0.6395521161045038}], 
             PointBox[{65.1, 0.6400922790429591}], 
             PointBox[{65.2, 0.6399340610561418}], 
             PointBox[{65.3, 0.6387542703417642}], 
             PointBox[{65.4, 0.6362178984719876}], 
             PointBox[{65.5, 0.6347847797887229}], 
             PointBox[{65.6, 0.6361341590273862}], 
             PointBox[{65.7, 0.635814400659123}], 
             PointBox[{65.8, 0.634864645302679}], 
             PointBox[{65.9, 0.6367182136185133}], 
             PointBox[{66., 0.6390821094776948}], 
             PointBox[{66.1, 0.640041621703418}], 
             PointBox[{66.2, 0.6401412651691556}], 
             PointBox[{66.3, 0.6394524986346942}], 
             PointBox[{66.4, 0.6373075226826282}], 
             PointBox[{66.5, 0.6350941423712614}], 
             PointBox[{66.6, 0.6353734534125345}], 
             PointBox[{66.7, 0.6366642979752734}], 
             PointBox[{66.8, 0.6349488456051556}], 
             PointBox[{66.9, 0.6358442628468376}], 
             PointBox[{67., 0.6383953532313612}], 
             PointBox[{67.1, 0.6398909659198807}], 
             PointBox[{67.2, 0.6402688552038815}], 
             PointBox[{67.3, 0.6399522024602212}], 
             PointBox[{67.4, 0.6383954999082544}], 
             PointBox[{67.5, 0.6358373915842433}], 
             PointBox[{67.6, 0.635004454943218}], 
             PointBox[{67.7, 0.6366936841518004}], 
             PointBox[{67.8, 0.635522076619824}], 
             PointBox[{67.9, 0.6352711565534643}], 
             PointBox[{68., 0.6375237727244666}], 
             PointBox[{68.1, 0.6395853460050744}], 
             PointBox[{68.2, 0.640321771135051}], 
             PointBox[{68.3, 0.6402996911949524}], 
             PointBox[{68.4, 0.639317827226058}], 
             PointBox[{68.5, 0.6369075333504753}], 
             PointBox[{68.6, 0.6351263609689963}], 
             PointBox[{68.7, 0.6359733090230526}], 
             PointBox[{68.8, 0.6364716959405454}], 
             PointBox[{68.9, 0.6351262940893929}], 
             PointBox[{69., 0.6366142730023892}], 
             PointBox[{69.1, 0.6390647795589294}], 
             PointBox[{69.2, 0.6402772662226395}], 
             PointBox[{69.3, 0.6405348815180645}], 
             PointBox[{69.4, 0.6400166551734642}], 
             PointBox[{69.5, 0.6381058106238173}], 
             PointBox[{69.6, 0.6357181615639829}], 
             PointBox[{69.7, 0.6354232401061635}], 
             PointBox[{69.8, 0.6370750915324078}], 
             PointBox[{69.9, 0.6354735052688013}], 
             PointBox[{70., 0.6358852085510441}], 
             PointBox[{70.1, 0.6383118738204664}], 
             PointBox[{70.2, 0.640084873956061}], 
             PointBox[{70.3, 0.6406729377434851}], 
             PointBox[{70.4, 0.6405137571493419}], 
             PointBox[{70.5, 0.6392137198263504}], 
             PointBox[{70.6, 0.6367089525365246}], 
             PointBox[{70.7, 0.6353663002923773}], 
             PointBox[{70.8, 0.6366217711685513}], 
             PointBox[{70.9, 0.6363140808867581}], 
             PointBox[{71., 0.6355228218282393}], 
             PointBox[{71.1, 0.6374160663673443}], 
             PointBox[{71.2, 0.639679179177063}], 
             PointBox[{71.3, 0.6407002588937248}], 
             PointBox[{71.4, 0.6408517847112029}], 
             PointBox[{71.5, 0.6400991366430494}], 
             PointBox[{71.6, 0.6379333517079269}], 
             PointBox[{71.7, 0.6358095412660746}], 
             PointBox[{71.8, 0.6359433218388337}], 
             PointBox[{71.9, 0.6372415786040281}], 
             PointBox[{72., 0.635636935261008}], 
             PointBox[{72.1, 0.6365794842546201}], 
             PointBox[{72.2, 0.6390158446303656}], 
             PointBox[{72.3, 0.6405727805202707}], 
             PointBox[{72.4, 0.6410562680635595}], 
             PointBox[{72.5, 0.6407384260025811}], 
             PointBox[{72.6, 0.6391546344467259}], 
             PointBox[{72.7, 0.6366948104801989}], 
             PointBox[{72.8, 0.6357147247602536}], 
             PointBox[{72.9, 0.6371944920144113}], 
             PointBox[{73., 0.6362828135763298}], 
             PointBox[{73.1, 0.6360278374284487}], 
             PointBox[{73.2, 0.6381401962191673}], 
             PointBox[{73.3, 0.6402248688923492}], 
             PointBox[{73.4, 0.6411236604061176}], 
             PointBox[{73.5, 0.641165126728294}], 
             PointBox[{73.6, 0.6401781894819503}], 
             PointBox[{73.7, 0.6378822054201302}], 
             PointBox[{73.8, 0.6360141648468144}], 
             PointBox[{73.9, 0.6364665795007828}], 
             PointBox[{74., 0.6372801655911807}], 
             PointBox[{74.1, 0.6359191369485704}], 
             PointBox[{74.2, 0.6372265152175937}], 
             PointBox[{74.3, 0.6396007675904709}], 
             PointBox[{74.4, 0.6410175142760852}], 
             PointBox[{74.5, 0.6414130901133122}], 
             PointBox[{74.6, 0.6409263241265968}], 
             PointBox[{74.7, 0.639138289214804}], 
             PointBox[{74.8, 0.6367846621492723}], 
             PointBox[{74.9, 0.6360718509910332}], 
             PointBox[{75., 0.6376120685252942}], 
             PointBox[{75.1, 0.6363464727595511}], 
             PointBox[{75.2, 0.636516710237581}], 
             PointBox[{75.3, 0.6387209022350685}], 
             PointBox[{75.4, 0.6406778008004065}], 
             PointBox[{75.5, 0.6414909278223826}], 
             PointBox[{75.6, 0.641413896148968}], 
             PointBox[{75.7, 0.640230426126083}], 
             PointBox[{75.8, 0.6378978409669157}], 
             PointBox[{75.9, 0.6362278286537596}], 
             PointBox[{76., 0.6369159865474467}], 
             PointBox[{76.1, 0.6372613564447069}], 
             PointBox[{76.2, 0.6362088793441875}], 
             PointBox[{76.3, 0.6377364642134532}], 
             PointBox[{76.4, 0.640046643389524}], 
             PointBox[{76.5, 0.6413739508764041}], 
             PointBox[{76.6, 0.6416796753056444}], 
             PointBox[{76.7, 0.6410356800806606}], 
             PointBox[{76.8, 0.6391273678553475}], 
             PointBox[{76.9, 0.6368780231164396}], 
             PointBox[{77., 0.6363616954376935}], 
             PointBox[{77.1, 0.6378520593306091}], 
             PointBox[{77.2, 0.636425034933591}], 
             PointBox[{77.3, 0.6368931438192076}], 
             PointBox[{77.4, 0.6391313929034868}], 
             PointBox[{77.5, 0.6410090378323337}], 
             PointBox[{77.6, 0.6417442123495507}], 
             PointBox[{77.7, 0.6415459010099205}], 
             PointBox[{77.8, 0.6402216112975764}], 
             PointBox[{77.9, 0.6378946212660108}], 
             PointBox[{78., 0.6363654160581862}], 
             PointBox[{78.1, 0.6372479972561859}], 
             PointBox[{78.2, 0.6371891456478397}], 
             PointBox[{78.3, 0.6364124939634409}], 
             PointBox[{78.4, 0.6380696990441578}], 
             PointBox[{78.5, 0.6403415982697238}], 
             PointBox[{78.6, 0.6415966666873615}], 
             PointBox[{78.7, 0.6418022050135386}], 
             PointBox[{78.8, 0.6410297495208124}], 
             PointBox[{78.9, 0.639057720351051}], 
             PointBox[{79., 0.6368842383186799}], 
             PointBox[{79.1, 0.63654042293963}], 
             PointBox[{79.2, 0.6379163457679462}], 
             PointBox[{79.3, 0.6364382683126295}], 
             PointBox[{79.4, 0.637107771498277}], 
             PointBox[{79.5, 0.6393743942144454}], 
             PointBox[{79.6, 0.64119567681994}], 
             PointBox[{79.7, 0.6418386650166751}], 
             PointBox[{79.8, 0.6415265116079942}], 
             PointBox[{79.9, 0.6401105905188252}], 
             PointBox[{80., 0.6377895117215746}], 
             PointBox[{80.1, 0.6363764192292719}], 
             PointBox[{80.2, 0.6374530491717091}], 
             PointBox[{80.3, 0.6370317333501961}], 
             PointBox[{80.4, 0.6364797044507076}], 
             PointBox[{80.5, 0.638234706569011}], 
             PointBox[{80.6, 0.6404910658514569}], 
             PointBox[{80.7, 0.6416582689331056}], 
             PointBox[{80.8, 0.641754022446817}], 
             PointBox[{80.9, 0.6408848479429081}], 
             PointBox[{81., 0.6388672149823433}], 
             PointBox[{81.1, 0.6367458196742336}], 
             PointBox[{81.2, 0.6366063950770896}], 
             PointBox[{81.3, 0.6378090344505659}], 
             PointBox[{81.4, 0.6363383852016483}], 
             PointBox[{81.5, 0.637165560447148}], 
             PointBox[{81.6, 0.6394803907425952}], 
             PointBox[{81.7, 0.6412330035802045}], 
             PointBox[{81.8, 0.6417581733123046}], 
             PointBox[{81.9, 0.6413463839925189}], 
             PointBox[{82., 0.6398608120713378}], 
             PointBox[{82.1, 0.6375247970523411}], 
             PointBox[{82.2, 0.6362540795917611}], 
             PointBox[{82.3, 0.6375435454280179}], 
             PointBox[{82.4, 0.6367616252330267}], 
             PointBox[{82.5, 0.6364087330156988}], 
             PointBox[{82.6, 0.6382778756041082}], 
             PointBox[{82.7, 0.6405183976307545}], 
             PointBox[{82.8, 0.6415571740083306}], 
             PointBox[{82.9, 0.6415396719490871}], 
             PointBox[{83., 0.6405928496215688}], 
             PointBox[{83.1, 0.6385118835178014}], 
             PointBox[{83.2, 0.6364496516535033}], 
             PointBox[{83.3, 0.6365967647880084}], 
             PointBox[{83.4, 0.6375304669223238}], 
             PointBox[{83.5, 0.6361196322150816}], 
             PointBox[{83.6, 0.6371166389488717}], 
             PointBox[{83.7, 0.6395024371040012}], 
             PointBox[{83.8, 0.6411367811049266}], 
             PointBox[{83.9, 0.6415205038994702}], 
             PointBox[{84., 0.6410220862432178}], 
             PointBox[{84.1, 0.6394546491170977}], 
             PointBox[{84.2, 0.6370846332405911}], 
             PointBox[{84.3, 0.6360395038296399}], 
             PointBox[{84.4, 0.6375336587918495}], 
             PointBox[{84.5, 0.6363776513902519}], 
             PointBox[{84.6, 0.6362446833712863}], 
             PointBox[{84.7, 0.6382742462040895}], 
             PointBox[{84.8, 0.6404588400555887}], 
             PointBox[{84.9, 0.641320697070815}], 
             PointBox[{85., 0.6411940047958322}], 
             PointBox[{85.1, 0.64016492159731}], 
             PointBox[{85.2, 0.6379800406848878}], 
             PointBox[{85.3, 0.6360336824614584}], 
             PointBox[{85.4, 0.6365776015237666}], 
             PointBox[{85.5, 0.637087049931926}], 
             PointBox[{85.6, 0.6358180569562185}], 
             PointBox[{85.7, 0.637047061699704}], 
             PointBox[{85.8, 0.6394978318626062}], 
             PointBox[{85.9, 0.6409395621431321}], 
             PointBox[{86., 0.6411718353297826}], 
             PointBox[{86.1, 0.6405893688534853}], 
             PointBox[{86.2, 0.6388942119375629}], 
             PointBox[{86.3, 0.6364997211479951}], 
             PointBox[{86.4, 0.6358157587184664}], 
             PointBox[{86.5, 0.6374087292524696}], 
             PointBox[{86.6, 0.6359135318834848}], 
             PointBox[{86.7, 0.6360681153121699}], 
             PointBox[{86.8, 0.63830489657949}], 
             PointBox[{86.9, 0.6403473947532092}], 
             PointBox[{87., 0.6409987139836021}], 
             PointBox[{87.1, 0.6407701729093183}], 
             PointBox[{87.2, 0.6396234701221346}], 
             PointBox[{87.3, 0.6372935629872847}], 
             PointBox[{87.4, 0.6355871855847207}], 
             PointBox[{87.5, 0.6366163257099305}], 
             PointBox[{87.6, 0.6365121909084208}], 
             PointBox[{87.7, 0.6355067501681652}], 
             PointBox[{87.8, 0.637053027684062}], 
             PointBox[{87.9, 0.6395075100826053}], 
             PointBox[{88., 0.6406863053585882}], 
             PointBox[{88.1, 0.6407746326572492}], 
             PointBox[{88.2, 0.6400904702541906}], 
             PointBox[{88.3, 0.6381973938081928}], 
             PointBox[{88.4, 0.6358542579412136}], 
             PointBox[{88.5, 0.6356885826322222}], 
             PointBox[{88.6, 0.6371156133799727}], 
             PointBox[{88.7, 0.6354386933087764}], 
             PointBox[{88.8, 0.6359825446521108}], 
             PointBox[{88.9, 0.6384268702901955}], 
             PointBox[{89., 0.6402150331843577}], 
             PointBox[{89.1, 0.6406537138050613}], 
             PointBox[{89.2, 0.6403241604334495}], 
             PointBox[{89.3, 0.6389916605429663}], 
             PointBox[{89.4, 0.6365173555319822}], 
             PointBox[{89.5, 0.6352284340094024}], 
             PointBox[{89.6, 0.6367249688656618}], 
             PointBox[{89.7, 0.6358810584194627}], 
             PointBox[{89.8, 0.6352838699908238}], 
             PointBox[{89.9, 0.637216694827629}], 
             PointBox[{90., 0.639544723342976}], 
             PointBox[{90.1, 0.6404287698500821}], 
             PointBox[{90.2, 0.6403899701526052}], 
             PointBox[{90.3, 0.639557784277912}], 
             PointBox[{90.4, 0.6374019560924193}], 
             PointBox[{90.5, 0.6352724401900411}], 
             PointBox[{90.6, 0.6357491782708725}], 
             PointBox[{90.7, 0.636619442972044}], 
             PointBox[{90.8, 0.6350469599195009}], 
             PointBox[{90.9, 0.6360870418957213}], 
             PointBox[{91., 0.6386464140014269}], 
             PointBox[{91.1, 0.6400911047515582}], 
             PointBox[{91.2, 0.6403440789200026}], 
             PointBox[{91.3, 0.639894972204033}], 
             PointBox[{91.4, 0.6382864069192201}], 
             PointBox[{91.5, 0.6357615070515932}], 
             PointBox[{91.6, 0.6350697267883438}], 
             PointBox[{91.7, 0.63679827590358}], 
             PointBox[{91.8, 0.6353030236776169}], 
             PointBox[{91.9, 0.6352514872100019}], 
             PointBox[{92., 0.6375605589497281}], 
             PointBox[{92.1, 0.6396057796044026}], 
             PointBox[{92.2, 0.6402168636080309}], 
             PointBox[{92.3, 0.6400602061014155}], 
             PointBox[{92.4, 0.6390027881352985}], 
             PointBox[{92.5, 0.6365806487773018}], 
             PointBox[{92.6, 0.634881104268902}], 
             PointBox[{92.7, 0.6360237929153537}], 
             PointBox[{92.8, 0.6359972181242421}], 
             PointBox[{92.9, 0.634837375521408}], 
             PointBox[{93., 0.6364363962685322}], 
             PointBox[{93.1, 0.6389267778655688}], 
             PointBox[{93.2, 0.6400099593983597}], 
             PointBox[{93.3, 0.6401130626555318}], 
             PointBox[{93.4, 0.6394978258942682}], 
             PointBox[{93.5, 0.6375376244588633}], 
             PointBox[{93.6, 0.6351625063120496}], 
             PointBox[{93.7, 0.635182391384799}], 
             PointBox[{93.8, 0.6366560805693573}], 
             PointBox[{93.9, 0.6348927121704308}], 
             PointBox[{94., 0.6354884775384355}], 
             PointBox[{94.1, 0.6380371643465099}], 
             PointBox[{94.2, 0.6396976229771754}], 
             PointBox[{94.3, 0.6400911586774013}], 
             PointBox[{94.4, 0.6398046470885862}], 
             PointBox[{94.5, 0.6384263331298465}], 
             PointBox[{94.6, 0.6358511965518768}], 
             PointBox[{94.7, 0.6347662317156989}], 
             PointBox[{94.8, 0.6364131682165308}], 
             PointBox[{94.9, 0.6354242584855921}], 
             PointBox[{95., 0.6348927914963087}], 
             PointBox[{95.1, 0.6370061554566017}], 
             PointBox[{95.2, 0.6392326134341588}], 
             PointBox[{95.3, 0.6400056942526062}], 
             PointBox[{95.4, 0.6399814347395167}], 
             PointBox[{95.5, 0.6391244688972614}], 
             PointBox[{95.6, 0.6368138796865798}], 
             PointBox[{95.7, 0.6348284214028135}], 
             PointBox[{95.8, 0.6355688939524585}], 
             PointBox[{95.9, 0.6362661710838002}], 
             PointBox[{96., 0.6347380652021789}], 
             PointBox[{96.1, 0.6360078526773265}], 
             PointBox[{96.2, 0.6385671306178021}], 
             PointBox[{96.3, 0.6398413890461417}], 
             PointBox[{96.4, 0.6400732518772135}], 
             PointBox[{96.5, 0.6396165719324903}], 
             PointBox[{96.6, 0.6378469694814577}], 
             PointBox[{96.7, 0.6353401750037702}], 
             PointBox[{96.8, 0.6349490191737593}], 
             PointBox[{96.9, 0.6366871054205091}], 
             PointBox[{97., 0.6350582148221808}], 
             PointBox[{97.1, 0.6352500950394036}], 
             PointBox[{97.2, 0.6377014521756436}], 
             PointBox[{97.3, 0.6395572507666365}], 
             PointBox[{97.4, 0.6401011205098127}], 
             PointBox[{97.5, 0.6399462509637878}], 
             PointBox[{97.6, 0.6387632806987072}], 
             PointBox[{97.7, 0.636226471246049}], 
             PointBox[{97.8, 0.6347967160098035}], 
             PointBox[{97.9, 0.6361396499601799}], 
             PointBox[{98., 0.6358298235663304}], 
             PointBox[{98.1, 0.6348817791732118}], 
             PointBox[{98.2, 0.6367375589378269}], 
             PointBox[{98.3, 0.6390963708837634}], 
             PointBox[{98.4, 0.6400592296881576}], 
             PointBox[{98.5, 0.6401637770045432}], 
             PointBox[{98.6, 0.6394740946559236}], 
             PointBox[{98.7, 0.6373265827190361}], 
             PointBox[{98.8, 0.63511759667445}], 
             PointBox[{98.9, 0.6353888441961585}], 
             PointBox[{99., 0.6366857455698866}], 
             PointBox[{99.1, 0.6349740709117349}], 
             PointBox[{99.2, 0.635871766282899}], 
             PointBox[{99.3, 0.638417155232182}], 
             PointBox[{99.4, 0.6399152247038068}], 
             PointBox[{99.5, 0.640299610132101}], 
             PointBox[{99.6, 0.6399850535371452}], 
             PointBox[{99.7, 0.6384266286697103}], 
             PointBox[{99.8, 0.6358725671420898}], 
             PointBox[{99.9, 0.6350326613705441}], 
             PointBox[{100., 0.6367119762975253}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0.6, 0.65}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], 
             PointBox[{0, 0.060145999999999124`}], 
             PointBox[{0.1, 0.05982466789095328}], 
             PointBox[{0.2, 0.057606477163866625`}], 
             PointBox[{0.3, 0.060644083756338556`}], 
             PointBox[{0.4, 0.05969844551830036}], 
             PointBox[{0.5, 0.056848802881649306`}], 
             PointBox[{0.6, 0.058362518228617384`}], 
             PointBox[{0.7, 0.06110773747040919}], 
             PointBox[{0.8, 0.058340332249132376`}], 
             PointBox[{0.9, 0.05868750787676766}], 
             PointBox[{1., 0.0602620933871352}], 
             PointBox[{1.1, 0.06006444749716806}], 
             PointBox[{1.2, 0.05758971544079518}], 
             PointBox[{1.3, 0.05893188455650285}], 
             PointBox[{1.4, 0.060379094791105085`}], 
             PointBox[{1.5, 0.05714379438497267}], 
             PointBox[{1.6, 0.05687137207429886}], 
             PointBox[{1.7, 0.0601354231782226}], 
             PointBox[{1.8, 0.059362385338717565`}], 
             PointBox[{1.9, 0.057335274390351666`}], 
             PointBox[{2., 0.05980433050880389}], 
             PointBox[{2.1, 0.05932547801626109}], 
             PointBox[{2.2, 0.057910108986670726`}], 
             PointBox[{2.3, 0.056822836891429494`}], 
             PointBox[{2.4, 0.059860768188686186`}], 
             PointBox[{2.5, 0.05755472918656146}], 
             PointBox[{2.6, 0.05556286472869869}], 
             PointBox[{2.7, 0.05810554828049577}], 
             PointBox[{2.8, 0.05969610566096869}], 
             PointBox[{2.9, 0.05649695910109848}], 
             PointBox[{3., 0.05819785849293156}], 
             PointBox[{3.1, 0.05852628070115092}], 
             PointBox[{3.2, 0.05782126171777261}], 
             PointBox[{3.3, 0.055239914393268356`}], 
             PointBox[{3.4, 0.057885962645430396`}], 
             PointBox[{3.5, 0.05769808801999667}], 
             PointBox[{3.6, 0.054600551764830564`}], 
             PointBox[{3.7, 0.05557873098940734}], 
             PointBox[{3.8, 0.05864505058423208}], 
             PointBox[{3.9, 0.05636901758268747}], 
             PointBox[{4., 0.05585746259543145}], 
             PointBox[{4.1, 0.05774518391125333}], 
             PointBox[{4.2, 0.05678207333740114}], 
             PointBox[{4.3, 0.05439778365929104}], 
             PointBox[{4.4, 0.054883246216037594`}], 
             PointBox[{4.5, 0.057013364258613045`}], 
             PointBox[{4.6, 0.053965958457289694`}], 
             PointBox[{4.7, 0.053050476991120143`}], 
             PointBox[{4.8, 0.05622032033952174}], 
             PointBox[{4.9, 0.056275005970866494`}], 
             PointBox[{5., 0.05360573635057879}], 
             PointBox[{5.1, 0.055913384932387525`}], 
             PointBox[{5.2, 0.055168919554159764`}], 
             PointBox[{5.3, 0.05374870695615349}], 
             PointBox[{5.4, 0.05188599699384956}], 
             PointBox[{5.5, 0.05498029648498145}], 
             PointBox[{5.6, 0.05341478938383354}], 
             PointBox[{5.7, 0.050869364170323644`}], 
             PointBox[{5.8, 0.05292192050097172}], 
             PointBox[{5.9, 0.055203088156354996`}], 
             PointBox[{6., 0.05212821748874997}], 
             PointBox[{6.1, 0.05297021831829654}], 
             PointBox[{6.2, 0.05383916833061894}], 
             PointBox[{6.3, 0.05252549218930577}], 
             PointBox[{6.4, 0.04972604424738264}], 
             PointBox[{6.5, 0.05157795058815116}], 
             PointBox[{6.6, 0.05244476292193831}], 
             PointBox[{6.7, 0.04920025658516049}], 
             PointBox[{6.8, 0.049377740517212845`}], 
             PointBox[{6.9, 0.052673437987079026`}], 
             PointBox[{7., 0.05130118470429899}], 
             PointBox[{7.1, 0.049675610479992305`}], 
             PointBox[{7.2, 0.051911254408920283`}], 
             PointBox[{7.3, 0.05049207704958718}], 
             PointBox[{7.4, 0.0483370774658881}], 
             PointBox[{7.5, 0.047627153942264126`}], 
             PointBox[{7.6, 0.05041836907153923}], 
             PointBox[{7.7, 0.0479590745367362}], 
             PointBox[{7.8, 0.04614581247712915}], 
             PointBox[{7.9, 0.048956861915441754`}], 
             PointBox[{8., 0.050141800867836143`}], 
             PointBox[{8.1, 0.047008704186227566`}], 
             PointBox[{8.2, 0.048705943953515254`}], 
             PointBox[{8.3, 0.048570207344696886`}], 
             PointBox[{8.4, 0.046957484493415795`}], 
             PointBox[{8.5, 0.044343169988533625`}], 
             PointBox[{8.6, 0.04698555571286984}], 
             PointBox[{8.7, 0.04673263811124433}], 
             PointBox[{8.8, 0.043617960526554284`}], 
             PointBox[{8.9, 0.044742054235854915`}], 
             PointBox[{9., 0.04774075023058543}], 
             PointBox[{9.1, 0.045407354184947464`}], 
             PointBox[{9.2, 0.04481439875200782}], 
             PointBox[{9.3, 0.04662377227131198}], 
             PointBox[{9.4, 0.044908611998319414`}], 
             PointBox[{9.5, 0.04228048380189735}], 
             PointBox[{9.6, 0.04265738288858093}], 
             PointBox[{9.7, 0.04483712059461848}], 
             PointBox[{9.8, 0.0419059244149804}], 
             PointBox[{9.9, 0.040806653270468875`}], 
             PointBox[{10., 0.04401847819739681}], 
             PointBox[{10.1, 0.04417671904813196}], 
             PointBox[{10.2, 0.041396781430471874`}], 
             PointBox[{10.3, 0.04349358717837348}], 
             PointBox[{10.4, 0.04268856810678079}], 
             PointBox[{10.5, 0.04090369716224253}], 
             PointBox[{10.6, 0.03879127722219106}], 
             PointBox[{10.7, 0.041710293247850264`}], 
             PointBox[{10.8, 0.04069800666921044}], 
             PointBox[{10.9, 0.03782031441691394}], 
             PointBox[{11., 0.03963218360823317}], 
             PointBox[{11.1, 0.042155546332825186`}], 
             PointBox[{11.2, 0.039362086852309755`}], 
             PointBox[{11.3, 0.039511600389479165`}], 
             PointBox[{11.4, 0.04088364116209022}], 
             PointBox[{11.5, 0.039257090949500625`}], 
             PointBox[{11.6, 0.036504119046230875`}], 
             PointBox[{11.7, 0.03761526756689727}], 
             PointBox[{11.8, 0.039272238456475005`}], 
             PointBox[{11.9, 0.03613211819973048}], 
             PointBox[{12., 0.035569015778358894`}], 
             PointBox[{12.1, 0.038907167113727555`}], 
             PointBox[{12.2, 0.03837401748252426}], 
             PointBox[{12.3, 0.03599058216417776}], 
             PointBox[{12.4, 0.0382410264127402}], 
             PointBox[{12.5, 0.03728787167030406}], 
             PointBox[{12.6, 0.03559248878055478}], 
             PointBox[{12.7, 0.033957390778056235`}], 
             PointBox[{12.8, 0.03691353894092619}], 
             PointBox[{12.9, 0.03551324266756495}], 
             PointBox[{13., 0.032808905034005034`}], 
             PointBox[{13.1, 0.03500536034373374}], 
             PointBox[{13.2, 0.03714999507547728}], 
             PointBox[{13.3, 0.0342243122592669}], 
             PointBox[{13.4, 0.03479109046814598}], 
             PointBox[{13.5, 0.03597279475021677}], 
             PointBox[{13.6, 0.03490369705313912}], 
             PointBox[{13.7, 0.03226292565299858}], 
             PointBox[{13.8, 0.033735561809224775`}], 
             PointBox[{13.9, 0.03514521270317643}], 
             PointBox[{14., 0.03192396520148529}], 
             PointBox[{14.1, 0.03162094554410373}], 
             PointBox[{14.2, 0.034961448406152715`}], 
             PointBox[{14.3, 0.03413379426364912}], 
             PointBox[{14.4, 0.03199001435764514}], 
             PointBox[{14.5, 0.034344265465878286`}], 
             PointBox[{14.6, 0.033853104612137044`}], 
             PointBox[{14.7, 0.03253497306424342}], 
             PointBox[{14.8, 0.03117945615001261}], 
             PointBox[{14.9, 0.034149563614955365`}], 
             PointBox[{15., 0.03263987822837081}], 
             PointBox[{15.1, 0.029976877402823208`}], 
             PointBox[{15.2, 0.03229383497365315}], 
             PointBox[{15.3, 0.03428881640954377}], 
             PointBox[{15.4, 0.031375771332205926`}], 
             PointBox[{15.5, 0.03213244561027588}], 
             PointBox[{15.6, 0.03347842435825873}], 
             PointBox[{15.7, 0.033371443280649296`}], 
             PointBox[{15.8, 0.030917873711173206`}], 
             PointBox[{15.9, 0.032523935349979896`}], 
             PointBox[{16., 0.0339066830923392}], 
             PointBox[{16.1, 0.030653114863375144`}], 
             PointBox[{16.2, 0.03039463746711644}], 
             PointBox[{16.3, 0.033713613367709706`}], 
             PointBox[{16.4, 0.03284960400275741}], 
             PointBox[{16.5, 0.03080867548039183}], 
             PointBox[{16.6, 0.033315341436115954`}], 
             PointBox[{16.7, 0.03372704885720261}], 
             PointBox[{16.8, 0.03283627140012765}], 
             PointBox[{16.9, 0.031631769870478076`}], 
             PointBox[{17., 0.034647231514515764`}], 
             PointBox[{17.1, 0.0330968547144316}], 
             PointBox[{17.2, 0.030443900891257886`}], 
             PointBox[{17.3, 0.03276812708534633}], 
             PointBox[{17.4, 0.034729617034259745`}], 
             PointBox[{17.5, 0.031844538975206414`}], 
             PointBox[{17.6, 0.03276324389483299}], 
             PointBox[{17.7, 0.034467012367497336`}], 
             PointBox[{17.8, 0.0352815699035415}], 
             PointBox[{17.9, 0.03296042610507452}], 
             PointBox[{18., 0.034705159160963985`}], 
             PointBox[{18.1, 0.03602207234049137}], 
             PointBox[{18.2, 0.03272901706025686}], 
             PointBox[{18.3, 0.03256059497397884}], 
             PointBox[{18.4, 0.03584859536696451}], 
             PointBox[{18.5, 0.034912020131931516`}], 
             PointBox[{18.6, 0.0330196428049688}], 
             PointBox[{18.7, 0.0357156057918023}], 
             PointBox[{18.8, 0.03696913365612873}], 
             PointBox[{18.9, 0.03619834117430668}], 
             PointBox[{19., 0.03521593962438518}], 
             PointBox[{19.1, 0.03826463700251858}], 
             PointBox[{19.2, 0.03648322623603364}], 
             PointBox[{19.3, 0.033988739425549516`}], 
             PointBox[{19.4, 0.03641456352494966}], 
             PointBox[{19.5, 0.03822123049854039}], 
             PointBox[{19.6, 0.03529343740190914}], 
             PointBox[{19.7, 0.0365672365452752}], 
             PointBox[{19.8, 0.03849807304194501}], 
             PointBox[{19.9, 0.03972648878909296}], 
             PointBox[{20., 0.03745074859112395}], 
             PointBox[{20.1, 0.03952706127942921}], 
             PointBox[{20.2, 0.04048042766915207}], 
             PointBox[{20.3, 0.037138326110615856`}], 
             PointBox[{20.4, 0.03732567441051782}], 
             PointBox[{20.5, 0.04055273662923406}], 
             PointBox[{20.6, 0.03926592500905538}], 
             PointBox[{20.7, 0.037769383784556486`}], 
             PointBox[{20.8, 0.040592014145966984`}], 
             PointBox[{20.9, 0.042272812368802454`}], 
             PointBox[{21., 0.041204893669845026`}], 
             PointBox[{21.1, 0.04068308058409412}], 
             PointBox[{21.2, 0.04364384665168662}], 
             PointBox[{21.3, 0.041364191525992786`}], 
             PointBox[{21.4, 0.03929267938013198}], 
             PointBox[{21.5, 0.04198490339136194}], 
             PointBox[{21.6, 0.043350653908802085`}], 
             PointBox[{21.7, 0.04037007669386158}], 
             PointBox[{21.8, 0.042237566617786715`}], 
             PointBox[{21.9, 0.044104008381152096`}], 
             PointBox[{22., 0.04514183752533639}], 
             PointBox[{22.1, 0.042942017043487136`}], 
             PointBox[{22.2, 0.04553828951031369}], 
             PointBox[{22.3, 0.04571488843413122}], 
             PointBox[{22.4, 0.04244152108011118}], 
             PointBox[{22.5, 0.04326328398068855}], 
             PointBox[{22.6, 0.0463187559096672}], 
             PointBox[{22.7, 0.04438185458023124}], 
             PointBox[{22.8, 0.043671780563825514`}], 
             PointBox[{22.9, 0.046381297614929325`}], 
             PointBox[{23., 0.0480788161506715}], 
             PointBox[{23.1, 0.046446242663028645`}], 
             PointBox[{23.2, 0.046725983235182636`}], 
             PointBox[{23.3, 0.04926622869058049}], 
             PointBox[{23.4, 0.04639201026054427}], 
             PointBox[{23.5, 0.0450461096433261}], 
             PointBox[{23.6, 0.04806951046024344}], 
             PointBox[{23.7, 0.048619079301045705`}], 
             PointBox[{23.8, 0.045829970533476865`}], 
             PointBox[{23.9, 0.04832387317774302}], 
             PointBox[{24., 0.04989681020570517}], 
             PointBox[{24.1, 0.050230059184474686`}], 
             PointBox[{24.2, 0.04836351788030406}], 
             PointBox[{24.3, 0.05144466438719231}], 
             PointBox[{24.4, 0.05049455147808643}], 
             PointBox[{24.5, 0.047583036492750995`}], 
             PointBox[{24.6, 0.04920776829574306}], 
             PointBox[{24.7, 0.05182565401962959}], 
             PointBox[{24.8, 0.04914148811400744}], 
             PointBox[{24.9, 0.04960175891548311}], 
             PointBox[{25., 0.05181372825754671}], 
             PointBox[{25.1, 0.053206877535274685`}], 
             PointBox[{25.2, 0.05102258523681375}], 
             PointBox[{25.3, 0.05242295456120568}], 
             PointBox[{25.4, 0.054006502419886165`}], 
             PointBox[{25.5, 0.050740660275612685`}], 
             PointBox[{25.6, 0.050383788227405295`}], 
             PointBox[{25.7, 0.053618821573202774`}], 
             PointBox[{25.8, 0.052974751035716056`}], 
             PointBox[{25.9, 0.05093191396878964}], 
             PointBox[{26., 0.0537106430599425}], 
             PointBox[{26.1, 0.054913961686648444`}], 
             PointBox[{26.2, 0.05418851041491633}], 
             PointBox[{26.3, 0.05315001666384751}], 
             PointBox[{26.4, 0.05628108347239845}], 
             PointBox[{26.5, 0.05413389964431191}], 
             PointBox[{26.6, 0.05196693677706368}], 
             PointBox[{26.7, 0.05440268299371565}], 
             PointBox[{26.8, 0.05613978889853962}], 
             PointBox[{26.9, 0.053031643812692576`}], 
             PointBox[{27., 0.054747117441211}], 
             PointBox[{27.1, 0.05615632529744703}], 
             PointBox[{27.2, 0.056907709415731575`}], 
             PointBox[{27.3, 0.05454995463260603}], 
             PointBox[{27.4, 0.05710528170741545}], 
             PointBox[{27.5, 0.057222568108723816`}], 
             PointBox[{27.6, 0.05402226881178157}], 
             PointBox[{27.7, 0.05480380273429069}], 
             PointBox[{27.8, 0.05790521434518807}], 
             PointBox[{27.9, 0.055903895523203996`}], 
             PointBox[{28., 0.055240458729698017`}], 
             PointBox[{28.1, 0.0576519305601347}], 
             PointBox[{28.2, 0.05848903163381036}], 
             PointBox[{28.3, 0.05666941181218033}], 
             PointBox[{28.4, 0.057007661103493715`}], 
             PointBox[{28.5, 0.05939678035094944}], 
             PointBox[{28.6, 0.05638345440608234}], 
             PointBox[{28.7, 0.05529528828267244}], 
             PointBox[{28.8, 0.058350710514469314`}], 
             PointBox[{28.9, 0.05869383189450447}], 
             PointBox[{29., 0.05595437711630163}], 
             PointBox[{29.1, 0.05847936136957092}], 
             PointBox[{29.2, 0.059097656794954795`}], 
             PointBox[{29.3, 0.05880922798272722}], 
             PointBox[{29.4, 0.05699762850547308}], 
             PointBox[{29.5, 0.06018427258468619}], 
             PointBox[{29.6, 0.05870892417576893}], 
             PointBox[{29.7, 0.05610329770838324}], 
             PointBox[{29.8, 0.058006269741258165`}], 
             PointBox[{29.9, 0.06040612590363524}], 
             PointBox[{30., 0.057403631991062305`}], 
             PointBox[{30.1, 0.058360428233726114`}], 
             PointBox[{30.2, 0.05979436990916993}], 
             PointBox[{30.3, 0.06017661562981759}], 
             PointBox[{30.4, 0.057699833925357935`}], 
             PointBox[{30.5, 0.05961149585244132}], 
             PointBox[{30.6, 0.06050806831364113}], 
             PointBox[{30.7, 0.05724134944375306}], 
             PointBox[{30.8, 0.05741679681347064}], 
             PointBox[{30.9, 0.06066522489834302}], 
             PointBox[{31., 0.0593329537610124}], 
             PointBox[{31.1, 0.05786450309460877}], 
             PointBox[{31.2, 0.060345341869894306`}], 
             PointBox[{31.3, 0.06041423312821834}], 
             PointBox[{31.4, 0.058879128654179}], 
             PointBox[{31.5, 0.058401064536586035`}], 
             PointBox[{31.6, 0.061227749843594664`}], 
             PointBox[{31.7, 0.05854546436206025}], 
             PointBox[{31.8, 0.056951376850975725`}], 
             PointBox[{31.9, 0.05975423557136598}], 
             PointBox[{32., 0.06081265995131288}], 
             PointBox[{32.1, 0.05773197868079037}], 
             PointBox[{32.2, 0.05987754660453221}], 
             PointBox[{32.3, 0.06016871146936525}], 
             PointBox[{32.4, 0.059806333418819586`}], 
             PointBox[{32.5, 0.05751871844820728}], 
             PointBox[{32.6, 0.06050986309904771}], 
             PointBox[{32.7, 0.059676556631048705`}], 
             PointBox[{32.8, 0.0567833974569586}], 
             PointBox[{32.9, 0.05821687474160114}], 
             PointBox[{33., 0.0610209048854379}], 
             PointBox[{33.1, 0.058315623747129064`}], 
             PointBox[{33.2, 0.05853509803548767}], 
             PointBox[{33.3, 0.06015016631346777}], 
             PointBox[{33.4, 0.05982406682914249}], 
             PointBox[{33.5, 0.05735643290472944}], 
             PointBox[{33.6, 0.058575631054603026`}], 
             PointBox[{33.7, 0.060130409514278595`}], 
             PointBox[{33.8, 0.056911281084895494`}], 
             PointBox[{33.9, 0.05654652813553327}], 
             PointBox[{34., 0.05980502017192444}], 
             PointBox[{34.1, 0.05915049592877863}], 
             PointBox[{34.2, 0.05701780157696867}], 
             PointBox[{34.3, 0.05947544476765154}], 
             PointBox[{34.4, 0.058912989789437986`}], 
             PointBox[{34.5, 0.05750730791214779}], 
             PointBox[{34.6, 0.05630030724591092}], 
             PointBox[{34.7, 0.05936520759941396}], 
             PointBox[{34.8, 0.057149691656028324`}], 
             PointBox[{34.9, 0.05507714414098109}], 
             PointBox[{35., 0.057559214455713256`}], 
             PointBox[{35.1, 0.05925389238614357}], 
             PointBox[{35.2, 0.056049774183324956`}], 
             PointBox[{35.3, 0.05764464110042852}], 
             PointBox[{35.4, 0.0580185221147422}], 
             PointBox[{35.5, 0.05722339834162598}], 
             PointBox[{35.6, 0.054594380126485716`}], 
             PointBox[{35.7, 0.05714963357249518}], 
             PointBox[{35.8, 0.057103168110655446`}], 
             PointBox[{35.9, 0.05397199191460499}], 
             PointBox[{36., 0.05484867965739356}], 
             PointBox[{36.1, 0.05795905281457179}], 
             PointBox[{36.2, 0.05578984997388898}], 
             PointBox[{36.3, 0.05512262940315891}], 
             PointBox[{36.4, 0.057068585667044106`}], 
             PointBox[{36.5, 0.055995751157488366`}], 
             PointBox[{36.6, 0.05363538057878926}], 
             PointBox[{36.7, 0.053960302106796115`}], 
             PointBox[{36.8, 0.0561995337580023}], 
             PointBox[{36.9, 0.05320714511777745}], 
             PointBox[{37., 0.05217266110686368}], 
             PointBox[{37.1, 0.05531089647179845}], 
             PointBox[{37.2, 0.05551772385413457}], 
             PointBox[{37.3, 0.052756048889471226`}], 
             PointBox[{37.4, 0.055010120095918956`}], 
             PointBox[{37.5, 0.05428857521088625}], 
             PointBox[{37.6, 0.05284699056981725}], 
             PointBox[{37.7, 0.05086033374835937}], 
             PointBox[{37.8, 0.05393074495948698}], 
             PointBox[{37.9, 0.05252211901898138}], 
             PointBox[{38., 0.04988491050555155}], 
             PointBox[{38.1, 0.05183238928676873}], 
             PointBox[{38.2, 0.054225595568867434`}], 
             PointBox[{38.3, 0.05121165544426851}], 
             PointBox[{38.4, 0.05187624204531794}], 
             PointBox[{38.5, 0.05287375185907721}], 
             PointBox[{38.6, 0.05146467791909739}], 
             PointBox[{38.7, 0.04865578124176755}], 
             PointBox[{38.8, 0.05033323938769597}], 
             PointBox[{38.9, 0.051390332086103566`}], 
             PointBox[{39., 0.048148927409006136`}], 
             PointBox[{39.1, 0.04816739656808851}], 
             PointBox[{39.2, 0.05148060008560297}], 
             PointBox[{39.3, 0.050296529309290794`}], 
             PointBox[{39.4, 0.04848446908112144}], 
             PointBox[{39.5, 0.050750229846219026`}], 
             PointBox[{39.6, 0.04933185105740489}], 
             PointBox[{39.7, 0.047223401315203396`}], 
             PointBox[{39.8, 0.04630224364051664}], 
             PointBox[{39.9, 0.049168915354158675`}], 
             PointBox[{40., 0.04686087218692846}], 
             PointBox[{40.1, 0.04488831301840031}], 
             PointBox[{40.2, 0.04760254274577642}], 
             PointBox[{40.3, 0.04898426042424522}], 
             PointBox[{40.4, 0.0458285233280054}], 
             PointBox[{40.5, 0.04736318187195767}], 
             PointBox[{40.6, 0.04741342957460246}], 
             PointBox[{40.7, 0.0457672040363668}], 
             PointBox[{40.8, 0.043068858263912935`}], 
             PointBox[{40.9, 0.045563450470606025`}], 
             PointBox[{41., 0.04556964435648712}], 
             PointBox[{41.1, 0.04239222972447836}], 
             PointBox[{41.2, 0.04331692541715913}], 
             PointBox[{41.3, 0.046408263553414805`}], 
             PointBox[{41.4, 0.04427072575553583}], 
             PointBox[{41.5, 0.043410848181662264`}], 
             PointBox[{41.6, 0.04535329667159651}], 
             PointBox[{41.7, 0.04365236537928394}], 
             PointBox[{41.8, 0.041110435088151036`}], 
             PointBox[{41.9, 0.041200367035080926`}], 
             PointBox[{42., 0.043566473207430616`}], 
             PointBox[{42.1, 0.04076724525717736}], 
             PointBox[{42.2, 0.03943157898359629}], 
             PointBox[{42.3, 0.04257135511025298}], 
             PointBox[{42.4, 0.043013547857558704`}], 
             PointBox[{42.5, 0.04010911810776562}], 
             PointBox[{42.6, 0.04208619230234035}], 
             PointBox[{42.7, 0.0415123068817438}], 
             PointBox[{42.8, 0.03980295957836279}], 
             PointBox[{42.9, 0.0375120228203348}], 
             PointBox[{43., 0.04033997456600391}], 
             PointBox[{43.1, 0.039643653076959}], 
             PointBox[{43.2, 0.036630224030843844`}], 
             PointBox[{43.3, 0.038202030880434425`}], 
             PointBox[{43.4, 0.04091157885229443}], 
             PointBox[{43.5, 0.03829797007233346}], 
             PointBox[{43.6, 0.03812108379846789}], 
             PointBox[{43.7, 0.03973068810809234}], 
             PointBox[{43.8, 0.038185438137491014`}], 
             PointBox[{43.9, 0.035534686613257024`}], 
             PointBox[{44., 0.03630342832847174}], 
             PointBox[{44.1, 0.038250363198433335`}], 
             PointBox[{44.2, 0.03522455763465566}], 
             PointBox[{44.3, 0.034340638465499125`}], 
             PointBox[{44.4, 0.0376415317111733}], 
             PointBox[{44.5, 0.037472037272902214`}], 
             PointBox[{44.6, 0.034869683449676246`}], 
             PointBox[{44.7, 0.037048612124495346`}], 
             PointBox[{44.8, 0.036372952019952935`}], 
             PointBox[{44.9, 0.03489455645883351}], 
             PointBox[{45., 0.03299621420237429}], 
             PointBox[{45.1, 0.03591762054851833}], 
             PointBox[{45.2, 0.03488580541512321}], 
             PointBox[{45.3, 0.031980223746718925`}], 
             PointBox[{45.4, 0.033893254364642175`}], 
             PointBox[{45.5, 0.03631352518140428}], 
             PointBox[{45.6, 0.03355153105616499}], 
             PointBox[{45.7, 0.03374648456864871}], 
             PointBox[{45.8, 0.03524989382886565}], 
             PointBox[{45.9, 0.0343686121457002}], 
             PointBox[{46., 0.03184290141120503}], 
             PointBox[{46.1, 0.032935910443049866`}], 
             PointBox[{46.2, 0.034711478793185084`}], 
             PointBox[{46.3, 0.0316012398794738}], 
             PointBox[{46.4, 0.030905238440937455`}], 
             PointBox[{46.5, 0.03423325671022736}], 
             PointBox[{46.6, 0.033828673977573644`}], 
             PointBox[{46.7, 0.03140469407327415}], 
             PointBox[{46.8, 0.03371885225603802}], 
             PointBox[{46.9, 0.03353657291001826}], 
             PointBox[{47., 0.032561244410452474`}], 
             PointBox[{47.1, 0.030897588887081027`}], 
             PointBox[{47.2, 0.03386309009985342}], 
             PointBox[{47.3, 0.032753732854944054`}], 
             PointBox[{47.4, 0.02985961402706463}], 
             PointBox[{47.5, 0.03186070807848028}], 
             PointBox[{47.6, 0.03418027932410427}], 
             PointBox[{47.7, 0.0314246357256064}], 
             PointBox[{47.8, 0.03178660928513987}], 
             PointBox[{47.9, 0.0334777256553065}], 
             PointBox[{48., 0.03362820766654034}], 
             PointBox[{48.1, 0.03129419914504969}], 
             PointBox[{48.2, 0.0325161227495661}], 
             PointBox[{48.3, 0.03428288404091621}], 
             PointBox[{48.4, 0.031139089065714703`}], 
             PointBox[{48.5, 0.03047485593475571}], 
             PointBox[{48.6, 0.03378583281741873}], 
             PointBox[{48.7, 0.033352935367616736`}], 
             PointBox[{48.8, 0.03101792396442828}], 
             PointBox[{48.9, 0.033495703165919016`}], 
             PointBox[{49., 0.03416699317175819}], 
             PointBox[{49.1, 0.03365322335840269}], 
             PointBox[{49.2, 0.03214445966152056}], 
             PointBox[{49.3, 0.0351695946087519}], 
             PointBox[{49.4, 0.033990630830638816`}], 
             PointBox[{49.5, 0.031121527076314083`}], 
             PointBox[{49.6, 0.03314714833175246}], 
             PointBox[{49.7, 0.03542135426154252}], 
             PointBox[{49.8, 0.03266777661840325}], 
             PointBox[{49.9, 0.03322094059727632}], 
             PointBox[{50., 0.03520300970352439}], 
             PointBox[{50.1, 0.036247762300909134`}], 
             PointBox[{50.2, 0.034013623625519636`}], 
             PointBox[{50.3, 0.03542377302245315}], 
             PointBox[{50.4, 0.03708786046614816}], 
             PointBox[{50.5, 0.03387278033743353}], 
             PointBox[{50.6, 0.0333582883200886}], 
             PointBox[{50.7, 0.036647097867487634`}], 
             PointBox[{50.8, 0.03608224059890566}], 
             PointBox[{50.9, 0.03391137188176933}], 
             PointBox[{51., 0.03659519958377775}], 
             PointBox[{51.1, 0.037981509514487546`}], 
             PointBox[{51.2, 0.03752977425239743}], 
             PointBox[{51.3, 0.03626831455058453}], 
             PointBox[{51.4, 0.0393584341803485}], 
             PointBox[{51.5, 0.037861232125138755`}], 
             PointBox[{51.6, 0.035178951752061496`}], 
             PointBox[{51.7, 0.03737648232774081}], 
             PointBox[{51.8, 0.0394555711210388}], 
             PointBox[{51.9, 0.036593973694799116`}], 
             PointBox[{52., 0.037582040671801535`}], 
             PointBox[{52.1, 0.039676130317734856`}], 
             PointBox[{52.2, 0.041072711121774665`}], 
             PointBox[{52.3, 0.038818936400221195`}], 
             PointBox[{52.4, 0.04064856022927747}], 
             PointBox[{52.5, 0.04189046845484056}], 
             PointBox[{52.6, 0.03857102927876144}], 
             PointBox[{52.7, 0.03849650476770647}], 
             PointBox[{52.8, 0.04175370475568159}], 
             PointBox[{52.9, 0.040743998190885436`}], 
             PointBox[{53., 0.0389922324734085}], 
             PointBox[{53.1, 0.04183320476591378}], 
             PointBox[{53.2, 0.043531422746316856`}], 
             PointBox[{53.3, 0.042688438696884844`}], 
             PointBox[{53.4, 0.04191732117192352}], 
             PointBox[{53.5, 0.044966396081084145`}], 
             PointBox[{53.6, 0.042865897058684585`}], 
             PointBox[{53.7, 0.04063284975134125}], 
             PointBox[{53.8, 0.043181168662598475`}], 
             PointBox[{53.9, 0.04477903092117637}], 
             PointBox[{54., 0.04178243280089745}], 
             PointBox[{54.1, 0.04346553294774886}], 
             PointBox[{54.2, 0.045381407566278065`}], 
             PointBox[{54.3, 0.04654744289463646}], 
             PointBox[{54.4, 0.044299448046216695`}], 
             PointBox[{54.5, 0.046752770834331034`}], 
             PointBox[{54.6, 0.047148976327913095`}], 
             PointBox[{54.7, 0.04384947053695848}], 
             PointBox[{54.8, 0.04448755091392927}], 
             PointBox[{54.9, 0.047608454687985774`}], 
             PointBox[{55., 0.045844037562690565`}], 
             PointBox[{55.1, 0.04491892239378796}], 
             PointBox[{55.2, 0.04766611212214958}], 
             PointBox[{55.3, 0.049320645521127804`}], 
             PointBox[{55.4, 0.047812184063417924`}], 
             PointBox[{55.5, 0.047887760832531476`}], 
             PointBox[{55.6, 0.05054852727123528}], 
             PointBox[{55.7, 0.047760264600833435`}], 
             PointBox[{55.8, 0.04628238355010925}], 
             PointBox[{55.9, 0.049236562906249906`}], 
             PointBox[{56., 0.04997298585542616}], 
             PointBox[{56.1, 0.04710193160318756}], 
             PointBox[{56.2, 0.04950856993370014}], 
             PointBox[{56.3, 0.05103875977951941}], 
             PointBox[{56.4, 0.051474484164025266`}], 
             PointBox[{56.5, 0.04951041951985381}], 
             PointBox[{56.6, 0.05254835484626306}], 
             PointBox[{56.7, 0.051739367420954856`}], 
             PointBox[{56.8, 0.048776448687924294`}], 
             PointBox[{56.9, 0.05028478830481781}], 
             PointBox[{57., 0.052991323770123874`}], 
             PointBox[{57.1, 0.05037796289303731}], 
             PointBox[{57.2, 0.05068843616542206}], 
             PointBox[{57.3, 0.05292169692657167}], 
             PointBox[{57.4, 0.05426137974769677}], 
             PointBox[{57.5, 0.05211084009377658}], 
             PointBox[{57.6, 0.05337607766582831}], 
             PointBox[{57.7, 0.05507440644012252}], 
             PointBox[{57.8, 0.051830245435639716`}], 
             PointBox[{57.9, 0.0513751684773229}], 
             PointBox[{58., 0.05459886205179739}], 
             PointBox[{58.1, 0.05408142753531063}], 
             PointBox[{58.2, 0.05193545459948624}], 
             PointBox[{58.3, 0.054692154783213306`}], 
             PointBox[{58.4, 0.05579870912930127}], 
             PointBox[{58.5, 0.05514063999107755}], 
             PointBox[{58.6, 0.053993824319905605`}], 
             PointBox[{58.7, 0.057149457626961886`}], 
             PointBox[{58.8, 0.05507256865673453}], 
             PointBox[{58.9, 0.052851155291439945`}], 
             PointBox[{59., 0.055225899329527324`}], 
             PointBox[{59.1, 0.05705239827241088}], 
             PointBox[{59.2, 0.053938367560786495`}], 
             PointBox[{59.3, 0.05557396741311225}], 
             PointBox[{59.4, 0.056955194379334}], 
             PointBox[{59.5, 0.05767260692224568}], 
             PointBox[{59.6, 0.055287075254726696`}], 
             PointBox[{59.7, 0.05778201379503035}], 
             PointBox[{59.8, 0.05797975241191056}], 
             PointBox[{59.9, 0.05476920945432623}], 
             PointBox[{60., 0.0554862614518579}], 
             PointBox[{60.1, 0.0586120660562458}], 
             PointBox[{60.2, 0.05667192599964275}], 
             PointBox[{60.3, 0.05592393142167162}], 
             PointBox[{60.4, 0.05833434732260666}], 
             PointBox[{60.5, 0.05906224533683082}], 
             PointBox[{60.6, 0.05726532243499924}], 
             PointBox[{60.7, 0.05752077910701626}], 
             PointBox[{60.8, 0.05995686783728902}], 
             PointBox[{60.9, 0.05696808606553234}], 
             PointBox[{61., 0.0558342507758335}], 
             PointBox[{61.1, 0.058869743724518975`}], 
             PointBox[{61.2, 0.05928023915676309}], 
             PointBox[{61.3, 0.05649976151261556}], 
             PointBox[{61.4, 0.05899287100845229}], 
             PointBox[{61.5, 0.059532032359009945`}], 
             PointBox[{61.6, 0.05923073981553383}], 
             PointBox[{61.7, 0.05736763259907684}], 
             PointBox[{61.8, 0.060546481716375174`}], 
             PointBox[{61.9, 0.059115456966473606`}], 
             PointBox[{62., 0.05648841359584507}], 
             PointBox[{62.1, 0.05835550041586127}], 
             PointBox[{62.2, 0.0607925764390155}], 
             PointBox[{62.3, 0.05780171266508376}], 
             PointBox[{62.4, 0.05870467670175745}], 
             PointBox[{62.5, 0.06012343920143046}], 
             PointBox[{62.6, 0.06041239943729355}], 
             PointBox[{62.7, 0.05792348813354351}], 
             PointBox[{62.8, 0.05978911621686904}], 
             PointBox[{62.9, 0.06072801021344806}], 
             PointBox[{63., 0.05746290676058894}], 
             PointBox[{63.1, 0.05760387182696803}], 
             PointBox[{63.2, 0.060857374517042186`}], 
             PointBox[{63.3, 0.05956450170550412}], 
             PointBox[{63.4, 0.05804959488902839}], 
             PointBox[{63.5, 0.06052023671624016}], 
             PointBox[{63.6, 0.06048419504144367}], 
             PointBox[{63.7, 0.05894235454117291}], 
             PointBox[{63.8, 0.05841432330983343}], 
             PointBox[{63.9, 0.06125773313347964}], 
             PointBox[{64., 0.0585985882928751}], 
             PointBox[{64.1, 0.056977856945675094`}], 
             PointBox[{64.2, 0.05976516649677407}], 
             PointBox[{64.3, 0.06086092537281134}], 
             PointBox[{64.4, 0.0577649526554559}], 
             PointBox[{64.5, 0.0598770133609133}], 
             PointBox[{64.6, 0.06012297396823645}], 
             PointBox[{64.7, 0.059699270049951056`}], 
             PointBox[{64.8, 0.05738076860982786}], 
             PointBox[{64.9, 0.06035196881680207}], 
             PointBox[{65., 0.05955753283795544}], 
             PointBox[{65.1, 0.05665054334850515}], 
             PointBox[{65.2, 0.05805692067741221}], 
             PointBox[{65.3, 0.060880884417995586`}], 
             PointBox[{65.4, 0.058195822111540695`}], 
             PointBox[{65.5, 0.05836506486501272}], 
             PointBox[{65.6, 0.05998085990482348}], 
             PointBox[{65.7, 0.059548631194929987`}], 
             PointBox[{65.8, 0.05707047164516582}], 
             PointBox[{65.9, 0.058242388129754914`}], 
             PointBox[{66., 0.059833581851837764`}], 
             PointBox[{66.1, 0.05662270960303737}], 
             PointBox[{66.2, 0.056223882728111484`}], 
             PointBox[{66.3, 0.05948159246329796}], 
             PointBox[{66.4, 0.05886823765979605}], 
             PointBox[{66.5, 0.056694540344078004`}], 
             PointBox[{66.6, 0.059138279887874255`}], 
             PointBox[{66.7, 0.058502830735577924`}], 
             PointBox[{66.8, 0.057071388994289894`}], 
             PointBox[{66.9, 0.055815163277768046`}], 
             PointBox[{67., 0.058884910350438094`}], 
             PointBox[{67.1, 0.056709231245802204`}], 
             PointBox[{67.2, 0.05460303680089878}], 
             PointBox[{67.3, 0.05706300630570973}], 
             PointBox[{67.4, 0.05879657473088746}], 
             PointBox[{67.5, 0.055592446248363646`}], 
             PointBox[{67.6, 0.05713438153404788}], 
             PointBox[{67.7, 0.05751511151063491}], 
             PointBox[{67.8, 0.05663622836255929}], 
             PointBox[{67.9, 0.053981395457085773`}], 
             PointBox[{68., 0.05649214875576607}], 
             PointBox[{68.1, 0.056509640561706945`}], 
             PointBox[{68.2, 0.05336396703778588}], 
             PointBox[{68.3, 0.054195829168518374`}], 
             PointBox[{68.4, 0.057324697763823616`}], 
             PointBox[{68.5, 0.05520458980407991}], 
             PointBox[{68.6, 0.054462120006239595`}], 
             PointBox[{68.7, 0.05642903825655251}], 
             PointBox[{68.8, 0.05527110059082206}], 
             PointBox[{68.9, 0.05290902980322749}], 
             PointBox[{69., 0.0531554819448501}], 
             PointBox[{69.1, 0.0554432366935543}], 
             PointBox[{69.2, 0.0524826947924318}], 
             PointBox[{69.3, 0.0513873384188548}], 
             PointBox[{69.4, 0.05451121844423585}], 
             PointBox[{69.5, 0.05479061604203069}], 
             PointBox[{69.6, 0.05198597977962966}], 
             PointBox[{69.7, 0.054203686266446664`}], 
             PointBox[{69.8, 0.053487287331235575`}], 
             PointBox[{69.9, 0.05200903415099761}], 
             PointBox[{70., 0.04995858369199958}], 
             PointBox[{70.1, 0.05300727758232547}], 
             PointBox[{70.2, 0.051689000885685336`}], 
             PointBox[{70.3, 0.04900124786025421}], 
             PointBox[{70.4, 0.050892464002084206`}], 
             PointBox[{70.5, 0.05334188722127722}], 
             PointBox[{70.6, 0.050367890047119605`}], 
             PointBox[{70.7, 0.05092690166813462}], 
             PointBox[{70.8, 0.05199597257571519}], 
             PointBox[{70.9, 0.05051553154484578}], 
             PointBox[{71., 0.047701194138140814`}], 
             PointBox[{71.1, 0.04927406198730956}], 
             PointBox[{71.2, 0.05044033027621926}], 
             PointBox[{71.3, 0.047205617300111545`}], 
             PointBox[{71.4, 0.04712943102846265}], 
             PointBox[{71.5, 0.05045021239319385}], 
             PointBox[{71.6, 0.049377567591120615`}], 
             PointBox[{71.7, 0.04745818761956592}], 
             PointBox[{71.8, 0.04973358302755459}], 
             PointBox[{71.9, 0.048320850229798734`}], 
             PointBox[{72., 0.04623345157596355}], 
             PointBox[{72.1, 0.045188075418318305`}], 
             PointBox[{72.2, 0.0480895700720507}], 
             PointBox[{72.3, 0.04588444498622711}], 
             PointBox[{72.4, 0.04381249861201514}], 
             PointBox[{72.5, 0.04646448034801723}], 
             PointBox[{72.6, 0.04796270210489982}], 
             PointBox[{72.7, 0.044805603156033644`}], 
             PointBox[{72.8, 0.046227339952924426`}], 
             PointBox[{72.9, 0.04640303912346426}], 
             PointBox[{73., 0.04473540718389134}], 
             PointBox[{73.1, 0.04199468874387703}], 
             PointBox[{73.2, 0.04438243086196253}], 
             PointBox[{73.3, 0.04455974848052562}], 
             PointBox[{73.4, 0.04134861064454807}], 
             PointBox[{73.5, 0.042140095005815746`}], 
             PointBox[{73.6, 0.04528386342905453}], 
             PointBox[{73.7, 0.04328338583404201}], 
             PointBox[{73.8, 0.042249427781871296`}], 
             PointBox[{73.9, 0.044270146163047655`}], 
             PointBox[{74., 0.04260015532603102}], 
             PointBox[{74.1, 0.040126661440547357`}], 
             PointBox[{74.2, 0.04002653488099141}], 
             PointBox[{74.3, 0.042505084068437136`}], 
             PointBox[{74.4, 0.03980973608658548}], 
             PointBox[{74.5, 0.038314018407032226`}], 
             PointBox[{74.6, 0.041396151117317224`}], 
             PointBox[{74.7, 0.04202817564570749}], 
             PointBox[{74.8, 0.03905758641199819}], 
             PointBox[{74.9, 0.04093626070680222}], 
             PointBox[{75., 0.0405403081217622}], 
             PointBox[{75.1, 0.03889876172001775}], 
             PointBox[{75.2, 0.03650588099348301}], 
             PointBox[{75.3, 0.03924993551697475}], 
             PointBox[{75.4, 0.03878154888019326}], 
             PointBox[{75.5, 0.03568618038872818}], 
             PointBox[{75.6, 0.037081576715915464`}], 
             PointBox[{75.7, 0.03990718737022874}], 
             PointBox[{75.8, 0.037439388856449915`}], 
             PointBox[{75.9, 0.03703215558355576}], 
             PointBox[{76., 0.03879624843050527}], 
             PointBox[{76.1, 0.0373458156862919}], 
             PointBox[{76.2, 0.034796412840891675`}], 
             PointBox[{76.3, 0.03531974231198395}], 
             PointBox[{76.4, 0.03745689290013869}], 
             PointBox[{76.5, 0.034535059999732644`}], 
             PointBox[{76.6, 0.03342399379710853}], 
             PointBox[{76.7, 0.036678999062959364`}], 
             PointBox[{76.8, 0.03676902877867265}], 
             PointBox[{76.9, 0.034037913064367945`}], 
             PointBox[{77., 0.036139937570209196`}], 
             PointBox[{77.1, 0.035693994685930056`}], 
             PointBox[{77.2, 0.03439682323988987}], 
             PointBox[{77.3, 0.03234085444347312}], 
             PointBox[{77.4, 0.03520504234025418}], 
             PointBox[{77.5, 0.03444979199844588}], 
             PointBox[{77.6, 0.0314207000237102}], 
             PointBox[{77.7, 0.03311393444476219}], 
             PointBox[{77.8, 0.035711858114970525`}], 
             PointBox[{77.9, 0.03309969705011521}], 
             PointBox[{78., 0.03302152706564156}], 
             PointBox[{78.1, 0.03474134028173454}], 
             PointBox[{78.2, 0.034036971125993326`}], 
             PointBox[{78.3, 0.03163648841348592}], 
             PointBox[{78.4, 0.032448509506384574`}], 
             PointBox[{78.5, 0.03446647053418629}], 
             PointBox[{78.6, 0.03146564316982956}], 
             PointBox[{78.7, 0.03049213711370943}], 
             PointBox[{78.8, 0.03378135063737262}], 
             PointBox[{78.9, 0.033683854701953474`}], 
             PointBox[{79., 0.03109321829597756}], 
             PointBox[{79.1, 0.03334433028707931}], 
             PointBox[{79.2, 0.03341687615709961}], 
             PointBox[{79.3, 0.03270895472559291}], 
             PointBox[{79.4, 0.030861575915892323`}], 
             PointBox[{79.5, 0.03378462913745707}], 
             PointBox[{79.6, 0.032970428725192284`}], 
             PointBox[{79.7, 0.02994020278748334}], 
             PointBox[{79.8, 0.03169876341981745}], 
             PointBox[{79.9, 0.034223230247847125`}], 
             PointBox[{80., 0.03161583901818467}], 
             PointBox[{80.1, 0.03169191339569762}], 
             PointBox[{80.2, 0.03361168958819888}], 
             PointBox[{80.3, 0.03396910210409263}], 
             PointBox[{80.4, 0.03175969623982017}], 
             PointBox[{80.5, 0.032704903143106645`}], 
             PointBox[{80.6, 0.03471763820402097}], 
             PointBox[{80.7, 0.03167679357014262}], 
             PointBox[{80.8, 0.030740743788670744`}], 
             PointBox[{80.9, 0.03401442954059289}], 
             PointBox[{81., 0.03388332940965285}], 
             PointBox[{81.1, 0.031377044954184447`}], 
             PointBox[{81.2, 0.03380297706270184}], 
             PointBox[{81.3, 0.03467501287887503}], 
             PointBox[{81.4, 0.034429532108346456`}], 
             PointBox[{81.5, 0.0327433069604463}], 
             PointBox[{81.6, 0.03574165552036164}], 
             PointBox[{81.7, 0.034819804716375184`}], 
             PointBox[{81.8, 0.031829541467004084`}], 
             PointBox[{81.9, 0.033640938040836774`}], 
             PointBox[{82., 0.03610349223410716}], 
             PointBox[{82.1, 0.033467313243294855`}], 
             PointBox[{82.2, 0.03377113859743043}], 
             PointBox[{82.3, 0.03593021905331094}], 
             PointBox[{82.4, 0.03713120195455455}], 
             PointBox[{82.5, 0.03498342945090303}], 
             PointBox[{82.6, 0.03616591018609724}], 
             PointBox[{82.7, 0.038041923198288516`}], 
             PointBox[{82.8, 0.03489415665234882}], 
             PointBox[{82.9, 0.03416412067640434}], 
             PointBox[{83., 0.03743066724183606}], 
             PointBox[{83.1, 0.037110189852417375`}], 
             PointBox[{83.2, 0.03477951997563506}], 
             PointBox[{83.3, 0.03743538978916703}], 
             PointBox[{83.4, 0.03891338184152184}], 
             PointBox[{83.5, 0.03866859664789719}], 
             PointBox[{83.6, 0.03724633732363808}], 
             PointBox[{83.7, 0.04034341620900333}], 
             PointBox[{83.8, 0.03902573118337232}], 
             PointBox[{83.9, 0.036242419786567615`}], 
             PointBox[{84., 0.038289665209571576`}], 
             PointBox[{84.1, 0.04052574521735628}], 
             PointBox[{84.2, 0.037722267366709646`}], 
             PointBox[{84.3, 0.038531152724668394`}], 
             PointBox[{84.4, 0.040722248424165115`}], 
             PointBox[{84.5, 0.04221058090393909}], 
             PointBox[{84.6, 0.03998608891164627}], 
             PointBox[{84.7, 0.041660754068147045`}], 
             PointBox[{84.8, 0.043066858180767005`}], 
             PointBox[{84.9, 0.03976949003681056}], 
             PointBox[{85., 0.039546041001374696`}], 
             PointBox[{85.1, 0.042808242095248764`}], 
             PointBox[{85.2, 0.041965077316021254`}], 
             PointBox[{85.3, 0.04007232473667497}], 
             PointBox[{85.4, 0.04291364899539191}], 
             PointBox[{85.5, 0.044612404775709935`}], 
             PointBox[{85.6, 0.043899487055802267`}], 
             PointBox[{85.7, 0.04299197731627651}], 
             PointBox[{85.8, 0.0460810786139474}], 
             PointBox[{85.9, 0.04407868449360915}], 
             PointBox[{86., 0.04176697432250926}], 
             PointBox[{86.1, 0.044229873588684805`}], 
             PointBox[{86.2, 0.045951524456276725`}], 
             PointBox[{86.3, 0.042951754293969274`}], 
             PointBox[{86.4, 0.044534330736013296`}], 
             PointBox[{86.5, 0.046467370335807674`}], 
             PointBox[{86.6, 0.04768465383901814}], 
             PointBox[{86.7, 0.04541636008861993}], 
             PointBox[{86.8, 0.047791871861622925`}], 
             PointBox[{86.9, 0.048293975213561345`}], 
             PointBox[{87., 0.04498735686349016}], 
             PointBox[{87.1, 0.045535015254856814`}], 
             PointBox[{87.2, 0.04868349891367724}], 
             PointBox[{87.3, 0.04700599313345255}], 
             PointBox[{87.4, 0.04597880206430429}], 
             PointBox[{87.5, 0.04873476013083286}], 
             PointBox[{87.6, 0.050341429886927275`}], 
             PointBox[{87.7, 0.04889090925965227}], 
             PointBox[{87.8, 0.048870021935944793`}], 
             PointBox[{87.9, 0.05158169254483001}], 
             PointBox[{88., 0.04882984963458433}], 
             PointBox[{88.1, 0.04730027145150565}], 
             PointBox[{88.2, 0.050219581018249644`}], 
             PointBox[{88.3, 0.05103862408090425}], 
             PointBox[{88.4, 0.048132088917190056`}], 
             PointBox[{88.5, 0.05049935642240293}], 
             PointBox[{88.6, 0.05198240742115728}], 
             PointBox[{88.7, 0.05244296027826307}], 
             PointBox[{88.8, 0.05043625520143852}], 
             PointBox[{88.9, 0.05345689197072971}], 
             PointBox[{89., 0.05269443648940924}], 
             PointBox[{89.1, 0.049718790447528645`}], 
             PointBox[{89.2, 0.051183015549389664`}], 
             PointBox[{89.3, 0.053922770018607756`}], 
             PointBox[{89.4, 0.05133102497464002}], 
             PointBox[{89.5, 0.05159150080566938}], 
             PointBox[{89.6, 0.053811396899271655`}], 
             PointBox[{89.7, 0.05508987745014075}], 
             PointBox[{89.8, 0.052944261552631336`}], 
             PointBox[{89.9, 0.05416603413207463}], 
             PointBox[{90., 0.055892965821290955`}], 
             PointBox[{90.1, 0.05265559945268181}], 
             PointBox[{90.2, 0.05217688394985811}], 
             PointBox[{90.3, 0.055396432075521994`}], 
             PointBox[{90.4, 0.0549116668408021}], 
             PointBox[{90.5, 0.052738036311143856`}], 
             PointBox[{90.6, 0.05547960759869385}], 
             PointBox[{90.7, 0.05650395577276851}], 
             PointBox[{90.8, 0.05584394092696566}], 
             PointBox[{90.9, 0.05466725776715842}], 
             PointBox[{91., 0.05782767400076753}], 
             PointBox[{91.1, 0.05575617220364647}], 
             PointBox[{91.2, 0.05353285742139423}], 
             PointBox[{91.3, 0.05589607728001418}], 
             PointBox[{91.4, 0.057738549361487895`}], 
             PointBox[{91.5, 0.054616777106697365`}], 
             PointBox[{91.6, 0.05624127089612494}], 
             PointBox[{91.7, 0.05757118448527619}], 
             PointBox[{91.8, 0.05823065582484029}], 
             PointBox[{91.9, 0.05583077755929376}], 
             PointBox[{92., 0.058323106775547515`}], 
             PointBox[{92.1, 0.05851435604097868}], 
             PointBox[{92.2, 0.05530874982071596}], 
             PointBox[{92.3, 0.0560259120694795}], 
             PointBox[{92.4, 0.05915406767144414}], 
             PointBox[{92.5, 0.05720689995348664}], 
             PointBox[{92.6, 0.056461378383487505`}], 
             PointBox[{92.7, 0.05884515431719613}], 
             PointBox[{92.8, 0.05948361314534242}], 
             PointBox[{92.9, 0.057664929318133114`}], 
             PointBox[{93., 0.05792323699888178}], 
             PointBox[{93.1, 0.060347858288777784`}], 
             PointBox[{93.2, 0.057354059592999204`}], 
             PointBox[{93.3, 0.056232629706414246`}], 
             PointBox[{93.4, 0.05927200648773412}], 
             PointBox[{93.5, 0.059668672284271994`}], 
             PointBox[{93.6, 0.05689174221115302}], 
             PointBox[{93.7, 0.059378688235187646`}], 
             PointBox[{93.8, 0.05983966248871482}], 
             PointBox[{93.9, 0.059484586166551744`}], 
             PointBox[{94., 0.05762152283074315}], 
             PointBox[{94.1, 0.06080167027578061}], 
             PointBox[{94.2, 0.059347949805537765`}], 
             PointBox[{94.3, 0.05673495109915407}], 
             PointBox[{94.4, 0.058616160895015666`}], 
             PointBox[{94.5, 0.061041462921752714`}], 
             PointBox[{94.6, 0.058036804659843205`}], 
             PointBox[{94.7, 0.058956893507224245`}], 
             PointBox[{94.8, 0.060325051742692766`}], 
             PointBox[{94.9, 0.06053044767435999}], 
             PointBox[{95., 0.05802260907545915}], 
             PointBox[{95.1, 0.05990860411129029}], 
             PointBox[{95.2, 0.0608163127414598}], 
             PointBox[{95.3, 0.05755444476401637}], 
             PointBox[{95.4, 0.05771705550266262}], 
             PointBox[{95.5, 0.06097133465643199}], 
             PointBox[{95.6, 0.0596474689801043}], 
             PointBox[{95.7, 0.058156393078479196`}], 
             PointBox[{95.8, 0.06060328509698351}], 
             PointBox[{95.9, 0.0604813845879061}], 
             PointBox[{96., 0.058893129924239826`}], 
             PointBox[{96.1, 0.05838779478835973}], 
             PointBox[{96.2, 0.06121232869004803}], 
             PointBox[{96.3, 0.05853855194667907}], 
             PointBox[{96.4, 0.056938522661094636`}], 
             PointBox[{96.5, 0.05974083684238531}], 
             PointBox[{96.6, 0.06080653409826422}], 
             PointBox[{96.7, 0.05771642986016181}], 
             PointBox[{96.8, 0.059832353028087856`}], 
             PointBox[{96.9, 0.060013258977539445`}], 
             PointBox[{97., 0.05951659882742274}], 
             PointBox[{97.1, 0.057199969851083464`}], 
             PointBox[{97.2, 0.06017844444395503}], 
             PointBox[{97.3, 0.05935614711166573}], 
             PointBox[{97.4, 0.05646014748881531}], 
             PointBox[{97.5, 0.057888696130501203`}], 
             PointBox[{97.6, 0.060699509445119586`}], 
             PointBox[{97.7, 0.057995255576708295`}], 
             PointBox[{97.8, 0.058184705915446354`}], 
             PointBox[{97.9, 0.059764160715149915`}], 
             PointBox[{98., 0.059247960389333304`}], 
             PointBox[{98.1, 0.05674259379486228}], 
             PointBox[{98.2, 0.05793685481243865}], 
             PointBox[{98.3, 0.05950206849418209}], 
             PointBox[{98.4, 0.05628994335641442}], 
             PointBox[{98.5, 0.05590932628225666}], 
             PointBox[{98.6, 0.05917294435995061}], 
             PointBox[{98.7, 0.05853086827354033}], 
             PointBox[{98.8, 0.05637308768775516}], 
             PointBox[{98.9, 0.058803396078058}], 
             PointBox[{99., 0.05809899648747561}], 
             PointBox[{99.1, 0.056615325005581384`}], 
             PointBox[{99.2, 0.055371694831651656`}], 
             PointBox[{99.3, 0.05843039227392761}], 
             PointBox[{99.4, 0.056247278057738305`}], 
             PointBox[{99.5, 0.054148663204705835`}], 
             PointBox[{99.6, 0.05662223444018602}], 
             PointBox[{99.7, 0.058338212153266594`}], 
             PointBox[{99.8, 0.055134403865223613`}], 
             PointBox[{99.9, 0.05667358584835519}], 
             PointBox[{100., 0.05702180728488508}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 0.2}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 180.}], 
             PointBox[{0.1, 186.16945971352018`}], 
             PointBox[{0.2, 185.5620286627668}], 
             PointBox[{0.3, 185.03703131602978`}], 
             PointBox[{0.4, 188.1734338057672}], 
             PointBox[{0.5, 186.7533017448917}], 
             PointBox[{0.6, 184.01415091949488`}], 
             PointBox[{0.7, 185.86520685007784`}], 
             PointBox[{0.8, 187.70147804422982`}], 
             PointBox[{0.9, 185.4307022720043}], 
             PointBox[{1., 189.42517824963136`}], 
             PointBox[{1.1, 196.66733607524287`}], 
             PointBox[{1.2, 198.86202037634104`}], 
             PointBox[{1.3, 196.6259106333319}], 
             PointBox[{1.4, 199.60475497121914`}], 
             PointBox[{1.5, 200.09593366212985`}], 
             PointBox[{1.6, 196.96430474269687`}], 
             PointBox[{1.7, 196.86464982623187`}], 
             PointBox[{1.8, 200.0972544063163}], 
             PointBox[{1.9, 198.19332104426357`}], 
             PointBox[{2., 199.38774744943512`}], 
             PointBox[{2.1, 206.37041885432743`}], 
             PointBox[{2.2, 211.37941303910094`}], 
             PointBox[{2.3, 209.40126659331594`}], 
             PointBox[{2.4, 210.58551901376654`}], 
             PointBox[{2.5, 212.96859659998998`}], 
             PointBox[{2.6, 210.49244324615427`}], 
             PointBox[{2.7, 208.5476076117248}], 
             PointBox[{2.8, 211.5023250042443}], 
             PointBox[{2.9, 211.7131873178034}], 
             PointBox[{3., 210.33316773114205`}], 
             PointBox[{3.1, 215.81582646862498`}], 
             PointBox[{3.2, 222.78279861463258`}], 
             PointBox[{3.3, 223.04986677397739`}], 
             PointBox[{3.4, 221.79900877348155`}], 
             PointBox[{3.5, 225.16887895658815`}], 
             PointBox[{3.6, 224.30026565386413`}], 
             PointBox[{3.7, 221.18559224202588`}], 
             PointBox[{3.8, 222.53104862644176`}], 
             PointBox[{3.9, 225.07302802120233`}], 
             PointBox[{4., 222.5801273020209}], 
             PointBox[{4.1, 225.59131246596849`}], 
             PointBox[{4.2, 233.1475818155886}], 
             PointBox[{4.3, 236.62185159492256`}], 
             PointBox[{4.4, 234.09788517241302`}], 
             PointBox[{4.5, 236.73700378074142`}], 
             PointBox[{4.6, 238.01698561551427`}], 
             PointBox[{4.7, 234.79142801940978`}], 
             PointBox[{4.8, 233.98523530324738`}], 
             PointBox[{4.9, 237.51276492033742`}], 
             PointBox[{5., 236.15709526926673`}], 
             PointBox[{5.1, 236.20751069634073`}], 
             PointBox[{5.2, 242.91044890095978`}], 
             PointBox[{5.3, 249.29970917361086`}], 
             PointBox[{5.4, 247.87064536575906`}], 
             PointBox[{5.5, 248.13981521098572`}], 
             PointBox[{5.6, 251.27562104080107`}], 
             PointBox[{5.7, 249.17376849290451`}], 
             PointBox[{5.8, 246.46204001190424`}], 
             PointBox[{5.9, 249.1519878067321}], 
             PointBox[{6., 250.43543847850341`}], 
             PointBox[{6.1, 248.15861165821224`}], 
             PointBox[{6.2, 252.8122666515441}], 
             PointBox[{6.3, 260.7856048507411}], 
             PointBox[{6.4, 262.5049098866757}], 
             PointBox[{6.5, 260.31252708397386`}], 
             PointBox[{6.6, 263.87397087446146`}], 
             PointBox[{6.7, 263.9533887236221}], 
             PointBox[{6.8, 260.2674556928051}], 
             PointBox[{6.9, 260.81481152675934`}], 
             PointBox[{7., 264.2929832469546}], 
             PointBox[{7.1, 261.8298861068927}], 
             PointBox[{7.2, 263.4631479712311}], 
             PointBox[{7.3, 271.29261302672484`}], 
             PointBox[{7.4, 276.81401865905207`}], 
             PointBox[{7.5, 274.2284049952582}], 
             PointBox[{7.6, 276.0389740278313}], 
             PointBox[{7.7, 278.61661581864075`}], 
             PointBox[{7.8, 275.42176713541363`}], 
             PointBox[{7.9, 273.4291663491144}], 
             PointBox[{8., 277.16666040272787`}], 
             PointBox[{8.1, 277.03781533086635`}], 
             PointBox[{8.2, 275.47716476405753`}], 
             PointBox[{8.3, 281.6509979202418}], 
             PointBox[{8.4, 289.95200452159156`}], 
             PointBox[{8.5, 289.96217891431013`}], 
             PointBox[{8.6, 288.6578246226595}], 
             PointBox[{8.7, 292.7112143861939}], 
             PointBox[{8.8, 291.6140169856344}], 
             PointBox[{8.9, 287.6988508120738}], 
             PointBox[{9., 289.6349725741551}], 
             PointBox[{9.1, 292.6235354145508}], 
             PointBox[{9.2, 289.54792819342697`}], 
             PointBox[{9.3, 292.7408048902293}], 
             PointBox[{9.4, 301.78066874434336`}], 
             PointBox[{9.5, 306.2816022398945}], 
             PointBox[{9.6, 303.1120324786068}], 
             PointBox[{9.7, 306.2172875712942}], 
             PointBox[{9.8, 308.17997416143993`}], 
             PointBox[{9.9, 303.9895308304945}], 
             PointBox[{10., 302.89251920703293`}], 
             PointBox[{10.1, 307.3455671600224}], 
             PointBox[{10.2, 305.9663623415004}], 
             PointBox[{10.3, 305.29398379953125`}], 
             PointBox[{10.4, 313.0592173305782}], 
             PointBox[{10.5, 321.674238026396}], 
             PointBox[{10.6, 320.246546942264}], 
             PointBox[{10.7, 319.9557729108886}], 
             PointBox[{10.8, 324.3354109046698}], 
             PointBox[{10.9, 322.1412127481565}], 
             PointBox[{11., 318.11848731787813`}], 
             PointBox[{11.1, 321.31148090624816`}], 
             PointBox[{11.2, 323.7023948719513}], 
             PointBox[{11.3, 320.304694319373}], 
             PointBox[{11.4, 325.0413821255872}], 
             PointBox[{11.5, 335.4787313257345}], 
             PointBox[{11.6, 339.04020020878676`}], 
             PointBox[{11.7, 335.6263455583349}], 
             PointBox[{11.8, 339.75759398783464`}], 
             PointBox[{11.9, 341.2494702976527}], 
             PointBox[{12., 336.1259820932994}], 
             PointBox[{12.1, 335.88034908605783`}], 
             PointBox[{12.2, 340.8430204743371}], 
             PointBox[{12.3, 338.50450571477734`}], 
             PointBox[{12.4, 338.6765057236335}], 
             PointBox[{12.5, 348.25455741138876`}], 
             PointBox[{12.6, 357.1937925533042}], 
             PointBox[{12.7, 354.71398704501917`}], 
             PointBox[{12.8, 355.2118823001313}], 
             PointBox[{12.9, 359.9602340445689}], 
             PointBox[{13., 356.86242683134753`}], 
             PointBox[{13.1, 352.70388250702536`}], 
             PointBox[{13.2, 356.87159406869614`}], 
             PointBox[{13.3, 358.86325464458815`}], 
             PointBox[{13.4, 355.2322349996561}], 
             PointBox[{13.5, 1.5027443279777744`}], 
             PointBox[{13.6, 13.333526939878979`}], 
             PointBox[{13.7, 16.22423266862333}], 
             PointBox[{13.8, 12.640992871407981`}], 
             PointBox[{13.9, 17.503143847260432`}], 
             PointBox[{14., 18.818804690392067`}], 
             PointBox[{14.1, 12.921931321657345`}], 
             PointBox[{14.2, 13.210472642384264`}], 
             PointBox[{14.3, 18.571303741468878`}], 
             PointBox[{14.4, 15.643023478654664`}], 
             PointBox[{14.5, 16.47850599427102}], 
             PointBox[{14.6, 27.80491515983788}], 
             PointBox[{14.7, 36.80393066879235}], 
             PointBox[{14.8, 33.72915109915309}], 
             PointBox[{14.9, 34.5857704399824}], 
             PointBox[{15., 39.68784807451733}], 
             PointBox[{15.1, 36.116681099971856`}], 
             PointBox[{15.2, 31.775095838915114`}], 
             PointBox[{15.3, 36.42929424627381}], 
             PointBox[{15.4, 38.31847400206828}], 
             PointBox[{15.5, 34.55165041426426}], 
             PointBox[{15.6, 42.06843227558426}], 
             PointBox[{15.7, 54.45438511950749}], 
             PointBox[{15.8, 56.862800822114295`}], 
             PointBox[{15.9, 53.19767846573576}], 
             PointBox[{16., 58.325547495429724`}], 
             PointBox[{16.1, 59.65612125908734}], 
             PointBox[{16.2, 53.4927834395749}], 
             PointBox[{16.3, 53.89723121797046}], 
             PointBox[{16.4, 59.36490188914047}], 
             PointBox[{16.5, 56.27589883166827}], 
             PointBox[{16.6, 57.57366752554435}], 
             PointBox[{16.7, 69.62341006461114}], 
             PointBox[{16.8, 77.87565236924753}], 
             PointBox[{16.9, 74.65674079433401}], 
             PointBox[{17., 75.59210706124618}], 
             PointBox[{17.1, 80.65103541153519}], 
             PointBox[{17.2, 77.07348897217742}], 
             PointBox[{17.3, 72.84586303612393}], 
             PointBox[{17.4, 77.41337206319794}], 
             PointBox[{17.5, 79.17764501552428}], 
             PointBox[{17.6, 75.61613440665552}], 
             PointBox[{17.7, 83.66961151564044}], 
             PointBox[{17.8, 95.07180552207082}], 
             PointBox[{17.9, 96.85253003361166}], 
             PointBox[{18., 93.45963559698345}], 
             PointBox[{18.1, 98.41525910309936}], 
             PointBox[{18.2, 99.48644602077508}], 
             PointBox[{18.3, 93.73702935363717}], 
             PointBox[{18.4, 94.21069839223739}], 
             PointBox[{18.5, 99.27405363836542}], 
             PointBox[{18.6, 96.23240389369151}], 
             PointBox[{18.7, 98.05905299467793}], 
             PointBox[{18.8, 109.41145603256807`}], 
             PointBox[{18.9, 116.18776205021115`}], 
             PointBox[{19., 113.02416436511307`}], 
             PointBox[{19.1, 114.22192586712472`}], 
             PointBox[{19.2, 118.65947112280077`}], 
             PointBox[{19.3, 115.14457320187617`}], 
             PointBox[{19.4, 111.59022887853776`}], 
             PointBox[{19.5, 115.84852902161661`}], 
             PointBox[{19.6, 117.05967195129375`}], 
             PointBox[{19.7, 114.1646708990985}], 
             PointBox[{19.8, 122.22582093026125`}], 
             PointBox[{19.9, 131.81253140303284`}], 
             PointBox[{20., 132.70040607597574`}], 
             PointBox[{20.1, 129.98483126987506`}], 
             PointBox[{20.2, 134.6426991730791}], 
             PointBox[{20.3, 134.96924627094396`}], 
             PointBox[{20.4, 129.97936073524116`}], 
             PointBox[{20.5, 130.8391729011117}], 
             PointBox[{20.6, 135.13085898715096`}], 
             PointBox[{20.7, 132.0710390330909}], 
             PointBox[{20.8, 134.76490145128827`}], 
             PointBox[{20.9, 144.83951608956892`}], 
             PointBox[{21., 149.97935226808684`}], 
             PointBox[{21.1, 146.86853283254965`}], 
             PointBox[{21.2, 148.6876644843347}], 
             PointBox[{21.3, 152.10492286389916`}], 
             PointBox[{21.4, 148.5179301284055}], 
             PointBox[{21.5, 145.98817337779417`}], 
             PointBox[{21.6, 150.0390097222058}], 
             PointBox[{21.7, 150.27139690514122`}], 
             PointBox[{21.8, 148.44530315098655`}], 
             PointBox[{21.9, 156.42855772756693`}], 
             PointBox[{22., 164.26275257258658`}], 
             PointBox[{22.1, 164.10616172775966`}], 
             PointBox[{22.2, 162.3815122215149}], 
             PointBox[{22.3, 166.6896117248496}], 
             PointBox[{22.4, 165.99718502716877`}], 
             PointBox[{22.5, 161.8493746089288}], 
             PointBox[{22.6, 163.3703141201249}], 
             PointBox[{22.7, 166.67001140025025`}], 
             PointBox[{22.8, 163.63848174499418`}], 
             PointBox[{22.9, 167.48878981444483`}], 
             PointBox[{23., 176.34862946152597`}], 
             PointBox[{23.1, 179.8986476328441}], 
             PointBox[{23.2, 176.9206473693299}], 
             PointBox[{23.3, 179.54317494626244`}], 
             PointBox[{23.4, 181.69259934385983`}], 
             PointBox[{23.5, 178.03088458644118`}], 
             PointBox[{23.6, 176.6581089033306}], 
             PointBox[{23.7, 180.55477700224267`}], 
             PointBox[{23.8, 179.60586803147024`}], 
             PointBox[{23.9, 179.22985372654023`}], 
             PointBox[{24., 187.14455783549118`}], 
             PointBox[{24.1, 193.45490010076736`}], 
             PointBox[{24.2, 192.23324766377362`}], 
             PointBox[{24.3, 191.79385350374096`}], 
             PointBox[{24.4, 195.52017677630235`}], 
             PointBox[{24.5, 193.8033731836376}], 
             PointBox[{24.6, 190.56649635039972`}], 
             PointBox[{24.7, 192.85505032232388`}], 
             PointBox[{24.8, 194.88909901854564`}], 
             PointBox[{24.9, 192.26808347830058`}], 
             PointBox[{25., 197.3336194343297}], 
             PointBox[{25.1, 205.12580808467928`}], 
             PointBox[{25.2, 207.06757525292207`}], 
             PointBox[{25.3, 204.55373174807372`}], 
             PointBox[{25.4, 207.84161353834833`}], 
             PointBox[{25.5, 208.58077880826062`}], 
             PointBox[{25.6, 205.0116122470432}], 
             PointBox[{25.7, 204.86184412176203`}], 
             PointBox[{25.8, 208.40819903312544`}], 
             PointBox[{25.9, 206.40885169980854`}], 
             PointBox[{26., 207.7849757166837}], 
             PointBox[{26.1, 215.5594454420718}], 
             PointBox[{26.2, 220.39219298999447`}], 
             PointBox[{26.3, 218.2903483075261}], 
             PointBox[{26.4, 219.33381502378808`}], 
             PointBox[{26.5, 222.09276083980083`}], 
             PointBox[{26.6, 219.55195458856141`}], 
             PointBox[{26.7, 217.35504482401205`}], 
             PointBox[{26.8, 220.3314492974167}], 
             PointBox[{26.9, 220.807403829249}], 
             PointBox[{27., 219.23742624227617`}], 
             PointBox[{27.1, 225.33425213326413`}], 
             PointBox[{27.2, 232.09441482595383`}], 
             PointBox[{27.3, 232.38264876713424`}], 
             PointBox[{27.4, 230.8932740161833}], 
             PointBox[{27.5, 234.3640654398733}], 
             PointBox[{27.6, 233.71165623115687`}], 
             PointBox[{27.7, 230.50607049386426`}], 
             PointBox[{27.8, 231.6114247431382}], 
             PointBox[{27.9, 234.33202552151934`}], 
             PointBox[{28., 231.85674966411804`}], 
             PointBox[{28.1, 235.0553000627312}], 
             PointBox[{28.2, 242.5479577036777}], 
             PointBox[{28.3, 245.750827755284}], 
             PointBox[{28.4, 243.29207411541634`}], 
             PointBox[{28.5, 245.69014097677837`}], 
             PointBox[{28.6, 247.13681115827586`}], 
             PointBox[{28.7, 244.10638150089807`}], 
             PointBox[{28.8, 243.12157949963085`}], 
             PointBox[{28.9, 246.4434562784931}], 
             PointBox[{29., 245.33615102814326`}], 
             PointBox[{29.1, 245.42098835922445`}], 
             PointBox[{29.2, 252.22584352973874`}], 
             PointBox[{29.3, 257.82754195170304`}], 
             PointBox[{29.4, 256.5934976866926}], 
             PointBox[{29.5, 256.657707024528}], 
             PointBox[{29.6, 259.64232115750036`}], 
             PointBox[{29.7, 257.80323006357173`}], 
             PointBox[{29.8, 255.28270605474387`}], 
             PointBox[{29.9, 257.5564992688988}], 
             PointBox[{30., 258.8647286442779}], 
             PointBox[{30.1, 256.82743677451714`}], 
             PointBox[{30.2, 261.6362022397555}], 
             PointBox[{30.3, 268.65479283462696`}], 
             PointBox[{30.4, 270.0236937609247}], 
             PointBox[{30.5, 268.05583215854904`}], 
             PointBox[{30.6, 271.2388671384639}], 
             PointBox[{30.7, 271.24150280505626`}], 
             PointBox[{30.8, 268.12223966553944`}], 
             PointBox[{30.9, 268.5036245417879}], 
             PointBox[{31., 271.5238366383038}], 
             PointBox[{31.1, 269.34289340121495`}], 
             PointBox[{31.2, 271.35634949922564`}], 
             PointBox[{31.3, 278.54258071298995`}], 
             PointBox[{31.4, 282.69511917503166`}], 
             PointBox[{31.5, 280.47114863472393`}], 
             PointBox[{31.6, 282.1974262304484}], 
             PointBox[{31.7, 284.1280170251977}], 
             PointBox[{31.8, 281.4409611060015}], 
             PointBox[{31.9, 279.9389187519734}], 
             PointBox[{32., 283.0387716709846}], 
             PointBox[{32.1, 282.630018285489}], 
             PointBox[{32.2, 281.8959919732175}], 
             PointBox[{32.3, 287.9411417491976}], 
             PointBox[{32.4, 294.22552753037434`}], 
             PointBox[{32.5, 293.74962523236866`}], 
             PointBox[{32.6, 293.1109817330464}], 
             PointBox[{32.7, 296.2784613621893}], 
             PointBox[{32.8, 294.94129859345526`}], 
             PointBox[{32.9, 292.1550472033017}], 
             PointBox[{33., 293.9245173495214}], 
             PointBox[{33.1, 295.86515751215217`}], 
             PointBox[{33.2, 293.55565009503266`}], 
             PointBox[{33.3, 297.3930252257452}], 
             PointBox[{33.4, 304.6760172732715}], 
             PointBox[{33.5, 307.04726098210244`}], 
             PointBox[{33.6, 304.7638500932861}], 
             PointBox[{33.7, 307.69753668409317`}], 
             PointBox[{33.8, 308.29362998862445`}], 
             PointBox[{33.9, 305.15445331350725`}], 
             PointBox[{34., 304.9565394910037}], 
             PointBox[{34.1, 308.2308983257214}], 
             PointBox[{34.2, 306.3936043049524}], 
             PointBox[{34.3, 307.4235896532581}], 
             PointBox[{34.4, 314.36046410324866`}], 
             PointBox[{34.5, 319.5554431449805}], 
             PointBox[{34.6, 317.6397718368764}], 
             PointBox[{34.7, 318.7052504006955}], 
             PointBox[{34.8, 321.18777571656284`}], 
             PointBox[{34.9, 318.75683930892666`}], 
             PointBox[{35., 316.71443593124553`}], 
             PointBox[{35.1, 319.6372052230512}], 
             PointBox[{35.2, 319.9854819452275}], 
             PointBox[{35.3, 318.4753361021428}], 
             PointBox[{35.4, 323.841332617636}], 
             PointBox[{35.5, 330.94949672445654`}], 
             PointBox[{35.6, 331.39059799139494`}], 
             PointBox[{35.7, 330.01028581491596`}], 
             PointBox[{35.8, 333.41827370409715`}], 
             PointBox[{35.9, 332.6596388931631}], 
             PointBox[{36., 329.47028632552644`}], 
             PointBox[{36.1, 330.7205314763991}], 
             PointBox[{36.2, 333.3906013093589}], 
             PointBox[{36.3, 330.87523483216904`}], 
             PointBox[{36.4, 333.7092810651821}], 
             PointBox[{36.5, 341.3121840224524}], 
             PointBox[{36.6, 345.04103077559995`}], 
             PointBox[{36.7, 342.4814698461225}], 
             PointBox[{36.8, 345.03965246374355`}], 
             PointBox[{36.9, 346.47910405115744`}], 
             PointBox[{37., 343.2398278683422}], 
             PointBox[{37.1, 342.2927535876219}], 
             PointBox[{37.2, 345.86575314687474`}], 
             PointBox[{37.3, 344.63831422001}], 
             PointBox[{37.4, 344.47695260628944`}], 
             PointBox[{37.5, 351.121237360473}], 
             PointBox[{37.6, 357.7698114595408}], 
             PointBox[{37.7, 356.4791474862563}], 
             PointBox[{37.8, 356.55969028631864`}], 
             PointBox[{37.9, 359.8335114170965}], 
             PointBox[{38., 357.8246332040014}], 
             PointBox[{38.1, 354.9592912075212}], 
             PointBox[{38.2, 357.58204325326176`}], 
             PointBox[{38.3, 359.08033167443176`}], 
             PointBox[{38.4, 356.6586970029307}], 
             PointBox[{38.5, 1.147905714283185}], 
             PointBox[{38.6, 9.288779705759856}], 
             PointBox[{38.7, 11.32466879126219}], 
             PointBox[{38.8, 8.969307057003144}], 
             PointBox[{38.9, 12.530694257218308`}], 
             PointBox[{39., 12.821594064559596`}], 
             PointBox[{39.1, 9.036749930419306}], 
             PointBox[{39.2, 9.407519643120395}], 
             PointBox[{39.3, 13.046200844612702`}], 
             PointBox[{39.4, 10.647638610424902`}], 
             PointBox[{39.5, 12.00405579817976}], 
             PointBox[{39.6, 19.858744657268705`}], 
             PointBox[{39.7, 25.785741546044374`}], 
             PointBox[{39.8, 23.254133131311022`}], 
             PointBox[{39.9, 24.851701497302162`}], 
             PointBox[{40., 27.683500598164635`}], 
             PointBox[{40.1, 24.54086455371931}], 
             PointBox[{40.2, 22.29954247834504}], 
             PointBox[{40.3, 26.03350755255822}], 
             PointBox[{40.4, 26.191122991020084`}], 
             PointBox[{40.5, 24.341987808052135`}], 
             PointBox[{40.6, 30.388535457697344`}], 
             PointBox[{40.7, 39.01935710596522}], 
             PointBox[{40.8, 39.39604968094545}], 
             PointBox[{40.9, 37.78231828907032}], 
             PointBox[{41., 41.95176238433593}], 
             PointBox[{41.1, 41.1180422888512}], 
             PointBox[{41.2, 36.986357421561735`}], 
             PointBox[{41.3, 38.718118415265884`}], 
             PointBox[{41.4, 42.01804289922271}], 
             PointBox[{41.5, 38.893187330066176`}], 
             PointBox[{41.6, 41.75914202980948}], 
             PointBox[{41.7, 50.94489476339895}], 
             PointBox[{41.8, 56.02616669956637}], 
             PointBox[{41.9, 52.77552566566237}], 
             PointBox[{42., 55.67260791562208}], 
             PointBox[{42.1, 58.026571124369354`}], 
             PointBox[{42.2, 53.83049405851882}], 
             PointBox[{42.3, 52.36485142763949}], 
             PointBox[{42.4, 56.91426895121077}], 
             PointBox[{42.5, 55.87591818504851}], 
             PointBox[{42.6, 54.757482363215274`}], 
             PointBox[{42.7, 62.44827621605936}], 
             PointBox[{42.8, 71.59379531553532}], 
             PointBox[{42.9, 70.57118862797711}], 
             PointBox[{43., 69.81252096933075}], 
             PointBox[{43.1, 74.44005746207479}], 
             PointBox[{43.2, 72.58449813745398}], 
             PointBox[{43.3, 68.19448224154348}], 
             PointBox[{43.4, 71.15073444961972}], 
             PointBox[{43.5, 74.03055146030768}], 
             PointBox[{43.6, 70.44675330214285}], 
             PointBox[{43.7, 74.79980941479567}], 
             PointBox[{43.8, 85.52010677082471}], 
             PointBox[{43.9, 89.84859767163127}], 
             PointBox[{44., 86.19760810492554}], 
             PointBox[{44.1, 90.11233316347665}], 
             PointBox[{44.2, 92.16102000268046}], 
             PointBox[{44.3, 86.98952155367836}], 
             PointBox[{44.4, 86.21896180661254}], 
             PointBox[{44.5, 91.38013893940462}], 
             PointBox[{44.6, 89.44979939589389}], 
             PointBox[{44.7, 89.00080530363232}], 
             PointBox[{44.8, 98.5289346122936}], 
             PointBox[{44.9, 108.1632500509226}], 
             PointBox[{45., 106.14402915937985`}], 
             PointBox[{45.1, 105.99949196604744`}], 
             PointBox[{45.2, 111.09309259964343`}], 
             PointBox[{45.3, 108.46878154412863`}], 
             PointBox[{45.4, 103.79698171766623`}], 
             PointBox[{45.5, 107.64963510217999`}], 
             PointBox[{45.6, 110.30456005361687`}], 
             PointBox[{45.7, 106.382488627154}], 
             PointBox[{45.8, 112.15193349084637`}], 
             PointBox[{45.9, 124.29876647380819`}], 
             PointBox[{46., 128.0874978863997}], 
             PointBox[{46.1, 124.16539908640601`}], 
             PointBox[{46.2, 128.72987689423437`}], 
             PointBox[{46.3, 130.74751528202577`}], 
             PointBox[{46.4, 124.85717059795334`}], 
             PointBox[{46.5, 124.44909024485374`}], 
             PointBox[{46.6, 130.02982123520104`}], 
             PointBox[{46.7, 127.61829099283011`}], 
             PointBox[{46.8, 127.66054043235422`}], 
             PointBox[{46.9, 138.81898598328183`}], 
             PointBox[{47., 148.47268453565746`}], 
             PointBox[{47.1, 145.93895471270673`}], 
             PointBox[{47.2, 146.01959843927267`}], 
             PointBox[{47.3, 151.4367091767796}], 
             PointBox[{47.4, 148.5008831023697}], 
             PointBox[{47.5, 143.62421275943876`}], 
             PointBox[{47.6, 147.8248111928706}], 
             PointBox[{47.7, 150.45012764007714`}], 
             PointBox[{47.8, 146.39314611781256`}], 
             PointBox[{47.9, 153.2054478191241}], 
             PointBox[{48., 165.70873903903015`}], 
             PointBox[{48.1, 168.97104746016322`}], 
             PointBox[{48.2, 165.00241313895287`}], 
             PointBox[{48.3, 169.71572526734815`}], 
             PointBox[{48.4, 171.7362682723575}], 
             PointBox[{48.5, 165.73645761891177`}], 
             PointBox[{48.6, 165.39157744060375`}], 
             PointBox[{48.7, 170.97353748982061`}], 
             PointBox[{48.8, 168.46696186761972`}], 
             PointBox[{48.9, 168.90722933374232`}], 
             PointBox[{49., 180.54964072110104`}], 
             PointBox[{49.1, 189.22655069914305`}], 
             PointBox[{49.2, 186.55440819887454`}], 
             PointBox[{49.3, 186.75050834205814`}], 
             PointBox[{49.4, 191.99033590232696`}], 
             PointBox[{49.5, 189.06006111984172`}], 
             PointBox[{49.6, 184.4497618590549}], 
             PointBox[{49.7, 188.50015485027419`}], 
             PointBox[{49.8, 190.89357265262535`}], 
             PointBox[{49.9, 187.11582587278573`}], 
             PointBox[{50., 194.3557999135612}], 
             PointBox[{50.1, 205.67568805485377`}], 
             PointBox[{50.2, 208.1231349918944}], 
             PointBox[{50.3, 204.5177698966562}], 
             PointBox[{50.4, 209.06623841198277`}], 
             PointBox[{50.5, 210.66183439698827`}], 
             PointBox[{50.6, 205.14649452639608`}], 
             PointBox[{50.7, 205.00769329340392`}], 
             PointBox[{50.8, 210.09287745654396`}], 
             PointBox[{50.9, 207.53773103564748`}], 
             PointBox[{51., 208.61168652258624`}], 
             PointBox[{51.1, 219.4972384643954}], 
             PointBox[{51.2, 226.54156956005164`}], 
             PointBox[{51.3, 223.80214073901385`}], 
             PointBox[{51.4, 224.42871510363256`}], 
             PointBox[{51.5, 228.96904794919047`}], 
             PointBox[{51.6, 225.94830065940494`}], 
             PointBox[{51.7, 222.15669726951316`}], 
             PointBox[{51.8, 225.9932312186889}], 
             PointBox[{51.9, 227.66929177799295`}], 
             PointBox[{52., 224.58293494335885`}], 
             PointBox[{52.1, 231.95149616163064`}], 
             PointBox[{52.2, 241.45536328334117`}], 
             PointBox[{52.3, 242.82996533305123`}], 
             PointBox[{52.4, 239.9315779787565}], 
             PointBox[{52.5, 244.30902851392105`}], 
             PointBox[{52.6, 244.99941290850543`}], 
             PointBox[{52.7, 240.1807408545326}], 
             PointBox[{52.8, 240.60842548066609`}], 
             PointBox[{52.9, 244.93132500244147`}], 
             PointBox[{53., 242.17486767956467`}], 
             PointBox[{53.1, 244.2835664022048}], 
             PointBox[{53.2, 254.0266132922339}], 
             PointBox[{53.3, 259.38929922483663`}], 
             PointBox[{53.4, 256.53376877201663`}], 
             PointBox[{53.5, 257.95697418050196`}], 
             PointBox[{53.6, 261.4714850700234}], 
             PointBox[{53.7, 258.2051560627037}], 
             PointBox[{53.8, 255.5000484331954}], 
             PointBox[{53.9, 259.2810580692437}], 
             PointBox[{54., 259.8483091110805}], 
             PointBox[{54.1, 257.81287344962675`}], 
             PointBox[{54.2, 265.31758248172804`}], 
             PointBox[{54.3, 273.1444952863105}], 
             PointBox[{54.4, 273.3336366967642}], 
             PointBox[{54.5, 271.4219679860637}], 
             PointBox[{54.6, 275.5905597431507}], 
             PointBox[{54.7, 275.1492526555382}], 
             PointBox[{54.8, 271.079110886631}], 
             PointBox[{54.9, 272.30754543681945`}], 
             PointBox[{55., 275.68756484484595`}], 
             PointBox[{55.1, 272.78742262265234`}], 
             PointBox[{55.2, 276.21004122557713`}], 
             PointBox[{55.3, 284.8960629255446}], 
             PointBox[{55.4, 288.65114391934907`}], 
             PointBox[{55.5, 285.7768550923236}], 
             PointBox[{55.6, 288.1521085389808}], 
             PointBox[{55.7, 290.4043512098064}], 
             PointBox[{55.8, 286.92892255657983`}], 
             PointBox[{55.9, 285.4065371011136}], 
             PointBox[{56., 289.1690693380077}], 
             PointBox[{56.1, 288.44363884028826`}], 
             PointBox[{56.2, 287.8544937121954}], 
             PointBox[{56.3, 295.4790197310882}], 
             PointBox[{56.4, 301.84339921815683`}], 
             PointBox[{56.5, 300.8442156522874}], 
             PointBox[{56.6, 300.2309117506203}], 
             PointBox[{56.7, 303.9184607788703}], 
             PointBox[{56.8, 302.36923403651593`}], 
             PointBox[{56.9, 299.1394566925681}], 
             PointBox[{57., 301.2414249171038}], 
             PointBox[{57.1, 303.38536142783244`}], 
             PointBox[{57.2, 300.7728989084497}], 
             PointBox[{57.3, 305.5444289593945}], 
             PointBox[{57.4, 313.27704742185597`}], 
             PointBox[{57.5, 315.39352978873285`}], 
             PointBox[{57.6, 312.87571510559394`}], 
             PointBox[{57.7, 316.0357839486485}], 
             PointBox[{57.8, 316.8685462787114}], 
             PointBox[{57.9, 313.39120581919593`}], 
             PointBox[{58., 313.11794723210863`}], 
             PointBox[{58.1, 316.6307641744172}], 
             PointBox[{58.2, 314.75061428695}], 
             PointBox[{58.3, 315.9391956025489}], 
             PointBox[{58.4, 323.56046438831356`}], 
             PointBox[{58.5, 328.4792352221532}], 
             PointBox[{58.6, 326.48977893025415`}], 
             PointBox[{58.7, 327.40402537940446`}], 
             PointBox[{58.8, 330.17712066733094`}], 
             PointBox[{58.9, 327.7385224425729}], 
             PointBox[{59., 325.5089220264422}], 
             PointBox[{59.1, 328.3850885738291}], 
             PointBox[{59.2, 328.9616650042127}], 
             PointBox[{59.3, 327.3353470211749}], 
             PointBox[{59.4, 333.2461412991082}], 
             PointBox[{59.5, 340.01754804512234`}], 
             PointBox[{59.6, 340.4320224652465}], 
             PointBox[{59.7, 338.88785692762235`}], 
             PointBox[{59.8, 342.31255837502164`}], 
             PointBox[{59.9, 341.7324242723359}], 
             PointBox[{60., 338.5562503976128}], 
             PointBox[{60.1, 339.57270571891667`}], 
             PointBox[{60.2, 342.3173941860125}], 
             PointBox[{60.3, 339.8783723771219}], 
             PointBox[{60.4, 342.93070053964686`}], 
             PointBox[{60.5, 350.3654690199452}], 
             PointBox[{60.6, 353.6590667071213}], 
             PointBox[{60.7, 351.2290044687768}], 
             PointBox[{60.8, 353.5548028705686}], 
             PointBox[{60.9, 355.03463276406836`}], 
             PointBox[{61., 352.05502813318316`}], 
             PointBox[{61.1, 351.02442550680945`}], 
             PointBox[{61.2, 354.31281819205435`}], 
             PointBox[{61.3, 353.2693461959898}], 
             PointBox[{61.4, 353.2774779483356}], 
             PointBox[{61.5, 359.97993730030873`}], 
             PointBox[{61.6, 5.6337388600448}], 
             PointBox[{61.7, 4.4692975907438495`}], 
             PointBox[{61.8, 4.475736120760094}], 
             PointBox[{61.9, 7.460125100962464}], 
             PointBox[{62., 5.667520321874697}], 
             PointBox[{62.1, 3.1386264459608335`}], 
             PointBox[{62.2, 5.363260747371154}], 
             PointBox[{62.3, 6.714635518060298}], 
             PointBox[{62.4, 4.661427077832304}], 
             PointBox[{62.5, 9.36693387715735}], 
             PointBox[{62.6, 16.39573499482425}], 
             PointBox[{62.7, 17.839912355999594`}], 
             PointBox[{62.8, 15.85288648714066}], 
             PointBox[{62.9, 19.011539080311085`}], 
             PointBox[{63., 19.04914358361436}], 
             PointBox[{63.1, 15.940363050059524`}], 
             PointBox[{63.2, 16.281956960520866`}], 
             PointBox[{63.3, 19.312971093071813`}], 
             PointBox[{63.4, 17.154883280229065`}], 
             PointBox[{63.5, 19.091488009211}], 
             PointBox[{63.6, 26.24386531771254}], 
             PointBox[{63.7, 30.468885528263268`}], 
             PointBox[{63.8, 28.263787170992394`}], 
             PointBox[{63.9, 29.952127397147756`}], 
             PointBox[{64., 31.907832656807013`}], 
             PointBox[{64.1, 29.238873379507485`}], 
             PointBox[{64.2, 27.708818554088467`}], 
             PointBox[{64.3, 30.797803297698298`}], 
             PointBox[{64.4, 30.42816586439882}], 
             PointBox[{64.5, 29.64607640058788}], 
             PointBox[{64.6, 35.63059191299703}], 
             PointBox[{64.7, 41.97652329060793}], 
             PointBox[{64.8, 41.5504260563277}], 
             PointBox[{64.9, 40.87285820008333}], 
             PointBox[{65., 44.053593740742436`}], 
             PointBox[{65.1, 42.743433814361026`}], 
             PointBox[{65.2, 39.93528263423872}], 
             PointBox[{65.3, 41.681933143896515`}], 
             PointBox[{65.4, 43.66140243714885}], 
             PointBox[{65.5, 41.33369464693976}], 
             PointBox[{65.6, 45.10309717430408}], 
             PointBox[{65.7, 52.416134713010464`}], 
             PointBox[{65.8, 54.868590280649364`}], 
             PointBox[{65.9, 52.56267544959208}], 
             PointBox[{66., 55.48625360961846}], 
             PointBox[{66.1, 56.12401578570592}], 
             PointBox[{66.2, 52.9704271458977}], 
             PointBox[{66.3, 52.737589354659924`}], 
             PointBox[{66.4, 56.03791553213351}], 
             PointBox[{66.5, 54.22115267689296}], 
             PointBox[{66.6, 55.179316375961605`}], 
             PointBox[{66.7, 62.10400589272244}], 
             PointBox[{66.8, 67.40533002292405}], 
             PointBox[{66.9, 65.50763029577068}], 
             PointBox[{67., 66.52946063772418}], 
             PointBox[{67.1, 69.06308163080598}], 
             PointBox[{67.2, 66.63971406359329}], 
             PointBox[{67.3, 64.54773347729274}], 
             PointBox[{67.4, 67.47308139293555}], 
             PointBox[{67.5, 67.88028440946479}], 
             PointBox[{67.6, 66.30414652477685}], 
             PointBox[{67.7, 71.62211889917762}], 
             PointBox[{67.8, 78.82861092312318}], 
             PointBox[{67.9, 79.35201729383435}], 
             PointBox[{68., 77.90859692350455}], 
             PointBox[{68.1, 81.34839060733933}], 
             PointBox[{68.2, 80.63900738508949}], 
             PointBox[{68.3, 77.39490945505229}], 
             PointBox[{68.4, 78.61262418320581}], 
             PointBox[{68.5, 81.35393742528622}], 
             PointBox[{68.6, 78.81749297550869}], 
             PointBox[{68.7, 81.56582221491522}], 
             PointBox[{68.8, 89.21983206528797}], 
             PointBox[{68.9, 93.10066031988391}], 
             PointBox[{69., 90.51112145573744}], 
             PointBox[{69.1, 93.03951163711206}], 
             PointBox[{69.2, 94.57159712314501}], 
             PointBox[{69.3, 91.30404887095804}], 
             PointBox[{69.4, 90.28187412273752}], 
             PointBox[{69.5, 93.89846778917848}], 
             PointBox[{69.6, 92.73433413745882}], 
             PointBox[{69.7, 92.45285271345915}], 
             PointBox[{69.8, 99.08669028876984}], 
             PointBox[{69.9, 105.91612984016443`}], 
             PointBox[{70., 104.69488420303296`}], 
             PointBox[{70.1, 104.6721872454418}], 
             PointBox[{70.2, 108.04114781293515`}], 
             PointBox[{70.3, 106.07512554823862`}], 
             PointBox[{70.4, 103.10419232560346`}], 
             PointBox[{70.5, 105.70827714750119`}], 
             PointBox[{70.6, 107.33568901767538`}], 
             PointBox[{70.7, 104.81933441577743`}], 
             PointBox[{70.8, 109.2261015572052}], 
             PointBox[{70.9, 117.50571297818729`}], 
             PointBox[{71., 119.74294976600711`}], 
             PointBox[{71.1, 117.28188136635066`}], 
             PointBox[{71.2, 120.85696146226942`}], 
             PointBox[{71.3, 121.28364394530479`}], 
             PointBox[{71.4, 117.41386367210136`}], 
             PointBox[{71.5, 117.68290033317163`}], 
             PointBox[{71.6, 121.43556016763088`}], 
             PointBox[{71.7, 119.07189381410873`}], 
             PointBox[{71.8, 120.25693296207416`}], 
             PointBox[{71.9, 128.1632102769226}], 
             PointBox[{72., 134.37796818524654`}], 
             PointBox[{72.1, 131.87409477855775`}], 
             PointBox[{72.2, 133.339009064873}], 
             PointBox[{72.3, 136.35058214275122`}], 
             PointBox[{72.4, 133.22884027872598`}], 
             PointBox[{72.5, 130.813744323592}], 
             PointBox[{72.6, 134.5629615477555}], 
             PointBox[{72.7, 134.91124223853996`}], 
             PointBox[{72.8, 132.8675274678299}], 
             PointBox[{72.9, 138.85596633143308`}], 
             PointBox[{73., 147.74454710261327`}], 
             PointBox[{73.1, 148.37298835204413`}], 
             PointBox[{73.2, 146.55033599828707`}], 
             PointBox[{73.3, 150.80649163956414`}], 
             PointBox[{73.4, 150.1581202457163}], 
             PointBox[{73.5, 145.85933766724955`}], 
             PointBox[{73.6, 147.45944770695093`}], 
             PointBox[{73.7, 150.97833329067112`}], 
             PointBox[{73.8, 147.82436310874365`}], 
             PointBox[{73.9, 150.47358513849795`}], 
             PointBox[{74., 159.80096307936338`}], 
             PointBox[{74.1, 165.30254311040267`}], 
             PointBox[{74.2, 162.00259265047399`}], 
             PointBox[{74.3, 164.74804509470144`}], 
             PointBox[{74.4, 167.38917009507279`}], 
             PointBox[{74.5, 163.18470194234482`}], 
             PointBox[{74.6, 161.4511068418915}], 
             PointBox[{74.7, 166.07040367507187`}], 
             PointBox[{74.8, 165.28549130324188`}], 
             PointBox[{74.9, 163.8539376141266}], 
             PointBox[{75., 171.52256456796803`}], 
             PointBox[{75.1, 181.06507037027933`}], 
             PointBox[{75.2, 180.3501501841097}], 
             PointBox[{75.3, 179.2547112527761}], 
             PointBox[{75.4, 184.05286017220718`}], 
             PointBox[{75.5, 182.45745114581587`}], 
             PointBox[{75.6, 177.79745984055754`}], 
             PointBox[{75.7, 180.57514881740596`}], 
             PointBox[{75.8, 183.8038524272913}], 
             PointBox[{75.9, 180.11303781202443`}], 
             PointBox[{76., 184.19284230735514`}], 
             PointBox[{76.1, 195.1415190421867}], 
             PointBox[{76.2, 200.02763261732034`}], 
             PointBox[{76.3, 196.23857926194933`}], 
             PointBox[{76.4, 199.96392232308895`}], 
             PointBox[{76.5, 202.42351896531213`}], 
             PointBox[{76.6, 197.24285182089795`}], 
             PointBox[{76.7, 196.0774158970246}], 
             PointBox[{76.8, 201.35522184528608`}], 
             PointBox[{76.9, 199.7578392813593}], 
             PointBox[{77., 198.86446110122134`}], 
             PointBox[{77.1, 208.36700351793868`}], 
             PointBox[{77.2, 218.47874380924023`}], 
             PointBox[{77.3, 216.83920409701966`}], 
             PointBox[{77.4, 216.220559602047}], 
             PointBox[{77.5, 221.5260679312841}], 
             PointBox[{77.6, 219.28396441205774`}], 
             PointBox[{77.7, 214.26172526437063`}], 
             PointBox[{77.8, 217.8449922777722}], 
             PointBox[{77.9, 220.9651671625196}], 
             PointBox[{78., 216.89461329444052`}], 
             PointBox[{78.1, 222.28054268598484`}], 
             PointBox[{78.2, 234.62118249809456`}], 
             PointBox[{78.3, 239.03504539974466`}], 
             PointBox[{78.4, 234.94055845868456`}], 
             PointBox[{78.5, 239.22464888480823`}], 
             PointBox[{78.6, 241.73387780959888`}], 
             PointBox[{78.7, 235.9203568525737}], 
             PointBox[{78.8, 234.99871963031086`}], 
             PointBox[{78.9, 240.66761738080996`}], 
             PointBox[{79., 238.68678308597683`}], 
             PointBox[{79.1, 238.17566181535724`}], 
             PointBox[{79.2, 249.169480571347}], 
             PointBox[{79.3, 259.19536300301735`}], 
             PointBox[{79.4, 257.1058358869423}], 
             PointBox[{79.5, 256.6393241420156}], 
             PointBox[{79.6, 262.20338518161736`}], 
             PointBox[{79.7, 259.7558783832626}], 
             PointBox[{79.8, 254.5687902880379}], 
             PointBox[{79.9, 258.3856844531092}], 
             PointBox[{80., 261.48682851641973`}], 
             PointBox[{80.1, 257.32111619359887`}], 
             PointBox[{80.2, 263.5968658711993}], 
             PointBox[{80.3, 276.0818214437908}], 
             PointBox[{80.4, 279.88417256507995`}], 
             PointBox[{80.5, 275.8012482284572}], 
             PointBox[{80.6, 280.15770065785847`}], 
             PointBox[{80.7, 282.6099286721334}], 
             PointBox[{80.8, 276.81277590756423`}], 
             PointBox[{80.9, 275.9628123481091}], 
             PointBox[{81., 281.5316925666447}], 
             PointBox[{81.1, 279.47413001252556`}], 
             PointBox[{81.2, 279.3629590786617}], 
             PointBox[{81.3, 290.64393208668685`}], 
             PointBox[{81.4, 299.49737751681346`}], 
             PointBox[{81.5, 297.240995496994}], 
             PointBox[{81.6, 296.96029433929584`}], 
             PointBox[{81.7, 302.24210655324845`}], 
             PointBox[{81.8, 299.7612429479921}], 
             PointBox[{81.9, 294.9786700972877}], 
             PointBox[{82., 298.6333426548378}], 
             PointBox[{82.1, 301.390870604994}], 
             PointBox[{82.2, 297.559312309936}], 
             PointBox[{82.3, 304.22228380284497`}], 
             PointBox[{82.4, 315.3831877777351}], 
             PointBox[{82.5, 318.21896223695006`}], 
             PointBox[{82.6, 314.55446276906173`}], 
             PointBox[{82.7, 318.7886205251959}], 
             PointBox[{82.8, 320.6764262048484}], 
             PointBox[{82.9, 315.3819522642973}], 
             PointBox[{83., 314.87014771392785`}], 
             PointBox[{83.1, 319.8942461644955}], 
             PointBox[{83.2, 317.6818652437677}], 
             PointBox[{83.3, 318.3098430879155}], 
             PointBox[{83.4, 328.8162794586606}], 
             PointBox[{83.5, 335.948767965696}], 
             PointBox[{83.6, 333.5120324660376}], 
             PointBox[{83.7, 333.7968056109372}], 
             PointBox[{83.8, 338.34084265020834`}], 
             PointBox[{83.9, 335.63712593265933`}], 
             PointBox[{84., 331.76199268467104`}], 
             PointBox[{84.1, 335.3010115932027}], 
             PointBox[{84.2, 337.2243847893304}], 
             PointBox[{84.3, 334.0827372135346}], 
             PointBox[{84.4, 340.98962589536836`}], 
             PointBox[{84.5, 350.36205484122684`}], 
             PointBox[{84.6, 352.0060255964501}], 
             PointBox[{84.7, 349.04948065188734`}], 
             PointBox[{84.8, 353.22251474527667`}], 
             PointBox[{84.9, 354.09673479975754`}], 
             PointBox[{85., 349.4326957354288}], 
             PointBox[{85.1, 349.61576431945866`}], 
             PointBox[{85.2, 353.90442407972535`}], 
             PointBox[{85.3, 351.3501150384678}], 
             PointBox[{85.4, 353.1345119845915}], 
             PointBox[{85.5, 2.611797398009215}], 
             PointBox[{85.6, 8.05202685589185}], 
             PointBox[{85.7, 5.372273675805062}], 
             PointBox[{85.8, 6.574483181233243}], 
             PointBox[{85.9, 10.098352958214441`}], 
             PointBox[{86., 7.029334364558167}], 
             PointBox[{86.1, 4.266897941893608}], 
             PointBox[{86.2, 7.865605115633023}], 
             PointBox[{86.3, 8.596924050565487}], 
             PointBox[{86.4, 6.4877091543693695`}], 
             PointBox[{86.5, 13.683652985887171`}], 
             PointBox[{86.6, 21.448959556602432`}], 
             PointBox[{86.7, 21.817886136296174`}], 
             PointBox[{86.8, 19.837764186395447`}], 
             PointBox[{86.9, 23.898915915724338`}], 
             PointBox[{87., 23.57265206834077}], 
             PointBox[{87.1, 19.587300208865283`}], 
             PointBox[{87.2, 20.661168157351263`}], 
             PointBox[{87.3, 24.04547932399835}], 
             PointBox[{87.4, 21.23743330493463}], 
             PointBox[{87.5, 24.437600156734028`}], 
             PointBox[{87.6, 32.97377764482905}], 
             PointBox[{87.7, 36.802443728395254`}], 
             PointBox[{87.8, 34.006103947578005`}], 
             PointBox[{87.9, 36.25516301076188}], 
             PointBox[{88., 38.521185612959755`}], 
             PointBox[{88.1, 35.160445254977645`}], 
             PointBox[{88.2, 33.59108568322024}], 
             PointBox[{88.3, 37.26090117710336}], 
             PointBox[{88.4, 36.631624249702796`}], 
             PointBox[{88.5, 35.96982160804069}], 
             PointBox[{88.6, 43.408282189093484`}], 
             PointBox[{88.7, 49.758568957458934`}], 
             PointBox[{88.8, 48.863205837717594`}], 
             PointBox[{88.9, 48.192755589137406`}], 
             PointBox[{89., 51.829487868386515`}], 
             PointBox[{89.1, 50.34933865120257}], 
             PointBox[{89.2, 47.15842942486284}], 
             PointBox[{89.3, 49.17236635121658}], 
             PointBox[{89.4, 51.33365942508651}], 
             PointBox[{89.5, 48.75112871534143}], 
             PointBox[{89.6, 53.380094418108115`}], 
             PointBox[{89.7, 61.04199302386565}], 
             PointBox[{89.8, 63.21195259766897}], 
             PointBox[{89.9, 60.7166725694008}], 
             PointBox[{90., 63.815313618574955`}], 
             PointBox[{90.1, 64.65563402568273}], 
             PointBox[{90.2, 61.24134601010174}], 
             PointBox[{90.3, 60.93602682787311}], 
             PointBox[{90.4, 64.41010329873306}], 
             PointBox[{90.5, 62.573404296175504`}], 
             PointBox[{90.6, 63.70918152948178}], 
             PointBox[{90.7, 71.22879459149407}], 
             PointBox[{90.8, 76.15207982507499}], 
             PointBox[{90.9, 74.20748138438196}], 
             PointBox[{91., 75.09418644653323}], 
             PointBox[{91.1, 77.83683661700559}], 
             PointBox[{91.2, 75.43671660461348}], 
             PointBox[{91.3, 73.22479333396817}], 
             PointBox[{91.4, 76.06086599343878}], 
             PointBox[{91.5, 76.64250315316609}], 
             PointBox[{91.6, 75.02780554047018}], 
             PointBox[{91.7, 80.85380915624262}], 
             PointBox[{91.8, 87.59962618487755}], 
             PointBox[{91.9, 88.03618226136129}], 
             PointBox[{92., 86.50311881491699}], 
             PointBox[{92.1, 89.89623669530793}], 
             PointBox[{92.2, 89.31515984015414}], 
             PointBox[{92.3, 86.17271951594454}], 
             PointBox[{92.4, 87.17810894150146}], 
             PointBox[{92.5, 89.90079153146728}], 
             PointBox[{92.6, 87.48078728559318}], 
             PointBox[{92.7, 90.50228345598066}], 
             PointBox[{92.8, 97.89170923194965}], 
             PointBox[{92.9, 101.18499093214328`}], 
             PointBox[{93., 98.77119114961488}], 
             PointBox[{93.1, 101.0930434994627}], 
             PointBox[{93.2, 102.54599985633178`}], 
             PointBox[{93.3, 99.5853532190312}], 
             PointBox[{93.4, 98.57032799089755}], 
             PointBox[{93.5, 101.84362428529386`}], 
             PointBox[{93.6, 100.79041988036109`}], 
             PointBox[{93.7, 100.81262916359344`}], 
             PointBox[{93.8, 107.47180533479514`}], 
             PointBox[{93.9, 113.1196012400371}], 
             PointBox[{94., 111.95109492437987`}], 
             PointBox[{94.1, 111.97992358269198`}], 
             PointBox[{94.2, 114.93905073895448`}], 
             PointBox[{94.3, 113.13897467528301`}], 
             PointBox[{94.4, 110.63124192670462`}], 
             PointBox[{94.5, 112.8640891535818}], 
             PointBox[{94.6, 114.18760455472494`}], 
             PointBox[{94.7, 112.15306179538268`}], 
             PointBox[{94.8, 116.84337015227092`}], 
             PointBox[{94.9, 123.86425058855983`}], 
             PointBox[{95., 125.2926289609099}], 
             PointBox[{95.1, 123.32378627102763`}], 
             PointBox[{95.2, 126.48313671187043`}], 
             PointBox[{95.3, 126.49543782346089`}], 
             PointBox[{95.4, 123.39358921735715`}], 
             PointBox[{95.5, 123.75912593803322`}], 
             PointBox[{95.6, 126.77654513549868`}], 
             PointBox[{95.7, 124.609187077727}], 
             PointBox[{95.8, 126.56123465919802`}], 
             PointBox[{95.9, 133.7048026275321}], 
             PointBox[{96., 137.92603681067257`}], 
             PointBox[{96.1, 135.71088827905118`}], 
             PointBox[{96.2, 137.42716617093586`}], 
             PointBox[{96.3, 139.3601892190453}], 
             PointBox[{96.4, 136.67790122543514`}], 
             PointBox[{96.5, 135.16785561560567`}], 
             PointBox[{96.6, 138.27213720066086`}], 
             PointBox[{96.7, 137.87167285655073`}], 
             PointBox[{96.8, 137.10981411186066`}], 
             PointBox[{96.9, 143.09366519341344`}], 
             PointBox[{97., 149.4562432476073}], 
             PointBox[{97.1, 149.0038503053452}], 
             PointBox[{97.2, 148.35389103268903`}], 
             PointBox[{97.3, 151.53401718268606`}], 
             PointBox[{97.4, 150.19982053956232`}], 
             PointBox[{97.5, 147.39133213181128`}], 
             PointBox[{97.6, 149.17006392629733`}], 
             PointBox[{97.7, 151.13056644835083`}], 
             PointBox[{97.8, 148.80033171038923`}], 
             PointBox[{97.9, 152.58224953595425`}], 
             PointBox[{98., 159.92075276530133`}], 
             PointBox[{98.1, 162.36611732136566`}], 
             PointBox[{98.2, 160.05746151104216`}], 
             PointBox[{98.3, 163.00512908032334`}], 
             PointBox[{98.4, 163.62761091861165`}], 
             PointBox[{98.5, 160.4515315456231}], 
             PointBox[{98.6, 160.24221982500208`}], 
             PointBox[{98.7, 163.5567574401861}], 
             PointBox[{98.8, 161.71631657202863`}], 
             PointBox[{98.9, 162.6852581032052}], 
             PointBox[{99., 169.632511861928}], 
             PointBox[{99.1, 174.96876485510296`}], 
             PointBox[{99.2, 173.04478799589705`}], 
             PointBox[{99.3, 174.09203103575948`}], 
             PointBox[{99.4, 176.6347573443802}], 
             PointBox[{99.5, 174.18278854998934`}], 
             PointBox[{99.6, 172.08494057806152`}], 
             PointBox[{99.7, 175.04559304831142`}], 
             PointBox[{99.8, 175.43994033498726`}], 
             PointBox[{99.9, 173.85254978288236`}], 
             PointBox[{100., 179.18686314335432`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 360}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
             40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {
             0, -180}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 180.}], 
             PointBox[{0.1, 175.5908575741434}], 
             PointBox[{0.2, 177.40611451957636`}], 
             PointBox[{0.3, 179.0873877842405}], 
             PointBox[{0.4, 177.17875561712356`}], 
             PointBox[{0.5, 179.9066296074975}], 
             PointBox[{0.6, -176.0314231512923}], 
             PointBox[{0.7, -176.61964561778353`}], 
             PointBox[{0.8, -177.27897613020554`}], 
             PointBox[{0.9, -173.84863139391564`}], 
             PointBox[{1., -176.38081100401678`}], 
             PointBox[{1.1, 178.3568837293601}], 
             PointBox[{1.2, 177.49985736005453`}], 
             PointBox[{1.3, -179.10852119191725`}], 
             PointBox[{1.4, 179.11152728603793`}], 
             PointBox[{1.5, 179.9078212399777}], 
             PointBox[{1.6, -175.62902766499212`}], 
             PointBox[{1.7, -174.2308953568853}], 
             PointBox[{1.8, -176.2511955471208}], 
             PointBox[{1.9, -173.19069663483526`}], 
             PointBox[{2., -173.11092364909916`}], 
             PointBox[{2.1, -178.17459020171327`}], 
             PointBox[{2.2, 178.40765380162793`}], 
             PointBox[{2.3, -178.42764317021124`}], 
             PointBox[{2.4, -178.43031323723676`}], 
             PointBox[{2.5, -179.54878790073803`}], 
             PointBox[{2.6, -175.7391200258212}], 
             PointBox[{2.7, -172.46386648704947`}], 
             PointBox[{2.8, -174.16095154923664`}], 
             PointBox[{2.9, -173.19214724329595`}], 
             PointBox[{3., -170.61606963921258`}], 
             PointBox[{3.1, -174.45978484812645`}], 
             PointBox[{3.2, -179.52767088654764`}], 
             PointBox[{3.3, -178.5192032807031}], 
             PointBox[{3.4, -176.0880871736972}], 
             PointBox[{3.5, -178.21440831676364`}], 
             PointBox[{3.6, -176.01701839000725`}], 
             PointBox[{3.7, -171.54634582998096`}], 
             PointBox[{3.8, -171.58500651628947`}], 
             PointBox[{3.9, -172.90682108844248`}], 
             PointBox[{4., -169.23107917214293`}], 
             PointBox[{4.1, -170.8548867497002}], 
             PointBox[{4.2, -176.39812037463435`}], 
             PointBox[{4.3, -178.40405414098495`}], 
             PointBox[{4.4, -174.67778831588566`}], 
             PointBox[{4.5, -176.08715580641865`}], 
             PointBox[{4.6, -176.0487571853323}], 
             PointBox[{4.7, -171.449457384344}], 
             PointBox[{4.8, -169.289530523934}], 
             PointBox[{4.9, -171.54413309804522`}], 
             PointBox[{5., -168.98311086603326`}], 
             PointBox[{5.1, -167.76895993237258`}], 
             PointBox[{5.2, -172.6441241314301}], 
             PointBox[{5.3, -177.25179635505674`}], 
             PointBox[{5.4, -174.5573328168466}], 
             PointBox[{5.5, -173.59855788717323`}], 
             PointBox[{5.6, -175.42920958473087`}], 
             PointBox[{5.7, -171.94474345428262`}], 
             PointBox[{5.8, -167.83914793866825`}], 
             PointBox[{5.9, -169.19718115424257`}], 
             PointBox[{6., -169.23184744673472`}], 
             PointBox[{6.1, -165.72299235579067`}], 
             PointBox[{6.2, -168.84031688858067`}], 
             PointBox[{6.3, -174.78161493021435`}], 
             PointBox[{6.4, -175.09312233425499`}], 
             PointBox[{6.5, -171.6570170811974}], 
             PointBox[{6.6, -173.92455462994712`}], 
             PointBox[{6.7, -172.6214200424074}], 
             PointBox[{6.8, -167.51121029437036`}], 
             PointBox[{6.9, -166.6686900593786}], 
             PointBox[{7., -168.84118348715037`}], 
             PointBox[{7.1, -165.12943714703306`}], 
             PointBox[{7.2, -165.40459985379312`}], 
             PointBox[{7.3, -171.2519759478855}], 
             PointBox[{7.4, -175.09368527053448`}], 
             PointBox[{7.5, -171.21854890768554`}], 
             PointBox[{7.6, -171.73908359506368`}], 
             PointBox[{7.7, -172.94154686661204`}], 
             PointBox[{7.8, -168.30357115468905`}], 
             PointBox[{7.9, -164.87054297056784`}], 
             PointBox[{8., -167.23816924383937`}], 
             PointBox[{8.1, -165.81788602212146`}], 
             PointBox[{8.2, -162.96017633593056`}], 
             PointBox[{8.3, -167.43629770132065`}], 
             PointBox[{8.4, -173.73632263564195`}], 
             PointBox[{8.5, -172.3512710909672}], 
             PointBox[{8.6, -169.74797527469036`}], 
             PointBox[{8.7, -172.43692118881154`}], 
             PointBox[{8.8, -169.89024721714122`}], 
             PointBox[{8.9, -164.4960581161049}], 
             PointBox[{9., -164.99861602234887`}], 
             PointBox[{9.1, -166.63839696892137`}], 
             PointBox[{9.2, -162.26115750975896`}], 
             PointBox[{9.3, -163.9900335178063}], 
             PointBox[{9.4, -170.9480459901588}], 
             PointBox[{9.5, -173.83276105353252`}], 
             PointBox[{9.6, -169.33290637667324`}], 
             PointBox[{9.7, -171.08222219565323`}], 
             PointBox[{9.8, -171.60077238709528`}], 
             PointBox[{9.9, -165.9074660028382}], 
             PointBox[{10., -163.32150174576782`}], 
             PointBox[{10.1, -166.36130526148463`}], 
             PointBox[{10.2, -163.6431117339598}], 
             PointBox[{10.3, -161.60324086493983`}], 
             PointBox[{10.4, -167.52278933123853`}], 
             PointBox[{10.5, -174.1873262788613}], 
             PointBox[{10.6, -171.35166481944452`}], 
             PointBox[{10.7, -169.7053338637861}], 
             PointBox[{10.8, -172.65450933006923`}], 
             PointBox[{10.9, -168.9498206339158}], 
             PointBox[{11., -163.39705714627598`}], 
             PointBox[{11.1, -165.11328457648142`}], 
             PointBox[{11.2, -166.11195375742045`}], 
             PointBox[{11.3, -161.36003141689525`}], 
             PointBox[{11.4, -164.52908104829567`}], 
             PointBox[{11.5, -172.833794924607}], 
             PointBox[{11.6, -174.8120168948435}], 
             PointBox[{11.7, -170.0261257418024}], 
             PointBox[{11.8, -172.74323554780494`}], 
             PointBox[{11.9, -172.7327672185511}], 
             PointBox[{12., -166.0560993767176}], 
             PointBox[{12.1, -164.2796699622677}], 
             PointBox[{12.2, -167.7903704029177}], 
             PointBox[{12.3, -164.07091715823844`}], 
             PointBox[{12.4, -162.8110950047576}], 
             PointBox[{12.5, -170.42552119528773`}], 
             PointBox[{12.6, -177.46778376857583`}], 
             PointBox[{12.7, -173.56241484157908`}], 
             PointBox[{12.8, -172.65852545890266`}], 
             PointBox[{12.9, -175.92515757456567`}], 
             PointBox[{13., -171.2705900728597}], 
             PointBox[{13.1, -165.54355320071772`}], 
             PointBox[{13.2, -168.20143659688074`}], 
             PointBox[{13.3, -168.76775817144699`}], 
             PointBox[{13.4, -163.74053798199566`}], 
             PointBox[{13.5, -168.35316689786669`}], 
             PointBox[{13.6, -178.0377938620295}], 
             PointBox[{13.7, -179.36657105576705`}], 
             PointBox[{13.8, -174.3812158851979}], 
             PointBox[{13.9, -177.78869837628372`}], 
             PointBox[{14., -177.56296299805035`}], 
             PointBox[{14.1, -170.08027494971975`}], 
             PointBox[{14.2, -168.81170356838084`}], 
             PointBox[{14.3, -172.6967131094425}], 
             PointBox[{14.4, -168.36068186370358`}], 
             PointBox[{14.5, -167.71488868339839`}], 
             PointBox[{14.6, -176.99398766955164`}], 
             PointBox[{14.7, 175.84779908309065`}], 
             PointBox[{14.8, -179.64431110540863`}], 
             PointBox[{14.9, -179.07243039756395`}], 
             PointBox[{15., 177.33616575236738`}], 
             PointBox[{15.1, -177.51137782407204`}], 
             PointBox[{15.2, -171.58295905438717`}], 
             PointBox[{15.3, -174.7133432071696}], 
             PointBox[{15.4, -175.1633112883519}], 
             PointBox[{15.5, -169.97662243806553`}], 
             PointBox[{15.6, -175.76289425071263`}], 
             PointBox[{15.7, 173.980043526195}], 
             PointBox[{15.8, 173.10712341055478`}], 
             PointBox[{15.9, 178.18443081909027`}], 
             PointBox[{16., 174.52786506942357`}], 
             PointBox[{16.1, 174.75332909541612`}], 
             PointBox[{16.2, -177.48822652011768`}], 
             PointBox[{16.3, -176.33167772073648`}], 
             PointBox[{16.4, 179.6779477674445}], 
             PointBox[{16.5, -175.81992596260716`}], 
             PointBox[{16.6, -175.60503762090593`}], 
             PointBox[{16.7, 174.4449761383985}], 
             PointBox[{16.8, 167.96726192792266`}], 
             PointBox[{16.9, 172.60836902532174`}], 
             PointBox[{17., 173.10430226530116`}], 
             PointBox[{17.1, 169.5596293723247}], 
             PointBox[{17.2, 174.71808031560795`}], 
             PointBox[{17.3, -179.4735923145745}], 
             PointBox[{17.4, 177.47228149733746`}], 
             PointBox[{17.5, 177.13719362963639`}], 
             PointBox[{17.6, -177.87873015523473`}], 
             PointBox[{17.7, 175.85684794661574`}], 
             PointBox[{17.8, 166.53567869900326`}], 
             PointBox[{17.9, 166.24906437123173`}], 
             PointBox[{18., 171.04153106139347`}], 
             PointBox[{18.1, 167.54899840841426`}], 
             PointBox[{18.2, 168.02363261774553`}], 
             PointBox[{18.3, 175.3525671033367}], 
             PointBox[{18.4, 176.41857713309946`}], 
             PointBox[{18.5, 172.80876283381986`}], 
             PointBox[{18.6, 177.24597173058464`}], 
             PointBox[{18.7, 176.94888174378139`}], 
             PointBox[{18.8, 167.72113705466654`}], 
             PointBox[{18.9, 162.63589181148018`}], 
             PointBox[{19., 167.1902935389444}], 
             PointBox[{19.1, 167.40359418231856`}], 
             PointBox[{19.2, 164.46045099980984`}], 
             PointBox[{19.3, 169.5322273715592}], 
             PointBox[{19.4, 174.6367373791727}], 
             PointBox[{19.5, 171.85627512034262`}], 
             PointBox[{19.6, 172.0407095336741}], 
             PointBox[{19.7, 176.34302000703974`}], 
             PointBox[{19.8, 170.12420567767003`}], 
             PointBox[{19.9, 162.5360165318998}], 
             PointBox[{20., 163.08334687842398`}], 
             PointBox[{20.1, 167.16577229180075`}], 
             PointBox[{20.2, 163.9420644965412}], 
             PointBox[{20.3, 165.1303415380862}], 
             PointBox[{20.4, 171.66215731902594`}], 
             PointBox[{20.5, 172.29745692670986`}], 
             PointBox[{20.6, 169.41272469452088`}], 
             PointBox[{20.7, 173.8317196734297}], 
             PointBox[{20.8, 172.68094505948284`}], 
             PointBox[{20.9, 164.7281383052723}], 
             PointBox[{21., 161.17716073248266`}], 
             PointBox[{21.1, 165.6308646250509}], 
             PointBox[{21.2, 165.18555021726934`}], 
             PointBox[{21.3, 163.22608110556212`}], 
             PointBox[{21.4, 168.3278957553266}], 
             PointBox[{21.5, 172.35736802373867`}], 
             PointBox[{21.6, 169.72823415151288`}], 
             PointBox[{21.7, 170.8400359711468}], 
             PointBox[{21.8, 174.04984971533486`}], 
             PointBox[{21.9, 167.9665525699129}], 
             PointBox[{22., 162.01035719868742`}], 
             PointBox[{22.1, 163.5303035855286}], 
             PointBox[{22.2, 166.57645899032832`}], 
             PointBox[{22.3, 163.6613217517879}], 
             PointBox[{22.4, 165.82455308608405`}], 
             PointBox[{22.5, 171.46133441128768`}], 
             PointBox[{22.6, 171.37388052043752`}], 
             PointBox[{22.7, 169.41891567321363`}], 
             PointBox[{22.8, 173.7636146973564}], 
             PointBox[{22.9, 171.48444161264706`}], 
             PointBox[{23., 164.70792540712318`}], 
             PointBox[{23.1, 162.6319496973374}], 
             PointBox[{23.2, 166.89692235798975`}], 
             PointBox[{23.3, 165.60326292582613`}], 
             PointBox[{23.4, 164.86758579922753`}], 
             PointBox[{23.5, 169.99206038849297`}], 
             PointBox[{23.6, 172.8017311825206}], 
             PointBox[{23.7, 170.25812272984695`}], 
             PointBox[{23.8, 172.49174806820156`}], 
             PointBox[{23.9, 174.23475099053394`}], 
             PointBox[{24., 168.28214006299095`}], 
             PointBox[{24.1, 163.69495688270035`}], 
             PointBox[{24.2, 166.20477983968885`}], 
             PointBox[{24.3, 167.9174115165515}], 
             PointBox[{24.4, 165.54092778269114`}], 
             PointBox[{24.5, 168.68050826871695`}], 
             PointBox[{24.6, 173.3464364212632}], 
             PointBox[{24.7, 172.42137440153965`}], 
             PointBox[{24.8, 171.66462556608167`}], 
             PointBox[{24.9, 175.5560801305437}], 
             PointBox[{25., 172.1246924736697}], 
             PointBox[{25.1, 166.3270553372604}], 
             PointBox[{25.2, 165.74502841100548`}], 
             PointBox[{25.3, 169.49232745480185`}], 
             PointBox[{25.4, 167.49135707913956`}], 
             PointBox[{25.5, 168.12408953249906`}], 
             PointBox[{25.6, 173.10268014812027`}], 
             PointBox[{25.7, 174.62305308075884`}], 
             PointBox[{25.8, 172.3591022270266}], 
             PointBox[{25.9, 175.58763916320822`}], 
             PointBox[{26., 175.58913012980338`}], 
             PointBox[{26.1, 169.82483825946474`}], 
             PointBox[{26.2, 166.54471492436642`}], 
             PointBox[{26.3, 169.86819409722375`}], 
             PointBox[{26.4, 170.05713087025288`}], 
             PointBox[{26.5, 168.612919842868}], 
             PointBox[{26.6, 172.53277653369514`}], 
             PointBox[{26.7, 176.10038975958378`}], 
             PointBox[{26.8, 174.41875262184476`}], 
             PointBox[{26.9, 175.15897552946626`}], 
             PointBox[{27., 177.9753264108549}], 
             PointBox[{27.1, 173.62048035930275`}], 
             PointBox[{27.2, 168.70677721894754`}], 
             PointBox[{27.3, 169.68036561709232`}], 
             PointBox[{27.4, 172.36197061433995`}], 
             PointBox[{27.5, 170.14880534851181`}], 
             PointBox[{27.6, 172.14090122381094`}], 
             PointBox[{27.7, 176.7088158202132}], 
             PointBox[{27.8, 176.91257830092218`}], 
             PointBox[{27.9, 175.41224421383595`}], 
             PointBox[{28., 179.0769219797403}], 
             PointBox[{28.1, 177.31632435311258`}], 
             PointBox[{28.2, 171.83273869237746`}], 
             PointBox[{28.3, 170.02600876088036`}], 
             PointBox[{28.4, 173.65869547048715`}], 
             PointBox[{28.5, 172.46826743960628`}], 
             PointBox[{28.6, 172.31591568969816`}], 
             PointBox[{28.7, 176.69204268294925`}], 
             PointBox[{28.8, 178.99761794706865`}], 
             PointBox[{28.9, 176.91212040649407`}], 
             PointBox[{29., 179.19078766565508`}], 
             PointBox[{29.1, -179.6364007089469}], 
             PointBox[{29.2, 175.4309523780903}], 
             PointBox[{29.3, 171.48707584368458`}], 
             PointBox[{29.4, 173.91402586615004`}], 
             PointBox[{29.5, 175.0202584746694}], 
             PointBox[{29.6, 173.2829654858433}], 
             PointBox[{29.7, 176.44364440556092`}], 
             PointBox[{29.8, -179.70893765444634`}], 
             PointBox[{29.9, 179.27681355736058`}], 
             PointBox[{30., 179.1444037961519}], 
             PointBox[{30.1, -177.64185808111142`}], 
             PointBox[{30.2, 179.11207572538842`}], 
             PointBox[{30.3, 174.02332654200654`}], 
             PointBox[{30.4, 173.93385277039852`}], 
             PointBox[{30.5, 177.05279601137954`}], 
             PointBox[{30.6, 175.0744716009831}], 
             PointBox[{30.7, 176.3633042737638}], 
             PointBox[{30.8, -179.19092957669636`}], 
             PointBox[{30.9, -178.2879769909232}], 
             PointBox[{31., 179.88780502756708`}], 
             PointBox[{31.1, -176.78091743936238`}], 
             PointBox[{31.2, -177.47377524883996`}], 
             PointBox[{31.3, 177.30930567792893`}], 
             PointBox[{31.4, 174.63524800656523`}], 
             PointBox[{31.5, 178.0178641887651}], 
             PointBox[{31.6, 177.46403280706}], 
             PointBox[{31.7, 176.79141402542882`}], 
             PointBox[{31.8, -179.20198021477336`}], 
             PointBox[{31.9, -176.39348746990072`}], 
             PointBox[{32., -178.26581714710846`}], 
             PointBox[{32.1, -176.70225941185709`}], 
             PointBox[{32.2, -174.76808092802457`}], 
             PointBox[{32.3, -179.0764546707578}], 
             PointBox[{32.4, 176.41985900982763`}], 
             PointBox[{32.5, 178.1088646120661}], 
             PointBox[{32.6, 179.90257404748627`}], 
             PointBox[{32.7, 177.9604521243382}], 
             PointBox[{32.8, -179.39604027612586`}], 
             PointBox[{32.9, -175.28644054839606`}], 
             PointBox[{33., -175.7909355136435}], 
             PointBox[{33.1, -176.55276424825206`}], 
             PointBox[{33.2, -173.08510124000168`}], 
             PointBox[{33.3, -175.477755789987}], 
             PointBox[{33.4, 179.2252069497954}], 
             PointBox[{33.5, 178.20626931353036`}], 
             PointBox[{33.6, -178.3521489047198}], 
             PointBox[{33.7, 179.91346769607844`}], 
             PointBox[{33.8, -179.39454487742842`}], 
             PointBox[{33.9, -174.92146408153712`}], 
             PointBox[{34., -173.42076687184453`}], 
             PointBox[{34.1, -175.47788596900136`}], 
             PointBox[{34.2, -172.48096910236563`}], 
             PointBox[{34.3, -172.2433329315936}], 
             PointBox[{34.4, -177.2749605322715}], 
             PointBox[{34.5, 179.14634625926192`}], 
             PointBox[{34.6, -177.7438217854433}], 
             PointBox[{34.7, -177.62439159142377`}], 
             PointBox[{34.8, -178.83966781098934`}], 
             PointBox[{34.9, -175.07118992299002`}], 
             PointBox[{35., -171.69226757886645`}], 
             PointBox[{35.1, -173.34989257533744`}], 
             PointBox[{35.2, -172.51189698854796`}], 
             PointBox[{35.3, -169.80441541563414`}], 
             PointBox[{35.4, -173.55054165069305`}], 
             PointBox[{35.5, -178.73821617762223`}], 
             PointBox[{35.6, -177.88878980204026`}], 
             PointBox[{35.7, -175.32187388564125`}], 
             PointBox[{35.8, -177.48160048084537`}], 
             PointBox[{35.9, -175.38879373077725`}], 
             PointBox[{36., -170.83594618916686`}], 
             PointBox[{36.1, -170.7699339501196}], 
             PointBox[{36.2, -172.21026358026575`}], 
             PointBox[{36.3, -168.50559476617855`}], 
             PointBox[{36.4, -169.9610598144136}], 
             PointBox[{36.5, -175.55143375336047`}], 
             PointBox[{36.6, -177.7857483470907}], 
             PointBox[{36.7, -174.01397122775234`}], 
             PointBox[{36.8, -175.33572075114716`}], 
             PointBox[{36.9, -175.4503420949477}], 
             PointBox[{37., -170.82900283076015`}], 
             PointBox[{37.1, -168.51751989525656`}], 
             PointBox[{37.2, -170.8056927245998}], 
             PointBox[{37.3, -168.3627927050802}], 
             PointBox[{37.4, -166.9354601086925}], 
             PointBox[{37.5, -171.77101699335617`}], 
             PointBox[{37.6, -176.60529766187028`}], 
             PointBox[{37.7, -174.03367295064163`}], 
             PointBox[{37.8, -172.87748780338006`}], 
             PointBox[{37.9, -174.83868418770362`}], 
             PointBox[{38., -171.43843493077657`}], 
             PointBox[{38.1, -167.16795073479807`}], 
             PointBox[{38.2, -168.44538229010504`}], 
             PointBox[{38.3, -168.68203741234538`}], 
             PointBox[{38.4, -165.0204261345898}], 
             PointBox[{38.5, -167.9878261757949}], 
             PointBox[{38.6, -174.08213082701695`}], 
             PointBox[{38.7, -174.68460276717087`}], 
             PointBox[{38.8, -171.07427157487473`}], 
             PointBox[{38.9, -173.33327577365708`}], 
             PointBox[{39., -172.2328880804671}], 
             PointBox[{39.1, -167.01258139224592`}], 
             PointBox[{39.2, -165.97955849916252`}], 
             PointBox[{39.3, -168.29779612837592`}], 
             PointBox[{39.4, -164.63868910762176`}], 
             PointBox[{39.5, -164.63865391309446`}], 
             PointBox[{39.6, -170.5258921457753}], 
             PointBox[{39.7, -174.73511903676626`}], 
             PointBox[{39.8, -170.89871068695356`}], 
             PointBox[{39.9, -171.1967626145888}], 
             PointBox[{40., -172.64492601153688`}], 
             PointBox[{40.1, -168.04876325053556`}], 
             PointBox[{40.2, -164.35354199885478`}], 
             PointBox[{40.3, -166.70203207407758`}], 
             PointBox[{40.4, -165.55392474426117`}], 
             PointBox[{40.5, -162.40083072145353`}], 
             PointBox[{40.6, -166.77165032018092`}], 
             PointBox[{40.7, -173.3729898740021}], 
             PointBox[{40.8, -172.33098149195575`}], 
             PointBox[{40.9, -169.40760198149655`}], 
             PointBox[{41., -172.2044821280324}], 
             PointBox[{41.1, -169.9123011532829}], 
             PointBox[{41.2, -164.2895100790447}], 
             PointBox[{41.3, -164.5725693102686}], 
             PointBox[{41.4, -166.50822683524893`}], 
             PointBox[{41.5, -162.07040335471902`}], 
             PointBox[{41.6, -163.48035142524168`}], 
             PointBox[{41.7, -170.59104032797404`}], 
             PointBox[{41.8, -174.01843239531445`}], 
             PointBox[{41.9, -169.4243023275667}], 
             PointBox[{42., -170.95760464874184`}], 
             PointBox[{42.1, -171.86023615406157`}], 
             PointBox[{42.2, -166.15149009251763`}], 
             PointBox[{42.3, -163.18353000072602`}], 
             PointBox[{42.4, -166.30435558307727`}], 
             PointBox[{42.5, -163.91378247887405`}], 
             PointBox[{42.6, -161.42483440155047`}], 
             PointBox[{42.7, -167.29842002810256`}], 
             PointBox[{42.8, -174.45542887357806`}], 
             PointBox[{42.9, -172.00537473726217`}], 
             PointBox[{43., -169.88333072173555`}], 
             PointBox[{43.1, -173.07501224845328`}], 
             PointBox[{43.2, -169.70210144054363`}], 
             PointBox[{43.3, -163.77155492901147`}], 
             PointBox[{43.4, -165.23725846390516`}], 
             PointBox[{43.5, -166.71128696767846`}], 
             PointBox[{43.6, -161.76509958497263`}], 
             PointBox[{43.7, -164.56720301237874`}], 
             PointBox[{43.8, -173.15300798421595`}], 
             PointBox[{43.9, -175.86518542981867`}], 
             PointBox[{44., -170.83317547265324`}], 
             PointBox[{44.1, -173.32987408238114`}], 
             PointBox[{44.2, -173.87254541199945`}], 
             PointBox[{44.3, -167.1410203488449}], 
             PointBox[{44.4, -164.8288788838072}], 
             PointBox[{44.5, -168.52558005175888`}], 
             PointBox[{44.6, -165.2045598871664}], 
             PointBox[{44.7, -163.32688536223213`}], 
             PointBox[{44.8, -170.92348488976495`}], 
             PointBox[{44.9, -178.61940182769104`}], 
             PointBox[{45., -175.1609144278009}], 
             PointBox[{45.1, -173.6116854357315}], 
             PointBox[{45.2, -177.22284571516138`}], 
             PointBox[{45.3, -173.03905938912794`}], 
             PointBox[{45.4, -166.79200020557982`}], 
             PointBox[{45.5, -169.1248113516267}], 
             PointBox[{45.6, -170.3450411487829}], 
             PointBox[{45.7, -165.02384823479224`}], 
             PointBox[{45.8, -169.161423334368}], 
             PointBox[{45.9, -179.15266963175964`}], 
             PointBox[{46., 178.64642981105862`}], 
             PointBox[{46.1, -176.02613397947425`}], 
             PointBox[{46.2, -179.13748789714737`}], 
             PointBox[{46.3, -179.61510709343565`}], 
             PointBox[{46.4, -172.13671315745887`}], 
             PointBox[{46.5, -170.16524342302}], 
             PointBox[{46.6, -174.26246278615872`}], 
             PointBox[{46.7, -170.438684852008}], 
             PointBox[{46.8, -169.01017509848316`}], 
             PointBox[{46.9, -178.15359588903812`}], 
             PointBox[{47., 174.07286622806714`}], 
             PointBox[{47.1, 178.04660734321806`}], 
             PointBox[{47.2, 179.39148512649263`}], 
             PointBox[{47.3, 175.4801824573151}], 
             PointBox[{47.4, 179.99481965638552`}], 
             PointBox[{47.5, -173.5399607509462}], 
             PointBox[{47.6, -176.21195154233283`}], 
             PointBox[{47.7, -177.3942659558088}], 
             PointBox[{47.8, -171.9208145259836}], 
             PointBox[{47.9, -177.03697110597568`}], 
             PointBox[{48., 172.60388607982168`}], 
             PointBox[{48.1, 170.8945675584764}], 
             PointBox[{48.2, 176.27234132446756`}], 
             PointBox[{48.3, 173.0228792260241}], 
             PointBox[{48.4, 172.55143600719748`}], 
             PointBox[{48.5, -179.8568304915534}], 
             PointBox[{48.6, -177.95022727359174`}], 
             PointBox[{48.7, 177.94688820401643`}], 
             PointBox[{48.8, -178.13514188622503`}], 
             PointBox[{48.9, -177.08097243768862`}], 
             PointBox[{49., 173.34694486461376`}], 
             PointBox[{49.1, 166.47760447549808`}], 
             PointBox[{49.2, 170.57175812016794`}], 
             PointBox[{49.3, 171.79801454528933`}], 
             PointBox[{49.4, 168.06196777704463`}], 
             PointBox[{49.5, 172.56526513791323`}], 
             PointBox[{49.6, 178.75252535395703`}], 
             PointBox[{49.7, 176.21440742027335`}], 
             PointBox[{49.8, 175.24782869139744`}], 
             PointBox[{49.9, -179.56189299141988`}], 
             PointBox[{50., 174.94666148476244`}], 
             PointBox[{50.1, 165.72679399501794`}], 
             PointBox[{50.2, 164.78217863474856`}], 
             PointBox[{50.3, 169.77815756839118`}], 
             PointBox[{50.4, 166.6800220831865}], 
             PointBox[{50.5, 166.61832027726632`}], 
             PointBox[{50.6, 173.70495998521073`}], 
             PointBox[{50.7, 175.3787616279442}], 
             PointBox[{50.8, 171.74306822491053`}], 
             PointBox[{50.9, 175.68609194143937`}], 
             PointBox[{51., 176.11657662093057`}], 
             PointBox[{51.1, 167.33228863102704`}], 
             PointBox[{51.2, 162.0031534604932}], 
             PointBox[{51.3, 166.12691761708265`}], 
             PointBox[{51.4, 166.89766019856324`}], 
             PointBox[{51.5, 163.83681773069839`}], 
             PointBox[{51.6, 168.40224908622622`}], 
             PointBox[{51.7, 173.73554965340736`}], 
             PointBox[{51.8, 171.3705428113899}], 
             PointBox[{51.9, 171.08225390646112`}], 
             PointBox[{52., 175.56019600613945`}], 
             PointBox[{52.1, 169.9912083919553}], 
             PointBox[{52.2, 162.50647482517525`}], 
             PointBox[{52.3, 162.567837502771}], 
             PointBox[{52.4, 166.81974319736037`}], 
             PointBox[{52.5, 163.86001219195896`}], 
             PointBox[{52.6, 164.66914072797226`}], 
             PointBox[{52.7, 171.0178440085583}], 
             PointBox[{52.8, 172.07632614074828`}], 
             PointBox[{52.9, 169.151628191059}], 
             PointBox[{53., 173.2548586135672}], 
             PointBox[{53.1, 172.65890120054246`}], 
             PointBox[{53.2, 165.0229459713155}], 
             PointBox[{53.3, 161.26325585479935`}], 
             PointBox[{53.4, 165.4506233934153}], 
             PointBox[{53.5, 165.3845620771972}], 
             PointBox[{53.6, 163.3105689434742}], 
             PointBox[{53.7, 168.07709161505772`}], 
             PointBox[{53.8, 172.27043130350648`}], 
             PointBox[{53.9, 169.90115358634648`}], 
             PointBox[{54., 170.6664833087052}], 
             PointBox[{54.1, 174.06589863292902`}], 
             PointBox[{54.2, 168.4215809824309}], 
             PointBox[{54.3, 162.49182204876706`}], 
             PointBox[{54.4, 163.6606387289503}], 
             PointBox[{54.5, 166.87814561081177`}], 
             PointBox[{54.6, 164.084619750196}], 
             PointBox[{54.7, 165.98026358010975`}], 
             PointBox[{54.8, 171.52580359499552`}], 
             PointBox[{54.9, 171.71954910169006`}], 
             PointBox[{55., 169.67273154457507`}], 
             PointBox[{55.1, 173.87086934343824`}], 
             PointBox[{55.2, 171.98644598331157`}], 
             PointBox[{55.3, 165.37884186774318`}], 
             PointBox[{55.4, 163.10275309781719`}], 
             PointBox[{55.5, 167.25070476897963`}], 
             PointBox[{55.6, 166.18709260839387`}], 
             PointBox[{55.7, 165.3313632759673}], 
             PointBox[{55.8, 170.2546643006135}], 
             PointBox[{55.9, 173.20151186030853`}], 
             PointBox[{56., 170.7805186987316}], 
             PointBox[{56.1, 172.7774397755129}], 
             PointBox[{56.2, 174.71193060775113`}], 
             PointBox[{56.3, 169.01899852778297`}], 
             PointBox[{56.4, 164.39207130399882`}], 
             PointBox[{56.5, 166.67053497546294`}], 
             PointBox[{56.6, 168.54151890209323`}], 
             PointBox[{56.7, 166.18693757012807`}], 
             PointBox[{56.8, 169.1435753654805}], 
             PointBox[{56.9, 173.78933420708927`}], 
             PointBox[{57., 173.03934740553086`}], 
             PointBox[{57.1, 172.16064725423348`}], 
             PointBox[{57.2, 176.02785380570276`}], 
             PointBox[{57.3, 172.85860623799817`}], 
             PointBox[{57.4, 167.12403709858336`}], 
             PointBox[{57.5, 166.36583183424955`}], 
             PointBox[{57.6, 170.1040957939549}], 
             PointBox[{57.7, 168.21546995769313`}], 
             PointBox[{57.8, 168.73960389891}], 
             PointBox[{57.9, 173.61328811506974`}], 
             PointBox[{58., 175.24584298484115`}], 
             PointBox[{58.1, 173.00440993461962`}], 
             PointBox[{58.2, 176.10113572113187`}], 
             PointBox[{58.3, 176.26873665259336`}], 
             PointBox[{58.4, 170.63986078252492`}], 
             PointBox[{58.5, 167.28153459065652`}], 
             PointBox[{58.6, 170.48322873825236`}], 
             PointBox[{58.7, 170.7880714483399}], 
             PointBox[{58.8, 169.31587936749565`}], 
             PointBox[{58.9, 173.1210866807014}], 
             PointBox[{59., 176.71064683955046`}], 
             PointBox[{59.1, 175.11941436084453`}], 
             PointBox[{59.2, 175.74849392816395`}], 
             PointBox[{59.3, 178.6068101845085}], 
             PointBox[{59.4, 174.41161977859156`}], 
             PointBox[{59.5, 169.49466351041337`}], 
             PointBox[{59.6, 170.3378664157499}], 
             PointBox[{59.7, 173.06364425508218`}], 
             PointBox[{59.8, 170.88463040666102`}], 
             PointBox[{59.9, 172.79325554479146`}], 
             PointBox[{60., 177.3220306149451}], 
             PointBox[{60.1, 177.60614105017157`}], 
             PointBox[{60.2, 176.07312604954495`}], 
             PointBox[{60.3, 179.69125941485981`}], 
             PointBox[{60.4, 178.05736005053768`}], 
             PointBox[{60.5, 172.62608662971616`}], 
             PointBox[{60.6, 170.73160404477676`}], 
             PointBox[{60.7, 174.3281078772343}], 
             PointBox[{60.8, 173.2003368207952}], 
             PointBox[{60.9, 173.00525750733505`}], 
             PointBox[{61., 177.3221489339121}], 
             PointBox[{61.1, 179.66632709683472`}], 
             PointBox[{61.2, 177.6075937139758}], 
             PointBox[{61.3, 179.81496937268093`}], 
             PointBox[{61.4, -178.94745424525172`}], 
             PointBox[{61.5, 176.20512141822837`}], 
             PointBox[{61.6, 172.2176597856087}], 
             PointBox[{61.7, 174.57148999425408`}], 
             PointBox[{61.8, 175.72857833388844`}], 
             PointBox[{61.9, 173.98404424416367`}], 
             PointBox[{62., 177.09154517038405`}], 
             PointBox[{62.1, -179.05824141129415`}], 
             PointBox[{62.2, 179.97186197613337`}], 
             PointBox[{62.3, 179.79129499311966`}], 
             PointBox[{62.4, -176.98610940289655`}], 
             PointBox[{62.5, 179.85469925176585`}], 
             PointBox[{62.6, 174.75954703881143`}], 
             PointBox[{62.7, 174.5965248706707}], 
             PointBox[{62.8, 177.73064750843332`}], 
             PointBox[{62.9, 175.77164664222073`}], 
             PointBox[{63., 177.02077595436276`}], 
             PointBox[{63.1, -178.5477258153769}], 
             PointBox[{63.2, -177.60786254752747`}], 
             PointBox[{63.3, -179.445540778368}], 
             PointBox[{63.4, -176.1407466497185}], 
             PointBox[{63.5, -176.76613701775204`}], 
             PointBox[{63.6, 178.0440392161545}], 
             PointBox[{63.7, 175.30553540193796`}], 
             PointBox[{63.8, 178.66858144060097`}], 
             PointBox[{63.9, 178.15018091160164`}], 
             PointBox[{64., 177.44984502693842`}], 
             PointBox[{64.1, -178.56352068948036`}], 
             PointBox[{64.2, -175.72792217469396`}], 
             PointBox[{64.3, -177.58973394486384`}], 
             PointBox[{64.4, -176.06605817105446`}], 
             PointBox[{64.5, -174.08757983164833`}], 
             PointBox[{64.6, -178.34745361131354`}], 
             PointBox[{64.7, 177.09770044899778`}], 
             PointBox[{64.8, 178.74029166833498`}], 
             PointBox[{64.9, -179.4269325670757}], 
             PointBox[{65., 178.6173214367227}], 
             PointBox[{65.1, -178.76608874859085`}], 
             PointBox[{65.2, -174.6335646363077}], 
             PointBox[{65.3, -175.1134052025518}], 
             PointBox[{65.4, -175.91224339535256`}], 
             PointBox[{65.5, -172.42623122576333`}], 
             PointBox[{65.6, -174.75898262188275`}], 
             PointBox[{65.7, 179.91706138979498`}], 
             PointBox[{65.8, 178.82579683360382`}], 
             PointBox[{65.9, -177.70724913865706`}], 
             PointBox[{66., -179.42971613256668`}], 
             PointBox[{66.1, -178.77749555875198`}], 
             PointBox[{66.2, -174.28724606870674`}], 
             PointBox[{66.3, -172.74790621426655`}], 
             PointBox[{66.4, -174.82683161909517`}], 
             PointBox[{66.5, -171.84726309746475`}], 
             PointBox[{66.6, -171.5396348893919}], 
             PointBox[{66.7, -176.5658201762999}], 
             PointBox[{66.8, 179.76387448229798`}], 
             PointBox[{66.9, -177.1382116336681}], 
             PointBox[{67., -176.97123516246938`}], 
             PointBox[{67.1, -178.2340104016257}], 
             PointBox[{67.2, -174.46884190222772`}], 
             PointBox[{67.3, -171.03503606660524`}], 
             PointBox[{67.4, -172.68911446836137`}], 
             PointBox[{67.5, -171.9043530938652}], 
             PointBox[{67.6, -169.1280684148005}], 
             PointBox[{67.7, -172.83485026765266`}], 
             PointBox[{67.8, -178.10830912170786`}], 
             PointBox[{67.9, -177.33062431820144`}], 
             PointBox[{68., -174.69461618579226`}], 
             PointBox[{68.1, -176.88096582129947`}], 
             PointBox[{68.2, -174.83189871198556`}], 
             PointBox[{68.3, -170.21769947749272`}], 
             PointBox[{68.4, -170.1114140175705}], 
             PointBox[{68.5, -171.61507210381387`}], 
             PointBox[{68.6, -167.8831537300066}], 
             PointBox[{68.7, -169.2552975581857}], 
             PointBox[{68.8, -174.8963422668312}], 
             PointBox[{68.9, -177.26528366567072`}], 
             PointBox[{69., -173.45510128718888`}], 
             PointBox[{69.1, -174.74037236393633`}], 
             PointBox[{69.2, -174.9410793398274}], 
             PointBox[{69.3, -170.28391132836987`}], 
             PointBox[{69.4, -167.8884203417183}], 
             PointBox[{69.5, -170.21051907786023`}], 
             PointBox[{69.6, -167.82228334372485`}], 
             PointBox[{69.7, -166.27123194749583`}], 
             PointBox[{69.8, -171.10588510600792`}], 
             PointBox[{69.9, -176.10025961805513`}], 
             PointBox[{70., -173.58607768682123`}], 
             PointBox[{70.1, -172.31865280012426`}], 
             PointBox[{70.2, -174.3677215405769}], 
             PointBox[{70.3, -171.0023701974933}], 
             PointBox[{70.4, -166.61683076935878`}], 
             PointBox[{70.5, -167.8648544384996}], 
             PointBox[{70.6, -168.22015478619142`}], 
             PointBox[{70.7, -164.45632428277167`}], 
             PointBox[{70.8, -167.3473783439913}], 
             PointBox[{70.9, -173.5713535034738}], 
             PointBox[{71., -174.3569809738765}], 
             PointBox[{71.1, -170.63148489498417`}], 
             PointBox[{71.2, -172.89632330885797`}], 
             PointBox[{71.3, -171.9237605004746}], 
             PointBox[{71.4, -166.60908009746345`}], 
             PointBox[{71.5, -165.4631831485749}], 
             PointBox[{71.6, -167.88366713859432`}], 
             PointBox[{71.7, -164.24949956177443`}], 
             PointBox[{71.8, -164.0763754518557}], 
             PointBox[{71.9, -170.02377297771454`}], 
             PointBox[{72., -174.495239638949}], 
             PointBox[{72.1, -170.67462171065563`}], 
             PointBox[{72.2, -170.83174169870472`}], 
             PointBox[{72.3, -172.4520614602734}], 
             PointBox[{72.4, -167.86801798822853`}], 
             PointBox[{72.5, -163.98832670767297`}], 
             PointBox[{72.6, -166.33994747867837`}], 
             PointBox[{72.7, -165.37117021028098`}], 
             PointBox[{72.8, -162.01674421505595`}], 
             PointBox[{72.9, -166.34123902183637`}], 
             PointBox[{73., -173.18257919754979`}], 
             PointBox[{73.1, -172.37515178132162`}], 
             PointBox[{73.2, -169.23409042530693`}], 
             PointBox[{73.3, -172.110543517294}], 
             PointBox[{73.4, -169.99611932624975`}], 
             PointBox[{73.5, -164.19670395465073`}], 
             PointBox[{73.6, -164.3365584729181}], 
             PointBox[{73.7, -166.47933822798223`}], 
             PointBox[{73.8, -162.0031857769136}], 
             PointBox[{73.9, -163.19921697265818`}], 
             PointBox[{74., -170.45685859039077`}], 
             PointBox[{74.1, -174.27856713731308`}], 
             PointBox[{74.2, -169.62502793661406`}], 
             PointBox[{74.3, -171.00016385082563`}], 
             PointBox[{74.4, -172.1839335433615}], 
             PointBox[{74.5, -166.45914770151285`}], 
             PointBox[{74.6, -163.21323850174667`}], 
             PointBox[{74.7, -166.39251975259685`}], 
             PointBox[{74.8, -164.24531236844632`}], 
             PointBox[{74.9, -161.43953771760425`}], 
             PointBox[{75., -167.30848590732057`}], 
             PointBox[{75.1, -174.8384914935814}], 
             PointBox[{75.2, -172.6819999096042}], 
             PointBox[{75.3, -170.21705444696272`}], 
             PointBox[{75.4, -173.57485655012715`}], 
             PointBox[{75.5, -170.4567639567249}], 
             PointBox[{75.6, -164.24850985938247`}], 
             PointBox[{75.7, -165.525708766967}], 
             PointBox[{75.8, -167.33870096396276`}], 
             PointBox[{75.9, -162.27899360228912`}], 
             PointBox[{76., -164.81690062354755`}], 
             PointBox[{76.1, -173.6320673714581}], 
             PointBox[{76.2, -176.87881744605693`}], 
             PointBox[{76.3, -171.7021124052044}], 
             PointBox[{76.4, -174.00630536535027`}], 
             PointBox[{76.5, -174.95706480880472`}], 
             PointBox[{76.6, -168.21150963740365`}], 
             PointBox[{76.7, -165.49697581709916`}], 
             PointBox[{76.8, -169.30152919250395`}], 
             PointBox[{76.9, -166.30641998485225`}], 
             PointBox[{77., -163.98534013907192`}], 
             PointBox[{77.1, -171.5778355134753}], 
             PointBox[{77.2, -179.72465551865025`}], 
             PointBox[{77.3, -176.63621965033963`}], 
             PointBox[{77.4, -174.6108314414305}], 
             PointBox[{77.5, -178.43346735896193`}], 
             PointBox[{77.6, -174.63026831097523`}], 
             PointBox[{77.7, -168.02844665972225`}], 
             PointBox[{77.8, -170.08536248225573`}], 
             PointBox[{77.9, -171.76463932876504`}], 
             PointBox[{78., -166.29281259746494`}], 
             PointBox[{78.1, -170.06287045558565`}], 
             PointBox[{78.2, 179.75512761360733`}], 
             PointBox[{78.3, 176.9467753541976}], 
             PointBox[{78.4, -177.55156069977238`}], 
             PointBox[{78.5, 179.61586019712558`}], 
             PointBox[{78.6, 178.64498770677164`}], 
             PointBox[{78.7, -173.9527947468814}], 
             PointBox[{78.8, -171.46438457628392`}], 
             PointBox[{78.9, -175.64535730363423`}], 
             PointBox[{79., -172.24986102267576`}], 
             PointBox[{79.1, -170.2747414657424}], 
             PointBox[{79.2, -179.27670602773287`}], 
             PointBox[{79.3, 172.60247073494975`}], 
             PointBox[{79.4, 176.13604705188482`}], 
             PointBox[{79.5, 178.02508612877864`}], 
             PointBox[{79.6, 173.9623645234169}], 
             PointBox[{79.7, 177.985664354841}], 
             PointBox[{79.8, -175.23890425606078`}], 
             PointBox[{79.9, -177.52537878580915`}], 
             PointBox[{80., -179.18222721186612`}], 
             PointBox[{80.1, -173.60316150115978`}], 
             PointBox[{80.2, -178.20508255665482`}], 
             PointBox[{80.3, 171.46023918520223`}], 
             PointBox[{80.4, 169.22186102460546`}], 
             PointBox[{80.5, 174.71050559431023`}], 
             PointBox[{80.6, 171.81135670765798`}], 
             PointBox[{80.7, 170.90186672205164`}], 
             PointBox[{80.8, 178.28700277436292`}], 
             PointBox[{80.9, -179.30264171728777`}], 
             PointBox[{81., 176.60699149795983`}], 
             PointBox[{81.1, -179.92674111059023`}], 
             PointBox[{81.2, -178.333616263124}], 
             PointBox[{81.3, 172.43361277624354`}], 
             PointBox[{81.4, 165.4078750227709}], 
             PointBox[{81.5, 169.0845928844792}], 
             PointBox[{81.6, 170.77981891626405`}], 
             PointBox[{81.7, 166.9927263655627}], 
             PointBox[{81.8, 171.0392006735783}], 
             PointBox[{81.9, 177.39395693098777`}], 
             PointBox[{82., 175.24853527540836`}], 
             PointBox[{82.1, 173.9140746596022}], 
             PointBox[{82.2, 179.1499330057777}], 
             PointBox[{82.3, 174.20873285378912`}], 
             PointBox[{82.4, 165.15601466562657`}], 
             PointBox[{82.5, 163.82709703415458`}], 
             PointBox[{82.6, 168.87409701469733`}], 
             PointBox[{82.7, 166.079477846004}], 
             PointBox[{82.8, 165.71518807245593`}], 
             PointBox[{82.9, 172.5729239446373}], 
             PointBox[{83., 174.61393996694096`}], 
             PointBox[{83.1, 171.03398929507966`}], 
             PointBox[{83.2, 174.62682719949225`}], 
             PointBox[{83.3, 175.48598627663887`}], 
             PointBox[{83.4, 167.06237167429936`}], 
             PointBox[{83.5, 161.65834884714423`}], 
             PointBox[{83.6, 165.47280463860807`}], 
             PointBox[{83.7, 166.57382814791345`}], 
             PointBox[{83.8, 163.49690104476758`}], 
             PointBox[{83.9, 167.73456211168377`}], 
             PointBox[{84., 173.1429489140137}], 
             PointBox[{84.1, 171.06832906830095`}], 
             PointBox[{84.2, 170.52478317347413`}], 
             PointBox[{84.3, 175.04577421628346`}], 
             PointBox[{84.4, 169.91041218463215`}], 
             PointBox[{84.5, 162.56587693816982`}], 
             PointBox[{84.6, 162.35576735876384`}], 
             PointBox[{84.7, 166.65445438747702`}], 
             PointBox[{84.8, 163.88570697508112`}], 
             PointBox[{84.9, 164.4982069429243}], 
             PointBox[{85., 170.6815133960772}], 
             PointBox[{85.1, 171.97558812487114`}], 
             PointBox[{85.2, 169.0762340321162}], 
             PointBox[{85.3, 172.96650265116477`}], 
             PointBox[{85.4, 172.6745155587414}], 
             PointBox[{85.5, 165.2915378357211}], 
             PointBox[{85.6, 161.4599995396129}], 
             PointBox[{85.7, 165.46168688566104`}], 
             PointBox[{85.8, 165.60314828245464`}], 
             PointBox[{85.9, 163.5058504023982}], 
             PointBox[{86., 168.0626069491409}], 
             PointBox[{86.1, 172.30258282490104`}], 
             PointBox[{86.2, 170.1057905561247}], 
             PointBox[{86.3, 170.6964401970181}], 
             PointBox[{86.4, 174.15499142256886`}], 
             PointBox[{86.5, 168.79407056373748`}], 
             PointBox[{86.6, 162.93304958644876`}], 
             PointBox[{86.7, 163.91550666515832`}], 
             PointBox[{86.8, 167.18870617385983`}], 
             PointBox[{86.9, 164.48847459859098`}], 
             PointBox[{87., 166.25571317449067`}], 
             PointBox[{87.1, 171.70464444944082`}], 
             PointBox[{87.2, 172.04234166462265`}], 
             PointBox[{87.3, 169.98051934700925`}], 
             PointBox[{87.4, 174.07426893555385`}], 
             PointBox[{87.5, 172.3915634836667}], 
             PointBox[{87.6, 165.92712008747185`}], 
             PointBox[{87.7, 163.57663336323458`}], 
             PointBox[{87.8, 167.63544901430578`}], 
             PointBox[{87.9, 166.68458166754863`}], 
             PointBox[{88., 165.80161867172137`}], 
             PointBox[{88.1, 170.59796356510924`}], 
             PointBox[{88.2, 173.58073088587844`}], 
             PointBox[{88.3, 171.24177554684138`}], 
             PointBox[{88.4, 173.1312784454858}], 
             PointBox[{88.5, 175.12358747614053`}], 
             PointBox[{88.6, 169.597930188771}], 
             PointBox[{88.7, 164.9885170012567}], 
             PointBox[{88.8, 167.15461250497174`}], 
             PointBox[{88.9, 169.07064059725963`}], 
             PointBox[{89., 166.75408558209165`}], 
             PointBox[{89.1, 169.62959273924935`}], 
             PointBox[{89.2, 174.22547209568438`}], 
             PointBox[{89.3, 173.55316195367777`}], 
             PointBox[{89.4, 172.64661997951043`}], 
             PointBox[{89.5, 176.47211713413708`}], 
             PointBox[{89.6, 173.42732121695008`}], 
             PointBox[{89.7, 167.7611664928554}], 
             PointBox[{89.8, 166.94479714836052`}], 
             PointBox[{89.9, 170.6502234866348}], 
             PointBox[{90., 168.81152896308777`}], 
             PointBox[{90.1, 169.31688136223966`}], 
             PointBox[{90.2, 174.11706858433172`}], 
             PointBox[{90.3, 175.77190542666358`}], 
             PointBox[{90.4, 173.55953452867834`}], 
             PointBox[{90.5, 176.60272626376536`}], 
             PointBox[{90.6, 176.8101462434206}], 
             PointBox[{90.7, 171.2719990462938}], 
             PointBox[{90.8, 167.908462983527}], 
             PointBox[{90.9, 171.05719312325527`}], 
             PointBox[{91., 171.37975881504826`}], 
             PointBox[{91.1, 169.928041446532}], 
             PointBox[{91.2, 173.6853157833175}], 
             PointBox[{91.3, 177.24829610071902`}], 
             PointBox[{91.4, 175.68850845796987`}], 
             PointBox[{91.5, 176.30381567667064`}], 
             PointBox[{91.6, 179.14084002224263`}], 
             PointBox[{91.7, 175.017560046399}], 
             PointBox[{91.8, 170.12533570743108`}], 
             PointBox[{91.9, 170.94098544727603`}], 
             PointBox[{92., 173.64777629134187`}], 
             PointBox[{92.1, 171.4920192641439}], 
             PointBox[{92.2, 173.39356327912537`}], 
             PointBox[{92.3, 177.88095759344287`}], 
             PointBox[{92.4, 178.16877744926023`}], 
             PointBox[{92.5, 176.6504544805648}], 
             PointBox[{92.6, -179.7579133600666}], 
             PointBox[{92.7, 178.62961982600973`}], 
             PointBox[{92.8, 173.23889198908}], 
             PointBox[{92.9, 171.34211980919645`}], 
             PointBox[{93., 174.91662456838822`}], 
             PointBox[{93.1, 173.78642391688481`}], 
             PointBox[{93.2, 173.61197309865383`}], 
             PointBox[{93.3, 177.9039001808269}], 
             PointBox[{93.4, -179.7732990682416}], 
             PointBox[{93.5, 178.1773151401576}], 
             PointBox[{93.6, -179.61125792244275`}], 
             PointBox[{93.7, -178.3940250059095}], 
             PointBox[{93.8, 176.79514535830822`}], 
             PointBox[{93.9, 172.81296387783368`}], 
             PointBox[{94., 175.16725904560008`}], 
             PointBox[{94.1, 176.29758810611384`}], 
             PointBox[{94.2, 174.57398202165496`}], 
             PointBox[{94.3, 177.68474624241935`}], 
             PointBox[{94.4, -178.49028285243548`}], 
             PointBox[{94.5, -179.47245642375492`}], 
             PointBox[{94.6, -179.62910326186102`}], 
             PointBox[{94.7, -176.42920041506295`}], 
             PointBox[{94.8, -179.57829394483997`}], 
             PointBox[{94.9, 175.33329388951825`}], 
             PointBox[{95., 175.18458883087442`}], 
             PointBox[{95.1, 178.2981512787228}], 
             PointBox[{95.2, 176.33606981601042`}], 
             PointBox[{95.3, 177.60824304187554`}], 
             PointBox[{95.4, -177.96939767913136`}], 
             PointBox[{95.5, -177.0556821418577}], 
             PointBox[{95.6, -178.88188768172404`}], 
             PointBox[{95.7, -175.56989622504625`}], 
             PointBox[{95.8, -176.21332385249843`}], 
             PointBox[{95.9, 178.60368450309034`}], 
             PointBox[{96., 175.86947001046792`}], 
             PointBox[{96.1, 179.24211310771352`}], 
             PointBox[{96.2, 178.69526018589386`}], 
             PointBox[{96.3, 178.01724333901075`}], 
             PointBox[{96.4, -177.9831310039881}], 
             PointBox[{96.5, -175.16788414381153`}], 
             PointBox[{96.6, -177.04533516756783`}], 
             PointBox[{96.7, -175.49105421813147`}], 
             PointBox[{96.8, -173.53330593531427`}], 
             PointBox[{96.9, -177.7941456393164}], 
             PointBox[{97., 177.6360770513129}], 
             PointBox[{97.1, 179.30636373178277`}], 
             PointBox[{97.2, -178.88721917831572`}], 
             PointBox[{97.3, 179.15908274921821`}], 
             PointBox[{97.4, -178.19882555994263`}], 
             PointBox[{97.5, -174.06450489912822`}], 
             PointBox[{97.6, -174.5749585798476}], 
             PointBox[{97.7, -175.35321518218552`}], 
             PointBox[{97.8, -171.86325490409217`}], 
             PointBox[{97.9, -174.2084438035381}], 
             PointBox[{98., -179.55630985437892`}], 
             PointBox[{98.1, 179.36286857919185`}], 
             PointBox[{98.2, -177.1645012464287}], 
             PointBox[{98.3, -178.90799442828575`}], 
             PointBox[{98.4, -178.23735125007806`}], 
             PointBox[{98.5, -173.7214385685802}], 
             PointBox[{98.6, -172.20239874332037`}], 
             PointBox[{98.7, -174.29220014416205`}], 
             PointBox[{98.8, -171.28572296432685`}], 
             PointBox[{98.9, -170.98671475546143`}], 
             PointBox[{99., -176.03497077334032`}], 
             PointBox[{99.1, -179.73482313967543`}], 
             PointBox[{99.2, -176.6060467724892}], 
             PointBox[{99.3, -176.4599845335615}], 
             PointBox[{99.4, -177.7272536027449}], 
             PointBox[{99.5, -173.92882516993268`}], 
             PointBox[{99.6, -170.4843295936007}], 
             PointBox[{99.7, -172.16871384314436`}], 
             PointBox[{99.8, -171.36610103076964`}], 
             PointBox[{99.9, -168.5744169985701}], 
             PointBox[{100., -172.2969380501454}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {-180, 180}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-328., 0}},
       PlotRangePadding->{6, 5}], {570, -528.}, ImageScaled[{0.5, 0.5}], {360, 312.},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {
     InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
            {Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
            {RGBColor[0.368417, 0.506779, 0.709798], 
             PointBox[{0, 0.6382220000000002}], 
             PointBox[{0.1, 0.6369270341522284}], 
             PointBox[{0.2, 0.637553053320335}], 
             PointBox[{0.3, 0.6396510421023557}], 
             PointBox[{0.4, 0.6415759293531875}], 
             PointBox[{0.5, 0.6424007639077278}], 
             PointBox[{0.6, 0.6420920425155128}], 
             PointBox[{0.7, 0.6406841793500048}], 
             PointBox[{0.8, 0.6385054816870271}], 
             PointBox[{0.9, 0.636919073710223}], 
             PointBox[{1., 0.6376001788662509}], 
             PointBox[{1.1, 0.6374931886769117}], 
             PointBox[{1.2, 0.6369042194396559}], 
             PointBox[{1.3, 0.6384513640454678}], 
             PointBox[{1.4, 0.640688033647853}], 
             PointBox[{1.5, 0.6420905708159974}], 
             PointBox[{1.6, 0.6422665295396439}], 
             PointBox[{1.7, 0.6413892398217619}], 
             PointBox[{1.8, 0.639522780799744}], 
             PointBox[{1.9, 0.6373924153301536}], 
             PointBox[{2., 0.6368170820439923}], 
             PointBox[{2.1, 0.6380828481082095}], 
             PointBox[{2.2, 0.6367257453924772}], 
             PointBox[{2.3, 0.6373411246609832}], 
             PointBox[{2.4, 0.6394775440363173}], 
             PointBox[{2.5, 0.6414470420026479}], 
             PointBox[{2.6, 0.6421427710166914}], 
             PointBox[{2.7, 0.6417338898570519}], 
             PointBox[{2.8, 0.6403603909555782}], 
             PointBox[{2.9, 0.6381706966228894}], 
             PointBox[{3., 0.6365730402981696}], 
             PointBox[{3.1, 0.6374828381323957}], 
             PointBox[{3.2, 0.6370981241462994}], 
             PointBox[{3.3, 0.6365486892135478}], 
             PointBox[{3.4, 0.6381196825173139}], 
             PointBox[{3.5, 0.6404497752462637}], 
             PointBox[{3.6, 0.6417422564021511}], 
             PointBox[{3.7, 0.6417658145636433}], 
             PointBox[{3.8, 0.640878294117823}], 
             PointBox[{3.9, 0.6390177780100886}], 
             PointBox[{4., 0.6368250200498776}], 
             PointBox[{4.1, 0.6364817799974154}], 
             PointBox[{4.2, 0.637659419904659}], 
             PointBox[{4.3, 0.6362148612870937}], 
             PointBox[{4.4, 0.6368724096679823}], 
             PointBox[{4.5, 0.6391431175921726}], 
             PointBox[{4.6, 0.6410596505406808}], 
             PointBox[{4.7, 0.6415459753451909}], 
             PointBox[{4.8, 0.6410677342111091}], 
             PointBox[{4.9, 0.6396983145524391}], 
             PointBox[{5., 0.6374132137419998}], 
             PointBox[{5.1, 0.6359486645840559}], 
             PointBox[{5.2, 0.6372314490938683}], 
             PointBox[{5.3, 0.636403570145923}], 
             PointBox[{5.4, 0.6359512396950712}], 
             PointBox[{5.5, 0.6376881545967806}], 
             PointBox[{5.6, 0.6400767176750946}], 
             PointBox[{5.7, 0.6411146830206588}], 
             PointBox[{5.8, 0.640991249216366}], 
             PointBox[{5.9, 0.6400875284219474}], 
             PointBox[{6., 0.6381203972409338}], 
             PointBox[{6.1, 0.6359188181693882}], 
             PointBox[{6.2, 0.6360903331384973}], 
             PointBox[{6.3, 0.636924493192562}], 
             PointBox[{6.4, 0.6354687886092767}], 
             PointBox[{6.5, 0.6363302089132178}], 
             PointBox[{6.6, 0.6388106929286204}], 
             PointBox[{6.7, 0.6404834549625936}], 
             PointBox[{6.8, 0.6407218076321642}], 
             PointBox[{6.9, 0.6401876875521537}], 
             PointBox[{7., 0.6387208716196812}], 
             PointBox[{7.1, 0.6362776112179213}], 
             PointBox[{7.2, 0.6352471587661512}], 
             PointBox[{7.3, 0.6368690911186565}], 
             PointBox[{7.4, 0.6354645936042641}], 
             PointBox[{7.5, 0.6352798299803869}], 
             PointBox[{7.6, 0.6373690604199259}], 
             PointBox[{7.7, 0.6396406856567266}], 
             PointBox[{7.8, 0.6403128015695764}], 
             PointBox[{7.9, 0.640068379949138}], 
             PointBox[{8., 0.6390810267584687}], 
             PointBox[{8.1, 0.6368559743055277}], 
             PointBox[{8.2, 0.6348823776750582}], 
             PointBox[{8.3, 0.6358424337912056}], 
             PointBox[{8.4, 0.6358694341061985}], 
             PointBox[{8.5, 0.6346377166867851}], 
             PointBox[{8.6, 0.6359527836155194}], 
             PointBox[{8.7, 0.63857254037955}], 
             PointBox[{8.8, 0.639788468976741}], 
             PointBox[{8.9, 0.6398052835823229}], 
             PointBox[{9., 0.6391890553802229}], 
             PointBox[{9.1, 0.6374449419126427}], 
             PointBox[{9.2, 0.6349383437116206}], 
             PointBox[{9.3, 0.634753606628951}], 
             PointBox[{9.4, 0.6362171454455756}], 
             PointBox[{9.5, 0.6344218285530527}], 
             PointBox[{9.6, 0.6347694675146008}], 
             PointBox[{9.7, 0.637307701995743}], 
             PointBox[{9.8, 0.6391469248334478}], 
             PointBox[{9.9, 0.6394534782225362}], 
             PointBox[{10., 0.6391042250819001}], 
             PointBox[{10.1, 0.6378793249163134}], 
             PointBox[{10.2, 0.6353164998111875}], 
             PointBox[{10.3, 0.6340415690475706}], 
             PointBox[{10.4, 0.6357582889471196}], 
             PointBox[{10.5, 0.6346044992774067}], 
             PointBox[{10.6, 0.6339401296782367}], 
             PointBox[{10.7, 0.635954953554549}], 
             PointBox[{10.8, 0.6383672659541539}], 
             PointBox[{10.9, 0.6390441869587558}], 
             PointBox[{11., 0.6388974177359912}], 
             PointBox[{11.1, 0.6380986297741954}], 
             PointBox[{11.2, 0.6358659061626152}], 
             PointBox[{11.3, 0.6337287513863755}], 
             PointBox[{11.4, 0.6347028184004132}], 
             PointBox[{11.5, 0.6350455952947782}], 
             PointBox[{11.6, 0.633487884304884}], 
             PointBox[{11.7, 0.6346841360396218}], 
             PointBox[{11.8, 0.6374274563487701}], 
             PointBox[{11.9, 0.6385858514398943}], 
             PointBox[{12., 0.6386230854678759}], 
             PointBox[{12.1, 0.6381286659260595}], 
             PointBox[{12.2, 0.6364102811508352}], 
             PointBox[{12.3, 0.6337711389568129}], 
             PointBox[{12.4, 0.6337186761986146}], 
             PointBox[{12.5, 0.6353161780522794}], 
             PointBox[{12.6, 0.6333870749845963}], 
             PointBox[{12.7, 0.6336474651912097}], 
             PointBox[{12.8, 0.636334546158105}], 
             PointBox[{12.9, 0.6380666805008641}], 
             PointBox[{13., 0.6383127933243042}], 
             PointBox[{13.1, 0.6380255861369452}], 
             PointBox[{13.2, 0.6368177324891608}], 
             PointBox[{13.3, 0.6341004275933559}], 
             PointBox[{13.4, 0.6330371291242122}], 
             PointBox[{13.5, 0.6349311555976695}], 
             PointBox[{13.6, 0.633590621114787}], 
             PointBox[{13.7, 0.632920447216612}], 
             PointBox[{13.8, 0.6351536747163801}], 
             PointBox[{13.9, 0.6374615372178236}], 
             PointBox[{14., 0.6379807259590857}], 
             PointBox[{14.1, 0.6378416999839481}], 
             PointBox[{14.2, 0.637042713475692}], 
             PointBox[{14.3, 0.6346062449528841}], 
             PointBox[{14.4, 0.6326679022526897}], 
             PointBox[{14.5, 0.6340427989468643}], 
             PointBox[{14.6, 0.6339941123464453}], 
             PointBox[{14.7, 0.6325017436866825}], 
             PointBox[{14.8, 0.6340028889206283}], 
             PointBox[{14.9, 0.6367397346225243}], 
             PointBox[{15., 0.6376265000882395}], 
             PointBox[{15.1, 0.6376117284852089}], 
             PointBox[{15.2, 0.6371019655801003}], 
             PointBox[{15.3, 0.635144166673649}], 
             PointBox[{15.4, 0.6325836902081577}], 
             PointBox[{15.5, 0.633115054925053}], 
             PointBox[{15.6, 0.6343500684778725}], 
             PointBox[{15.7, 0.632355173239722}], 
             PointBox[{15.8, 0.6330024177620316}], 
             PointBox[{15.9, 0.6358815856550972}], 
             PointBox[{16., 0.637238051281121}], 
             PointBox[{16.1, 0.6373539428413416}], 
             PointBox[{16.2, 0.6370362601724107}], 
             PointBox[{16.3, 0.6355900450885122}], 
             PointBox[{16.4, 0.6327482705998575}], 
             PointBox[{16.5, 0.6323685771010125}], 
             PointBox[{16.6, 0.6343131949888559}], 
             PointBox[{16.7, 0.6324345573385054}], 
             PointBox[{16.8, 0.6322246404234086}], 
             PointBox[{16.9, 0.6348988896218467}], 
             PointBox[{17., 0.6367947925828087}], 
             PointBox[{17.1, 0.6370746713583234}], 
             PointBox[{17.2, 0.6368834072724021}], 
             PointBox[{17.3, 0.6358744707699525}], 
             PointBox[{17.4, 0.6330983794014345}], 
             PointBox[{17.5, 0.6318376279360625}], 
             PointBox[{17.6, 0.6337718016143145}], 
             PointBox[{17.7, 0.6326796835118822}], 
             PointBox[{17.8, 0.6316801465319519}], 
             PointBox[{17.9, 0.6338488181784464}], 
             PointBox[{18., 0.6362693232848962}], 
             PointBox[{18.1, 0.636771005147187}], 
             PointBox[{18.2, 0.6366681875424138}], 
             PointBox[{18.3, 0.6359862620232692}], 
             PointBox[{18.4, 0.6335369389656527}], 
             PointBox[{18.5, 0.6315050247313323}], 
             PointBox[{18.6, 0.6329552959202954}], 
             PointBox[{18.7, 0.6329909970549091}], 
             PointBox[{18.8, 0.6313362177800766}], 
             PointBox[{18.9, 0.6328125245764886}], 
             PointBox[{19., 0.6356332031311152}], 
             PointBox[{19.1, 0.6364332853875697}], 
             PointBox[{19.2, 0.6364018762819561}], 
             PointBox[{19.3, 0.6359431822062303}], 
             PointBox[{19.4, 0.6339502944694255}], 
             PointBox[{19.5, 0.6313439477721787}], 
             PointBox[{19.6, 0.6321117109354265}], 
             PointBox[{19.7, 0.6332072461860654}], 
             PointBox[{19.8, 0.631143169854919}], 
             PointBox[{19.9, 0.6318648049985353}], 
             PointBox[{20., 0.6348657001020651}], 
             PointBox[{20.1, 0.6360459074132971}], 
             PointBox[{20.2, 0.6360853052668564}], 
             PointBox[{20.3, 0.6357695001506917}], 
             PointBox[{20.4, 0.6342396339707502}], 
             PointBox[{20.5, 0.6313190212795005}], 
             PointBox[{20.6, 0.6313446737693135}], 
             PointBox[{20.7, 0.6331533542939421}], 
             PointBox[{20.8, 0.6310429826234102}], 
             PointBox[{20.9, 0.6310417390234168}], 
             PointBox[{21., 0.6339639578435591}], 
             PointBox[{21.1, 0.6355899069960519}], 
             PointBox[{21.2, 0.6357112027267906}], 
             PointBox[{21.3, 0.6354808299301288}], 
             PointBox[{21.4, 0.6343455010300647}], 
             PointBox[{21.5, 0.6313758670313884}], 
             PointBox[{21.6, 0.6306615954293817}], 
             PointBox[{21.7, 0.6327550363782843}], 
             PointBox[{21.8, 0.6309705295211433}], 
             PointBox[{21.9, 0.630327810315153}], 
             PointBox[{22., 0.6329457928085467}], 
             PointBox[{22.1, 0.6350415138128053}], 
             PointBox[{22.2, 0.6352638409381316}], 
             PointBox[{22.3, 0.6350787755980655}], 
             PointBox[{22.4, 0.634242284046831}], 
             PointBox[{22.5, 0.6314346576071969}], 
             PointBox[{22.6, 0.6300293027935414}], 
             PointBox[{22.7, 0.6320752223623205}], 
             PointBox[{22.8, 0.6308459230684194}], 
             PointBox[{22.9, 0.6296724835034906}], 
             PointBox[{23., 0.6318425232834801}], 
             PointBox[{23.1, 0.6343762266043156}], 
             PointBox[{23.2, 0.6347201738494198}], 
             PointBox[{23.3, 0.634551841234182}], 
             PointBox[{23.4, 0.6339204788843225}], 
             PointBox[{23.5, 0.631396666710351}], 
             PointBox[{23.6, 0.6293957377093742}], 
             PointBox[{23.7, 0.6312208596785582}], 
             PointBox[{23.8, 0.6305748248934868}], 
             PointBox[{23.9, 0.6289996540059186}], 
             PointBox[{24., 0.630677965022253}], 
             PointBox[{24.1, 0.6335696367575958}], 
             PointBox[{24.2, 0.6340474460442677}], 
             PointBox[{24.3, 0.6338724858518897}], 
             PointBox[{24.4, 0.6333676202497075}], 
             PointBox[{24.5, 0.631158929562838}], 
             PointBox[{24.6, 0.6286921573756094}], 
             PointBox[{24.7, 0.6302560991801767}], 
             PointBox[{24.8, 0.6300562853758743}], 
             PointBox[{24.9, 0.6282172593571947}], 
             PointBox[{25., 0.6294510983534597}], 
             PointBox[{25.1, 0.6326013759995808}], 
             PointBox[{25.2, 0.6332032655108912}], 
             PointBox[{25.3, 0.6329977344167188}], 
             PointBox[{25.4, 0.6325579959008854}], 
             PointBox[{25.5, 0.6306235741093048}], 
             PointBox[{25.6, 0.6278292543887486}], 
             PointBox[{25.7, 0.6291872760781736}], 
             PointBox[{25.8, 0.6291890186741528}], 
             PointBox[{25.9, 0.6272218283944032}], 
             PointBox[{26., 0.628130508139402}], 
             PointBox[{26.1, 0.631457351623445}], 
             PointBox[{26.2, 0.6321325803717561}], 
             PointBox[{26.3, 0.6318687857738691}], 
             PointBox[{26.4, 0.6314450373852324}], 
             PointBox[{26.5, 0.6296979097383792}], 
             PointBox[{26.6, 0.6266981980437343}], 
             PointBox[{26.7, 0.6279837129719458}], 
             PointBox[{26.8, 0.6278682732407792}], 
             PointBox[{26.9, 0.6259143644648988}], 
             PointBox[{27., 0.6266721084855055}], 
             PointBox[{27.1, 0.6301344227411353}], 
             PointBox[{27.2, 0.6307716839991977}], 
             PointBox[{27.3, 0.6304169433849125}], 
             PointBox[{27.4, 0.6299707351414241}], 
             PointBox[{27.5, 0.6282920546049039}], 
             PointBox[{27.6, 0.6251902983551756}], 
             PointBox[{27.7, 0.6265907014997579}], 
             PointBox[{27.8, 0.625999319515678}], 
             PointBox[{27.9, 0.6242375114254431}], 
             PointBox[{28., 0.6250703134092623}], 
             PointBox[{28.1, 0.6286507002644153}], 
             PointBox[{28.2, 0.6290653247923724}], 
             PointBox[{28.3, 0.628590384878903}], 
             PointBox[{28.4, 0.6280877905156718}], 
             PointBox[{28.5, 0.6263218243876395}], 
             PointBox[{28.6, 0.6232608552466146}], 
             PointBox[{28.7, 0.6248855933340265}], 
             PointBox[{28.8, 0.6235979399189071}], 
             PointBox[{28.9, 0.6222501330403449}], 
             PointBox[{29., 0.623440977442526}], 
             PointBox[{29.1, 0.6270435139236309}], 
             PointBox[{29.2, 0.6270068191668011}], 
             PointBox[{29.3, 0.6264016015594727}], 
             PointBox[{29.4, 0.6258068688061977}], 
             PointBox[{29.5, 0.6237383397305047}], 
             PointBox[{29.6, 0.6210621767390839}], 
             PointBox[{29.7, 0.6225565967745406}], 
             PointBox[{29.8, 0.6209395429786378}], 
             PointBox[{29.9, 0.6201923715788926}], 
             PointBox[{30., 0.6220947280498625}], 
             PointBox[{30.1, 0.6253227308349655}], 
             PointBox[{30.2, 0.6246903185692186}], 
             PointBox[{30.3, 0.6239766994796451}], 
             PointBox[{30.4, 0.6232271463312713}], 
             PointBox[{30.5, 0.6205830173604632}], 
             PointBox[{30.6, 0.61904155473066}], 
             PointBox[{30.7, 0.6196033528003535}], 
             PointBox[{30.8, 0.6185055296688993}], 
             PointBox[{30.9, 0.6184580431980214}], 
             PointBox[{31., 0.6214262491207801}], 
             PointBox[{31.1, 0.6234270445264276}], 
             PointBox[{31.2, 0.6223080406541233}], 
             PointBox[{31.3, 0.6215194381545526}], 
             PointBox[{31.4, 0.6204889256203522}], 
             PointBox[{31.5, 0.6171580215269199}], 
             PointBox[{31.6, 0.6173315090462899}], 
             PointBox[{31.7, 0.6170057665937118}], 
             PointBox[{31.8, 0.6166974772152342}], 
             PointBox[{31.9, 0.6174699092800577}], 
             PointBox[{32., 0.6213860381310538}], 
             PointBox[{32.1, 0.6213556617607651}], 
             PointBox[{32.2, 0.6200567859745801}], 
             PointBox[{32.3, 0.6191961903212333}], 
             PointBox[{32.4, 0.6176310068706711}], 
             PointBox[{32.5, 0.6144466024718398}], 
             PointBox[{32.6, 0.6153760071016603}], 
             PointBox[{32.7, 0.6153806344062013}], 
             PointBox[{32.8, 0.6157018421018726}], 
             PointBox[{32.9, 0.6175819078607359}], 
             PointBox[{33., 0.6209897151248417}], 
             PointBox[{33.1, 0.6192886598808819}], 
             PointBox[{33.2, 0.6180501094770192}], 
             PointBox[{33.3, 0.6170500494162189}], 
             PointBox[{33.4, 0.6146323071404476}], 
             PointBox[{33.5, 0.6133473158696516}], 
             PointBox[{33.6, 0.6141693636433369}], 
             PointBox[{33.7, 0.6146860601539725}], 
             PointBox[{33.8, 0.6155833082201205}], 
             PointBox[{33.9, 0.6187931540697689}], 
             PointBox[{34., 0.6195249691129068}], 
             PointBox[{34.1, 0.6174382321552351}], 
             PointBox[{34.2, 0.6163192463583197}], 
             PointBox[{34.3, 0.6150235008132457}], 
             PointBox[{34.4, 0.6121210288221828}], 
             PointBox[{34.5, 0.6128472765072823}], 
             PointBox[{34.6, 0.6139468958002275}], 
             PointBox[{34.7, 0.6147593483799542}], 
             PointBox[{34.8, 0.6163867160518123}], 
             PointBox[{34.9, 0.6198317322441287}], 
             PointBox[{35., 0.6176337307865137}], 
             PointBox[{35.1, 0.6159205400788972}], 
             PointBox[{35.2, 0.6148628361927636}], 
             PointBox[{35.3, 0.6130896869379526}], 
             PointBox[{35.4, 0.6114556402757222}], 
             PointBox[{35.5, 0.6132620470114564}], 
             PointBox[{35.6, 0.6144029566336044}], 
             PointBox[{35.7, 0.6154883355341585}], 
             PointBox[{35.8, 0.6180318911182489}], 
             PointBox[{35.9, 0.6189793601434894}], 
             PointBox[{36., 0.6160555668176684}], 
             PointBox[{36.1, 0.6147906011441471}], 
             PointBox[{36.2, 0.6137061276921922}], 
             PointBox[{36.3, 0.6116984869533985}], 
             PointBox[{36.4, 0.6122491037496134}], 
             PointBox[{36.5, 0.6142818892473912}], 
             PointBox[{36.6, 0.6153515533045856}], 
             PointBox[{36.7, 0.6168091832107796}], 
             PointBox[{36.8, 0.6196468182385168}], 
             PointBox[{36.9, 0.6171635539044568}], 
             PointBox[{37., 0.61504523963039}], 
             PointBox[{37.1, 0.6141122647475604}], 
             PointBox[{37.2, 0.612995448486379}], 
             PointBox[{37.3, 0.6116173659772483}], 
             PointBox[{37.4, 0.6140863634241046}], 
             PointBox[{37.5, 0.6156341029766996}], 
             PointBox[{37.6, 0.6167049460317483}], 
             PointBox[{37.7, 0.6186025074656255}], 
             PointBox[{37.8, 0.6195588310961745}], 
             PointBox[{37.9, 0.6159113594098796}], 
             PointBox[{38., 0.6146708130086257}], 
             PointBox[{38.1, 0.6140166774866372}], 
             PointBox[{38.2, 0.6131288869523329}], 
             PointBox[{38.3, 0.6132649635073385}], 
             PointBox[{38.4, 0.616127370059683}], 
             PointBox[{38.5, 0.617257658695302}], 
             PointBox[{38.6, 0.6184134232030792}], 
             PointBox[{38.7, 0.6204192227232246}], 
             PointBox[{38.8, 0.6182192774988465}], 
             PointBox[{38.9, 0.6156022271802459}], 
             PointBox[{39., 0.6150117123763843}], 
             PointBox[{39.1, 0.6147598609622351}], 
             PointBox[{39.2, 0.6139149637102135}], 
             PointBox[{39.3, 0.6162297060548597}], 
             PointBox[{39.4, 0.6182423296911813}], 
             PointBox[{39.5, 0.6191527697405466}], 
             PointBox[{39.6, 0.6204065161258715}], 
             PointBox[{39.7, 0.6214407216855786}], 
             PointBox[{39.8, 0.6175231435252019}], 
             PointBox[{39.9, 0.6162046414694897}], 
             PointBox[{40., 0.616205156256845}], 
             PointBox[{40.1, 0.6165405076590116}], 
             PointBox[{40.2, 0.615753347507274}], 
             PointBox[{40.3, 0.6192179746064351}], 
             PointBox[{40.4, 0.6205058489802554}], 
             PointBox[{40.5, 0.6213117251148406}], 
             PointBox[{40.6, 0.6225259184649892}], 
             PointBox[{40.7, 0.6216155722435253}], 
             PointBox[{40.8, 0.6180167937350739}], 
             PointBox[{40.9, 0.617656769992369}], 
             PointBox[{41., 0.618382111803538}], 
             PointBox[{41.1, 0.618462103430769}], 
             PointBox[{41.2, 0.6189559393528625}], 
             PointBox[{41.3, 0.6220445463763435}], 
             PointBox[{41.4, 0.622929602927108}], 
             PointBox[{41.5, 0.6236638284778326}], 
             PointBox[{41.6, 0.6245620560537466}], 
             PointBox[{41.7, 0.6219734599057356}], 
             PointBox[{41.8, 0.6194435851827982}], 
             PointBox[{41.9, 0.6198312509198491}], 
             PointBox[{42., 0.6213155720090306}], 
             PointBox[{42.1, 0.6202596371347879}], 
             PointBox[{42.2, 0.6222924033361411}], 
             PointBox[{42.3, 0.6247252246637218}], 
             PointBox[{42.4, 0.6253983325965623}], 
             PointBox[{42.5, 0.6260414906434666}], 
             PointBox[{42.6, 0.6264130725154563}], 
             PointBox[{42.7, 0.623038779244599}], 
             PointBox[{42.8, 0.6213879625157965}], 
             PointBox[{42.9, 0.6224166004678001}], 
             PointBox[{43., 0.6240571079467361}], 
             PointBox[{43.1, 0.6223740831998426}], 
             PointBox[{43.2, 0.6251484673169723}], 
             PointBox[{43.3, 0.6271565305024615}], 
             PointBox[{43.4, 0.6277102107939246}], 
             PointBox[{43.5, 0.6282355222774951}], 
             PointBox[{43.6, 0.6281083425014488}], 
             PointBox[{43.7, 0.6245676626489907}], 
             PointBox[{43.8, 0.6234232883858694}], 
             PointBox[{43.9, 0.6249442126373668}], 
             PointBox[{44., 0.626054314148547}], 
             PointBox[{44.1, 0.624408310220489}], 
             PointBox[{44.2, 0.6273825206905158}], 
             PointBox[{44.3, 0.629213732609082}], 
             PointBox[{44.4, 0.6296971318523622}], 
             PointBox[{44.5, 0.6301012914372631}], 
             PointBox[{44.6, 0.6296646118668552}], 
             PointBox[{44.7, 0.6261916961972218}], 
             PointBox[{44.8, 0.625233672972943}], 
             PointBox[{44.9, 0.6270336583616254}], 
             PointBox[{45., 0.6275808751256717}], 
             PointBox[{45.1, 0.6260807530347314}], 
             PointBox[{45.2, 0.6290141014737164}], 
             PointBox[{45.3, 0.6308523007440451}], 
             PointBox[{45.4, 0.6313025593648229}], 
             PointBox[{45.5, 0.6316069974282954}], 
             PointBox[{45.6, 0.6310552960718689}], 
             PointBox[{45.7, 0.6277152784427833}], 
             PointBox[{45.8, 0.6266907104256172}], 
             PointBox[{45.9, 0.6285680152030297}], 
             PointBox[{46., 0.6288611072999879}], 
             PointBox[{46.1, 0.6273639998163422}], 
             PointBox[{46.2, 0.6301213381434136}], 
             PointBox[{46.3, 0.6321026155700924}], 
             PointBox[{46.4, 0.6325592924922965}], 
             PointBox[{46.5, 0.6327943589426425}], 
             PointBox[{46.6, 0.6322612532751032}], 
             PointBox[{46.7, 0.6290996566405448}], 
             PointBox[{46.8, 0.6278137022537911}], 
             PointBox[{46.9, 0.6296072789557136}], 
             PointBox[{47., 0.6299808913998011}], 
             PointBox[{47.1, 0.6283442087607365}], 
             PointBox[{47.2, 0.6308002700858646}], 
             PointBox[{47.3, 0.6330226404231133}], 
             PointBox[{47.4, 0.6335328366839099}], 
             PointBox[{47.5, 0.633727777775258}], 
             PointBox[{47.6, 0.6332845410793256}], 
             PointBox[{47.7, 0.6303739123502091}], 
             PointBox[{47.8, 0.6286903888353513}], 
             PointBox[{47.9, 0.6302572996062349}], 
             PointBox[{48., 0.6309802096786894}], 
             PointBox[{48.1, 0.6291291901883715}], 
             PointBox[{48.2, 0.6311478361639135}], 
             PointBox[{48.3, 0.633663596511285}], 
             PointBox[{48.4, 0.6342869495322602}], 
             PointBox[{48.5, 0.6344669133309793}], 
             PointBox[{48.6, 0.6341377621031851}], 
             PointBox[{48.7, 0.6315716158582618}], 
             PointBox[{48.8, 0.629424834135492}], 
             PointBox[{48.9, 0.6306256048056947}], 
             PointBox[{49., 0.6318620717257554}], 
             PointBox[{49.1, 0.629814258638384}], 
             PointBox[{49.2, 0.6312657027698853}], 
             PointBox[{49.3, 0.6340593654854344}], 
             PointBox[{49.4, 0.6348714713025913}], 
             PointBox[{49.5, 0.6350606874750466}], 
             PointBox[{49.6, 0.6348427433266268}], 
             PointBox[{49.7, 0.6327005386262525}], 
             PointBox[{49.8, 0.6301138253960509}], 
             PointBox[{49.9, 0.6308169513946913}], 
             PointBox[{50., 0.6325766186328342}], 
             PointBox[{50.1, 0.6304748469640573}], 
             PointBox[{50.2, 0.6312594251058095}], 
             PointBox[{50.3, 0.6342272915859409}], 
             PointBox[{50.4, 0.6353190894633305}], 
             PointBox[{50.5, 0.6355462108396661}], 
             PointBox[{50.6, 0.6354240651938731}], 
             PointBox[{50.7, 0.6337437494600342}], 
             PointBox[{50.8, 0.6308390501268711}], 
             PointBox[{50.9, 0.6309289165432}], 
             PointBox[{51., 0.6330275935019162}], 
             PointBox[{51.1, 0.6311682339898624}], 
             PointBox[{51.2, 0.6312298265831486}], 
             PointBox[{51.3, 0.6341787096739564}], 
             PointBox[{51.4, 0.6356468893779219}], 
             PointBox[{51.5, 0.635949628703963}], 
             PointBox[{51.6, 0.635906819600486}], 
             PointBox[{51.7, 0.6346720406686266}], 
             PointBox[{51.8, 0.6316588743844653}], 
             PointBox[{51.9, 0.6310453841775578}], 
             PointBox[{52., 0.6331438238218268}], 
             PointBox[{52.1, 0.6319335011810435}], 
             PointBox[{52.2, 0.6312617999607146}], 
             PointBox[{52.3, 0.6339369459745996}], 
             PointBox[{52.4, 0.6358568893428836}], 
             PointBox[{52.5, 0.63628946066885}], 
             PointBox[{52.6, 0.6363148174097442}], 
             PointBox[{52.7, 0.6354672112177745}], 
             PointBox[{52.8, 0.6325968771408116}], 
             PointBox[{52.9, 0.6312368642058547}], 
             PointBox[{53., 0.6329758151502954}], 
             PointBox[{53.1, 0.63277470244561}], 
             PointBox[{53.2, 0.631414651578397}], 
             PointBox[{53.3, 0.6335556060450472}], 
             PointBox[{53.4, 0.6359369972154953}], 
             PointBox[{53.5, 0.6365754922283388}], 
             PointBox[{53.6, 0.6366691697693128}], 
             PointBox[{53.7, 0.636129288598607}], 
             PointBox[{53.8, 0.6336290162213472}], 
             PointBox[{53.9, 0.6315634121789353}], 
             PointBox[{54., 0.6326834770164864}], 
             PointBox[{54.1, 0.6336117302806932}], 
             PointBox[{54.2, 0.6317287564390506}], 
             PointBox[{54.3, 0.6331280344311525}], 
             PointBox[{54.4, 0.6358655504786199}], 
             PointBox[{54.5, 0.6368099304107333}], 
             PointBox[{54.6, 0.6369859342297247}], 
             PointBox[{54.7, 0.6366768881388855}], 
             PointBox[{54.8, 0.634687574928395}], 
             PointBox[{54.9, 0.6320783904645123}], 
             PointBox[{55., 0.6324308943803499}], 
             PointBox[{55.1, 0.6342224519812961}], 
             PointBox[{55.2, 0.6322320431451229}], 
             PointBox[{55.3, 0.632765797385439}], 
             PointBox[{55.4, 0.6356218076202538}], 
             PointBox[{55.5, 0.636983410443951}], 
             PointBox[{55.6, 0.637275960080637}], 
             PointBox[{55.7, 0.6371373590769728}], 
             PointBox[{55.8, 0.6356906902535455}], 
             PointBox[{55.9, 0.6328195211598093}], 
             PointBox[{56., 0.6323265678370441}], 
             PointBox[{56.1, 0.6343545071838311}], 
             PointBox[{56.2, 0.632946056468726}], 
             PointBox[{56.3, 0.6325712308208938}], 
             PointBox[{56.4, 0.6352102393337395}], 
             PointBox[{56.5, 0.6370740731453992}], 
             PointBox[{56.6, 0.6375437693796645}], 
             PointBox[{56.7, 0.6375384118949371}], 
             PointBox[{56.8, 0.6365764183749065}], 
             PointBox[{56.9, 0.6337872995111584}], 
             PointBox[{57., 0.6324356063281226}], 
             PointBox[{57.1, 0.6340506984272887}], 
             PointBox[{57.2, 0.633853230273694}], 
             PointBox[{57.3, 0.6326143651567643}], 
             PointBox[{57.4, 0.6346882886977726}], 
             PointBox[{57.5, 0.6370470694559014}], 
             PointBox[{57.6, 0.6377851249575276}], 
             PointBox[{57.7, 0.6379021557928097}], 
             PointBox[{57.8, 0.6373256474868761}], 
             PointBox[{57.9, 0.6349226606262651}], 
             PointBox[{58., 0.6328065728817122}], 
             PointBox[{58.1, 0.6336388304307289}], 
             PointBox[{58.2, 0.6347808085548595}], 
             PointBox[{58.3, 0.632934947585286}], 
             PointBox[{58.4, 0.6341721680541993}], 
             PointBox[{58.5, 0.6368610622227434}], 
             PointBox[{58.6, 0.637984421721786}], 
             PointBox[{58.7, 0.6382422565003437}], 
             PointBox[{58.8, 0.6379535512607672}], 
             PointBox[{58.9, 0.6361109577401436}], 
             PointBox[{59., 0.6334797541470554}], 
             PointBox[{59.1, 0.6333933553820179}], 
             PointBox[{59.2, 0.6352917613284258}], 
             PointBox[{59.3, 0.6335617292750998}], 
             PointBox[{59.4, 0.6338052946294513}], 
             PointBox[{59.5, 0.6364911749105205}], 
             PointBox[{59.6, 0.6381101135617339}], 
             PointBox[{59.7, 0.6385610157675462}], 
             PointBox[{59.8, 0.6384897745347746}], 
             PointBox[{59.9, 0.6372302446241862}], 
             PointBox[{60., 0.6344653705320005}], 
             PointBox[{60.1, 0.6334380669220255}], 
             PointBox[{60.2, 0.6351197582290152}], 
             PointBox[{60.3, 0.6344998343840352}], 
             PointBox[{60.4, 0.6337080084129921}], 
             PointBox[{60.5, 0.6359691996081926}], 
             PointBox[{60.6, 0.6381131118078119}], 
             PointBox[{60.7, 0.6388472981109321}], 
             PointBox[{60.8, 0.6389614425168335}], 
             PointBox[{60.9, 0.6382038462236058}], 
             PointBox[{61., 0.6357054874678727}], 
             PointBox[{61.1, 0.6338263766610805}], 
             PointBox[{61.2, 0.6346713965084771}], 
             PointBox[{61.3, 0.6355833113440463}], 
             PointBox[{61.4, 0.6339543045959549}], 
             PointBox[{61.5, 0.6354113403933568}], 
             PointBox[{61.6, 0.63793571644077}], 
             PointBox[{61.7, 0.6390728862474632}], 
             PointBox[{61.8, 0.63938238671224}], 
             PointBox[{61.9, 0.6390153339641365}], 
             PointBox[{62., 0.6370594977147903}], 
             PointBox[{62.1, 0.6345886526981392}], 
             PointBox[{62.2, 0.6344274826549319}], 
             PointBox[{62.3, 0.6362050361551144}], 
             PointBox[{62.4, 0.6345922566168027}], 
             PointBox[{62.5, 0.6349907756176264}], 
             PointBox[{62.6, 0.63754258458614}], 
             PointBox[{62.7, 0.639187409535726}], 
             PointBox[{62.8, 0.6397486440933609}], 
             PointBox[{62.9, 0.639683186418068}], 
             PointBox[{63., 0.6383542716063894}], 
             PointBox[{63.1, 0.6357146424978535}], 
             PointBox[{63.2, 0.6345694989140364}], 
             PointBox[{63.3, 0.635963004062836}], 
             PointBox[{63.4, 0.635625785888725}], 
             PointBox[{63.5, 0.6348681377372828}], 
             PointBox[{63.6, 0.6369747678001939}], 
             PointBox[{63.7, 0.6391220770395486}], 
             PointBox[{63.8, 0.6400333191537403}], 
             PointBox[{63.9, 0.6402304858344667}], 
             PointBox[{64., 0.6394658057740972}], 
             PointBox[{64.1, 0.6371037213692173}], 
             PointBox[{64.2, 0.6351354409640945}], 
             PointBox[{64.3, 0.6355178969686217}], 
             PointBox[{64.4, 0.6367346078763498}], 
             PointBox[{64.5, 0.6351505807853495}], 
             PointBox[{64.6, 0.6363801117918745}], 
             PointBox[{64.7, 0.6388119428860638}], 
             PointBox[{64.8, 0.640185391616156}], 
             PointBox[{64.9, 0.6406632300887394}], 
             PointBox[{65., 0.640352049469899}], 
             PointBox[{65.1, 0.6385595946515371}], 
             PointBox[{65.2, 0.6361168233565702}], 
             PointBox[{65.3, 0.6354379440079257}], 
             PointBox[{65.4, 0.6369963184428624}], 
             PointBox[{65.5, 0.6359058002868004}], 
             PointBox[{65.6, 0.6359669850974987}], 
             PointBox[{65.7, 0.6382500075147205}], 
             PointBox[{65.8, 0.6401313188567146}], 
             PointBox[{65.9, 0.6409616957930324}], 
             PointBox[{66., 0.6410218730689724}], 
             PointBox[{66.1, 0.6398705520938454}], 
             PointBox[{66.2, 0.6374318527935751}], 
             PointBox[{66.3, 0.6358356446611615}], 
             PointBox[{66.4, 0.6364931980491642}], 
             PointBox[{66.5, 0.637038551621466}], 
             PointBox[{66.6, 0.63591513655952}], 
             PointBox[{66.7, 0.6375471364808073}], 
             PointBox[{66.8, 0.6397974550344931}], 
             PointBox[{66.9, 0.6410778079630606}], 
             PointBox[{67., 0.6414899804668182}], 
             PointBox[{67.1, 0.6409093734764122}], 
             PointBox[{67.2, 0.6388880765190021}], 
             PointBox[{67.3, 0.6366831532568925}], 
             PointBox[{67.4, 0.6362153366469969}], 
             PointBox[{67.5, 0.6376863389972974}], 
             PointBox[{67.6, 0.6363488334114071}], 
             PointBox[{67.7, 0.6369189334492753}], 
             PointBox[{67.8, 0.6391638511149133}], 
             PointBox[{67.9, 0.6409408429221658}], 
             PointBox[{68., 0.6417498115248907}], 
             PointBox[{68.1, 0.6416459864789702}], 
             PointBox[{68.2, 0.6402371085789861}], 
             PointBox[{68.3, 0.6378833639310074}], 
             PointBox[{68.4, 0.6364565122789353}], 
             PointBox[{68.5, 0.6372153010842873}], 
             PointBox[{68.6, 0.6372890068762267}], 
             PointBox[{68.7, 0.6365905576142593}], 
             PointBox[{68.8, 0.638330688971821}], 
             PointBox[{68.9, 0.6404823669725531}], 
             PointBox[{69., 0.6417654843654386}], 
             PointBox[{69.1, 0.6420951890679758}], 
             PointBox[{69.2, 0.6412953991291485}], 
             PointBox[{69.3, 0.6392388471932189}], 
             PointBox[{69.4, 0.6371732194078241}], 
             PointBox[{69.5, 0.6367545237894385}], 
             PointBox[{69.6, 0.6380736567326738}], 
             PointBox[{69.7, 0.63673251280263}], 
             PointBox[{69.8, 0.6375188688377711}], 
             PointBox[{69.9, 0.6396937463365576}], 
             PointBox[{70., 0.6414788562200194}], 
             PointBox[{70.1, 0.6422676275520914}], 
             PointBox[{70.2, 0.6420007737663234}], 
             PointBox[{70.3, 0.6404901149108106}], 
             PointBox[{70.4, 0.6382379818786228}], 
             PointBox[{70.5, 0.6368336439734917}], 
             PointBox[{70.6, 0.6376335833185531}], 
             PointBox[{70.7, 0.6374281337811911}], 
             PointBox[{70.8, 0.636972700999871}], 
             PointBox[{70.9, 0.6386898290292929}], 
             PointBox[{71., 0.6408366393231344}], 
             PointBox[{71.1, 0.6421466951225475}], 
             PointBox[{71.2, 0.642366371914147}], 
             PointBox[{71.3, 0.6414397907632179}], 
             PointBox[{71.4, 0.6394378752148421}], 
             PointBox[{71.5, 0.6374056122860691}], 
             PointBox[{71.6, 0.6369858377573031}], 
             PointBox[{71.7, 0.6381900799482013}], 
             PointBox[{71.8, 0.6368799311518749}], 
             PointBox[{71.9, 0.637704081243738}], 
             PointBox[{72., 0.6398513989845414}], 
             PointBox[{72.1, 0.6416924744955564}], 
             PointBox[{72.2, 0.6424189377825553}], 
             PointBox[{72.3, 0.6420190057910026}], 
             PointBox[{72.4, 0.6405133212614705}], 
             PointBox[{72.5, 0.6383157975847831}], 
             PointBox[{72.6, 0.6368744821962817}], 
             PointBox[{72.7, 0.6377627463907756}], 
             PointBox[{72.8, 0.6373483167564311}], 
             PointBox[{72.9, 0.6369836150028838}], 
             PointBox[{73., 0.638661440097683}], 
             PointBox[{73.1, 0.6408686411030168}], 
             PointBox[{73.2, 0.6421637122550752}], 
             PointBox[{73.3, 0.6422489965452988}], 
             PointBox[{73.4, 0.6412788243143863}], 
             PointBox[{73.5, 0.6393368587094984}], 
             PointBox[{73.6, 0.6372686076185877}], 
             PointBox[{73.7, 0.6369139469369096}], 
             PointBox[{73.8, 0.638031148638849}], 
             PointBox[{73.9, 0.6367074302522909}], 
             PointBox[{74., 0.637513466972709}], 
             PointBox[{74.1, 0.6397045550108122}], 
             PointBox[{74.2, 0.6415804509182647}], 
             PointBox[{74.3, 0.642174210332061}], 
             PointBox[{74.4, 0.6416828602429193}], 
             PointBox[{74.5, 0.6402165502040674}], 
             PointBox[{74.6, 0.6380042962050425}], 
             PointBox[{74.7, 0.6365635695990047}], 
             PointBox[{74.8, 0.6376588023299559}], 
             PointBox[{74.9, 0.6369784270164853}], 
             PointBox[{75., 0.636647748544596}], 
             PointBox[{75.1, 0.6383523269171507}], 
             PointBox[{75.2, 0.6406450831146591}], 
             PointBox[{75.3, 0.6418216753609954}], 
             PointBox[{75.4, 0.6417635708218175}], 
             PointBox[{75.5, 0.6407924158804186}], 
             PointBox[{75.6, 0.6388525297373319}], 
             PointBox[{75.7, 0.6367303828806411}], 
             PointBox[{75.8, 0.6366241394360018}], 
             PointBox[{75.9, 0.6375777911018838}], 
             PointBox[{76., 0.6362199065141155}], 
             PointBox[{76.1, 0.6370638275892154}], 
             PointBox[{76.2, 0.6393847986953984}], 
             PointBox[{76.3, 0.6411904766803794}], 
             PointBox[{76.4, 0.6415828632565034}], 
             PointBox[{76.5, 0.6410339358487198}], 
             PointBox[{76.6, 0.6395726950626203}], 
             PointBox[{76.7, 0.6372666559939226}], 
             PointBox[{76.8, 0.6359866955040743}], 
             PointBox[{76.9, 0.6373892883552439}], 
             PointBox[{77., 0.6363087548446035}], 
             PointBox[{77.1, 0.6360689202813504}], 
             PointBox[{77.2, 0.6379382733705342}], 
             PointBox[{77.3, 0.6402631826533793}], 
             PointBox[{77.4, 0.6411869173794544}], 
             PointBox[{77.5, 0.6409972177512084}], 
             PointBox[{77.6, 0.6400141009059985}], 
             PointBox[{77.7, 0.6379651955069116}], 
             PointBox[{77.8, 0.6358646806488392}], 
             PointBox[{77.9, 0.6362786743031222}], 
             PointBox[{78., 0.6368088807709964}], 
             PointBox[{78.1, 0.6354978101061703}], 
             PointBox[{78.2, 0.6365421557057843}], 
             PointBox[{78.3, 0.6390454053585527}], 
             PointBox[{78.4, 0.6405926797417322}], 
             PointBox[{78.5, 0.6407559564361637}], 
             PointBox[{78.6, 0.6401596496104606}], 
             PointBox[{78.7, 0.6385955553803297}], 
             PointBox[{78.8, 0.6361559948972773}], 
             PointBox[{78.9, 0.6353441213493548}], 
             PointBox[{79., 0.6369466358749694}], 
             PointBox[{79.1, 0.6353995712046886}], 
             PointBox[{79.2, 0.6354209216013103}], 
             PointBox[{79.3, 0.6376238490469514}], 
             PointBox[{79.4, 0.6397923193809809}], 
             PointBox[{79.5, 0.6403689203263021}], 
             PointBox[{79.6, 0.6400722704328755}], 
             PointBox[{79.7, 0.639000919420767}], 
             PointBox[{79.8, 0.6367027383137035}], 
             PointBox[{79.9, 0.6348851463566405}], 
             PointBox[{80., 0.6360492239675496}], 
             PointBox[{80.1, 0.6357394697070812}], 
             PointBox[{80.2, 0.6346955638887156}], 
             PointBox[{80.3, 0.6361850416371355}], 
             PointBox[{80.4, 0.6387690219012149}], 
             PointBox[{80.5, 0.6398651748485038}], 
             PointBox[{80.6, 0.6398283702956165}], 
             PointBox[{80.7, 0.6391497365930864}], 
             PointBox[{80.8, 0.6373005092840104}], 
             PointBox[{80.9, 0.6348591084385994}], 
             PointBox[{81., 0.6349126165966549}], 
             PointBox[{81.1, 0.6361602172433585}], 
             PointBox[{81.2, 0.6343940484156158}], 
             PointBox[{81.3, 0.6349424850429443}], 
             PointBox[{81.4, 0.6375393145665209}], 
             PointBox[{81.5, 0.6392486730734295}], 
             PointBox[{81.6, 0.6394888595787054}], 
             PointBox[{81.7, 0.6390930155084321}], 
             PointBox[{81.8, 0.6377690041237828}], 
             PointBox[{81.9, 0.6351769689660407}], 
             PointBox[{82., 0.6341146464471173}], 
             PointBox[{82.1, 0.6358909674303226}], 
             PointBox[{82.2, 0.6344978117541088}], 
             PointBox[{82.3, 0.634036636691947}], 
             PointBox[{82.4, 0.6361934681565667}], 
             PointBox[{82.5, 0.6385009196281359}], 
             PointBox[{82.6, 0.6390881381568785}], 
             PointBox[{82.7, 0.638902178835097}], 
             PointBox[{82.8, 0.6380268551351894}], 
             PointBox[{82.9, 0.6356992603928525}], 
             PointBox[{83., 0.6337174101938212}], 
             PointBox[{83.1, 0.6348970281727578}], 
             PointBox[{83.2, 0.6349030991618189}], 
             PointBox[{83.3, 0.6335056737492477}], 
             PointBox[{83.4, 0.6348919261371107}], 
             PointBox[{83.5, 0.6375978197303287}], 
             PointBox[{83.6, 0.6386393509746122}], 
             PointBox[{83.7, 0.638634925780726}], 
             PointBox[{83.8, 0.6380865380659041}], 
             PointBox[{83.9, 0.6362508427459185}], 
             PointBox[{84., 0.6336819299663244}], 
             PointBox[{84.1, 0.6338639153193518}], 
             PointBox[{84.2, 0.6352551755728646}], 
             PointBox[{84.3, 0.633329515132764}], 
             PointBox[{84.4, 0.6337968007965922}], 
             PointBox[{84.5, 0.6365375067049978}], 
             PointBox[{84.6, 0.6381350438808404}], 
             PointBox[{84.7, 0.6383274072881847}], 
             PointBox[{84.8, 0.6380015391412497}], 
             PointBox[{84.9, 0.6366883760142117}], 
             PointBox[{85., 0.6339479837902983}], 
             PointBox[{85.1, 0.6331088913086004}], 
             PointBox[{85.2, 0.6350291194289907}], 
             PointBox[{85.3, 0.6334647043814793}], 
             PointBox[{85.4, 0.6329977594519011}], 
             PointBox[{85.5, 0.6353695690529498}], 
             PointBox[{85.6, 0.6375522756232472}], 
             PointBox[{85.7, 0.6379963268016126}], 
             PointBox[{85.8, 0.6378260481069842}], 
             PointBox[{85.9, 0.6369457619488965}], 
             PointBox[{86., 0.6344156500178645}], 
             PointBox[{86.1, 0.632664230890491}], 
             PointBox[{86.2, 0.634214866360595}], 
             PointBox[{86.3, 0.6338272075211937}], 
             PointBox[{86.4, 0.6325071218722849}], 
             PointBox[{86.5, 0.6342005115427669}], 
             PointBox[{86.6, 0.6368609729346313}], 
             PointBox[{86.7, 0.6376441953502154}], 
             PointBox[{86.8, 0.6375977895061857}], 
             PointBox[{86.9, 0.6370305566031869}], 
             PointBox[{87., 0.6349471753070768}], 
             PointBox[{87.1, 0.6325052191101244}], 
             PointBox[{87.2, 0.633266536560111}], 
             PointBox[{87.3, 0.6342141609013886}], 
             PointBox[{87.4, 0.6322922811296169}], 
             PointBox[{87.5, 0.6331541230887332}], 
             PointBox[{87.6, 0.6360370058378594}], 
             PointBox[{87.7, 0.6372616747795784}], 
             PointBox[{87.8, 0.6373380365896434}], 
             PointBox[{87.9, 0.6369802442610151}], 
             PointBox[{88., 0.635409773832193}], 
             PointBox[{88.1, 0.6325984621237645}], 
             PointBox[{88.2, 0.63246362046412}], 
             PointBox[{88.3, 0.6342945678278236}], 
             PointBox[{88.4, 0.6323067569737116}], 
             PointBox[{88.5, 0.6323134178713304}], 
             PointBox[{88.6, 0.6350826699551024}], 
             PointBox[{88.7, 0.6368300169335203}], 
             PointBox[{88.8, 0.6370545840514305}], 
             PointBox[{88.9, 0.6368333316197424}], 
             PointBox[{89., 0.6357208556919242}], 
             PointBox[{89.1, 0.6328893378576271}], 
             PointBox[{89.2, 0.6318671486430029}], 
             PointBox[{89.3, 0.6338735142568604}], 
             PointBox[{89.4, 0.6324948370179493}], 
             PointBox[{89.5, 0.6317002261844629}], 
             PointBox[{89.6, 0.634040197055368}], 
             PointBox[{89.7, 0.6363235901795306}], 
             PointBox[{89.8, 0.6367457012842745}], 
             PointBox[{89.9, 0.6366167296671408}], 
             PointBox[{90., 0.6358561348735537}], 
             PointBox[{90.1, 0.6332895144183586}], 
             PointBox[{90.2, 0.6314642455776611}], 
             PointBox[{90.3, 0.6331045431850402}], 
             PointBox[{90.4, 0.6327715356537794}], 
             PointBox[{90.5, 0.6312884070350822}], 
             PointBox[{90.6, 0.6329854507084928}], 
             PointBox[{90.7, 0.6357144087292456}], 
             PointBox[{90.8, 0.6364032405075085}], 
             PointBox[{90.9, 0.6363436621659682}], 
             PointBox[{91., 0.6358280347631029}], 
             PointBox[{91.1, 0.6336879029711703}], 
             PointBox[{91.2, 0.6312277255129662}], 
             PointBox[{91.3, 0.6322466020613559}], 
             PointBox[{91.4, 0.6330003147230068}], 
             PointBox[{91.5, 0.6310286284449106}], 
             PointBox[{91.6, 0.6319934225883572}], 
             PointBox[{91.7, 0.6349788903624455}], 
             PointBox[{91.8, 0.6360123117000979}], 
             PointBox[{91.9, 0.6360157209525662}], 
             PointBox[{92., 0.635658503491461}], 
             PointBox[{92.1, 0.6339808337822718}], 
             PointBox[{92.2, 0.6311232016954798}], 
             PointBox[{92.3, 0.6314355398573359}], 
             PointBox[{92.4, 0.633015029704681}], 
             PointBox[{92.5, 0.630861376557626}], 
             PointBox[{92.6, 0.6311067879312983}], 
             PointBox[{92.7, 0.634107001261706}], 
             PointBox[{92.8, 0.6355540160914323}], 
             PointBox[{92.9, 0.6356252089361779}], 
             PointBox[{93., 0.6353631813011089}], 
             PointBox[{93.1, 0.6340964686723016}], 
             PointBox[{93.2, 0.6310994544545722}], 
             PointBox[{93.3, 0.6306944315307185}], 
             PointBox[{93.4, 0.6327107056262735}], 
             PointBox[{93.5, 0.6307199357131121}], 
             PointBox[{93.6, 0.6303209598601991}], 
             PointBox[{93.7, 0.6331069261892484}], 
             PointBox[{93.8, 0.635005307270655}], 
             PointBox[{93.9, 0.6351556807807037}], 
             PointBox[{94., 0.6349444789951921}], 
             PointBox[{94.1, 0.6339983670311611}], 
             PointBox[{94.2, 0.6310821304355365}], 
             PointBox[{94.3, 0.629995021495052}], 
             PointBox[{94.4, 0.6321060452330797}], 
             PointBox[{94.5, 0.6305247192292085}], 
             PointBox[{94.6, 0.6295885752033854}], 
             PointBox[{94.7, 0.6320036473185725}], 
             PointBox[{94.8, 0.6343408508208441}], 
             PointBox[{94.9, 0.6345826023284686}], 
             PointBox[{95., 0.6343895143274886}], 
             PointBox[{95.1, 0.6336690330415524}], 
             PointBox[{95.2, 0.6309749632625572}], 
             PointBox[{95.3, 0.6292849329194411}], 
             PointBox[{95.4, 0.631288754001704}], 
             PointBox[{95.5, 0.6301814143855071}], 
             PointBox[{95.6, 0.628835371546506}], 
             PointBox[{95.7, 0.6308164686389964}], 
             PointBox[{95.8, 0.6335345720661657}], 
             PointBox[{95.9, 0.6338711371547467}], 
             PointBox[{96., 0.6336696367444322}], 
             PointBox[{96.1, 0.6330919492148205}], 
             PointBox[{96.2, 0.6306703785752862}], 
             PointBox[{96.3, 0.6284937837756417}], 
             PointBox[{96.4, 0.6303258449075864}], 
             PointBox[{96.5, 0.6295845669223468}], 
             PointBox[{96.6, 0.627966711242936}], 
             PointBox[{96.7, 0.6295472488085938}], 
             PointBox[{96.8, 0.6325617703325953}], 
             PointBox[{96.9, 0.6329740868388142}], 
             PointBox[{97., 0.6327386800280218}], 
             PointBox[{97.1, 0.6322371091496194}], 
             PointBox[{97.2, 0.6300607558635234}], 
             PointBox[{97.3, 0.6275331886952732}], 
             PointBox[{97.4, 0.629233097963547}], 
             PointBox[{97.5, 0.6286236706827191}], 
             PointBox[{97.6, 0.6268811893796867}], 
             PointBox[{97.7, 0.6281754268052958}], 
             PointBox[{97.8, 0.631402998860392}], 
             PointBox[{97.9, 0.6318326051579042}], 
             PointBox[{98., 0.6315356750003832}], 
             PointBox[{98.1, 0.6310569108006698}], 
             PointBox[{98.2, 0.629041521193339}], 
             PointBox[{98.3, 0.6263014041635891}], 
             PointBox[{98.4, 0.6279781644862827}], 
             PointBox[{98.5, 0.6271897330291719}], 
             PointBox[{98.6, 0.6254861156445067}], 
             PointBox[{98.7, 0.626674512460773}], 
             PointBox[{98.8, 0.6300481362129164}], 
             PointBox[{98.9, 0.6303806768479494}], 
             PointBox[{99., 0.629993516825329}], 
             PointBox[{99.1, 0.6294933076661543}], 
             PointBox[{99.2, 0.6275085493863415}], 
             PointBox[{99.3, 0.6247119860341129}], 
             PointBox[{99.4, 0.6264725446755904}], 
             PointBox[{99.5, 0.625212782157944}], 
             PointBox[{99.6, 0.6237455001246353}], 
             PointBox[{99.7, 0.6250734538211107}], 
             PointBox[{99.8, 0.6285043095351519}], 
             PointBox[{99.9, 0.6285696482782424}], 
             PointBox[{100., 0.6280706984091117}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0.6, 0.65}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], 
             PointBox[{0, 0.018454500000006}], 
             PointBox[{0.1, 0.018302980016150026`}], 
             PointBox[{0.2, 0.016222620726993632`}], 
             PointBox[{0.3, 0.01882176606747196}], 
             PointBox[{0.4, 0.019046331618021647`}], 
             PointBox[{0.5, 0.015658613099822367`}], 
             PointBox[{0.6, 0.016680071710092007`}], 
             PointBox[{0.7, 0.0195884466326019}], 
             PointBox[{0.8, 0.01768696558886705}], 
             PointBox[{0.9, 0.016771380089363602`}], 
             PointBox[{1., 0.019458047391263972`}], 
             PointBox[{1.1, 0.02157776688129039}], 
             PointBox[{1.2, 0.020442579332469353`}], 
             PointBox[{1.3, 0.02012097539812574}], 
             PointBox[{1.4, 0.023019069915701525`}], 
             PointBox[{1.5, 0.021104794435608823`}], 
             PointBox[{1.6, 0.01865219073102994}], 
             PointBox[{1.7, 0.021420943633944818`}], 
             PointBox[{1.8, 0.022754404030237298`}], 
             PointBox[{1.9, 0.01998819669455986}], 
             PointBox[{2., 0.021640497099628075`}], 
             PointBox[{2.1, 0.02483972199294028}], 
             PointBox[{2.2, 0.02694264724938342}], 
             PointBox[{2.3, 0.02484735924574658}], 
             PointBox[{2.4, 0.027028542321284044`}], 
             PointBox[{2.5, 0.028138740150596978`}], 
             PointBox[{2.6, 0.02475533431795107}], 
             PointBox[{2.7, 0.02483285973663195}], 
             PointBox[{2.8, 0.028026418945901858`}], 
             PointBox[{2.9, 0.026861646712965315`}], 
             PointBox[{3., 0.025432839646026925`}], 
             PointBox[{3.1, 0.02894955443224773}], 
             PointBox[{3.2, 0.032798826115354486`}], 
             PointBox[{3.3, 0.0319875760111909}], 
             PointBox[{3.4, 0.03152090514275454}], 
             PointBox[{3.5, 0.03458881786692273}], 
             PointBox[{3.6, 0.03261317195772726}], 
             PointBox[{3.7, 0.030220427320931147`}], 
             PointBox[{3.8, 0.03279854856151709}], 
             PointBox[{3.9, 0.03431874992050046}], 
             PointBox[{4., 0.03151719576931311}], 
             PointBox[{4.1, 0.03346411081563442}], 
             PointBox[{4.2, 0.03738520365092062}], 
             PointBox[{4.3, 0.039430759089683826`}], 
             PointBox[{4.4, 0.03739773356362973}], 
             PointBox[{4.5, 0.03988745195338261}], 
             PointBox[{4.6, 0.040501633454288595`}], 
             PointBox[{4.7, 0.037111656799152785`}], 
             PointBox[{4.8, 0.037641950262425006`}], 
             PointBox[{4.9, 0.04072473528115493}], 
             PointBox[{5., 0.03915004881438915}], 
             PointBox[{5.1, 0.03827335802057437}], 
             PointBox[{5.2, 0.04199866070567455}], 
             PointBox[{5.3, 0.045726176991237134`}], 
             PointBox[{5.4, 0.04443498612462108}], 
             PointBox[{5.5, 0.04460328266961017}], 
             PointBox[{5.6, 0.04740181327496825}], 
             PointBox[{5.7, 0.04467154648151956}], 
             PointBox[{5.8, 0.04306081376436843}], 
             PointBox[{5.9, 0.04594748602374099}], 
             PointBox[{6., 0.046783263666404624`}], 
             PointBox[{6.1, 0.04400494830000094}], 
             PointBox[{6.2, 0.04679941831496562}], 
             PointBox[{6.3, 0.0504646880207604}], 
             PointBox[{6.4, 0.05150928168083449}], 
             PointBox[{6.5, 0.04974004107348756}], 
             PointBox[{6.6, 0.052847546130005224`}], 
             PointBox[{6.7, 0.0521116760194168}], 
             PointBox[{6.8, 0.0490902531292608}], 
             PointBox[{6.9, 0.050555986813083736`}], 
             PointBox[{7., 0.05323694667824311}], 
             PointBox[{7.1, 0.0507296816513078}], 
             PointBox[{7.2, 0.05125481595066044}], 
             PointBox[{7.3, 0.054662098142429054`}], 
             PointBox[{7.4, 0.05759155394927391}], 
             PointBox[{7.5, 0.055639996474404256`}], 
             PointBox[{7.6, 0.057077473972088434`}], 
             PointBox[{7.7, 0.05876690710420515}], 
             PointBox[{7.8, 0.05545331704858473}], 
             PointBox[{7.9, 0.05509027011404793}], 
             PointBox[{8., 0.05825575573499641}], 
             PointBox[{8.1, 0.0576902404403949}], 
             PointBox[{8.2, 0.055754431744938056`}], 
             PointBox[{8.3, 0.05908898281134142}], 
             PointBox[{8.4, 0.06220442360532933}], 
             PointBox[{8.5, 0.06175248021968818}], 
             PointBox[{8.6, 0.06093251455173099}], 
             PointBox[{8.7, 0.06414373823815865}], 
             PointBox[{8.8, 0.06177352571116764}], 
             PointBox[{8.9, 0.059782625171140406`}], 
             PointBox[{9., 0.06224531722171407}], 
             PointBox[{9.1, 0.06385723300707549}], 
             PointBox[{9.2, 0.060766522669403786`}], 
             PointBox[{9.3, 0.06305451298066185}], 
             PointBox[{9.4, 0.06575735031235665}], 
             PointBox[{9.5, 0.0672937060394999}], 
             PointBox[{9.6, 0.06516613000683771}], 
             PointBox[{9.7, 0.06809357008341024}], 
             PointBox[{9.8, 0.06766885804928834}], 
             PointBox[{9.9, 0.06462347240982456}], 
             PointBox[{10., 0.0657369728340972}], 
             PointBox[{10.1, 0.06866830059562344}], 
             PointBox[{10.2, 0.06628768981734565}], 
             PointBox[{10.3, 0.06645605180266574}], 
             PointBox[{10.4, 0.0693076301611322}], 
             PointBox[{10.5, 0.07174220627622176}], 
             PointBox[{10.6, 0.06984623233523841}], 
             PointBox[{10.7, 0.07099059986890656}], 
             PointBox[{10.8, 0.07277690618658317}], 
             PointBox[{10.9, 0.06949126264362375}], 
             PointBox[{11., 0.06908913926882858}], 
             PointBox[{11.1, 0.07221878602697299}], 
             PointBox[{11.2, 0.07176160487624311}], 
             PointBox[{11.3, 0.06972447508803499}], 
             PointBox[{11.4, 0.07282745027391817}], 
             PointBox[{11.5, 0.07501390305535129}], 
             PointBox[{11.6, 0.07452178593175246}], 
             PointBox[{11.7, 0.07358871728812282}], 
             PointBox[{11.8, 0.07680722545392873}], 
             PointBox[{11.9, 0.07423149914723054}], 
             PointBox[{12., 0.07246274205204696}], 
             PointBox[{12.1, 0.07494393067732014}], 
             PointBox[{12.2, 0.0764822934212721}], 
             PointBox[{12.3, 0.07328678314574574}], 
             PointBox[{12.4, 0.07574337976763106}], 
             PointBox[{12.5, 0.07762198567325083}], 
             PointBox[{12.6, 0.07869762603461408}], 
             PointBox[{12.7, 0.07650926707918605}], 
             PointBox[{12.8, 0.07967056478238263}], 
             PointBox[{12.9, 0.07867621126459787}], 
             PointBox[{13., 0.07589886697818328}], 
             PointBox[{13.1, 0.07727587942759055}], 
             PointBox[{13.2, 0.08008981810929061}], 
             PointBox[{13.3, 0.07728227625743637}], 
             PointBox[{13.4, 0.07807696774732586}], 
             PointBox[{13.5, 0.08029938946590938}], 
             PointBox[{13.6, 0.08207953795681557}], 
             PointBox[{13.7, 0.07987499078621384}], 
             PointBox[{13.8, 0.08162059886416752}], 
             PointBox[{13.9, 0.08264476154676288}], 
             PointBox[{14., 0.07938689419220969}], 
             PointBox[{14.1, 0.07950843450910763}], 
             PointBox[{14.2, 0.08268816826455841}], 
             PointBox[{14.3, 0.08144961962691376}], 
             PointBox[{14.4, 0.08017762311274507}], 
             PointBox[{14.5, 0.0830051267471468}], 
             PointBox[{14.6, 0.08463733420927459}], 
             PointBox[{14.7, 0.08342668919931008}], 
             PointBox[{14.8, 0.08322191525243294}], 
             PointBox[{14.9, 0.0859595400246118}], 
             PointBox[{15., 0.08289507233121322}], 
             PointBox[{15.1, 0.08180583596233182}], 
             PointBox[{15.2, 0.0846310302820714}], 
             PointBox[{15.3, 0.08530475618953347}], 
             PointBox[{15.4, 0.08244103992689704}], 
             PointBox[{15.5, 0.08532153198718816}], 
             PointBox[{15.6, 0.08666588811742147}], 
             PointBox[{15.7, 0.08683487085610003}], 
             PointBox[{15.8, 0.08506344761942847}], 
             PointBox[{15.9, 0.0885115975608958}], 
             PointBox[{16., 0.08637936167568487}], 
             PointBox[{16.1, 0.08425424500283316}], 
             PointBox[{16.2, 0.0862885980475384}], 
             PointBox[{16.3, 0.08848948652261769}], 
             PointBox[{16.4, 0.08515171471902815}], 
             PointBox[{16.5, 0.08718511626516695}], 
             PointBox[{16.6, 0.08868317960916514}], 
             PointBox[{16.7, 0.08987825151135763}], 
             PointBox[{16.8, 0.08744993423410474}], 
             PointBox[{16.9, 0.09036035858797004}], 
             PointBox[{17., 0.08977988767167011}], 
             PointBox[{17.1, 0.08690141773617914}], 
             PointBox[{17.2, 0.08794408383326473}], 
             PointBox[{17.3, 0.09096328867637288}], 
             PointBox[{17.4, 0.08835857143377641}], 
             PointBox[{17.5, 0.0888089040650585}], 
             PointBox[{17.6, 0.09094713078554327}], 
             PointBox[{17.7, 0.0924876423920521}], 
             PointBox[{17.8, 0.09035417624177819}], 
             PointBox[{17.9, 0.09180602412374986}], 
             PointBox[{18., 0.09302413896767979}], 
             PointBox[{18.1, 0.0897801387075255}], 
             PointBox[{18.2, 0.089787219697198}], 
             PointBox[{18.3, 0.09294556568654405}], 
             PointBox[{18.4, 0.09185875514082065}], 
             PointBox[{18.5, 0.0904977614476114}], 
             PointBox[{18.6, 0.09328879715116309}], 
             PointBox[{18.7, 0.09475257853737996}], 
             PointBox[{18.8, 0.09359084708223638}], 
             PointBox[{18.9, 0.09331607289006051}], 
             PointBox[{19., 0.0960464826677533}], 
             PointBox[{19.1, 0.09291873265948931}], 
             PointBox[{19.2, 0.09194536895821612}], 
             PointBox[{19.3, 0.0947544867966465}], 
             PointBox[{19.4, 0.09535286954726226}], 
             PointBox[{19.5, 0.09255951259469138}], 
             PointBox[{19.6, 0.09554296858877019}], 
             PointBox[{19.7, 0.0969220591349483}], 
             PointBox[{19.8, 0.09699221121755858}], 
             PointBox[{19.9, 0.09533951022413613}], 
             PointBox[{20., 0.09883245263284801}], 
             PointBox[{20.1, 0.09634688724517518}], 
             PointBox[{20.2, 0.09451368600214163}], 
             PointBox[{20.3, 0.09669274426803805}], 
             PointBox[{20.4, 0.09865499686369873}], 
             PointBox[{20.5, 0.09523824004103337}], 
             PointBox[{20.6, 0.0977621655130065}], 
             PointBox[{20.7, 0.09932393859146603}], 
             PointBox[{20.8, 0.10049005843513091`}], 
             PointBox[{20.9, 0.09814000486777127}], 
             PointBox[{21., 0.10147851403551626`}], 
             PointBox[{21.1, 0.10010165312628644`}], 
             PointBox[{21.2, 0.09757906082721039}], 
             PointBox[{21.3, 0.09900976338839321}], 
             PointBox[{21.4, 0.10180539426353115`}], 
             PointBox[{21.5, 0.09865807540219906}], 
             PointBox[{21.6, 0.10014490469584003`}], 
             PointBox[{21.7, 0.10219563190359321`}], 
             PointBox[{21.8, 0.10413181094292628`}], 
             PointBox[{21.9, 0.10178531251470244`}], 
             PointBox[{22., 0.10422942318782658`}], 
             PointBox[{22.1, 0.10423912210582405`}], 
             PointBox[{22.2, 0.10123555968383881`}], 
             PointBox[{22.3, 0.10191061697767127`}], 
             PointBox[{22.4, 0.10503201855419617`}], 
             PointBox[{22.5, 0.10281596270384967`}], 
             PointBox[{22.6, 0.10294976682570732`}], 
             PointBox[{22.7, 0.10562477002988818`}], 
             PointBox[{22.8, 0.10807251553910129`}], 
             PointBox[{22.9, 0.1062590913320368}], 
             PointBox[{23., 0.10745441040854341`}], 
             PointBox[{23.1, 0.10885206117802732`}], 
             PointBox[{23.2, 0.10559543728301185`}], 
             PointBox[{23.3, 0.105578305478903}], 
             PointBox[{23.4, 0.10865893032819514`}], 
             PointBox[{23.5, 0.10765641939527204`}], 
             PointBox[{23.6, 0.10645215501430157`}], 
             PointBox[{23.7, 0.10967741590970469`}], 
             PointBox[{23.8, 0.11256196649508513`}], 
             PointBox[{23.9, 0.11157621615235126`}], 
             PointBox[{24., 0.11156195556281916`}], 
             PointBox[{24.1, 0.11409332135307411`}], 
             PointBox[{24.2, 0.11079713690492896`}], 
             PointBox[{24.3, 0.11019700909870919`}], 
             PointBox[{24.4, 0.11303435578077965`}], 
             PointBox[{24.5, 0.11318356078261883`}], 
             PointBox[{24.6, 0.11091828411309494`}], 
             PointBox[{24.7, 0.11451623257005132`}], 
             PointBox[{24.8, 0.11792111095671982`}], 
             PointBox[{24.9, 0.11783654715781061`}], 
             PointBox[{25., 0.1169090572826024}], 
             PointBox[{25.1, 0.12019256764925329`}], 
             PointBox[{25.2, 0.11700665348624294`}], 
             PointBox[{25.3, 0.11596517722165818`}], 
             PointBox[{25.4, 0.11849809723016962`}], 
             PointBox[{25.5, 0.11952887542998858`}], 
             PointBox[{25.6, 0.11658581943755278`}], 
             PointBox[{25.7, 0.12041499922822643`}], 
             PointBox[{25.8, 0.1245094943655794}], 
             PointBox[{25.9, 0.12521601414749975`}], 
             PointBox[{26., 0.12375072317120349`}], 
             PointBox[{26.1, 0.1274392176985268}], 
             PointBox[{26.2, 0.1243983429697193}], 
             PointBox[{26.3, 0.12308409930270969`}], 
             PointBox[{26.4, 0.12535944621264455`}], 
             PointBox[{26.5, 0.12693180106524712`}], 
             PointBox[{26.6, 0.12364975460406069`}], 
             PointBox[{26.7, 0.12771659531748816`}], 
             PointBox[{26.8, 0.13267247524663353`}], 
             PointBox[{26.9, 0.13388653061084613`}], 
             PointBox[{27., 0.13221539433972634`}], 
             PointBox[{27.1, 0.13609933130327923`}], 
             PointBox[{27.2, 0.1330919458624631}], 
             PointBox[{27.3, 0.13170688338850742`}], 
             PointBox[{27.4, 0.13384541305758743`}], 
             PointBox[{27.5, 0.1356224902058518}], 
             PointBox[{27.6, 0.1322355457691046}], 
             PointBox[{27.7, 0.13676144922905917`}], 
             PointBox[{27.8, 0.142592234608302}], 
             PointBox[{27.9, 0.14383992263389295`}], 
             PointBox[{28., 0.14223482561876252`}], 
             PointBox[{28.1, 0.14621427949595356`}], 
             PointBox[{28.2, 0.14301538142736195`}], 
             PointBox[{28.3, 0.14180771354333002`}], 
             PointBox[{28.4, 0.14397193489017776`}], 
             PointBox[{28.5, 0.14559795282835444`}], 
             PointBox[{28.6, 0.1423438443760928}], 
             PointBox[{28.7, 0.14775082532142633`}], 
             PointBox[{28.8, 0.1539475593584834}], 
             PointBox[{28.9, 0.15463731482145357`}], 
             PointBox[{29., 0.15342838551248553`}], 
             PointBox[{29.1, 0.15728300389384037`}], 
             PointBox[{29.2, 0.15372595015617205`}], 
             PointBox[{29.3, 0.15299329814797763`}], 
             PointBox[{29.4, 0.15533618748517783`}], 
             PointBox[{29.5, 0.1563170321514319}], 
             PointBox[{29.6, 0.15378414650480995`}], 
             PointBox[{29.7, 0.16037837300546792`}], 
             PointBox[{29.8, 0.16560950236887864`}], 
             PointBox[{29.9, 0.1653027242361004}], 
             PointBox[{30., 0.16511891623475597`}], 
             PointBox[{30.1, 0.16805869338056717`}], 
             PointBox[{30.2, 0.16438316386741852`}], 
             PointBox[{30.3, 0.16441437038425277`}], 
             PointBox[{30.4, 0.16699503649133082`}], 
             PointBox[{30.5, 0.16654324882727126`}], 
             PointBox[{30.6, 0.16612787384998418`}], 
             PointBox[{30.7, 0.17302552253473216`}], 
             PointBox[{30.8, 0.17600930465525755`}], 
             PointBox[{30.9, 0.1747171603047829}], 
             PointBox[{31., 0.17657162600225865`}], 
             PointBox[{31.1, 0.17706043080503076`}], 
             PointBox[{31.2, 0.17408940688594599`}], 
             PointBox[{31.3, 0.17504203431403706`}], 
             PointBox[{31.4, 0.1776575329101965}], 
             PointBox[{31.5, 0.17502302547997117`}], 
             PointBox[{31.6, 0.178340639914941}], 
             PointBox[{31.7, 0.1833488501385588}], 
             PointBox[{31.8, 0.1840406574280192}], 
             PointBox[{31.9, 0.18239892567896263`}], 
             PointBox[{32., 0.1866274906200377}], 
             PointBox[{32.1, 0.1837456368624112}], 
             PointBox[{32.2, 0.18233057224135135`}], 
             PointBox[{32.3, 0.1841202434250862}], 
             PointBox[{32.4, 0.18601893729190683`}], 
             PointBox[{32.5, 0.18236263393150037`}], 
             PointBox[{32.6, 0.18824552617404905`}], 
             PointBox[{32.7, 0.1904103945962602}], 
             PointBox[{32.8, 0.18948907482103566`}], 
             PointBox[{32.9, 0.18899176167689039`}], 
             PointBox[{33., 0.1929962589492625}], 
             PointBox[{33.1, 0.18871249164009607`}], 
             PointBox[{33.2, 0.1890105894097454}], 
             PointBox[{33.3, 0.19125849723115818`}], 
             PointBox[{33.4, 0.190904864483343}], 
             PointBox[{33.5, 0.19016940439361785`}], 
             PointBox[{33.6, 0.19456596093743395`}], 
             PointBox[{33.7, 0.19448828643723154`}], 
             PointBox[{33.8, 0.19288229954656486`}], 
             PointBox[{33.9, 0.19550234626203306`}], 
             PointBox[{34., 0.19514444558890598`}], 
             PointBox[{34.1, 0.19264479260800424`}], 
             PointBox[{34.2, 0.19415831952371027`}], 
             PointBox[{34.3, 0.19606894565161825`}], 
             PointBox[{34.4, 0.19266539805821215`}], 
             PointBox[{34.5, 0.19618161303664322`}], 
             PointBox[{34.6, 0.19761857863185112`}], 
             PointBox[{34.7, 0.1962320988316074}], 
             PointBox[{34.8, 0.19532088134179426`}], 
             PointBox[{34.9, 0.20014114022366575`}], 
             PointBox[{35., 0.19567728373359297`}], 
             PointBox[{35.1, 0.19570714131824665`}], 
             PointBox[{35.2, 0.19766428258254407`}], 
             PointBox[{35.3, 0.19783280121321714`}], 
             PointBox[{35.4, 0.19483019057348602`}], 
             PointBox[{35.5, 0.19894563701334497`}], 
             PointBox[{35.6, 0.19812408589019645`}], 
             PointBox[{35.7, 0.19639985861914833`}], 
             PointBox[{35.8, 0.19805389981219493`}], 
             PointBox[{35.9, 0.19959706182874654`}], 
             PointBox[{36., 0.19618081806311302`}], 
             PointBox[{36.1, 0.19765614555617428`}], 
             PointBox[{36.2, 0.19913079324242333`}], 
             PointBox[{36.3, 0.1962486670505658}], 
             PointBox[{36.4, 0.1972544652385931}], 
             PointBox[{36.5, 0.19862101952284297`}], 
             PointBox[{36.6, 0.19676238448013436`}], 
             PointBox[{36.7, 0.1958172305188416}], 
             PointBox[{36.8, 0.20032481000079003`}], 
             PointBox[{36.9, 0.19656228425306785`}], 
             PointBox[{37., 0.19635451479277496`}], 
             PointBox[{37.1, 0.1980247576845346}], 
             PointBox[{37.2, 0.19787144210402616`}], 
             PointBox[{37.3, 0.19336647585231018`}], 
             PointBox[{37.4, 0.19715657900314476`}], 
             PointBox[{37.5, 0.19592441858169257`}], 
             PointBox[{37.6, 0.19406781705982382`}], 
             PointBox[{37.7, 0.1951569109872582}], 
             PointBox[{37.8, 0.19819183200460985`}], 
             PointBox[{37.9, 0.19389930621805532`}], 
             PointBox[{38., 0.19535810658871963`}], 
             PointBox[{38.1, 0.19619228098375133`}], 
             PointBox[{38.2, 0.1933221792510956}], 
             PointBox[{38.3, 0.19151770309208835`}], 
             PointBox[{38.4, 0.19363808683594264`}], 
             PointBox[{38.5, 0.191411469674974}], 
             PointBox[{38.6, 0.19038873107531992`}], 
             PointBox[{38.7, 0.19396945580796854`}], 
             PointBox[{38.8, 0.1919771074165544}], 
             PointBox[{38.9, 0.19097706345433674`}], 
             PointBox[{39., 0.19238041047618523`}], 
             PointBox[{39.1, 0.1914335867446399}], 
             PointBox[{39.2, 0.18583078449131998`}], 
             PointBox[{39.3, 0.18833560963796178`}], 
             PointBox[{39.4, 0.18743400898198384`}], 
             PointBox[{39.5, 0.18531578558230014`}], 
             PointBox[{39.6, 0.1857728117132423}], 
             PointBox[{39.7, 0.18983538319740825`}], 
             PointBox[{39.8, 0.18521470397398462`}], 
             PointBox[{39.9, 0.18648493731348845`}], 
             PointBox[{40., 0.18671088266107083`}], 
             PointBox[{40.1, 0.18313649295695994`}], 
             PointBox[{40.2, 0.17788827649412922`}], 
             PointBox[{40.3, 0.1814791151442417}], 
             PointBox[{40.4, 0.1791040694615091}], 
             PointBox[{40.5, 0.17765218160194468`}], 
             PointBox[{40.6, 0.17980222760540276`}], 
             PointBox[{40.7, 0.18130557661424027`}], 
             PointBox[{40.8, 0.17797072661366886`}], 
             PointBox[{40.9, 0.1795996574782609}], 
             PointBox[{41., 0.1778508557807809}], 
             PointBox[{41.1, 0.17165381109527825`}], 
             PointBox[{41.2, 0.16993487521923706`}], 
             PointBox[{41.3, 0.17169395409492658`}], 
             PointBox[{41.4, 0.16901619343189409`}], 
             PointBox[{41.5, 0.16844146993099432`}], 
             PointBox[{41.6, 0.1717839344969229}], 
             PointBox[{41.7, 0.1702088725071113}], 
             PointBox[{41.8, 0.16922949425659167`}], 
             PointBox[{41.9, 0.17017989799807878`}], 
             PointBox[{42., 0.16605637996651046`}], 
             PointBox[{42.1, 0.15906876629377378`}], 
             PointBox[{42.2, 0.16039349393364385`}], 
             PointBox[{42.3, 0.16030976323308496`}], 
             PointBox[{42.4, 0.15777189409606424`}], 
             PointBox[{42.5, 0.158023222902541}], 
             PointBox[{42.6, 0.1616865625888383}], 
             PointBox[{42.7, 0.1584125546527307}], 
             PointBox[{42.8, 0.15896368318625756`}], 
             PointBox[{42.9, 0.15894999288884437`}], 
             PointBox[{43., 0.15314227369558767`}], 
             PointBox[{43.1, 0.14705537273545524`}], 
             PointBox[{43.2, 0.14977663368403132`}], 
             PointBox[{43.3, 0.14868917548937918`}], 
             PointBox[{43.4, 0.1463416531502556}], 
             PointBox[{43.5, 0.14718361550012968`}], 
             PointBox[{43.6, 0.1506417854332803}], 
             PointBox[{43.7, 0.1468479966179674}], 
             PointBox[{43.8, 0.1480868671168224}], 
             PointBox[{43.9, 0.14735518505518755`}], 
             PointBox[{44., 0.14132369576808348`}], 
             PointBox[{44.1, 0.13628636879248354`}], 
             PointBox[{44.2, 0.13942481887424818`}], 
             PointBox[{44.3, 0.13797778741891056`}], 
             PointBox[{44.4, 0.1357077901223479}], 
             PointBox[{44.5, 0.13684369597547855`}], 
             PointBox[{44.6, 0.14006954025828325`}], 
             PointBox[{44.7, 0.1362566894177357}], 
             PointBox[{44.8, 0.13769806163000398`}], 
             PointBox[{44.9, 0.13677981398901715`}], 
             PointBox[{45., 0.1314278889826257}], 
             PointBox[{45.1, 0.12704412494802925`}], 
             PointBox[{45.2, 0.1301741913930764}], 
             PointBox[{45.3, 0.12880340141590732`}], 
             PointBox[{45.4, 0.12645656637280142`}], 
             PointBox[{45.5, 0.1276164540939887}], 
             PointBox[{45.6, 0.13078290484490565`}], 
             PointBox[{45.7, 0.12714680591686803`}], 
             PointBox[{45.8, 0.12846318958663372`}], 
             PointBox[{45.9, 0.12787422047364522`}], 
             PointBox[{46., 0.12339509319386904`}], 
             PointBox[{46.1, 0.11938055992309957`}], 
             PointBox[{46.2, 0.12222237495417221`}], 
             PointBox[{46.3, 0.12129264135101112`}], 
             PointBox[{46.4, 0.11873861261308434`}], 
             PointBox[{46.5, 0.11970103328604159`}], 
             PointBox[{46.6, 0.12293763560408898`}], 
             PointBox[{46.7, 0.11968595325515144`}], 
             PointBox[{46.8, 0.12054313879928866`}], 
             PointBox[{46.9, 0.12062924671129205`}], 
             PointBox[{47., 0.11691136254212771`}], 
             PointBox[{47.1, 0.11319204229710798`}], 
             PointBox[{47.2, 0.11541931287606036`}], 
             PointBox[{47.3, 0.11527739827130064`}], 
             PointBox[{47.4, 0.1124519466024654}], 
             PointBox[{47.5, 0.11303366429388856`}], 
             PointBox[{47.6, 0.1163433547804075}], 
             PointBox[{47.7, 0.1137924029390025}], 
             PointBox[{47.8, 0.11382290733810413`}], 
             PointBox[{47.9, 0.11474499238840784`}], 
             PointBox[{48., 0.11162305869996157`}], 
             PointBox[{48.1, 0.10828781624937225`}], 
             PointBox[{48.2, 0.10953145470208568`}], 
             PointBox[{48.3, 0.11046238113530535`}], 
             PointBox[{48.4, 0.10740109801687933`}], 
             PointBox[{48.5, 0.10745016630375978`}], 
             PointBox[{48.6, 0.11071786863950035`}], 
             PointBox[{48.7, 0.10923217811634847`}], 
             PointBox[{48.8, 0.10812753952244651`}], 
             PointBox[{48.9, 0.10985824794612921`}], 
             PointBox[{49., 0.10723086689397746`}], 
             PointBox[{49.1, 0.1044297638931942}], 
             PointBox[{49.2, 0.10440140508913227`}], 
             PointBox[{49.3, 0.10650750906187671`}], 
             PointBox[{49.4, 0.10338061014592817`}], 
             PointBox[{49.5, 0.10277735969071113`}], 
             PointBox[{49.6, 0.10581386788584209`}], 
             PointBox[{49.7, 0.10566031884749241`}], 
             PointBox[{49.8, 0.10333499903664356`}], 
             PointBox[{49.9, 0.10563037539809154`}], 
             PointBox[{50., 0.10353774668704001`}], 
             PointBox[{50.1, 0.1013503238332086}], 
             PointBox[{50.2, 0.09999258122250851}], 
             PointBox[{50.3, 0.10305731994949163`}], 
             PointBox[{50.4, 0.10019555191430982`}], 
             PointBox[{50.5, 0.09886297130715743}], 
             PointBox[{50.6, 0.10145341264791344`}], 
             PointBox[{50.7, 0.10267111626868305`}], 
             PointBox[{50.8, 0.09940633938892958}], 
             PointBox[{50.9, 0.101787830783366}], 
             PointBox[{51., 0.10044788826043033`}], 
             PointBox[{51.1, 0.09877069928484687}], 
             PointBox[{51.2, 0.0963405761624671}], 
             PointBox[{51.3, 0.09977367463990454}], 
             PointBox[{51.4, 0.09765598121368968}], 
             PointBox[{51.5, 0.09558359093089998}], 
             PointBox[{51.6, 0.09752233662312944}], 
             PointBox[{51.7, 0.09988014455252417}], 
             PointBox[{51.8, 0.09634637922948186}], 
             PointBox[{51.9, 0.09814720232984589}], 
             PointBox[{52., 0.09787025523931997}], 
             PointBox[{52.1, 0.09642406244135193}], 
             PointBox[{52.2, 0.09345134300662931}], 
             PointBox[{52.3, 0.09639976659262488}], 
             PointBox[{52.4, 0.09555679088014385}], 
             PointBox[{52.5, 0.09283577529297465}], 
             PointBox[{52.6, 0.09394951769347648}], 
             PointBox[{52.7, 0.09701511844634919}], 
             PointBox[{52.8, 0.09410166409744114}], 
             PointBox[{52.9, 0.09463177105148779}], 
             PointBox[{53., 0.09558810820327195}], 
             PointBox[{53.1, 0.09409515779859388}], 
             PointBox[{53.2, 0.09121890561967565}], 
             PointBox[{53.3, 0.09285188734259359}], 
             PointBox[{53.4, 0.09365482351049004}], 
             PointBox[{53.5, 0.09052894684116633}], 
             PointBox[{53.6, 0.09068821216566895}], 
             PointBox[{53.7, 0.09394926813204041}], 
             PointBox[{53.8, 0.09244414125167794}], 
             PointBox[{53.9, 0.09128092464715695}], 
             PointBox[{54., 0.0932804373551566}], 
             PointBox[{54.1, 0.09169569996326478}], 
             PointBox[{54.2, 0.08941620168907745}], 
             PointBox[{54.3, 0.08927035129166701}], 
             PointBox[{54.4, 0.09165320944880459}], 
             PointBox[{54.5, 0.08856664994239742}], 
             PointBox[{54.6, 0.08770293765255868}], 
             PointBox[{54.7, 0.0906740529591375}], 
             PointBox[{54.8, 0.09094955831973468}], 
             PointBox[{54.9, 0.0882398742019891}], 
             PointBox[{55., 0.09067716948434933}], 
             PointBox[{55.1, 0.0893485467092379}], 
             PointBox[{55.2, 0.08774308639604828}], 
             PointBox[{55.3, 0.0859392096183351}], 
             PointBox[{55.4, 0.08922900299757396}], 
             PointBox[{55.5, 0.08682767504488971}], 
             PointBox[{55.6, 0.08496153836085998}], 
             PointBox[{55.7, 0.0872424953372868}], 
             PointBox[{55.8, 0.0891391693678545}], 
             PointBox[{55.9, 0.08569510599086518}], 
             PointBox[{56., 0.08765662410194622}], 
             PointBox[{56.1, 0.08724583128776131}], 
             PointBox[{56.2, 0.08588978953067052}], 
             PointBox[{56.3, 0.08308734309840911}], 
             PointBox[{56.4, 0.08613039283187707}], 
             PointBox[{56.5, 0.08513454621725723}], 
             PointBox[{56.6, 0.08242976694730066}], 
             PointBox[{56.7, 0.08372219272128402}], 
             PointBox[{56.8, 0.0866735310719336}], 
             PointBox[{56.9, 0.08371467600135526}], 
             PointBox[{57., 0.08425581691394955}], 
             PointBox[{57.1, 0.08521380114781558}], 
             PointBox[{57.2, 0.08361791447581385}], 
             PointBox[{57.3, 0.08071344184625852}], 
             PointBox[{57.4, 0.08233674375541616}], 
             PointBox[{57.5, 0.08322207730414449}], 
             PointBox[{57.6, 0.0800628319126768}], 
             PointBox[{57.7, 0.08017202842792175}], 
             PointBox[{57.8, 0.08344917308182356}], 
             PointBox[{57.9, 0.08206097206392042}], 
             PointBox[{58., 0.08066460999383435}], 
             PointBox[{58.1, 0.08274302519712344}], 
             PointBox[{58.2, 0.08092195845677305}], 
             PointBox[{58.3, 0.0785683155882514}], 
             PointBox[{58.4, 0.07814992788640943}], 
             PointBox[{58.5, 0.08073194130347935}], 
             PointBox[{58.6, 0.07778377032837885}], 
             PointBox[{58.7, 0.07663669730546979}], 
             PointBox[{58.8, 0.0795485049906852}], 
             PointBox[{58.9, 0.0801802145282917}], 
             PointBox[{59., 0.07719734689047594}], 
             PointBox[{59.1, 0.07948050627429397}], 
             PointBox[{59.2, 0.07817687757776574}], 
             PointBox[{59.3, 0.07626795654123228}], 
             PointBox[{59.4, 0.07405205870468037}], 
             PointBox[{59.5, 0.0772919121176103}], 
             PointBox[{59.6, 0.07544575537970519}], 
             PointBox[{59.7, 0.07314842587441545}], 
             PointBox[{59.8, 0.07513920264187392}], 
             PointBox[{59.9, 0.07747717951711654}], 
             PointBox[{60., 0.07414613001384325}], 
             PointBox[{60.1, 0.07539913203026467}], 
             PointBox[{60.2, 0.07556581193818777}], 
             PointBox[{60.3, 0.07344050640815455}], 
             PointBox[{60.4, 0.07036744682288956}], 
             PointBox[{60.5, 0.07272889618525812}], 
             PointBox[{60.6, 0.07278261370622276}], 
             PointBox[{60.7, 0.06972325874403738}], 
             PointBox[{60.8, 0.07040165993599119}], 
             PointBox[{60.9, 0.07362859216867176}], 
             PointBox[{61., 0.07148093440850396}], 
             PointBox[{61.1, 0.07074503319203337}], 
             PointBox[{61.2, 0.07243980939293121}], 
             PointBox[{61.3, 0.06997217675913983}], 
             PointBox[{61.4, 0.06703116334429635}], 
             PointBox[{61.5, 0.06730884605903384}], 
             PointBox[{61.6, 0.06938389243527354}], 
             PointBox[{61.7, 0.06633385225706895}], 
             PointBox[{61.8, 0.06550567905136967}], 
             PointBox[{61.9, 0.06866547879090648}], 
             PointBox[{62., 0.0686614085264066}], 
             PointBox[{62.1, 0.06598443327084866}], 
             PointBox[{62.2, 0.06818321518195673}], 
             PointBox[{62.3, 0.0663515301423727}], 
             PointBox[{62.4, 0.06365409510686142}], 
             PointBox[{62.5, 0.06170165634933455}], 
             PointBox[{62.6, 0.06479394948281055}], 
             PointBox[{62.7, 0.06284888581039463}], 
             PointBox[{62.8, 0.060608264205603155`}], 
             PointBox[{62.9, 0.06285177878292222}], 
             PointBox[{63., 0.0649154108971739}], 
             PointBox[{63.1, 0.061609984061689764`}], 
             PointBox[{63.2, 0.06277998127757448}], 
             PointBox[{63.3, 0.06284011496289511}], 
             PointBox[{63.4, 0.05977862828794857}], 
             PointBox[{63.5, 0.05653511876256828}], 
             PointBox[{63.6, 0.05882184722497388}], 
             PointBox[{63.7, 0.05895084788890547}], 
             PointBox[{63.8, 0.05584206587870404}], 
             PointBox[{63.9, 0.0565421382636203}], 
             PointBox[{64., 0.05977155487702772}], 
             PointBox[{64.1, 0.05768486515710444}], 
             PointBox[{64.2, 0.05668031833937489}], 
             PointBox[{64.3, 0.05845440891272943}], 
             PointBox[{64.4, 0.0553561277585817}], 
             PointBox[{64.5, 0.05192804511727354}], 
             PointBox[{64.6, 0.05189968261177637}], 
             PointBox[{64.7, 0.05412866093619606}], 
             PointBox[{64.8, 0.0512488364227258}], 
             PointBox[{64.9, 0.050118071291620214`}], 
             PointBox[{65., 0.05328851827037285}], 
             PointBox[{65.1, 0.053561385199628664`}], 
             PointBox[{65.2, 0.05064346926397187}], 
             PointBox[{65.3, 0.05259396515644629}], 
             PointBox[{65.4, 0.05108626859226954}], 
             PointBox[{65.5, 0.04747541016753011}], 
             PointBox[{65.6, 0.04501734196035177}], 
             PointBox[{65.7, 0.047915207516278265`}], 
             PointBox[{65.8, 0.04665163437872911}], 
             PointBox[{65.9, 0.043962453736608}], 
             PointBox[{66., 0.04591161189848914}], 
             PointBox[{66.1, 0.04834982215314046}], 
             PointBox[{66.2, 0.045322474962364134`}], 
             PointBox[{66.3, 0.04560391834310797}], 
             PointBox[{66.4, 0.046534857521596217`}], 
             PointBox[{66.5, 0.04270737495796501}], 
             PointBox[{66.6, 0.03904607187517325}], 
             PointBox[{66.7, 0.040405730419269176`}], 
             PointBox[{66.8, 0.04156120082362167}], 
             PointBox[{66.9, 0.038387420843117574`}], 
             PointBox[{67., 0.03828269696129295}], 
             PointBox[{67.1, 0.04167285542163052}], 
             PointBox[{67.2, 0.040566063790936024`}], 
             PointBox[{67.3, 0.0384344161256214}], 
             PointBox[{67.4, 0.04050305855805394}], 
             PointBox[{67.5, 0.03798189513780412}], 
             PointBox[{67.6, 0.03408308404434937}], 
             PointBox[{67.7, 0.03262520369647726}], 
             PointBox[{67.8, 0.035370614095010494`}], 
             PointBox[{67.9, 0.033437606451015796`}], 
             PointBox[{68., 0.0311734584247989}], 
             PointBox[{68.1, 0.03387876682574828}], 
             PointBox[{68.2, 0.03541998426776225}], 
             PointBox[{68.3, 0.03225865846564985}], 
             PointBox[{68.4, 0.033161742980793815`}], 
             PointBox[{68.5, 0.03349102439036607}], 
             PointBox[{68.6, 0.029537495877266777`}], 
             PointBox[{68.7, 0.026141019126811185`}], 
             PointBox[{68.8, 0.028018287435139337`}], 
             PointBox[{68.9, 0.028690469467796617`}], 
             PointBox[{69., 0.02543790043619585}], 
             PointBox[{69.1, 0.02588992498260445}], 
             PointBox[{69.2, 0.029160310048633703`}], 
             PointBox[{69.3, 0.027545124016435406`}], 
             PointBox[{69.4, 0.025798499504849016`}], 
             PointBox[{69.5, 0.027872380998603577`}], 
             PointBox[{69.6, 0.025277905631746873`}], 
             PointBox[{69.7, 0.021951047351833817`}], 
             PointBox[{69.8, 0.02083504192947627}], 
             PointBox[{69.9, 0.023521551605335346`}], 
             PointBox[{70., 0.02168185573515057}], 
             PointBox[{70.1, 0.019294637373654257`}], 
             PointBox[{70.2, 0.022127747959140964`}], 
             PointBox[{70.3, 0.023528397647203766`}], 
             PointBox[{70.4, 0.020496458802104312`}], 
             PointBox[{70.5, 0.021342354544196435`}], 
             PointBox[{70.6, 0.021945122298521698`}], 
             PointBox[{70.7, 0.01960075810965779}], 
             PointBox[{70.8, 0.016793632352785644`}], 
             PointBox[{70.9, 0.018285866500472675`}], 
             PointBox[{71., 0.019675645373601777`}], 
             PointBox[{71.1, 0.01650532401388829}], 
             PointBox[{71.2, 0.016172030301582242`}], 
             PointBox[{71.3, 0.019542861741841104`}], 
             PointBox[{71.4, 0.018689887298283435`}], 
             PointBox[{71.5, 0.01644775686652602}], 
             PointBox[{71.6, 0.01869379461129195}], 
             PointBox[{71.7, 0.018382967614663993`}], 
             PointBox[{71.8, 0.0177418104609042}], 
             PointBox[{71.9, 0.01597123701599522}], 
             PointBox[{72., 0.018791477196251054`}], 
             PointBox[{72.1, 0.018383438009450945`}], 
             PointBox[{72.2, 0.015107496487070035`}], 
             PointBox[{72.3, 0.016772184316938676`}], 
             PointBox[{72.4, 0.019310258546792275`}], 
             PointBox[{72.5, 0.016986753217601392`}], 
             PointBox[{72.6, 0.016689407889828336`}], 
             PointBox[{72.7, 0.019139405988861984`}], 
             PointBox[{72.8, 0.0210360922647534}], 
             PointBox[{72.9, 0.019462438842130836`}], 
             PointBox[{73., 0.019699658832035196`}], 
             PointBox[{73.1, 0.02235340490618227}], 
             PointBox[{73.2, 0.019992663011081917`}], 
             PointBox[{73.3, 0.017992379542872167`}], 
             PointBox[{73.4, 0.021048001020488365`}], 
             PointBox[{73.5, 0.0218412867075927}], 
             PointBox[{73.6, 0.01911922435769594}], 
             PointBox[{73.7, 0.02123146588515128}], 
             PointBox[{73.8, 0.024338257864060655`}], 
             PointBox[{73.9, 0.025915697608875295`}], 
             PointBox[{74., 0.02390614912348772}], 
             PointBox[{74.1, 0.02644555600472959}], 
             PointBox[{74.2, 0.027033591529380376`}], 
             PointBox[{74.3, 0.02361639123644377}], 
             PointBox[{74.4, 0.024214919511859837`}], 
             PointBox[{74.5, 0.02726758973665892}], 
             PointBox[{74.6, 0.025661076054610196`}], 
             PointBox[{74.7, 0.024734374906390716`}], 
             PointBox[{74.8, 0.028319593370301276`}], 
             PointBox[{74.9, 0.032047372756553026`}], 
             PointBox[{75., 0.03082235996845724}], 
             PointBox[{75.1, 0.030825997432783674`}], 
             PointBox[{75.2, 0.033715141980009994`}], 
             PointBox[{75.3, 0.03135702703117088}], 
             PointBox[{75.4, 0.02931910137705993}], 
             PointBox[{75.5, 0.03215548246476783}], 
             PointBox[{75.6, 0.033230364531283765`}], 
             PointBox[{75.7, 0.03046894937529003}], 
             PointBox[{75.8, 0.032858341299851594`}], 
             PointBox[{75.9, 0.03683807742189174}], 
             PointBox[{76., 0.038373709751384176`}], 
             PointBox[{76.1, 0.036461039101553}], 
             PointBox[{76.2, 0.039243697457549916`}], 
             PointBox[{76.3, 0.03935743522517402}], 
             PointBox[{76.4, 0.03602560522156387}], 
             PointBox[{76.5, 0.03697411248616554}], 
             PointBox[{76.6, 0.03990326884221292}], 
             PointBox[{76.7, 0.03795441012501008}], 
             PointBox[{76.8, 0.037597170625457275`}], 
             PointBox[{76.9, 0.04137807962626296}], 
             PointBox[{77., 0.044966239584369086`}], 
             PointBox[{77.1, 0.043375049675798645`}], 
             PointBox[{77.2, 0.044012501714175915`}], 
             PointBox[{77.3, 0.0465125872787335}], 
             PointBox[{77.4, 0.043537289922624275`}], 
             PointBox[{77.5, 0.042293436000476796`}], 
             PointBox[{77.6, 0.045333722955575556`}], 
             PointBox[{77.7, 0.04571630204066677}], 
             PointBox[{77.8, 0.043142837544028825`}], 
             PointBox[{77.9, 0.04623186815722593}], 
             PointBox[{78., 0.04997839124163064}], 
             PointBox[{78.1, 0.05054124218064889}], 
             PointBox[{78.2, 0.04902538763130371}], 
             PointBox[{78.3, 0.05225176744293681}], 
             PointBox[{78.4, 0.0510590930034812}], 
             PointBox[{78.5, 0.04823260151560351}], 
             PointBox[{78.6, 0.05002500500213332}], 
             PointBox[{78.7, 0.05245053107807207}], 
             PointBox[{78.8, 0.04972146438995206}], 
             PointBox[{78.9, 0.05075406137166016}], 
             PointBox[{79., 0.054170938715782775`}], 
             PointBox[{79.1, 0.05687260433931156}], 
             PointBox[{79.2, 0.0548049278569757}], 
             PointBox[{79.3, 0.05667025460516207}], 
             PointBox[{79.4, 0.05791191450143753}], 
             PointBox[{79.5, 0.05455834132707253}], 
             PointBox[{79.6, 0.05455435269204969}], 
             PointBox[{79.7, 0.05773249484699596}], 
             PointBox[{79.8, 0.05671942326470816}], 
             PointBox[{79.9, 0.055205816058169176`}], 
             PointBox[{80., 0.058601436357550406`}], 
             PointBox[{80.1, 0.06177675275319526}], 
             PointBox[{80.2, 0.060938439006593396`}], 
             PointBox[{80.3, 0.06052855428111834}], 
             PointBox[{80.4, 0.06356773028063038}], 
             PointBox[{80.5, 0.06091073388333638}], 
             PointBox[{80.6, 0.05921328731330784}], 
             PointBox[{80.7, 0.06188463507144417}], 
             PointBox[{80.8, 0.0631071756847215}], 
             PointBox[{80.9, 0.06009470262766773}], 
             PointBox[{81., 0.06270276703624815}], 
             PointBox[{81.1, 0.06546052685355087}], 
             PointBox[{81.2, 0.06664257988047609}], 
             PointBox[{81.3, 0.06465687054592549}], 
             PointBox[{81.4, 0.0677955693118255}], 
             PointBox[{81.5, 0.06691426368953311}], 
             PointBox[{81.6, 0.0640286320279905}], 
             PointBox[{81.7, 0.06544521563107351}], 
             PointBox[{81.8, 0.06820062272989842}], 
             PointBox[{81.9, 0.0655359663640012}], 
             PointBox[{82., 0.06619518985012293}], 
             PointBox[{82.1, 0.06896479867774395}], 
             PointBox[{82.2, 0.0713360346721771}], 
             PointBox[{82.3, 0.06927162823739567}], 
             PointBox[{82.4, 0.07085902737925777}], 
             PointBox[{82.5, 0.0722084919767984}], 
             PointBox[{82.6, 0.06889734828685981}], 
             PointBox[{82.7, 0.06881207183978975}], 
             PointBox[{82.8, 0.07198256391185838}], 
             PointBox[{82.9, 0.07107482288282052}], 
             PointBox[{83., 0.06945261902513165}], 
             PointBox[{83.1, 0.07255547482614445}], 
             PointBox[{83.2, 0.07483829170793202}], 
             PointBox[{83.3, 0.07399270111434063}], 
             PointBox[{83.4, 0.07346296006981469}], 
             PointBox[{83.5, 0.07648750817527247}], 
             PointBox[{83.6, 0.07367319069140152}], 
             PointBox[{83.7, 0.07218020288624402}], 
             PointBox[{83.8, 0.07485134326952145}], 
             PointBox[{83.9, 0.07600119884953464}], 
             PointBox[{84., 0.07292788984018078}], 
             PointBox[{84.1, 0.07562825046956478}], 
             PointBox[{84.2, 0.07753048807185517}], 
             PointBox[{84.3, 0.0783140190910079}], 
             PointBox[{84.4, 0.07629695176785752}], 
             PointBox[{84.5, 0.07961077557615025}], 
             PointBox[{84.6, 0.07819839525976505}], 
             PointBox[{84.7, 0.0756105310272872}], 
             PointBox[{84.8, 0.07725505310236393}], 
             PointBox[{84.9, 0.07986546161805659}], 
             PointBox[{85., 0.07683906658300013}], 
             PointBox[{85.1, 0.07808150044460092}], 
             PointBox[{85.2, 0.08017522763407207}], 
             PointBox[{85.3, 0.08189928874497225}], 
             PointBox[{85.4, 0.07959375546988867}], 
             PointBox[{85.5, 0.08174994553192456}], 
             PointBox[{85.6, 0.08230178189962788}], 
             PointBox[{85.7, 0.07910161646290723}], 
             PointBox[{85.8, 0.07951637479908584}], 
             PointBox[{85.9, 0.08268506830495978}], 
             PointBox[{86., 0.08101630398032472}], 
             PointBox[{86.1, 0.08022245207022484}], 
             PointBox[{86.2, 0.08293680352927667}], 
             PointBox[{86.3, 0.08466241183913598}], 
             PointBox[{86.4, 0.0831585358620713}], 
             PointBox[{86.5, 0.08341204694540559}], 
             PointBox[{86.6, 0.0858111310059369}], 
             PointBox[{86.7, 0.08263049329420946}], 
             PointBox[{86.8, 0.08182457743502966}], 
             PointBox[{86.9, 0.08478273188867012}], 
             PointBox[{87., 0.08500981970102577}], 
             PointBox[{87.1, 0.08244652913178721}], 
             PointBox[{87.2, 0.0854024248162639}], 
             PointBox[{87.3, 0.08681830071102907}], 
             PointBox[{87.4, 0.0866656514266774}], 
             PointBox[{87.5, 0.0852070589484365}], 
             PointBox[{87.6, 0.08860100706870133}], 
             PointBox[{87.7, 0.08616137490505114}], 
             PointBox[{87.8, 0.0842796665591172}], 
             PointBox[{87.9, 0.08653637861819294}], 
             PointBox[{88., 0.08841666202042868}], 
             PointBox[{88.1, 0.08507383910818231}], 
             PointBox[{88.2, 0.08742133453595205}], 
             PointBox[{88.3, 0.08885109903369678}], 
             PointBox[{88.4, 0.08987227139067876}], 
             PointBox[{88.5, 0.08751835431227194}], 
             PointBox[{88.6, 0.09068711878529187}], 
             PointBox[{88.7, 0.0896465316632278}], 
             PointBox[{88.8, 0.08693868754753843}], 
             PointBox[{88.9, 0.08825136154497443}], 
             PointBox[{89., 0.09112649948240864}], 
             PointBox[{89.1, 0.08822151805706673}], 
             PointBox[{89.2, 0.08915981283450337}], 
             PointBox[{89.3, 0.09112355495560172}], 
             PointBox[{89.4, 0.09268179265656949}], 
             PointBox[{89.5, 0.09039304088554073}], 
             PointBox[{89.6, 0.09230735760949767}], 
             PointBox[{89.7, 0.09302628697150192}], 
             PointBox[{89.8, 0.08984110147720542}], 
             PointBox[{89.9, 0.09013798199450358}], 
             PointBox[{90., 0.09331297624951161}], 
             PointBox[{90.1, 0.09175420642281987}], 
             PointBox[{90.2, 0.09090649463150889}], 
             PointBox[{90.3, 0.09356442295663024}], 
             PointBox[{90.4, 0.09515004049696202}], 
             PointBox[{90.5, 0.09367729460066009}], 
             PointBox[{90.6, 0.0938971398624542}], 
             PointBox[{90.7, 0.09624421807662795}], 
             PointBox[{90.8, 0.09302212906030517}], 
             PointBox[{90.9, 0.09233902524952732}], 
             PointBox[{91., 0.09528493567409367}], 
             PointBox[{91.1, 0.09539503167097561}], 
             PointBox[{91.2, 0.09296994775467524}], 
             PointBox[{91.3, 0.09598963632334451}], 
             PointBox[{91.4, 0.09748446270082198}], 
             PointBox[{91.5, 0.09720406473992435}], 
             PointBox[{91.6, 0.0959232997095016}], 
             PointBox[{91.7, 0.09928315679045904}], 
             PointBox[{91.8, 0.09652031356379286}], 
             PointBox[{91.9, 0.09496067148014808}], 
             PointBox[{92., 0.09735729887439865}], 
             PointBox[{92.1, 0.09893263291870794}], 
             PointBox[{92.2, 0.09561566762020635}], 
             PointBox[{92.3, 0.0984056562745932}], 
             PointBox[{92.4, 0.09999639723442488}], 
             PointBox[{92.5, 0.1008945943788111}], 
             PointBox[{92.6, 0.09870912358954904}], 
             PointBox[{92.7, 0.10221921579225525`}], 
             PointBox[{92.8, 0.10038385143512277`}], 
             PointBox[{92.9, 0.09809895127043132}], 
             PointBox[{93., 0.0997995303634353}], 
             PointBox[{93.1, 0.1023600000450565}], 
             PointBox[{93.2, 0.09901078589737265}], 
             PointBox[{93.3, 0.10098649699588054`}], 
             PointBox[{93.4, 0.1029643814241732}], 
             PointBox[{93.5, 0.10478564391722216`}], 
             PointBox[{93.6, 0.1023827415128006}], 
             PointBox[{93.7, 0.10526316305219975`}], 
             PointBox[{93.8, 0.10468080738276421`}], 
             PointBox[{93.9, 0.1018565100339746}], 
             PointBox[{94., 0.10283569857585148`}], 
             PointBox[{94.1, 0.10587301465608859`}], 
             PointBox[{94.2, 0.10320489492603056`}], 
             PointBox[{94.3, 0.10398405956659586`}], 
             PointBox[{94.4, 0.1065399650296711}], 
             PointBox[{94.5, 0.10902517954052017`}], 
             PointBox[{94.6, 0.1069622854329606}], 
             PointBox[{94.7, 0.10875976122836714`}], 
             PointBox[{94.8, 0.10951549291735613`}], 
             PointBox[{94.9, 0.10635367804685213`}], 
             PointBox[{95., 0.10666653370938406`}], 
             PointBox[{95.1, 0.10978820456945347`}], 
             PointBox[{95.2, 0.10818000732406802`}], 
             PointBox[{95.3, 0.10767855098346386`}], 
             PointBox[{95.4, 0.1108219699532714}], 
             PointBox[{95.5, 0.11386037101115852`}], 
             PointBox[{95.6, 0.11247251265726758`}], 
             PointBox[{95.7, 0.11311447658637913`}], 
             PointBox[{95.8, 0.11504831531799574`}], 
             PointBox[{95.9, 0.11173817015801064`}], 
             PointBox[{96., 0.11149179538318647`}], 
             PointBox[{96.1, 0.11446490859570517`}], 
             PointBox[{96.2, 0.11394633241471841`}], 
             PointBox[{96.3, 0.11234982472685529`}], 
             PointBox[{96.4, 0.11597651641076027`}], 
             PointBox[{96.5, 0.11961314338719883`}], 
             PointBox[{96.6, 0.11900662753060422`}], 
             PointBox[{96.7, 0.11870910266712185`}], 
             PointBox[{96.8, 0.12150466255615297`}], 
             PointBox[{96.9, 0.11818145172288638`}], 
             PointBox[{97., 0.1175204948367923}], 
             PointBox[{97.1, 0.12025850552617076`}], 
             PointBox[{97.2, 0.1206150908008898}], 
             PointBox[{97.3, 0.11825878742521398`}], 
             PointBox[{97.4, 0.12227524722022826`}], 
             PointBox[{97.5, 0.12664352453186717`}], 
             PointBox[{97.6, 0.1267201257344041}], 
             PointBox[{97.7, 0.1258327818209837}], 
             PointBox[{97.8, 0.12915086673881343`}], 
             PointBox[{97.9, 0.1258541736782133}], 
             PointBox[{98., 0.12495647490079259`}], 
             PointBox[{98.1, 0.12748635488243049`}], 
             PointBox[{98.2, 0.12838548088618065`}], 
             PointBox[{98.3, 0.12562676956526958`}], 
             PointBox[{98.4, 0.1300639693296262}], 
             PointBox[{98.5, 0.1352667826671726}], 
             PointBox[{98.6, 0.13573694706631714`}], 
             PointBox[{98.7, 0.13462531831316624`}], 
             PointBox[{98.8, 0.13818977304093966`}], 
             PointBox[{98.9, 0.13484941730506908`}], 
             PointBox[{99., 0.1339306391356068}], 
             PointBox[{99.1, 0.13635650887085132`}], 
             PointBox[{99.2, 0.1374151012576022}], 
             PointBox[{99.3, 0.13460025679934517`}], 
             PointBox[{99.4, 0.13967971276003083`}], 
             PointBox[{99.5, 0.1455537616962485}], 
             PointBox[{99.6, 0.14595566261351864`}], 
             PointBox[{99.7, 0.1449944553531933}], 
             PointBox[{99.8, 0.14853427409383851`}], 
             PointBox[{99.9, 0.1450343838613386}], 
             PointBox[{100., 0.14435465598688157`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 0.2}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 180.}], 
             PointBox[{0.1, 198.59222752746794`}], 
             PointBox[{0.2, 196.5090021985358}], 
             PointBox[{0.3, 193.3206137301961}], 
             PointBox[{0.4, 203.2683221384529}], 
             PointBox[{0.5, 202.50462739632633`}], 
             PointBox[{0.6, 191.05341406774315`}], 
             PointBox[{0.7, 196.19558661650203`}], 
             PointBox[{0.8, 203.68206124175862`}], 
             PointBox[{0.9, 196.43806106193588`}], 
             PointBox[{1., 203.69410133867774`}], 
             PointBox[{1.1, 223.3238708220148}], 
             PointBox[{1.2, 231.6773716601227}], 
             PointBox[{1.3, 225.17809031395103`}], 
             PointBox[{1.4, 228.3888725124967}], 
             PointBox[{1.5, 235.73293309354966`}], 
             PointBox[{1.6, 228.9655678798728}], 
             PointBox[{1.7, 223.6824546005447}], 
             PointBox[{1.8, 231.30765153474857`}], 
             PointBox[{1.9, 232.433528685358}], 
             PointBox[{2., 228.10686528804075`}], 
             PointBox[{2.1, 241.57262233678094`}], 
             PointBox[{2.2, 253.1554757556623}], 
             PointBox[{2.3, 253.17355142008358`}], 
             PointBox[{2.4, 249.2479012153719}], 
             PointBox[{2.5, 255.8980820420107}], 
             PointBox[{2.6, 257.0361515427694}], 
             PointBox[{2.7, 249.35337146210466`}], 
             PointBox[{2.8, 250.71120822831398`}], 
             PointBox[{2.9, 256.68791514639435`}], 
             PointBox[{3., 252.45380844802855`}], 
             PointBox[{3.1, 256.2755750316751}], 
             PointBox[{3.2, 267.77468714884793`}], 
             PointBox[{3.3, 272.9617084983198}], 
             PointBox[{3.4, 268.8212179030581}], 
             PointBox[{3.5, 270.6919353432913}], 
             PointBox[{3.6, 275.5507995313967}], 
             PointBox[{3.7, 271.2880744092339}], 
             PointBox[{3.8, 267.70761155093544`}], 
             PointBox[{3.9, 272.5268246777708}], 
             PointBox[{4., 273.28164535563224`}], 
             PointBox[{4.1, 270.6601155719348}], 
             PointBox[{4.2, 279.63327087351274`}], 
             PointBox[{4.3, 286.87685258227174`}], 
             PointBox[{4.4, 286.46369691199266`}], 
             PointBox[{4.5, 284.1399543111751}], 
             PointBox[{4.6, 289.0253930659503}], 
             PointBox[{4.7, 288.8334404436294}], 
             PointBox[{4.8, 283.94110871174354`}], 
             PointBox[{4.9, 285.26571720100725`}], 
             PointBox[{5., 289.14377125299575`}], 
             PointBox[{5.1, 285.8457215914822}], 
             PointBox[{5.2, 289.89269362939194`}], 
             PointBox[{5.3, 297.8789944684857}], 
             PointBox[{5.4, 300.9913787657158}], 
             PointBox[{5.5, 297.8188127570164}], 
             PointBox[{5.6, 300.23508023310546`}], 
             PointBox[{5.7, 302.8858026116196}], 
             PointBox[{5.8, 299.1961141261543}], 
             PointBox[{5.9, 297.4765041177589}], 
             PointBox[{6., 301.3426237213108}], 
             PointBox[{6.1, 300.7026981297421}], 
             PointBox[{6.2, 300.1218466667371}], 
             PointBox[{6.3, 307.56132734751475`}], 
             PointBox[{6.4, 312.72437669269937`}], 
             PointBox[{6.5, 311.4886421229023}], 
             PointBox[{6.6, 310.8114434437964}], 
             PointBox[{6.7, 314.5774481479071}], 
             PointBox[{6.8, 313.0696555198516}], 
             PointBox[{6.9, 309.86215498874174`}], 
             PointBox[{7., 311.8500209380973}], 
             PointBox[{7.1, 313.97317603685036`}], 
             PointBox[{7.2, 311.40731533405494`}], 
             PointBox[{7.3, 316.43953282328243`}], 
             PointBox[{7.4, 322.6710674427037}], 
             PointBox[{7.5, 324.11526241812817`}], 
             PointBox[{7.6, 321.73469711469295`}], 
             PointBox[{7.7, 324.8090335034472}], 
             PointBox[{7.8, 325.4937629048179}], 
             PointBox[{7.9, 322.2544810167326}], 
             PointBox[{8., 322.0515281404592}], 
             PointBox[{8.1, 325.2734300555996}], 
             PointBox[{8.2, 323.39784790737787`}], 
             PointBox[{8.3, 325.07357446120966`}], 
             PointBox[{8.4, 331.6377492521135}], 
             PointBox[{8.5, 335.1982548103554}], 
             PointBox[{8.6, 333.21809271257825`}], 
             PointBox[{8.7, 334.31191400232575`}], 
             PointBox[{8.8, 336.63270654259907`}], 
             PointBox[{8.9, 334.2989515739666}], 
             PointBox[{9., 332.51292973512034`}], 
             PointBox[{9.1, 335.1417820621097}], 
             PointBox[{9.2, 335.3128786896791}], 
             PointBox[{9.3, 334.3248027010841}], 
             PointBox[{9.4, 340.0531661983764}], 
             PointBox[{9.5, 344.94817387691427`}], 
             PointBox[{9.6, 344.7192541945043}], 
             PointBox[{9.7, 343.7367096733436}], 
             PointBox[{9.8, 346.72612554322023`}], 
             PointBox[{9.9, 345.75705139735885`}], 
             PointBox[{10., 343.24055727228335`}], 
             PointBox[{10.1, 344.42150881752667`}], 
             PointBox[{10.2, 346.41996217670766`}], 
             PointBox[{10.3, 344.339753353641}], 
             PointBox[{10.4, 348.1373335740604}], 
             PointBox[{10.5, 353.787314983798}], 
             PointBox[{10.6, 355.55080388099515`}], 
             PointBox[{10.7, 353.55329140829224`}], 
             PointBox[{10.8, 356.03854427011015`}], 
             PointBox[{10.9, 356.5353394434904}], 
             PointBox[{11., 354.0230248616355}], 
             PointBox[{11.1, 353.71292388015934`}], 
             PointBox[{11.2, 356.4141304273349}], 
             PointBox[{11.3, 354.85221830718285`}], 
             PointBox[{11.4, 356.302996402512}], 
             PointBox[{11.5, 2.064359589507168}], 
             PointBox[{11.6, 5.436167196649245}], 
             PointBox[{11.7, 3.8258708557111727`}], 
             PointBox[{11.8, 4.880018678872486}], 
             PointBox[{11.9, 6.631847568981457}], 
             PointBox[{12., 4.647637007167175}], 
             PointBox[{12.1, 3.236891507239363}], 
             PointBox[{12.2, 5.518976284679042}], 
             PointBox[{12.3, 5.443168644975302}], 
             PointBox[{12.4, 4.9024641954549555`}], 
             PointBox[{12.5, 10.006923155932895`}], 
             PointBox[{12.6, 14.469790009506054`}], 
             PointBox[{12.7, 14.190301437594538`}], 
             PointBox[{12.8, 13.611196230591078`}], 
             PointBox[{12.9, 16.09161978294251}], 
             PointBox[{13., 14.971198295203884`}], 
             PointBox[{13.1, 12.96021379490472}], 
             PointBox[{13.2, 14.202757289884405`}], 
             PointBox[{13.3, 15.646930175659532`}], 
             PointBox[{13.4, 13.984775380820645`}], 
             PointBox[{13.5, 17.772566254170904`}], 
             PointBox[{13.6, 22.868633442564736`}], 
             PointBox[{13.7, 24.1802799130627}], 
             PointBox[{13.8, 22.56039790727916}], 
             PointBox[{13.9, 24.99526169505304}], 
             PointBox[{14., 24.914256931389065`}], 
             PointBox[{14.1, 22.753247834114816`}], 
             PointBox[{14.2, 22.848231461439067`}], 
             PointBox[{14.3, 25.14765961768479}], 
             PointBox[{14.4, 23.449516074125015`}], 
             PointBox[{14.5, 25.561368140194094`}], 
             PointBox[{14.6, 30.836972622681134`}], 
             PointBox[{14.7, 33.54687426028954}], 
             PointBox[{14.8, 31.865485524031357`}], 
             PointBox[{14.9, 33.471051343308424`}], 
             PointBox[{15., 34.438560544353436`}], 
             PointBox[{15.1, 32.48428958927089}], 
             PointBox[{15.2, 31.631170162766985`}], 
             PointBox[{15.3, 33.938209262169316`}], 
             PointBox[{15.4, 33.11136354014757}], 
             PointBox[{15.5, 33.55873149637832}], 
             PointBox[{15.6, 38.536831692386556`}], 
             PointBox[{15.7, 42.28038687171273}], 
             PointBox[{15.8, 41.38306142052545}], 
             PointBox[{15.9, 41.7066371812066}], 
             PointBox[{16., 43.5312375545795}], 
             PointBox[{16.1, 42.052242604479545`}], 
             PointBox[{16.2, 40.56218897837673}], 
             PointBox[{16.3, 42.25483192620995}], 
             PointBox[{16.4, 42.701340396331666`}], 
             PointBox[{16.5, 41.83229648323203}], 
             PointBox[{16.6, 46.07932405716417}], 
             PointBox[{16.7, 50.48721283029609}], 
             PointBox[{16.8, 50.79949837306693}], 
             PointBox[{16.9, 49.92379419511592}], 
             PointBox[{17., 52.19780863277708}], 
             PointBox[{17.1, 51.385114883229505`}], 
             PointBox[{17.2, 49.568183428314356`}], 
             PointBox[{17.3, 50.38154164916571}], 
             PointBox[{17.4, 51.933393977849114`}], 
             PointBox[{17.5, 50.36818298276413}], 
             PointBox[{17.6, 53.54775314636896}], 
             PointBox[{17.7, 58.29681251883334}], 
             PointBox[{17.8, 59.8441868139919}], 
             PointBox[{17.9, 58.304523304003496`}], 
             PointBox[{18., 60.467279275229934`}], 
             PointBox[{18.1, 60.43267374604051}], 
             PointBox[{18.2, 58.55349607009302}], 
             PointBox[{18.3, 58.5050085182007}], 
             PointBox[{18.4, 60.6286989739684}], 
             PointBox[{18.5, 59.101321771142636`}], 
             PointBox[{18.6, 61.02920115349855}], 
             PointBox[{18.7, 65.82381584983219}], 
             PointBox[{18.8, 68.39906045838626}], 
             PointBox[{18.9, 66.89021851184563}], 
             PointBox[{19., 68.39942748021254}], 
             PointBox[{19.1, 69.15822837084471}], 
             PointBox[{19.2, 67.42694507660761}], 
             PointBox[{19.3, 66.68657996610652}], 
             PointBox[{19.4, 68.78946726565155}], 
             PointBox[{19.5, 67.91229980835745}], 
             PointBox[{19.6, 68.58696782195904}], 
             PointBox[{19.7, 73.15616065817696}], 
             PointBox[{19.8, 76.46753087836458}], 
             PointBox[{19.9, 75.55031783872455}], 
             PointBox[{20., 76.08465539315328}], 
             PointBox[{20.1, 77.53317010578667}], 
             PointBox[{20.2, 76.10822593932994}], 
             PointBox[{20.3, 74.89371401644411}], 
             PointBox[{20.4, 76.55083254575636}], 
             PointBox[{20.5, 76.62697778201127}], 
             PointBox[{20.6, 76.23136306887511}], 
             PointBox[{20.7, 80.34447233991114}], 
             PointBox[{20.8, 84.10869979095581}], 
             PointBox[{20.9, 84.05703715077047}], 
             PointBox[{21., 83.6247697296965}], 
             PointBox[{21.1, 85.53599109895742}], 
             PointBox[{21.2, 84.52614079149583}], 
             PointBox[{21.3, 83.04416294421789}], 
             PointBox[{21.4, 84.06702140571188}], 
             PointBox[{21.5, 85.05118899427353}], 
             PointBox[{21.6, 83.9255081875682}], 
             PointBox[{21.7, 87.40417946628168}], 
             PointBox[{21.8, 91.38552788467408}], 
             PointBox[{21.9, 92.20505470842987}], 
             PointBox[{22., 91.08971998798171}], 
             PointBox[{22.1, 93.14991176795672}], 
             PointBox[{22.2, 92.61341977061738}], 
             PointBox[{22.3, 91.03335319511972}], 
             PointBox[{22.4, 91.42538622723852}], 
             PointBox[{22.5, 93.02865440927373}], 
             PointBox[{22.6, 91.59126922419347}], 
             PointBox[{22.7, 94.33041705602648}], 
             PointBox[{22.8, 98.34154410454093}], 
             PointBox[{22.9, 99.86524326581598}], 
             PointBox[{23., 98.46678583846663}], 
             PointBox[{23.1, 100.35911625646558`}], 
             PointBox[{23.2, 100.29975707843147`}], 
             PointBox[{23.3, 98.74482984225432}], 
             PointBox[{23.4, 98.62054682270774}], 
             PointBox[{23.5, 100.48028054983108`}], 
             PointBox[{23.6, 99.10988661515371}], 
             PointBox[{23.7, 101.09654035447664`}], 
             PointBox[{23.8, 104.9849492884356}], 
             PointBox[{23.9, 106.97144882788243`}], 
             PointBox[{24., 105.63688868112261`}], 
             PointBox[{24.1, 107.13826848250037`}], 
             PointBox[{24.2, 107.50421112416359`}], 
             PointBox[{24.3, 106.05112007384402`}], 
             PointBox[{24.4, 105.56528430183863`}], 
             PointBox[{24.5, 107.38737359545694`}], 
             PointBox[{24.6, 106.3230327369889}], 
             PointBox[{24.7, 107.63720860966853`}], 
             PointBox[{24.8, 111.27475207477077`}], 
             PointBox[{24.9, 113.47123162602799`}], 
             PointBox[{25., 112.39358296634202`}], 
             PointBox[{25.1, 113.4330248250509}], 
             PointBox[{25.2, 114.12383666811584`}], 
             PointBox[{25.3, 112.8051984874206}], 
             PointBox[{25.4, 112.10886546158515`}], 
             PointBox[{25.5, 113.7341292191266}], 
             PointBox[{25.6, 113.03827510931256`}], 
             PointBox[{25.7, 113.83479676528509`}], 
             PointBox[{25.8, 117.10640217301776`}], 
             PointBox[{25.9, 119.28218770163474`}], 
             PointBox[{26., 118.48529622082172`}], 
             PointBox[{26.1, 119.13884293167975`}], 
             PointBox[{26.2, 120.02031650607012`}], 
             PointBox[{26.3, 118.83017958768768`}], 
             PointBox[{26.4, 118.05205913771502`}], 
             PointBox[{26.5, 119.45187763804525`}], 
             PointBox[{26.6, 119.03587104873674`}], 
             PointBox[{26.7, 119.51485431858396`}], 
             PointBox[{26.8, 122.2977084524687}], 
             PointBox[{26.9, 124.26234391914139`}], 
             PointBox[{27., 123.6461199718212}], 
             PointBox[{27.1, 124.08989918496539`}], 
             PointBox[{27.2, 125.0095892462075}], 
             PointBox[{27.3, 123.91419597152435`}], 
             PointBox[{27.4, 123.15656918309654`}], 
             PointBox[{27.5, 124.39354462915983`}], 
             PointBox[{27.6, 124.07220935353466`}], 
             PointBox[{27.7, 124.4422152424226}], 
             PointBox[{27.8, 126.59054891070994`}], 
             PointBox[{27.9, 128.21394435436093`}], 
             PointBox[{28., 127.61681065548679`}], 
             PointBox[{28.1, 128.08078938810021`}], 
             PointBox[{28.2, 128.86933369650012`}], 
             PointBox[{28.3, 127.82817457018194`}], 
             PointBox[{28.4, 127.1755290246564}], 
             PointBox[{28.5, 128.35569902628174`}], 
             PointBox[{28.6, 127.89588558889476`}], 
             PointBox[{28.7, 128.30588727222369`}], 
             PointBox[{28.8, 129.71756921128994`}], 
             PointBox[{28.9, 130.9408322220951}], 
             PointBox[{29., 130.20409551558168`}], 
             PointBox[{29.1, 130.93882727825476`}], 
             PointBox[{29.2, 131.40153093976232`}], 
             PointBox[{29.3, 130.3987979466419}], 
             PointBox[{29.4, 129.93101359539605`}], 
             PointBox[{29.5, 131.14700107195358`}], 
             PointBox[{29.6, 130.3325245957181}], 
             PointBox[{29.7, 130.72226804446942`}], 
             PointBox[{29.8, 131.5612437062582}], 
             PointBox[{29.9, 132.36311339415244`}], 
             PointBox[{30., 131.41481370371324`}], 
             PointBox[{30.1, 132.60100999408618`}], 
             PointBox[{30.2, 132.55754802120887`}], 
             PointBox[{30.3, 131.63087709646658`}], 
             PointBox[{30.4, 131.43959697344937`}], 
             PointBox[{30.5, 132.6591073159383}], 
             PointBox[{30.6, 131.4484488566003}], 
             PointBox[{30.7, 131.60847407465667`}], 
             PointBox[{30.8, 132.25650241928213`}], 
             PointBox[{30.9, 132.58783813988376`}], 
             PointBox[{31., 131.6174697964759}], 
             PointBox[{31.1, 133.1071826426894}], 
             PointBox[{31.2, 132.5384545839189}], 
             PointBox[{31.3, 131.77850070106683`}], 
             PointBox[{31.4, 131.97044812725076`}], 
             PointBox[{31.5, 132.82272761023555`}], 
             PointBox[{31.6, 131.46288580290482`}], 
             PointBox[{31.7, 131.53732898288035`}], 
             PointBox[{31.8, 132.08124237223586`}], 
             PointBox[{31.9, 131.84799679309876`}], 
             PointBox[{32., 131.48917771244683`}], 
             PointBox[{32.1, 132.58690007794374`}], 
             PointBox[{32.2, 131.73203824272235`}], 
             PointBox[{32.3, 131.25308962728494`}], 
             PointBox[{32.4, 131.90850327813547`}], 
             PointBox[{32.5, 131.6720402809635}], 
             PointBox[{32.6, 130.624668161868}], 
             PointBox[{32.7, 130.98916806239106`}], 
             PointBox[{32.8, 131.27153823805602`}], 
             PointBox[{32.9, 130.46758273302777`}], 
             PointBox[{33., 131.3147631025273}], 
             PointBox[{33.1, 131.33871268765182`}], 
             PointBox[{33.2, 130.54023065759884`}], 
             PointBox[{33.3, 130.45234705854628`}], 
             PointBox[{33.4, 131.39339217569835`}], 
             PointBox[{33.5, 129.86671234895218`}], 
             PointBox[{33.6, 129.68569568819333`}], 
             PointBox[{33.7, 130.11190519850166`}], 
             PointBox[{33.8, 129.95576103934985`}], 
             PointBox[{33.9, 129.0900849785577}], 
             PointBox[{34., 130.547691843507}], 
             PointBox[{34.1, 129.76462860882833`}], 
             PointBox[{34.2, 129.26619359051858`}], 
             PointBox[{34.3, 129.6411087227142}], 
             PointBox[{34.4, 129.95627698455172`}], 
             PointBox[{34.5, 128.25298879233145`}], 
             PointBox[{34.6, 128.75117320118343`}], 
             PointBox[{34.7, 128.9274617378178}], 
             PointBox[{34.8, 128.2481882241948}], 
             PointBox[{34.9, 128.4637120588812}], 
             PointBox[{35., 129.0188537896184}], 
             PointBox[{35.1, 128.1846330550703}], 
             PointBox[{35.2, 128.09364714241045`}], 
             PointBox[{35.3, 128.81806694890486`}], 
             PointBox[{35.4, 127.49221227993154`}], 
             PointBox[{35.5, 127.18835081878615`}], 
             PointBox[{35.6, 127.66853133163238`}], 
             PointBox[{35.7, 127.43638648204175`}], 
             PointBox[{35.8, 126.51873776579166`}], 
             PointBox[{35.9, 127.91640747114324`}], 
             PointBox[{36., 127.23312155000204`}], 
             PointBox[{36.1, 126.77150252093088`}], 
             PointBox[{36.2, 127.0864639524517}], 
             PointBox[{36.3, 127.45571614288392`}], 
             PointBox[{36.4, 125.54978449479049`}], 
             PointBox[{36.5, 126.24277861642383`}], 
             PointBox[{36.6, 126.3677197054971}], 
             PointBox[{36.7, 125.70046325622798`}], 
             PointBox[{36.8, 125.50847702044945`}], 
             PointBox[{36.9, 126.48403633052044`}], 
             PointBox[{37., 125.60074863937507`}], 
             PointBox[{37.1, 125.58293866691228`}], 
             PointBox[{37.2, 126.13240705232427`}], 
             PointBox[{37.3, 125.07436630164443`}], 
             PointBox[{37.4, 124.55703752660409`}], 
             PointBox[{37.5, 125.16116189977708`}], 
             PointBox[{37.6, 124.86465016598756`}], 
             PointBox[{37.7, 123.97520953037504`}], 
             PointBox[{37.8, 125.11215590550356`}], 
             PointBox[{37.9, 124.6934648441113}], 
             PointBox[{38., 124.2643943454307}], 
             PointBox[{38.1, 124.59198838612944`}], 
             PointBox[{38.2, 124.84027830922032`}], 
             PointBox[{38.3, 122.99926342843654`}], 
             PointBox[{38.4, 123.78170481522386`}], 
             PointBox[{38.5, 123.93564753849995`}], 
             PointBox[{38.6, 123.27182292126858`}], 
             PointBox[{38.7, 122.77154506679229`}], 
             PointBox[{38.8, 124.12065278722771`}], 
             PointBox[{38.9, 123.16380506065488`}], 
             PointBox[{39., 123.24403888838073`}], 
             PointBox[{39.1, 123.68728412860503`}], 
             PointBox[{39.2, 123.0844205777157}], 
             PointBox[{39.3, 122.10300633049033`}], 
             PointBox[{39.4, 122.98372675104005`}], 
             PointBox[{39.5, 122.69909071945494`}], 
             PointBox[{39.6, 121.83443984670811`}], 
             PointBox[{39.7, 122.36965568665858`}], 
             PointBox[{39.8, 122.66863975555938`}], 
             PointBox[{39.9, 122.10504139353287`}], 
             PointBox[{40., 122.54771253931867`}], 
             PointBox[{40.1, 122.76988986940393`}], 
             PointBox[{40.2, 121.54548160865302`}], 
             PointBox[{40.3, 121.86788797908054`}], 
             PointBox[{40.4, 122.3268504786723}], 
             PointBox[{40.5, 121.70241460918949`}], 
             PointBox[{40.6, 120.92935568949554`}], 
             PointBox[{40.7, 122.303501781363}], 
             PointBox[{40.8, 121.58993797656194`}], 
             PointBox[{40.9, 121.62447226224009`}], 
             PointBox[{41., 122.2538263873503}], 
             PointBox[{41.1, 122.36006812088097`}], 
             PointBox[{41.2, 121.04954078105216`}], 
             PointBox[{41.3, 122.13606020064933`}], 
             PointBox[{41.4, 122.16403572271284`}], 
             PointBox[{41.5, 121.31203248364925`}], 
             PointBox[{41.6, 120.93428613090843`}], 
             PointBox[{41.7, 122.37283538868789`}], 
             PointBox[{41.8, 121.35340971612402`}], 
             PointBox[{41.9, 121.9105031509122}], 
             PointBox[{42., 122.6615514276052}], 
             PointBox[{42.1, 123.04478964594871`}], 
             PointBox[{42.2, 121.9516613648459}], 
             PointBox[{42.3, 123.21898281615631`}], 
             PointBox[{42.4, 122.9213363835544}], 
             PointBox[{42.5, 121.9430277993686}], 
             PointBox[{42.6, 122.07221284245348`}], 
             PointBox[{42.7, 123.14578843671768`}], 
             PointBox[{42.8, 122.23465272906711`}], 
             PointBox[{42.9, 123.23642276510753`}], 
             PointBox[{43., 124.37013491997538`}], 
             PointBox[{43.1, 124.94850322743001`}], 
             PointBox[{43.2, 124.1972925396676}], 
             PointBox[{43.3, 125.45918274584704`}], 
             PointBox[{43.4, 124.93807707468937`}], 
             PointBox[{43.5, 123.89516621099443`}], 
             PointBox[{43.6, 124.42240269906355`}], 
             PointBox[{43.7, 125.16552646464044`}], 
             PointBox[{43.8, 124.40589105646401`}], 
             PointBox[{43.9, 125.81356563092677`}], 
             PointBox[{44., 127.63774606802616`}], 
             PointBox[{44.1, 128.2271356676468}], 
             PointBox[{44.2, 127.68589797824758`}], 
             PointBox[{44.3, 128.97783048992997`}], 
             PointBox[{44.4, 128.32180858772352`}], 
             PointBox[{44.5, 127.2232320206912}], 
             PointBox[{44.6, 127.95739595059325`}], 
             PointBox[{44.7, 128.589649258251}], 
             PointBox[{44.8, 127.86285596590707`}], 
             PointBox[{44.9, 129.62710159245574`}], 
             PointBox[{45., 132.1438058142243}], 
             PointBox[{45.1, 132.79598571106894`}], 
             PointBox[{45.2, 132.24632260566113`}], 
             PointBox[{45.3, 133.66098593019666`}], 
             PointBox[{45.4, 132.9573329149018}], 
             PointBox[{45.5, 131.77614626078847`}], 
             PointBox[{45.6, 132.5352733077435}], 
             PointBox[{45.7, 133.29134612900083`}], 
             PointBox[{45.8, 132.44469890251492`}], 
             PointBox[{45.9, 134.45607692900072`}], 
             PointBox[{46., 137.52427227241398`}], 
             PointBox[{46.1, 138.42306147763875`}], 
             PointBox[{46.2, 137.67086902666918`}], 
             PointBox[{46.3, 139.27690985535696`}], 
             PointBox[{46.4, 138.62629883294272`}], 
             PointBox[{46.5, 137.33079743138887`}], 
             PointBox[{46.6, 137.9539883957969}], 
             PointBox[{46.7, 139.0226433673761}], 
             PointBox[{46.8, 137.94547296814332`}], 
             PointBox[{46.9, 140.02961158541376`}], 
             PointBox[{47., 143.50880540404162`}], 
             PointBox[{47.1, 144.85418308506038`}], 
             PointBox[{47.2, 143.79039198023878`}], 
             PointBox[{47.3, 145.57817209905113`}], 
             PointBox[{47.4, 145.10416330679342`}], 
             PointBox[{47.5, 143.68279160000517`}], 
             PointBox[{47.6, 144.0291424879108}], 
             PointBox[{47.7, 145.50949766471658`}], 
             PointBox[{47.8, 144.19901663134172`}], 
             PointBox[{47.9, 146.13451828040235`}], 
             PointBox[{48., 149.89947510153365`}], 
             PointBox[{48.1, 151.85616870745525`}], 
             PointBox[{48.2, 150.50925487840482`}], 
             PointBox[{48.3, 152.3486312979671}], 
             PointBox[{48.4, 152.19796949033034`}], 
             PointBox[{48.5, 150.67402976135628`}], 
             PointBox[{48.6, 150.63481363486514`}], 
             PointBox[{48.7, 152.48901663091632`}], 
             PointBox[{48.8, 151.0998855103414}], 
             PointBox[{48.9, 152.63818078312983`}], 
             PointBox[{49., 156.5599946176563}], 
             PointBox[{49.1, 159.2247424835156}], 
             PointBox[{49.2, 157.79294798083845`}], 
             PointBox[{49.3, 159.4207185611757}], 
             PointBox[{49.4, 159.7479201808729}], 
             PointBox[{49.5, 158.1868493127902}], 
             PointBox[{49.6, 157.69854363737437`}], 
             PointBox[{49.7, 159.73912527275888`}], 
             PointBox[{49.8, 158.58238027209086`}], 
             PointBox[{49.9, 159.4782828625688}], 
             PointBox[{50., 163.4088937031459}], 
             PointBox[{50.1, 166.79018354416868`}], 
             PointBox[{50.2, 165.61771098210957`}], 
             PointBox[{50.3, 166.68831279014947`}], 
             PointBox[{50.4, 167.6174423842462}], 
             PointBox[{50.5, 166.1305584409864}], 
             PointBox[{50.6, 165.1831206861488}], 
             PointBox[{50.7, 167.11800078382183`}], 
             PointBox[{50.8, 166.57888289846957`}], 
             PointBox[{50.9, 166.6471227216381}], 
             PointBox[{51., 170.40725401491235`}], 
             PointBox[{51.1, 174.42232496098381`}], 
             PointBox[{51.2, 173.91280737778246`}], 
             PointBox[{51.3, 174.12450872736926`}], 
             PointBox[{51.4, 175.68459745382032`}], 
             PointBox[{51.5, 174.42980165073416`}], 
             PointBox[{51.6, 173.0671754958147}], 
             PointBox[{51.7, 174.58869792109607`}], 
             PointBox[{51.8, 174.97138816770735`}], 
             PointBox[{51.9, 174.17737548719282`}], 
             PointBox[{52., 177.54208208745973`}], 
             PointBox[{52.1, 182.03177258723227`}], 
             PointBox[{52.2, 182.5340422868049}], 
             PointBox[{52.3, 181.79482459621815`}], 
             PointBox[{52.4, 183.8388552073623}], 
             PointBox[{52.5, 183.0143255051716}], 
             PointBox[{52.6, 181.3316850927416}], 
             PointBox[{52.7, 182.20161475140057`}], 
             PointBox[{52.8, 183.565337914654}], 
             PointBox[{52.9, 182.12663240007208`}], 
             PointBox[{53., 184.82065940724996`}], 
             PointBox[{53.1, 189.5702840308904}], 
             PointBox[{53.2, 191.2927589597748}], 
             PointBox[{53.3, 189.84094185012864`}], 
             PointBox[{53.4, 191.99068537456944`}], 
             PointBox[{53.5, 191.81331087926512`}], 
             PointBox[{53.6, 189.95514984635682`}], 
             PointBox[{53.7, 190.05100488061527`}], 
             PointBox[{53.8, 192.13250494812894`}], 
             PointBox[{53.9, 190.5554758295154}], 
             PointBox[{54., 192.28486805446929`}], 
             PointBox[{54.1, 197.03665399709948`}], 
             PointBox[{54.2, 200.01005596919052`}], 
             PointBox[{54.3, 198.40498393356305`}], 
             PointBox[{54.4, 200.09316892189602`}], 
             PointBox[{54.5, 200.74690364069727`}], 
             PointBox[{54.6, 198.90982857485062`}], 
             PointBox[{54.7, 198.22655302974152`}], 
             PointBox[{54.8, 200.51707941757667`}], 
             PointBox[{54.9, 199.48168877083916`}], 
             PointBox[{55., 200.01389389418574`}], 
             PointBox[{55.1, 204.48185980595636`}], 
             PointBox[{55.2, 208.5561238618666}], 
             PointBox[{55.3, 207.51826017015685`}], 
             PointBox[{55.4, 208.18483905462608`}], 
             PointBox[{55.5, 209.72550447464985`}], 
             PointBox[{55.6, 208.16101560205325`}], 
             PointBox[{55.7, 206.79194893234703`}], 
             PointBox[{55.8, 208.72695752965814`}], 
             PointBox[{55.9, 208.81433575365176`}], 
             PointBox[{56., 208.11723391014183`}], 
             PointBox[{56.1, 211.98932479799228`}], 
             PointBox[{56.2, 216.85573407043347`}], 
             PointBox[{56.3, 217.0345324024838}], 
             PointBox[{56.4, 216.42645771681822`}], 
             PointBox[{56.5, 218.65242347087596`}], 
             PointBox[{56.6, 217.66201781289575`}], 
             PointBox[{56.7, 215.78098337157434`}], 
             PointBox[{56.8, 216.9216505117836}], 
             PointBox[{56.9, 218.31062367657546`}], 
             PointBox[{57., 216.7228381491092}], 
             PointBox[{57.1, 219.63998929107544`}], 
             PointBox[{57.2, 224.8834278342494}], 
             PointBox[{57.3, 226.68056314332253`}], 
             PointBox[{57.4, 225.08842270753723`}], 
             PointBox[{57.5, 227.44637488806018`}], 
             PointBox[{57.6, 227.34588833235117`}], 
             PointBox[{57.7, 225.20323454686456`}], 
             PointBox[{57.8, 225.31929460502127`}], 
             PointBox[{57.9, 227.65195002500232`}], 
             PointBox[{58., 225.94659942711368`}], 
             PointBox[{58.1, 227.53497209394865`}], 
             PointBox[{58.2, 232.6858275510095}], 
             PointBox[{58.3, 236.17869414984355`}], 
             PointBox[{58.4, 234.42938324750787`}], 
             PointBox[{58.5, 236.0942460617557}], 
             PointBox[{58.6, 237.1168337628422}], 
             PointBox[{58.7, 235.04937181923705`}], 
             PointBox[{58.8, 234.1145645538436}], 
             PointBox[{58.9, 236.64797085851774`}], 
             PointBox[{59., 235.81121779529798`}], 
             PointBox[{59.1, 235.825248773512}], 
             PointBox[{59.2, 240.4268642767799}], 
             PointBox[{59.3, 245.32608734154294`}], 
             PointBox[{59.4, 244.49955203329074`}], 
             PointBox[{59.5, 244.73317803369315`}], 
             PointBox[{59.6, 246.84810424081314`}], 
             PointBox[{59.7, 245.28802337794434`}], 
             PointBox[{59.8, 243.4462751265651}], 
             PointBox[{59.9, 245.38398809618695`}], 
             PointBox[{60., 246.11968108716587`}], 
             PointBox[{60.1, 244.7085053521683}], 
             PointBox[{60.2, 248.31483656380004`}], 
             PointBox[{60.3, 254.00512343940437`}], 
             PointBox[{60.4, 255.03665459609596`}], 
             PointBox[{60.5, 253.70865538097408`}], 
             PointBox[{60.6, 256.40424961400583`}], 
             PointBox[{60.7, 255.85017755887034`}], 
             PointBox[{60.8, 253.40341507814557`}], 
             PointBox[{60.9, 254.16337674530473`}], 
             PointBox[{61., 256.4327731579391}], 
             PointBox[{61.1, 254.4062257356753}], 
             PointBox[{61.2, 256.5059524547057}], 
             PointBox[{61.3, 262.22358483654824`}], 
             PointBox[{61.4, 265.58756360110215`}], 
             PointBox[{61.5, 263.49251520565105`}], 
             PointBox[{61.6, 265.7217231689858}], 
             PointBox[{61.7, 266.6061490634028}], 
             PointBox[{61.8, 264.03871966159306`}], 
             PointBox[{61.9, 263.34817556628644`}], 
             PointBox[{62., 266.33468739658986`}], 
             PointBox[{62.1, 265.0545720516768}], 
             PointBox[{62.2, 265.2065446964616}], 
             PointBox[{62.3, 270.2754622868448}], 
             PointBox[{62.4, 275.7128829070936}], 
             PointBox[{62.5, 274.3848502208965}], 
             PointBox[{62.6, 274.9591196225035}], 
             PointBox[{62.7, 277.35360536240216`}], 
             PointBox[{62.8, 275.3625003886398}], 
             PointBox[{62.9, 273.2606785850125}], 
             PointBox[{63., 275.7967653672114}], 
             PointBox[{63.1, 276.4647688815903}], 
             PointBox[{63.2, 274.7437902209206}], 
             PointBox[{63.3, 278.60392679329846`}], 
             PointBox[{63.4, 285.1063971140325}], 
             PointBox[{63.5, 286.18935330211235`}], 
             PointBox[{63.6, 284.6447553988945}], 
             PointBox[{63.7, 287.86908399705277`}], 
             PointBox[{63.8, 287.30549377859745`}], 
             PointBox[{63.9, 284.1741615049573}], 
             PointBox[{64., 285.2282032422707}], 
             PointBox[{64.1, 288.0036480153041}], 
             PointBox[{64.2, 285.5402427433256}], 
             PointBox[{64.3, 287.43947682274273`}], 
             PointBox[{64.4, 293.79887850184986`}], 
             PointBox[{64.5, 298.22900652860903`}], 
             PointBox[{64.6, 295.6093340557365}], 
             PointBox[{64.7, 298.0930223669639}], 
             PointBox[{64.8, 299.6593078177371}], 
             PointBox[{64.9, 296.337826735025}], 
             PointBox[{65., 295.26090885617816`}], 
             PointBox[{65.1, 299.04097549159235`}], 
             PointBox[{65.2, 297.88855295906876`}], 
             PointBox[{65.3, 297.148147589556}], 
             PointBox[{65.4, 302.56144579873813`}], 
             PointBox[{65.5, 309.69901031857285`}], 
             PointBox[{65.6, 308.5116215855239}], 
             PointBox[{65.7, 308.4612138012727}], 
             PointBox[{65.8, 312.0789642086343}], 
             PointBox[{65.9, 309.94537774804195`}], 
             PointBox[{66., 306.61373173289667`}], 
             PointBox[{66.1, 309.6271392860596}], 
             PointBox[{66.2, 311.450123593208}], 
             PointBox[{66.3, 308.4726345905437}], 
             PointBox[{66.4, 312.07919377946723`}], 
             PointBox[{66.5, 320.10553229870396`}], 
             PointBox[{66.6, 323.17432589925636`}], 
             PointBox[{66.7, 320.2105966580491}], 
             PointBox[{66.8, 324.3210892617115}], 
             PointBox[{66.9, 324.9944162377418}], 
             PointBox[{67., 320.15844258071667`}], 
             PointBox[{67.1, 320.6203176285491}], 
             PointBox[{67.2, 325.21229878301716`}], 
             PointBox[{67.3, 322.4381216907158}], 
             PointBox[{67.4, 322.76402759272946`}], 
             PointBox[{67.5, 330.22156246809186`}], 
             PointBox[{67.6, 338.4563632023538}], 
             PointBox[{67.7, 335.28595414209707`}], 
             PointBox[{67.8, 336.8660900220157}], 
             PointBox[{67.9, 341.1394423095275}], 
             PointBox[{68., 337.0224054836968}], 
             PointBox[{68.1, 333.5331606636622}], 
             PointBox[{68.2, 338.6805993790142}], 
             PointBox[{68.3, 339.61364066313405`}], 
             PointBox[{68.4, 335.98994781628153`}], 
             PointBox[{68.5, 341.7681337124199}], 
             PointBox[{68.6, 353.0785662786994}], 
             PointBox[{68.7, 355.3188480381027}], 
             PointBox[{68.8, 351.8892107808059}], 
             PointBox[{68.9, 358.0485410518129}], 
             PointBox[{69., 358.2709767828259}], 
             PointBox[{69.1, 350.9083712044727}], 
             PointBox[{69.2, 353.07821608763686`}], 
             PointBox[{69.3, 359.0633131818279}], 
             PointBox[{69.4, 354.54385695821895`}], 
             PointBox[{69.5, 355.7680275752664}], 
             PointBox[{69.6, 7.578113113870174}], 
             PointBox[{69.7, 19.498062763239137`}], 
             PointBox[{69.8, 14.322011574672391`}], 
             PointBox[{69.9, 16.881615574048677`}], 
             PointBox[{70., 23.63979504908477}], 
             PointBox[{70.1, 17.149286991887863`}], 
             PointBox[{70.2, 11.95278306953286}], 
             PointBox[{70.3, 19.767335770113878`}], 
             PointBox[{70.4, 21.366289519713284`}], 
             PointBox[{70.5, 15.671499628294804`}], 
             PointBox[{70.6, 25.17124386707269}], 
             PointBox[{70.7, 44.34391546757328}], 
             PointBox[{70.8, 49.010752844626595`}], 
             PointBox[{70.9, 42.695545360800274`}], 
             PointBox[{71., 51.149458400441674`}], 
             PointBox[{71.1, 54.41024196863606}], 
             PointBox[{71.2, 42.58141613551959}], 
             PointBox[{71.3, 43.979854429753615`}], 
             PointBox[{71.4, 53.46240725041435}], 
             PointBox[{71.5, 48.546222957252084`}], 
             PointBox[{71.6, 48.6409256669379}], 
             PointBox[{71.7, 68.28744113655456}], 
             PointBox[{71.8, 85.69845165523341}], 
             PointBox[{71.9, 81.58367396607571}], 
             PointBox[{72., 80.35751360624153}], 
             PointBox[{72.1, 90.48096144202538}], 
             PointBox[{72.2, 87.43530796392054}], 
             PointBox[{72.3, 76.81713060553845}], 
             PointBox[{72.4, 83.66614880094701}], 
             PointBox[{72.5, 89.88743550989838}], 
             PointBox[{72.6, 82.1670911019606}], 
             PointBox[{72.7, 92.02744718580254}], 
             PointBox[{72.8, 112.01922842584437`}], 
             PointBox[{72.9, 119.0441502927585}], 
             PointBox[{73., 112.03783120206963`}], 
             PointBox[{73.1, 116.81943647588433`}], 
             PointBox[{73.2, 123.49700323933007`}], 
             PointBox[{73.3, 115.2286911986805}], 
             PointBox[{73.4, 111.358716972634}], 
             PointBox[{73.5, 119.67432981360763`}], 
             PointBox[{73.6, 119.26289525741477`}], 
             PointBox[{73.7, 116.1497591549836}], 
             PointBox[{73.8, 131.0166531755609}], 
             PointBox[{73.9, 142.28105849145234`}], 
             PointBox[{74., 141.05572308435518`}], 
             PointBox[{74.1, 137.93025511947982`}], 
             PointBox[{74.2, 145.107609002116}], 
             PointBox[{74.3, 145.12735318954577`}], 
             PointBox[{74.4, 137.29402083555726`}], 
             PointBox[{74.5, 139.7968328278866}], 
             PointBox[{74.6, 145.4130755401381}], 
             PointBox[{74.7, 140.54341099926057`}], 
             PointBox[{74.8, 146.01248375110188`}], 
             PointBox[{74.9, 157.56467903040308`}], 
             PointBox[{75., 162.0502650851489}], 
             PointBox[{75.1, 157.53284814647594`}], 
             PointBox[{75.2, 160.33198572478113`}], 
             PointBox[{75.3, 164.79442217820156`}], 
             PointBox[{75.4, 159.7999407939275}], 
             PointBox[{75.5, 156.86060792146174`}], 
             PointBox[{75.6, 162.13390556164686`}], 
             PointBox[{75.7, 162.01134588121323`}], 
             PointBox[{75.8, 160.12849199908888`}], 
             PointBox[{75.9, 169.7000179337725}], 
             PointBox[{76., 176.65567761847365`}], 
             PointBox[{76.1, 175.49680928971034`}], 
             PointBox[{76.2, 173.7384968304038}], 
             PointBox[{76.3, 178.81731917678698`}], 
             PointBox[{76.4, 177.94242004222122`}], 
             PointBox[{76.5, 173.08935617317098`}], 
             PointBox[{76.6, 175.0671511955082}], 
             PointBox[{76.7, 178.59708176092326`}], 
             PointBox[{76.8, 175.0915747707326}], 
             PointBox[{76.9, 180.1090546436051}], 
             PointBox[{77., 187.96082063655163`}], 
             PointBox[{77.1, 190.50758462759399`}], 
             PointBox[{77.2, 187.24802886984742`}], 
             PointBox[{77.3, 190.2256703651414}], 
             PointBox[{77.4, 192.44594321884097`}], 
             PointBox[{77.5, 188.4450382125505}], 
             PointBox[{77.6, 187.19852187660572`}], 
             PointBox[{77.7, 191.23501660318755`}], 
             PointBox[{77.8, 190.0053818718016}], 
             PointBox[{77.9, 190.1385986600243}], 
             PointBox[{78., 197.7746225134319}], 
             PointBox[{78.1, 202.6181073314913}], 
             PointBox[{78.2, 200.907883155998}], 
             PointBox[{78.3, 200.76682618829696`}], 
             PointBox[{78.4, 204.43815848164365`}], 
             PointBox[{78.5, 202.4988169074789}], 
             PointBox[{78.6, 199.47324991495262`}], 
             PointBox[{78.7, 201.86968204082237`}], 
             PointBox[{78.8, 203.55275872091906`}], 
             PointBox[{78.9, 201.15368773043565`}], 
             PointBox[{79., 206.74626956100684`}], 
             PointBox[{79.1, 212.78205041313564`}], 
             PointBox[{79.2, 213.72503549258698`}], 
             PointBox[{79.3, 211.52089571811186`}], 
             PointBox[{79.4, 214.84150869475312`}], 
             PointBox[{79.5, 215.11896235498511`}], 
             PointBox[{79.6, 211.81896446799513`}], 
             PointBox[{79.7, 212.01226929323926`}], 
             PointBox[{79.8, 215.1525212869169}], 
             PointBox[{79.9, 212.99253971947365`}], 
             PointBox[{80., 215.31360633026637`}], 
             PointBox[{80.1, 221.85761095863356`}], 
             PointBox[{80.2, 225.05047831902255`}], 
             PointBox[{80.3, 222.85929903196168`}], 
             PointBox[{80.4, 224.3932461591375}], 
             PointBox[{80.5, 226.4362453541381}], 
             PointBox[{80.6, 223.88736540089135`}], 
             PointBox[{80.7, 222.36019426792507`}], 
             PointBox[{80.8, 225.19042044116372`}], 
             PointBox[{80.9, 224.92158151532195`}], 
             PointBox[{81., 224.36784540156793`}], 
             PointBox[{81.1, 230.33442194658306`}], 
             PointBox[{81.2, 234.9884321443473}], 
             PointBox[{81.3, 234.35874702134424`}], 
             PointBox[{81.4, 233.74673918135142`}], 
             PointBox[{81.5, 236.6756546939639}], 
             PointBox[{81.6, 235.41282120484158`}], 
             PointBox[{81.7, 232.99671278854672`}], 
             PointBox[{81.8, 234.48978734040165`}], 
             PointBox[{81.9, 236.17904465400932`}], 
             PointBox[{82., 234.19486082522383`}], 
             PointBox[{82.1, 238.43640628914198`}], 
             PointBox[{82.2, 243.9464729257965}], 
             PointBox[{82.3, 245.3115934941317}], 
             PointBox[{82.4, 243.4169675019478}], 
             PointBox[{82.5, 246.08878614268588`}], 
             PointBox[{82.6, 246.27835470555425`}], 
             PointBox[{82.7, 243.73239658569958`}], 
             PointBox[{82.8, 243.7113172881862}], 
             PointBox[{82.9, 246.35534443588}], 
             PointBox[{83., 244.58087345291935`}], 
             PointBox[{83.1, 246.5196170472195}], 
             PointBox[{83.2, 252.28978948224056`}], 
             PointBox[{83.3, 255.34845729229133`}], 
             PointBox[{83.4, 253.56262787260727`}], 
             PointBox[{83.5, 254.96655201791305`}], 
             PointBox[{83.6, 256.46799283168036`}], 
             PointBox[{83.7, 254.3485837800199}], 
             PointBox[{83.8, 253.14136133686247`}], 
             PointBox[{83.9, 255.57427300043057`}], 
             PointBox[{84., 255.13932398357528`}], 
             PointBox[{84.1, 254.98098391205576`}], 
             PointBox[{84.2, 260.2657933728643}], 
             PointBox[{84.3, 264.5070250598489}], 
             PointBox[{84.4, 263.8942740998545}], 
             PointBox[{84.5, 263.65307677292515`}], 
             PointBox[{84.6, 266.016646555221}], 
             PointBox[{84.7, 264.6887414545787}], 
             PointBox[{84.8, 262.7835971650463}], 
             PointBox[{84.9, 264.273369225089}], 
             PointBox[{85., 265.4094193552443}], 
             PointBox[{85.1, 263.9187196668788}], 
             PointBox[{85.2, 268.0320953983134}], 
             PointBox[{85.3, 272.9917021167648}], 
             PointBox[{85.4, 273.9431268608141}], 
             PointBox[{85.5, 272.48829995949745`}], 
             PointBox[{85.6, 274.9949533790317}], 
             PointBox[{85.7, 274.6642015060921}], 
             PointBox[{85.8, 272.5192046666597}], 
             PointBox[{85.9, 272.86581309592964`}], 
             PointBox[{86., 275.03173259604347`}], 
             PointBox[{86.1, 273.2569302813052}], 
             PointBox[{86.2, 275.7693289928996}], 
             PointBox[{86.3, 281.0109724435779}], 
             PointBox[{86.4, 283.406216935659}], 
             PointBox[{86.5, 281.66120105327377`}], 
             PointBox[{86.6, 283.5152484707216}], 
             PointBox[{86.7, 284.23062432061124`}], 
             PointBox[{86.8, 282.2148208797057}], 
             PointBox[{86.9, 281.5667984682897}], 
             PointBox[{87., 283.9268912887509}], 
             PointBox[{87.1, 282.83280564778676`}], 
             PointBox[{87.2, 283.67198487323697`}], 
             PointBox[{87.3, 288.73311254021297`}], 
             PointBox[{87.4, 292.2306278878077}], 
             PointBox[{87.5, 291.0905646119726}], 
             PointBox[{87.6, 291.74484751438024`}], 
             PointBox[{87.7, 293.37009128100607`}], 
             PointBox[{87.8, 291.762533882442}], 
             PointBox[{87.9, 290.41345359096135`}], 
             PointBox[{88., 292.28494635999067`}], 
             PointBox[{88.1, 292.4006338146313}], 
             PointBox[{88.2, 291.82970107682786`}], 
             PointBox[{88.3, 296.27652853883995`}], 
             PointBox[{88.4, 300.505541596462}], 
             PointBox[{88.5, 300.4897540283227}], 
             PointBox[{88.6, 299.89424949072475`}], 
             PointBox[{88.7, 302.0833162035308}], 
             PointBox[{88.8, 301.0854860423626}], 
             PointBox[{88.9, 299.3446957186074}], 
             PointBox[{89., 300.3868280979052}], 
             PointBox[{89.1, 301.67647121876274`}], 
             PointBox[{89.2, 300.2410254023432}], 
             PointBox[{89.3, 303.72151689510315`}], 
             PointBox[{89.4, 308.35673502320316`}], 
             PointBox[{89.5, 309.56919422244164`}], 
             PointBox[{89.6, 308.1546312524153}], 
             PointBox[{89.7, 310.3910700087329}], 
             PointBox[{89.8, 310.1293890872903}], 
             PointBox[{89.9, 308.2660096891274}], 
             PointBox[{90., 308.4416105350521}], 
             PointBox[{90.1, 310.44953775565625`}], 
             PointBox[{90.2, 308.85163164012715`}], 
             PointBox[{90.3, 311.1467592925006}], 
             PointBox[{90.4, 315.900457924437}], 
             PointBox[{90.5, 318.1751326905254}], 
             PointBox[{90.6, 316.6036700350701}], 
             PointBox[{90.7, 318.34049566963597`}], 
             PointBox[{90.8, 318.85458346365505`}], 
             PointBox[{90.9, 317.08316764851014`}], 
             PointBox[{91., 316.53325655682136`}], 
             PointBox[{91.1, 318.67432120548654`}], 
             PointBox[{91.2, 317.55702625749296`}], 
             PointBox[{91.3, 318.61793915526897`}], 
             PointBox[{91.4, 323.22737719165326`}], 
             PointBox[{91.5, 326.28605061586717`}], 
             PointBox[{91.6, 325.1516935871819}], 
             PointBox[{91.7, 326.0066775012529}], 
             PointBox[{91.8, 327.2296418661579}], 
             PointBox[{91.9, 325.7115884313586}], 
             PointBox[{92., 324.64406766176705`}], 
             PointBox[{92.1, 326.4523735938867}], 
             PointBox[{92.2, 326.20016384305967`}], 
             PointBox[{92.3, 326.1531433141671}], 
             PointBox[{92.4, 330.39298599653563`}], 
             PointBox[{92.5, 333.94822784471336`}], 
             PointBox[{92.6, 333.5902699602481}], 
             PointBox[{92.7, 333.47853615847924`}], 
             PointBox[{92.8, 335.2289772541863}], 
             PointBox[{92.9, 334.07540864181084`}], 
             PointBox[{93., 332.696784784893}], 
             PointBox[{93.1, 333.93058627023555`}], 
             PointBox[{93.2, 334.5933446417315}], 
             PointBox[{93.3, 333.7196156139534}], 
             PointBox[{93.4, 337.4144528529607}], 
             PointBox[{93.5, 341.21952050795744`}], 
             PointBox[{93.6, 341.7009847852484}], 
             PointBox[{93.7, 340.822766485329}], 
             PointBox[{93.8, 342.82960683894464`}], 
             PointBox[{93.9, 342.10175797934033`}], 
             PointBox[{94., 340.58500811646195`}], 
             PointBox[{94.1, 341.20550368162304`}], 
             PointBox[{94.2, 342.5680692026906}], 
             PointBox[{94.3, 341.2417956708993}], 
             PointBox[{94.4, 344.2813045800394}], 
             PointBox[{94.5, 348.1392589481843}], 
             PointBox[{94.6, 349.3299009821176}], 
             PointBox[{94.7, 348.03737618998304`}], 
             PointBox[{94.8, 350.00687947088}], 
             PointBox[{94.9, 349.713772516918}], 
             PointBox[{95., 348.18696899536917`}], 
             PointBox[{95.1, 348.2837294694223}], 
             PointBox[{95.2, 350.01725241595346`}], 
             PointBox[{95.3, 348.60276326346}], 
             PointBox[{95.4, 350.9607403844294}], 
             PointBox[{95.5, 354.71093440766646`}], 
             PointBox[{95.6, 356.3851136659903}], 
             PointBox[{95.7, 355.01935035161165`}], 
             PointBox[{95.8, 356.72448781875585`}], 
             PointBox[{95.9, 356.8221805592287}], 
             PointBox[{96., 355.3671344763679}], 
             PointBox[{96.1, 355.08494229202483`}], 
             PointBox[{96.2, 356.8925743112088}], 
             PointBox[{96.3, 355.6445967387566}], 
             PointBox[{96.4, 357.38336864639047`}], 
             PointBox[{96.5, 0.8860437177143239}], 
             PointBox[{96.6, 2.7950299864345864`}], 
             PointBox[{96.7, 1.5724256737125446`}], 
             PointBox[{96.8, 2.9168452025615403`}], 
             PointBox[{96.9, 3.312705003031355}], 
             PointBox[{97., 1.968150385882163}], 
             PointBox[{97.1, 1.4582034202235656`}], 
             PointBox[{97.2, 3.1565966158317593`}], 
             PointBox[{97.3, 2.1699279036727286`}], 
             PointBox[{97.4, 3.427146597094159}], 
             PointBox[{97.5, 6.548055522964045}], 
             PointBox[{97.6, 8.459326091829041}], 
             PointBox[{97.7, 7.439697442537079}], 
             PointBox[{97.8, 8.469433512800022}], 
             PointBox[{97.9, 9.032882220420195}], 
             PointBox[{98., 7.8013813463010715`}], 
             PointBox[{98.1, 7.197883923273128}], 
             PointBox[{98.2, 8.728675849332781}], 
             PointBox[{98.3, 7.948794590847932}], 
             PointBox[{98.4, 8.907038676504335}], 
             PointBox[{98.5, 11.501363545526747`}], 
             PointBox[{98.6, 13.22367113508694}], 
             PointBox[{98.7, 12.34185664719758}], 
             PointBox[{98.8, 13.211191273314995`}], 
             PointBox[{98.9, 13.784730780111907`}], 
             PointBox[{99., 12.64574947357262}], 
             PointBox[{99.1, 12.060595579620061`}], 
             PointBox[{99.2, 13.45774867735489}], 
             PointBox[{99.3, 12.727360710208748`}], 
             PointBox[{99.4, 13.56080976620238}], 
             PointBox[{99.5, 15.486048921530656`}], 
             PointBox[{99.6, 16.887397735493735`}], 
             PointBox[{99.7, 16.015924103994482`}], 
             PointBox[{99.8, 16.938795740071466`}], 
             PointBox[{99.9, 17.34373548636915}], 
             PointBox[{100., 16.275905136946335`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 360}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
             40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {
             0, -180}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 180.}], 
             PointBox[{0.1, 163.4003307194546}], 
             PointBox[{0.2, 167.0095820010872}], 
             PointBox[{0.3, 171.69840314211655`}], 
             PointBox[{0.4, 163.3300581072229}], 
             PointBox[{0.5, 165.74792884088652`}], 
             PointBox[{0.6, 178.87090774545362`}], 
             PointBox[{0.7, 175.34898565963243`}], 
             PointBox[{0.8, 169.3957704473159}], 
             PointBox[{0.9, 178.12668328675966`}], 
             PointBox[{1., 172.55921138082908`}], 
             PointBox[{1.1, 155.1196583352828}], 
             PointBox[{1.2, 148.4183947472888}], 
             PointBox[{1.3, 156.3926549093943}], 
             PointBox[{1.4, 154.7057496415307}], 
             PointBox[{1.5, 148.96978135191637`}], 
             PointBox[{1.6, 157.39501447251268`}], 
             PointBox[{1.7, 164.3165563950813}], 
             PointBox[{1.8, 158.25199596035714`}], 
             PointBox[{1.9, 158.6075218298945}], 
             PointBox[{2., 164.45449594413367`}], 
             PointBox[{2.1, 153.01059369634868`}], 
             PointBox[{2.2, 143.34905469278465`}], 
             PointBox[{2.3, 144.81218725290546`}], 
             PointBox[{2.4, 150.20143035419983`}], 
             PointBox[{2.5, 145.09189509804105`}], 
             PointBox[{2.6, 145.56732144786974`}], 
             PointBox[{2.7, 154.87909320591007`}], 
             PointBox[{2.8, 155.0952332448187}], 
             PointBox[{2.9, 150.6031085366767}], 
             PointBox[{3., 156.2831484740102}], 
             PointBox[{3.1, 154.15125254876216`}], 
             PointBox[{3.2, 144.79657909435218`}], 
             PointBox[{3.3, 141.17688551647052`}], 
             PointBox[{3.4, 146.72854822299087`}], 
             PointBox[{3.5, 146.31911678185156`}], 
             PointBox[{3.6, 143.00354838093517`}], 
             PointBox[{3.7, 148.85720946412584`}], 
             PointBox[{3.8, 154.00464378404195`}], 
             PointBox[{3.9, 150.67029164895212`}], 
             PointBox[{4., 151.32464118729467`}], 
             PointBox[{4.1, 155.42125518802823`}], 
             PointBox[{4.2, 148.47518612837712`}], 
             PointBox[{4.3, 143.02509312363236`}], 
             PointBox[{4.4, 144.82646186592092`}], 
             PointBox[{4.5, 148.5301600566504}], 
             PointBox[{4.6, 145.10026124535761`}], 
             PointBox[{4.7, 146.81896796027422`}], 
             PointBox[{4.8, 153.24798623992228`}], 
             PointBox[{4.9, 153.39850256666887`}], 
             PointBox[{5., 150.9053701681869}], 
             PointBox[{5.1, 155.5671284782793}], 
             PointBox[{5.2, 153.20468381348746`}], 
             PointBox[{5.3, 147.2614816968753}], 
             PointBox[{5.4, 145.58301917737754`}], 
             PointBox[{5.5, 150.06309938544655`}], 
             PointBox[{5.6, 149.00708476363798`}], 
             PointBox[{5.7, 147.79799126188254`}], 
             PointBox[{5.8, 152.9713084566065}], 
             PointBox[{5.9, 156.1415064890639}], 
             PointBox[{6., 153.63840817573782`}], 
             PointBox[{6.1, 155.57633849207377`}], 
             PointBox[{6.2, 157.57359510593415`}], 
             PointBox[{6.3, 152.1509709435004}], 
             PointBox[{6.4, 148.59124850609714`}], 
             PointBox[{6.5, 151.08736735107868`}], 
             PointBox[{6.6, 153.03138589331957`}], 
             PointBox[{6.7, 150.60888867341328`}], 
             PointBox[{6.8, 153.52759307758515`}], 
             PointBox[{6.9, 158.14457445326389`}], 
             PointBox[{7., 157.49467330337575`}], 
             PointBox[{7.1, 156.62284927333712`}], 
             PointBox[{7.2, 160.452767590662}], 
             PointBox[{7.3, 157.13190416353973`}], 
             PointBox[{7.4, 152.76211266845894`}], 
             PointBox[{7.5, 152.5843065304589}], 
             PointBox[{7.6, 156.14823276111474`}], 
             PointBox[{7.7, 154.3158060258247}], 
             PointBox[{7.8, 154.9544222384966}], 
             PointBox[{7.9, 159.5467008409023}], 
             PointBox[{8., 161.05551409632426`}], 
             PointBox[{8.1, 159.04745691977132`}], 
             PointBox[{8.2, 162.09501510679638`}], 
             PointBox[{8.3, 161.80952317978608`}], 
             PointBox[{8.4, 157.21117878171117`}], 
             PointBox[{8.5, 155.01714785644162`}], 
             PointBox[{8.6, 158.11709591404815`}], 
             PointBox[{8.7, 158.16857836782674`}], 
             PointBox[{8.8, 157.07455813067645`}], 
             PointBox[{8.9, 160.6921110452049}], 
             PointBox[{9., 163.7427960417599}], 
             PointBox[{9.1, 162.294958313174}], 
             PointBox[{9.2, 163.23201371925097`}], 
             PointBox[{9.3, 165.40454904460148`}], 
             PointBox[{9.4, 161.46276872149338`}], 
             PointBox[{9.5, 158.148610920367}], 
             PointBox[{9.6, 159.4696310240506}], 
             PointBox[{9.7, 161.51166368878785`}], 
             PointBox[{9.8, 159.65044697784288`}], 
             PointBox[{9.9, 161.82464930189963`}], 
             PointBox[{10., 165.55570275204627`}], 
             PointBox[{10.1, 165.52382595720155`}], 
             PointBox[{10.2, 164.58523869743476`}], 
             PointBox[{10.3, 167.72634673531957`}], 
             PointBox[{10.4, 165.38834715334633`}], 
             PointBox[{10.5, 161.5347855602131}], 
             PointBox[{10.6, 160.8958977086122}], 
             PointBox[{10.7, 163.88213884823472`}], 
             PointBox[{10.8, 162.43152363868376`}], 
             PointBox[{10.9, 163.05511392825701`}], 
             PointBox[{11., 166.72448750989406`}], 
             PointBox[{11.1, 168.1494515825325}], 
             PointBox[{11.2, 166.47060799733754`}], 
             PointBox[{11.3, 169.01287144075468`}], 
             PointBox[{11.4, 168.74553528943852`}], 
             PointBox[{11.5, 164.80993013795796`}], 
             PointBox[{11.6, 162.68321815040235`}], 
             PointBox[{11.7, 165.23312658379018`}], 
             PointBox[{11.8, 165.13015372974405`}], 
             PointBox[{11.9, 164.41160220510756`}], 
             PointBox[{12., 167.48974276975787`}], 
             PointBox[{12.1, 169.9772028223888}], 
             PointBox[{12.2, 168.68746910435948`}], 
             PointBox[{12.3, 169.68591622784152`}], 
             PointBox[{12.4, 171.2320853793426}], 
             PointBox[{12.5, 167.76243344270006`}], 
             PointBox[{12.6, 164.75033429972973`}], 
             PointBox[{12.7, 165.95271859338573`}], 
             PointBox[{12.8, 167.41180628968868`}], 
             PointBox[{12.9, 165.8791444415474}], 
             PointBox[{13., 168.02604145845726`}], 
             PointBox[{13.1, 171.07114261191964`}], 
             PointBox[{13.2, 170.79444119125765`}], 
             PointBox[{13.3, 170.2292512119111}], 
             PointBox[{13.4, 172.7852356062358}], 
             PointBox[{13.5, 170.33766596413443`}], 
             PointBox[{13.6, 166.88913677172968`}], 
             PointBox[{13.7, 166.53175052007828`}], 
             PointBox[{13.8, 168.97351109809097`}], 
             PointBox[{13.9, 167.40649256830693`}], 
             PointBox[{14., 168.44332479314835`}], 
             PointBox[{14.1, 171.5916718598619}], 
             PointBox[{14.2, 172.436003736344}], 
             PointBox[{14.3, 170.98237363255248`}], 
             PointBox[{14.4, 173.49978881012066`}], 
             PointBox[{14.5, 172.4683559896439}], 
             PointBox[{14.6, 168.90046663432986`}], 
             PointBox[{14.7, 167.24077435304935`}], 
             PointBox[{14.8, 169.7012790341123}], 
             PointBox[{14.9, 168.89197775757566`}], 
             PointBox[{15., 168.80755816373494`}], 
             PointBox[{15.1, 171.69839800631053`}], 
             PointBox[{15.2, 173.46154795466828`}], 
             PointBox[{15.3, 171.97441366933526`}], 
             PointBox[{15.4, 173.5658915257045}], 
             PointBox[{15.5, 174.01722856725428`}], 
             PointBox[{15.6, 170.6334244873069}], 
             PointBox[{15.7, 168.1030464415071}], 
             PointBox[{15.8, 169.75684523352902`}], 
             PointBox[{15.9, 170.16686199775359`}], 
             PointBox[{16., 169.15186959189668`}], 
             PointBox[{16.1, 171.51252077016943`}], 
             PointBox[{16.2, 173.87908443698325`}], 
             PointBox[{16.3, 172.98400543070056`}], 
             PointBox[{16.4, 173.25875985633502`}], 
             PointBox[{16.5, 174.90555355490687`}], 
             PointBox[{16.6, 172.02100345847612`}], 
             PointBox[{16.7, 169.0149690399685}], 
             PointBox[{16.8, 169.46414770191404`}], 
             PointBox[{16.9, 171.0187356778988}], 
             PointBox[{17., 169.4817908565783}], 
             PointBox[{17.1, 171.1166809148308}], 
             PointBox[{17.2, 173.7713660949812}], 
             PointBox[{17.3, 173.7325981677368}], 
             PointBox[{17.4, 172.86560394954904`}], 
             PointBox[{17.5, 175.12421206059298`}], 
             PointBox[{17.6, 173.0517017676175}], 
             PointBox[{17.7, 169.83735669435373`}], 
             PointBox[{17.8, 169.09246061901285`}], 
             PointBox[{17.9, 171.26283469776718`}], 
             PointBox[{18., 169.76691981019576`}], 
             PointBox[{18.1, 170.55907512693557`}], 
             PointBox[{18.2, 173.23110774854467`}], 
             PointBox[{18.3, 174.02696815986565`}], 
             PointBox[{18.4, 172.5556998297252}], 
             PointBox[{18.5, 174.71139389238488`}], 
             PointBox[{18.6, 173.67588753343625`}], 
             PointBox[{18.7, 170.434073600778}], 
             PointBox[{18.8, 168.74330671525604`}], 
             PointBox[{18.9, 170.84099708325994`}], 
             PointBox[{19., 169.93081060907934`}], 
             PointBox[{19.1, 169.85902836642344`}], 
             PointBox[{19.2, 172.33093132477916`}], 
             PointBox[{19.3, 173.78425690805125`}], 
             PointBox[{19.4, 172.30182031598088`}], 
             PointBox[{19.5, 173.75024887155087`}], 
             PointBox[{19.6, 173.8050304067965}], 
             PointBox[{19.7, 170.6884027244978}], 
             PointBox[{19.8, 168.37789557902033`}], 
             PointBox[{19.9, 169.8490014289182}], 
             PointBox[{20., 169.84666839661622`}], 
             PointBox[{20.1, 169.00804285785307`}], 
             PointBox[{20.2, 171.1124364875741}], 
             PointBox[{20.3, 172.9957902380229}], 
             PointBox[{20.4, 171.92326822793075`}], 
             PointBox[{20.5, 172.36238434940788`}], 
             PointBox[{20.6, 173.36228301132542`}], 
             PointBox[{20.7, 170.51861086285498`}], 
             PointBox[{20.8, 167.8797806389539}], 
             PointBox[{20.9, 168.457737585828}], 
             PointBox[{21., 169.35252746605875`}], 
             PointBox[{21.1, 167.96662854076385`}], 
             PointBox[{21.2, 169.58374003585777`}], 
             PointBox[{21.3, 171.6783438167422}], 
             PointBox[{21.4, 171.1953323688158}], 
             PointBox[{21.5, 170.66644623098728`}], 
             PointBox[{21.6, 172.2917118629939}], 
             PointBox[{21.7, 169.8654549472394}], 
             PointBox[{21.8, 167.1023860887617}], 
             PointBox[{21.9, 166.78687140700458`}], 
             PointBox[{22., 168.2884646363418}], 
             PointBox[{22.1, 166.65982864891157`}], 
             PointBox[{22.2, 167.7175081387395}], 
             PointBox[{22.3, 169.83883313588012`}], 
             PointBox[{22.4, 169.92765623979722`}], 
             PointBox[{22.5, 168.7108378531666}], 
             PointBox[{22.6, 170.54872301958676`}], 
             PointBox[{22.7, 168.64823704543232`}], 
             PointBox[{22.8, 165.88528060540375`}], 
             PointBox[{22.9, 164.8418994747608}], 
             PointBox[{23., 166.5379568022745}], 
             PointBox[{23.1, 164.97098044625636`}], 
             PointBox[{23.2, 165.44784513575541`}], 
             PointBox[{23.3, 167.45352719433868`}], 
             PointBox[{23.4, 167.97974420348692`}], 
             PointBox[{23.5, 166.42271911827265`}], 
             PointBox[{23.6, 168.0878506525296}], 
             PointBox[{23.7, 166.7428238244429}], 
             PointBox[{23.8, 164.06002854045073`}], 
             PointBox[{23.9, 162.51441914470342`}], 
             PointBox[{24., 164.03851792851856`}], 
             PointBox[{24.1, 162.73817380577748`}], 
             PointBox[{24.2, 162.66332027342287`}], 
             PointBox[{24.3, 164.45197209345133`}], 
             PointBox[{24.4, 165.2341917943413}], 
             PointBox[{24.5, 163.6080908420954}], 
             PointBox[{24.6, 164.8437866492095}], 
             PointBox[{24.7, 163.98688640602268`}], 
             PointBox[{24.8, 161.4465323375116}], 
             PointBox[{24.9, 159.61345828304547`}], 
             PointBox[{25., 160.74353065667674`}], 
             PointBox[{25.1, 159.7544455473908}], 
             PointBox[{25.2, 159.19887447165456`}], 
             PointBox[{25.3, 160.70590821265432`}], 
             PointBox[{25.4, 161.55822198373426`}], 
             PointBox[{25.5, 159.98909874318997`}], 
             PointBox[{25.6, 160.70441973055495`}], 
             PointBox[{25.7, 160.18244285780384`}], 
             PointBox[{25.8, 157.84212870076226`}], 
             PointBox[{25.9, 155.88558745776027`}], 
             PointBox[{26., 156.55604114982998`}], 
             PointBox[{26.1, 155.7651071066648}], 
             PointBox[{26.2, 154.82507017231183`}], 
             PointBox[{26.3, 156.0151755556035}], 
             PointBox[{26.4, 156.76379285806615`}], 
             PointBox[{26.5, 155.23468378052348`}], 
             PointBox[{26.6, 155.47833045513835`}], 
             PointBox[{26.7, 155.081975101406}], 
             PointBox[{26.8, 153.00172222984475`}], 
             PointBox[{26.9, 151.01606414470007`}], 
             PointBox[{27., 151.27131873218968`}], 
             PointBox[{27.1, 150.45377617686972`}], 
             PointBox[{27.2, 149.2346046287057}], 
             PointBox[{27.3, 150.08999865938313`}], 
             PointBox[{27.4, 150.57615333874855`}], 
             PointBox[{27.5, 148.96578355914608`}], 
             PointBox[{27.6, 148.87228033185966`}], 
             PointBox[{27.7, 148.3792358619794}], 
             PointBox[{27.8, 146.60724810307875`}], 
             PointBox[{27.9, 144.60896761114054`}], 
             PointBox[{28., 144.54650872156344`}], 
             PointBox[{28.1, 143.41629640717292`}], 
             PointBox[{28.2, 142.035073359526}], 
             PointBox[{28.3, 142.53755490116237`}], 
             PointBox[{28.4, 142.6118573697895}], 
             PointBox[{28.5, 140.7460677981726}], 
             PointBox[{28.6, 140.49439854506272`}], 
             PointBox[{28.7, 139.74667841614792`}], 
             PointBox[{28.8, 138.22116757560434`}], 
             PointBox[{28.9, 136.1722054362217}], 
             PointBox[{29., 135.89560380547482`}], 
             PointBox[{29.1, 134.15148755731934`}], 
             PointBox[{29.2, 132.7576342256325}], 
             PointBox[{29.3, 132.86780566331072`}], 
             PointBox[{29.4, 132.388240189739}], 
             PointBox[{29.5, 130.1103260292184}], 
             PointBox[{29.6, 129.87955575882734`}], 
             PointBox[{29.7, 128.90810985404823`}], 
             PointBox[{29.8, 127.27755661232004`}], 
             PointBox[{29.9, 125.1655386775783}], 
             PointBox[{30., 124.72644163247605`}], 
             PointBox[{30.1, 122.16449811718849`}], 
             PointBox[{30.2, 120.91825206194335`}], 
             PointBox[{30.3, 120.56495546929727`}], 
             PointBox[{30.4, 119.40023126010783`}], 
             PointBox[{30.5, 116.70833021200451`}], 
             PointBox[{30.6, 116.56007984688404`}], 
             PointBox[{30.7, 115.41889478251687`}], 
             PointBox[{30.8, 113.27844618715972`}], 
             PointBox[{30.9, 111.20168797921724`}], 
             PointBox[{31., 110.43757973984248`}], 
             PointBox[{31.1, 107.2288498848975}], 
             PointBox[{31.2, 106.16227369261469`}], 
             PointBox[{31.3, 105.25633541619027`}], 
             PointBox[{31.4, 103.29852726375611`}], 
             PointBox[{31.5, 100.58992548504102`}], 
             PointBox[{31.6, 100.37399183911111`}], 
             PointBox[{31.7, 98.6863867930224}], 
             PointBox[{31.8, 96.12589732385095}], 
             PointBox[{31.9, 94.28431059916693}], 
             PointBox[{32., 92.61650757074676}], 
             PointBox[{32.1, 89.52310769538963}], 
             PointBox[{32.2, 88.43112751961235}], 
             PointBox[{32.3, 86.8911998508811}], 
             PointBox[{32.4, 84.09867311805283}], 
             PointBox[{32.5, 82.20634357953895}], 
             PointBox[{32.6, 81.42257318073462}], 
             PointBox[{32.7, 78.85199407437176}], 
             PointBox[{32.8, 76.23023533844025}], 
             PointBox[{32.9, 74.7476324044037}], 
             PointBox[{33., 71.64302311424035}], 
             PointBox[{33.1, 69.42127052374781}], 
             PointBox[{33.2, 68.00226977849888}], 
             PointBox[{33.3, 65.76953245429831}], 
             PointBox[{33.4, 62.39989730835077}], 
             PointBox[{33.5, 61.713683875877905`}], 
             PointBox[{33.6, 59.6193390606968}], 
             PointBox[{33.7, 56.66696662244067}], 
             PointBox[{33.8, 54.31958896564538}], 
             PointBox[{33.9, 52.774160011056665`}], 
             PointBox[{34., 48.90446976969906}], 
             PointBox[{34.1, 47.32800523651531}], 
             PointBox[{34.2, 45.38335986773018}], 
             PointBox[{34.3, 42.450363227795606`}], 
             PointBox[{34.4, 39.56580258669783}], 
             PointBox[{34.5, 38.963683801594016`}], 
             PointBox[{34.6, 35.83860366558656}], 
             PointBox[{34.7, 33.015222000860376`}], 
             PointBox[{34.8, 31.141507292213646`}], 
             PointBox[{34.9, 28.427709903378855`}], 
             PointBox[{35., 25.388030766072916`}], 
             PointBox[{35.1, 23.72010902749389}], 
             PointBox[{35.2, 21.196739700641047`}], 
             PointBox[{35.3, 17.768705869111727`}], 
             PointBox[{35.4, 16.611110091187584`}], 
             PointBox[{35.5, 14.33902213615147}], 
             PointBox[{35.6, 11.134820961775404`}], 
             PointBox[{35.7, 8.723785571746703}], 
             PointBox[{35.8, 7.10702935612062}], 
             PointBox[{35.9, 3.160478257392242}], 
             PointBox[{36., 1.3258435816424026`}], 
             PointBox[{36.1, -0.8225168994322303}], 
             PointBox[{36.2, -3.8491200320968346`}], 
             PointBox[{36.3, -6.900784923567699}], 
             PointBox[{36.4, -7.420850225946197}], 
             PointBox[{36.5, -10.832140171391075`}], 
             PointBox[{36.6, -13.627331440726266`}], 
             PointBox[{36.7, -15.518162610511354`}], 
             PointBox[{36.8, -17.823235165029473`}], 
             PointBox[{36.9, -21.32690751820701}], 
             PointBox[{37., -22.98840684566676}], 
             PointBox[{37.1, -25.623521953024465`}], 
             PointBox[{37.2, -28.866841278206266`}], 
             PointBox[{37.3, -30.230746911242022`}], 
             PointBox[{37.4, -32.25204515007499}], 
             PointBox[{37.5, -35.49228792057693}], 
             PointBox[{37.6, -37.72236160776811}], 
             PointBox[{37.7, -39.256886411021696`}], 
             PointBox[{37.8, -42.84019419353717}], 
             PointBox[{37.9, -44.8705458987024}], 
             PointBox[{38., -46.9709481720929}], 
             PointBox[{38.1, -49.89247595976485}], 
             PointBox[{38.2, -52.612940966297174`}], 
             PointBox[{38.3, -52.9881539662274}], 
             PointBox[{38.4, -56.27805801145951}], 
             PointBox[{38.5, -58.86484830423797}], 
             PointBox[{38.6, -60.521710771732614`}], 
             PointBox[{38.7, -62.28643228485453}], 
             PointBox[{38.8, -65.96594451659257}], 
             PointBox[{38.9, -67.3494791371777}], 
             PointBox[{39., -69.85074846052885}], 
             PointBox[{39.1, -72.67113227135269}], 
             PointBox[{39.2, -74.08155919718774}], 
             PointBox[{39.3, -75.26568955899711}], 
             PointBox[{39.4, -78.42060411084822}], 
             PointBox[{39.5, -80.29094361836178}], 
             PointBox[{39.6, -81.49185064906851}], 
             PointBox[{39.7, -84.10745619829686}], 
             PointBox[{39.8, -86.53596532477968}], 
             PointBox[{39.9, -88.14316088632404}], 
             PointBox[{40., -90.76152438379359}], 
             PointBox[{40.1, -92.89555285092501}], 
             PointBox[{40.2, -93.31422126290636}], 
             PointBox[{40.3, -95.61693311063573}], 
             PointBox[{40.4, -98.00722709398542}], 
             PointBox[{40.5, -99.20283684808237}], 
             PointBox[{40.6, -100.1970095842189}], 
             PointBox[{40.7, -103.40807215202585`}], 
             PointBox[{40.8, -104.55453625259906`}], 
             PointBox[{40.9, -106.48447667663277`}], 
             PointBox[{41., -108.86468353385135`}], 
             PointBox[{41.1, -110.20843046954542`}], 
             PointBox[{41.2, -110.33324124048886`}], 
             PointBox[{41.3, -113.05837621034516`}], 
             PointBox[{41.4, -114.61841894773534`}], 
             PointBox[{41.5, -115.20935679243121`}], 
             PointBox[{41.6, -116.26265476598564`}], 
             PointBox[{41.7, -119.22026885066225`}], 
             PointBox[{41.8, -119.73399591419002`}], 
             PointBox[{41.9, -121.79775042609253`}], 
             PointBox[{42., -123.67560484038404`}], 
             PointBox[{42.1, -124.7599089755713}], 
             PointBox[{42.2, -124.83366647439834`}], 
             PointBox[{42.3, -127.3344009962675}], 
             PointBox[{42.4, -128.15359016186267`}], 
             PointBox[{42.5, -128.22548365027978`}], 
             PointBox[{42.6, -129.42697685864914`}], 
             PointBox[{42.7, -131.65778000529826`}], 
             PointBox[{42.8, -131.91297754335028`}], 
             PointBox[{42.9, -133.95760035726198`}], 
             PointBox[{43., -135.50536746408397`}], 
             PointBox[{43.1, -136.47558115506763`}], 
             PointBox[{43.2, -136.56237734608294`}], 
             PointBox[{43.3, -138.66296601193244`}], 
             PointBox[{43.4, -138.8687089530431}], 
             PointBox[{43.5, -138.50356102196383`}], 
             PointBox[{43.6, -139.75181487182272`}], 
             PointBox[{43.7, -141.29506495590977`}], 
             PointBox[{43.8, -141.33629494900742`}], 
             PointBox[{43.9, -143.32237150282526`}], 
             PointBox[{44., -144.97348500806402`}], 
             PointBox[{44.1, -145.73364980455517`}], 
             PointBox[{44.2, -145.7175588307291}], 
             PointBox[{44.3, -147.508052888541}], 
             PointBox[{44.4, -147.24465197350582`}], 
             PointBox[{44.5, -146.50044250723658`}], 
             PointBox[{44.6, -147.64181174140322`}], 
             PointBox[{44.7, -148.75896745220962`}], 
             PointBox[{44.8, -148.51085408695508`}], 
             PointBox[{44.9, -150.46225205729934`}], 
             PointBox[{45., -152.4059475905451}], 
             PointBox[{45.1, -153.02183972261264`}], 
             PointBox[{45.2, -152.73348446522868`}], 
             PointBox[{45.3, -154.3750552022757}], 
             PointBox[{45.4, -153.79578654149736`}], 
             PointBox[{45.5, -152.70506457908778`}], 
             PointBox[{45.6, -153.6092046182348}], 
             PointBox[{45.7, -154.59077894418442`}], 
             PointBox[{45.8, -153.9627491874562}], 
             PointBox[{45.9, -155.87796552037253`}], 
             PointBox[{46., -158.10379105766333`}], 
             PointBox[{46.1, -158.76950117795786`}], 
             PointBox[{46.2, -158.06724439041864`}], 
             PointBox[{46.3, -159.69179149468255`}], 
             PointBox[{46.4, -158.95818857479026`}], 
             PointBox[{46.5, -157.54469670823892`}], 
             PointBox[{46.6, -158.10090235398093`}], 
             PointBox[{46.7, -159.18786542332236`}], 
             PointBox[{46.8, -158.1285703082467}], 
             PointBox[{46.9, -159.93513864659326`}], 
             PointBox[{47., -162.38386016910226`}], 
             PointBox[{47.1, -163.30854416956572`}], 
             PointBox[{47.2, -162.12729026636225`}], 
             PointBox[{47.3, -163.77590697984851`}], 
             PointBox[{47.4, -163.0614408104375}], 
             PointBox[{47.5, -161.3592836001626}], 
             PointBox[{47.6, -161.46841251818842`}], 
             PointBox[{47.7, -162.80158695984574`}], 
             PointBox[{47.8, -161.3551976806848}], 
             PointBox[{47.9, -162.907849785508}], 
             PointBox[{48., -165.5183062333308}], 
             PointBox[{48.1, -166.8674871333642}], 
             PointBox[{48.2, -165.268185813562}], 
             PointBox[{48.3, -166.84849884704454`}], 
             PointBox[{48.4, -166.33886607697787`}], 
             PointBox[{48.5, -164.40707436476805`}], 
             PointBox[{48.6, -163.99335696652997`}], 
             PointBox[{48.7, -165.56523974523589`}], 
             PointBox[{48.8, -163.92011124330747`}], 
             PointBox[{48.9, -165.0174192181221}], 
             PointBox[{49., -167.72698230180686`}], 
             PointBox[{49.1, -169.58772120032518`}], 
             PointBox[{49.2, -167.78975796575105`}], 
             PointBox[{49.3, -169.06509312304843`}], 
             PointBox[{49.4, -168.94451976078562`}], 
             PointBox[{49.5, -166.87598796698876`}], 
             PointBox[{49.6, -165.90119868826878`}], 
             PointBox[{49.7, -167.54543752996688`}], 
             PointBox[{49.8, -166.0355840806369}], 
             PointBox[{49.9, -166.45532193811232`}], 
             PointBox[{50., -169.18743926366733`}], 
             PointBox[{50.1, -171.5532812632664}], 
             PointBox[{50.2, -169.91070892839343`}], 
             PointBox[{50.3, -170.55318100243312`}], 
             PointBox[{50.4, -170.96809454388858`}], 
             PointBox[{50.5, -168.8953800015879}], 
             PointBox[{50.6, -167.36903910747787`}], 
             PointBox[{50.7, -168.8081538328115}], 
             PointBox[{50.8, -167.8337493787476}], 
             PointBox[{50.9, -167.39717691449914`}], 
             PointBox[{51., -170.0371987535691}], 
             PointBox[{51.1, -172.8202938611721}], 
             PointBox[{51.2, -171.73436863705865`}], 
             PointBox[{51.3, -171.4532051960923}], 
             PointBox[{51.4, -172.44880139666202`}], 
             PointBox[{51.5, -170.54647326779377`}], 
             PointBox[{51.6, -168.527798101808}], 
             PointBox[{51.7, -169.46476768131834`}], 
             PointBox[{51.8, -169.33880276763375`}], 
             PointBox[{51.9, -168.00900485701277`}], 
             PointBox[{52., -170.3693755849672}], 
             PointBox[{52.1, -173.437880163081}], 
             PointBox[{52.2, -173.24055037288053`}], 
             PointBox[{52.3, -171.94935698767222`}], 
             PointBox[{52.4, -173.38915670349525`}], 
             PointBox[{52.5, -171.86865265000233`}], 
             PointBox[{52.6, -169.4648844578187}], 
             PointBox[{52.7, -169.66985227350233`}], 
             PointBox[{52.8, -170.4554420960776}], 
             PointBox[{52.9, -168.44422358881275`}], 
             PointBox[{53., -170.24858660087193`}], 
             PointBox[{53.1, -173.4619005710265}], 
             PointBox[{53.2, -174.3277148775669}], 
             PointBox[{53.3, -172.26541293381888`}], 
             PointBox[{53.4, -173.77650868255296`}], 
             PointBox[{53.5, -172.8652698149017}], 
             PointBox[{53.6, -170.23058016995492`}], 
             PointBox[{53.7, -169.58820808994642`}], 
             PointBox[{53.8, -171.0223102619566}], 
             PointBox[{53.9, -168.82993393539073`}], 
             PointBox[{54., -169.75452422292437`}], 
             PointBox[{54.1, -172.96727390147134`}], 
             PointBox[{54.2, -174.87760356679064`}], 
             PointBox[{54.3, -172.5972878009634}], 
             PointBox[{54.4, -173.61295774504106`}], 
             PointBox[{54.5, -173.50287528953777`}], 
             PointBox[{54.6, -170.84167851240636`}], 
             PointBox[{54.7, -169.35319198530487`}], 
             PointBox[{54.8, -170.92516580248775`}], 
             PointBox[{54.9, -169.22584397473838`}], 
             PointBox[{55., -168.99862915666017`}], 
             PointBox[{55.1, -172.04211846069666`}], 
             PointBox[{55.2, -174.8020962715018}], 
             PointBox[{55.3, -173.00778689717845`}], 
             PointBox[{55.4, -172.96494943086145`}], 
             PointBox[{55.5, -173.71698265497253`}], 
             PointBox[{55.6, -171.2873543157184}], 
             PointBox[{55.7, -169.05160925386735`}], 
             PointBox[{55.8, -170.1947500495662}], 
             PointBox[{55.9, -169.56350561406725`}], 
             PointBox[{56., -168.11611919062852`}], 
             PointBox[{56.1, -170.74681730981683`}], 
             PointBox[{56.2, -174.0566899456535}], 
             PointBox[{56.3, -173.36523239163216`}], 
             PointBox[{56.4, -172.0047467364784}], 
             PointBox[{56.5, -173.4188251207961}], 
             PointBox[{56.6, -171.5278228261741}], 
             PointBox[{56.7, -168.72346053714136`}], 
             PointBox[{56.8, -168.9979179721122}], 
             PointBox[{56.9, -169.60615441706614`}], 
             PointBox[{57., -167.24863062227087`}], 
             PointBox[{57.1, -169.09470380398125`}], 
             PointBox[{57.2, -172.64140370016685`}], 
             PointBox[{57.3, -173.398665579909}], 
             PointBox[{57.4, -171.00104251001903`}], 
             PointBox[{57.5, -172.52121425047517`}], 
             PointBox[{57.6, -171.48925050788966`}], 
             PointBox[{57.7, -168.3709030220416}], 
             PointBox[{57.8, -167.54695357038145`}], 
             PointBox[{57.9, -169.02810532479634`}], 
             PointBox[{58., -166.51252430096793`}], 
             PointBox[{58.1, -167.13718406363478`}], 
             PointBox[{58.2, -170.61936484369653`}], 
             PointBox[{58.3, -172.8258894114042}], 
             PointBox[{58.4, -170.20030256955943`}], 
             PointBox[{58.5, -170.99488450790523`}], 
             PointBox[{58.6, -171.0582643068119}], 
             PointBox[{58.7, -167.96679243007384`}], 
             PointBox[{58.8, -166.02008453270537`}], 
             PointBox[{58.9, -167.6227298122758}], 
             PointBox[{59., -165.91947193491796`}], 
             PointBox[{59.1, -165.01079891056725`}], 
             PointBox[{59.2, -168.12279982654582`}], 
             PointBox[{59.3, -171.43917210281506`}], 
             PointBox[{59.4, -169.63268631245592`}], 
             PointBox[{59.5, -168.95382493476063`}], 
             PointBox[{59.6, -170.08259070563508`}], 
             PointBox[{59.7, -167.45442232792993`}], 
             PointBox[{59.8, -164.5319943609793}], 
             PointBox[{59.9, -165.4535528879569}], 
             PointBox[{60., -165.25320020935033`}], 
             PointBox[{60.1, -162.90945228535566`}], 
             PointBox[{60.2, -165.23926740065508`}], 
             PointBox[{60.3, -169.12511589391943`}], 
             PointBox[{60.4, -169.01310342978832`}], 
             PointBox[{60.5, -166.71729529472213`}], 
             PointBox[{60.6, -168.39703464925697`}], 
             PointBox[{60.7, -166.7352701671989}], 
             PointBox[{60.8, -163.1431984744413}], 
             PointBox[{60.9, -162.79930189422157`}], 
             PointBox[{61., -164.05072848901182`}], 
             PointBox[{61.1, -161.04687698363705`}], 
             PointBox[{61.2, -162.00774755813472`}], 
             PointBox[{61.3, -165.90662741085544`}], 
             PointBox[{61.4, -167.8693466173354}], 
             PointBox[{61.5, -164.73067761936545`}], 
             PointBox[{61.6, -165.90765575375553`}], 
             PointBox[{61.7, -165.64901697728783`}], 
             PointBox[{61.8, -161.87710581124702`}], 
             PointBox[{61.9, -159.99668923070567`}], 
             PointBox[{62., -161.87277962773078`}], 
             PointBox[{62.1, -159.5475105175501}], 
             PointBox[{62.2, -158.60682880531385`}], 
             PointBox[{62.3, -162.0495251437169}], 
             PointBox[{62.4, -165.75633821666997`}], 
             PointBox[{62.5, -163.2710049744419}], 
             PointBox[{62.6, -162.74659315448662`}], 
             PointBox[{62.7, -163.96545161347603`}], 
             PointBox[{62.8, -160.71784265399037`}], 
             PointBox[{62.9, -157.3456838327038}], 
             PointBox[{63., -158.67277981403458`}], 
             PointBox[{63.1, -158.2117714761771}], 
             PointBox[{63.2, -155.37900647125207`}], 
             PointBox[{63.3, -157.8409525420284}], 
             PointBox[{63.4, -162.390257181185}], 
             PointBox[{63.5, -162.12872207999317`}], 
             PointBox[{63.6, -159.42475295188342`}], 
             PointBox[{63.7, -161.44074521162838`}], 
             PointBox[{63.8, -159.57740429308615`}], 
             PointBox[{63.9, -155.10419064712914`}], 
             PointBox[{64., -154.85139661674475`}], 
             PointBox[{64.1, -156.40247406646085`}], 
             PointBox[{64.2, -152.76849131283234`}], 
             PointBox[{64.3, -153.39080027015007`}], 
             PointBox[{64.4, -157.8498937084005}], 
             PointBox[{64.5, -160.63346677182562`}], 
             PointBox[{64.6, -156.76891807046923`}], 
             PointBox[{64.7, -158.00768069807964`}], 
             PointBox[{64.8, -158.24024238026323`}], 
             PointBox[{64.9, -153.5175321307761}], 
             PointBox[{65., -151.04378555499716`}], 
             PointBox[{65.1, -153.49796422515647`}], 
             PointBox[{65.2, -151.0939773173377}], 
             PointBox[{65.3, -149.09624183813867`}], 
             PointBox[{65.4, -152.86023805241712`}], 
             PointBox[{65.5, -158.02160770635965`}], 
             PointBox[{65.6, -155.45164371847204`}], 
             PointBox[{65.7, -154.11168534162425`}], 
             PointBox[{65.8, -156.3695255149214}], 
             PointBox[{65.9, -152.79053382491838`}], 
             PointBox[{66., -147.98612480388692`}], 
             PointBox[{66.1, -149.57405336930242`}], 
             PointBox[{66.2, -150.0531300594812}], 
             PointBox[{66.3, -145.77826817088499`}], 
             PointBox[{66.4, -147.9299523388545}], 
             PointBox[{66.5, -153.89163520577858`}], 
             PointBox[{66.6, -155.33445466851117`}], 
             PointBox[{66.7, -151.02027556315443`}], 
             PointBox[{66.8, -153.74876325796504`}], 
             PointBox[{66.9, -152.94916315145383`}], 
             PointBox[{67., -146.58349215690396`}], 
             PointBox[{67.1, -145.53172220943088`}], 
             PointBox[{67.2, -148.684159969358}], 
             PointBox[{67.3, -144.54322112382215`}], 
             PointBox[{67.4, -143.4783765747561}], 
             PointBox[{67.5, -149.08918575738062`}], 
             PointBox[{67.6, -155.35220795238274`}], 
             PointBox[{67.7, -150.73172277703998`}], 
             PointBox[{67.8, -150.90670980182767`}], 
             PointBox[{67.9, -153.69509886435117`}], 
             PointBox[{68., -148.0139035434986}], 
             PointBox[{68.1, -142.9426325571403}], 
             PointBox[{68.2, -146.56071765180968`}], 
             PointBox[{68.3, -146.0464710673623}], 
             PointBox[{68.4, -141.0180636272853}], 
             PointBox[{68.5, -145.19873215984262`}], 
             PointBox[{68.6, -154.3579655108042}], 
             PointBox[{68.7, -154.95783714480785`}], 
             PointBox[{68.8, -150.09008697100944`}], 
             PointBox[{68.9, -154.76366864453303`}], 
             PointBox[{69., -153.4111146731957}], 
             PointBox[{69.1, -144.423723851025}], 
             PointBox[{69.2, -144.99045383191697`}], 
             PointBox[{69.3, -149.44806063352735`}], 
             PointBox[{69.4, -143.47502355006145`}], 
             PointBox[{69.5, -143.2098385396166}], 
             PointBox[{69.6, -153.0430482922966}], 
             PointBox[{69.7, -163.00139299946022`}], 
             PointBox[{69.8, -156.3231217696084}], 
             PointBox[{69.9, -157.40070027380716`}], 
             PointBox[{70., -162.59433266588894`}], 
             PointBox[{70.1, -154.46478466444387`}], 
             PointBox[{70.2, -147.61605489850626`}], 
             PointBox[{70.3, -153.83315048798977`}], 
             PointBox[{70.4, -153.918937185088}], 
             PointBox[{70.5, -146.75136354839924`}], 
             PointBox[{70.6, -154.56080724014464`}], 
             PointBox[{70.7, -171.54688007058576`}], 
             PointBox[{70.8, -174.5666505512345}], 
             PointBox[{70.9, -166.76731568357354`}], 
             PointBox[{71., -173.6826186270191}], 
             PointBox[{71.1, -175.31831060724653`}], 
             PointBox[{71.2, -161.81819798849028`}], 
             PointBox[{71.3, -161.569142582528}], 
             PointBox[{71.4, -169.48186280445225`}], 
             PointBox[{71.5, -163.07128208757058`}], 
             PointBox[{71.6, -161.626181642554}], 
             PointBox[{71.7, -179.22459628837532`}], 
             PointBox[{71.8, 165.2962877492173}], 
             PointBox[{71.9, 170.92476354935206`}], 
             PointBox[{72., 173.65645603319717`}], 
             PointBox[{72.1, 165.1203059935724}], 
             PointBox[{72.2, 169.8247240748242}], 
             PointBox[{72.3, -177.88705423660576`}], 
             PointBox[{72.4, 176.87742433516541`}], 
             PointBox[{72.5, 172.1826516511719}], 
             PointBox[{72.6, -178.6074904330817}], 
             PointBox[{72.7, 173.26642087315122`}], 
             PointBox[{72.8, 155.45293155961554`}], 
             PointBox[{72.9, 150.04582289179962`}], 
             PointBox[{73., 158.5290115120879}], 
             PointBox[{73.1, 155.2806781241743}], 
             PointBox[{73.2, 150.22004602810193`}], 
             PointBox[{73.3, 160.1497213774128}], 
             PointBox[{73.4, 165.6553869278723}], 
             PointBox[{73.5, 158.89483449001273`}], 
             PointBox[{73.6, 160.78609093176055`}], 
             PointBox[{73.7, 165.43958264884714`}], 
             PointBox[{73.8, 152.64793502854445`}], 
             PointBox[{73.9, 143.2459251840628}], 
             PointBox[{74., 145.94531791730697`}], 
             PointBox[{74.1, 150.5433392338091}], 
             PointBox[{74.2, 144.9181752557779}], 
             PointBox[{74.3, 146.5201822426825}], 
             PointBox[{74.4, 155.9844283725106}], 
             PointBox[{74.5, 155.05251163607318`}], 
             PointBox[{74.6, 150.9182420470679}], 
             PointBox[{74.7, 157.24156071504694`}], 
             PointBox[{74.8, 153.51626863620186`}], 
             PointBox[{74.9, 144.08657533711084`}], 
             PointBox[{75., 141.1407840366519}], 
             PointBox[{75.1, 147.07509328251763`}], 
             PointBox[{75.2, 145.74970374794793`}], 
             PointBox[{75.3, 142.84249890343926`}], 
             PointBox[{75.4, 149.4344231305513}], 
             PointBox[{75.5, 153.94112622110697`}], 
             PointBox[{75.6, 150.15052823642327`}], 
             PointBox[{75.7, 151.68497878757626`}], 
             PointBox[{75.8, 155.0702080712217}], 
             PointBox[{75.9, 147.57171781751094`}], 
             PointBox[{76., 142.354356418291}], 
             PointBox[{76.1, 144.89886273370212`}], 
             PointBox[{76.2, 148.04873803597002`}], 
             PointBox[{76.3, 144.4393719445652}], 
             PointBox[{76.4, 146.8514771378468}], 
             PointBox[{76.5, 153.24537371603947`}], 
             PointBox[{76.6, 152.74221122741437`}], 
             PointBox[{76.7, 150.59798775929085`}], 
             PointBox[{76.8, 155.48011970990774`}], 
             PointBox[{76.9, 152.2092337576396}], 
             PointBox[{77., 146.36452668248967`}], 
             PointBox[{77.1, 145.2315990830175}], 
             PointBox[{77.2, 149.80715479741048`}], 
             PointBox[{77.3, 148.20388324845408`}], 
             PointBox[{77.4, 147.4385990242081}], 
             PointBox[{77.5, 152.9308259741374}], 
             PointBox[{77.6, 155.62985419017787`}], 
             PointBox[{77.7, 152.9565798620315}], 
             PointBox[{77.8, 155.49078894716513`}], 
             PointBox[{77.9, 156.8107181290543}], 
             PointBox[{78., 151.22011009289417`}], 
             PointBox[{78.1, 147.93257984966476`}], 
             PointBox[{78.2, 150.90475407517806`}], 
             PointBox[{78.3, 152.32543335954688`}], 
             PointBox[{78.4, 150.012312383471}], 
             PointBox[{78.5, 153.37320562372042`}], 
             PointBox[{78.6, 157.81276801234344`}], 
             PointBox[{78.7, 156.75488845061773`}], 
             PointBox[{78.8, 156.3265841374523}], 
             PointBox[{78.9, 160.0084992767661}], 
             PointBox[{79., 156.192563301498}], 
             PointBox[{79.1, 151.9673718954873}], 
             PointBox[{79.2, 152.27875825693627`}], 
             PointBox[{79.3, 155.67617474596045`}], 
             PointBox[{79.4, 153.61181383802614`}], 
             PointBox[{79.5, 154.67042596809188`}], 
             PointBox[{79.6, 159.33026841618994`}], 
             PointBox[{79.7, 160.44445678941702`}], 
             PointBox[{79.8, 158.51953982119448`}], 
             PointBox[{79.9, 161.86148340466025`}], 
             PointBox[{80., 160.98042796966183`}], 
             PointBox[{80.1, 156.39990617970034`}], 
             PointBox[{80.2, 154.53895965812262`}], 
             PointBox[{80.3, 157.8546026929762}], 
             PointBox[{80.4, 157.4785102075257}], 
             PointBox[{80.5, 156.67591305979295`}], 
             PointBox[{80.6, 160.51726622050046`}], 
             PointBox[{80.7, 163.31204080860334`}], 
             PointBox[{80.8, 161.6631310069206}], 
             PointBox[{80.9, 163.0454263085703}], 
             PointBox[{81., 164.81113601353718`}], 
             PointBox[{81.1, 160.6815673362944}], 
             PointBox[{81.2, 157.5529719586848}], 
             PointBox[{81.3, 159.27015810220473`}], 
             PointBox[{81.4, 160.951421774349}], 
             PointBox[{81.5, 159.16390853939083`}], 
             PointBox[{81.6, 161.6418780119493}], 
             PointBox[{81.7, 165.2767621976309}], 
             PointBox[{81.8, 164.93265654342395`}], 
             PointBox[{81.9, 164.3054428410469}], 
             PointBox[{82., 167.3650065417969}], 
             PointBox[{82.1, 164.64555712916626`}], 
             PointBox[{82.2, 160.8918516367412}], 
             PointBox[{82.3, 160.6314105850397}], 
             PointBox[{82.4, 163.5208267171838}], 
             PointBox[{82.5, 161.89509268343681`}], 
             PointBox[{82.6, 162.8366224453639}], 
             PointBox[{82.7, 166.54484084242722`}], 
             PointBox[{82.8, 167.68085276772035`}], 
             PointBox[{82.9, 166.05880740365683`}], 
             PointBox[{83., 168.82097493700712`}], 
             PointBox[{83.1, 168.10889096310711`}], 
             PointBox[{83.2, 164.17210674081434`}], 
             PointBox[{83.3, 162.3171984313958}], 
             PointBox[{83.4, 165.04298166814988`}], 
             PointBox[{83.5, 164.5990127512414}], 
             PointBox[{83.6, 164.1414226386405}], 
             PointBox[{83.7, 167.360592757439}], 
             PointBox[{83.8, 169.64488193479337`}], 
             PointBox[{83.9, 168.20198171422817`}], 
             PointBox[{84., 169.56246877512604`}], 
             PointBox[{84.1, 170.75048460984544`}], 
             PointBox[{84.2, 167.1500940147016}], 
             PointBox[{84.3, 164.3021827950579}], 
             PointBox[{84.4, 165.82935573588475`}], 
             PointBox[{84.5, 166.9562338081596}], 
             PointBox[{84.6, 165.549984689751}], 
             PointBox[{84.7, 167.91062597221753`}], 
             PointBox[{84.8, 170.8506352878976}], 
             PointBox[{84.9, 170.32327429839643`}], 
             PointBox[{85., 170.06572462307668`}], 
             PointBox[{85.1, 172.46252823878604`}], 
             PointBox[{85.2, 169.74948197487538`}], 
             PointBox[{85.3, 166.39212376627984`}], 
             PointBox[{85.4, 166.37296588218305`}], 
             PointBox[{85.5, 168.65181166858383`}], 
             PointBox[{85.6, 167.02054008018604`}], 
             PointBox[{85.7, 168.31347729375557`}], 
             PointBox[{85.8, 171.44675360104884`}], 
             PointBox[{85.9, 172.03541738959757`}], 
             PointBox[{86., 170.7117500484601}], 
             PointBox[{86.1, 173.31087555381237`}], 
             PointBox[{86.2, 171.9243755490752}], 
             PointBox[{86.3, 168.38297798235726`}], 
             PointBox[{86.4, 166.99768178027443`}], 
             PointBox[{86.5, 169.51915867339267`}], 
             PointBox[{86.6, 168.46616775428993`}], 
             PointBox[{86.7, 168.63993082498928`}], 
             PointBox[{86.8, 171.5932953326119}], 
             PointBox[{86.9, 173.14702009113535`}], 
             PointBox[{87., 171.60073149963864`}], 
             PointBox[{87.1, 173.4598275242315}], 
             PointBox[{87.2, 173.5468866157462}], 
             PointBox[{87.3, 170.1127147196239}], 
             PointBox[{87.4, 167.7701277448432}], 
             PointBox[{87.5, 169.65713544520986`}], 
             PointBox[{87.6, 169.73817408963077`}], 
             PointBox[{87.7, 168.92768021905067`}], 
             PointBox[{87.8, 171.41781805649953`}], 
             PointBox[{87.9, 173.63884551001684`}], 
             PointBox[{88., 172.556796193021}], 
             PointBox[{88.1, 173.15904557853355`}], 
             PointBox[{88.2, 174.52192286052014`}], 
             PointBox[{88.3, 171.4935987703211}], 
             PointBox[{88.4, 168.60407948657667`}], 
             PointBox[{88.5, 169.36171743850718`}], 
             PointBox[{88.6, 170.63448001037614`}], 
             PointBox[{88.7, 169.18590636833687`}], 
             PointBox[{88.8, 171.00659760830604`}], 
             PointBox[{88.9, 173.58022180039552`}], 
             PointBox[{89., 173.30310263815045`}], 
             PointBox[{89.1, 172.691465462216}], 
             PointBox[{89.2, 174.82550697062834`}], 
             PointBox[{89.3, 172.507873615039}], 
             PointBox[{89.4, 169.36353931957274`}], 
             PointBox[{89.5, 168.91974415232835`}], 
             PointBox[{89.6, 170.95959530605614`}], 
             PointBox[{89.7, 169.3907932079528}], 
             PointBox[{89.8, 170.4101320405971}], 
             PointBox[{89.9, 173.06084227603424`}], 
             PointBox[{90., 173.62181016453542`}], 
             PointBox[{90.1, 172.25588008361956`}], 
             PointBox[{90.2, 174.4809983617015}], 
             PointBox[{90.3, 173.12035698525142`}], 
             PointBox[{90.4, 169.9084572053107}], 
             PointBox[{90.5, 168.46661267330637`}], 
             PointBox[{90.6, 170.61639682952227`}], 
             PointBox[{90.7, 169.47603120173153`}], 
             PointBox[{90.8, 169.64809086130117`}], 
             PointBox[{90.9, 172.1537312288565}], 
             PointBox[{91., 173.40454588695866`}], 
             PointBox[{91.1, 171.8700246679582}], 
             PointBox[{91.2, 173.55258871523984`}], 
             PointBox[{91.3, 173.247691692457}], 
             PointBox[{91.4, 170.1137905027863}], 
             PointBox[{91.5, 167.98607785601052`}], 
             PointBox[{91.6, 169.6566905027139}], 
             PointBox[{91.7, 169.32723277022887`}], 
             PointBox[{91.8, 168.71157891541952`}], 
             PointBox[{91.9, 170.9014380885783}], 
             PointBox[{92., 172.62420016375836`}], 
             PointBox[{92.1, 171.38315982051427`}], 
             PointBox[{92.2, 172.14000880184176`}], 
             PointBox[{92.3, 172.80480105809693`}], 
             PointBox[{92.4, 169.88252740789903`}], 
             PointBox[{92.5, 167.3706656882423}], 
             PointBox[{92.6, 168.22727427547215`}], 
             PointBox[{92.7, 168.79062472791702`}], 
             PointBox[{92.8, 167.56009546673158`}], 
             PointBox[{92.9, 169.31143752648495`}], 
             PointBox[{93., 171.28689472511178`}], 
             PointBox[{93.1, 170.5720645651454}], 
             PointBox[{93.2, 170.34888625290478`}], 
             PointBox[{93.3, 171.7251634409913}], 
             PointBox[{93.4, 169.14219046950166`}], 
             PointBox[{93.5, 166.47247734782286`}], 
             PointBox[{93.6, 166.4541196016071}], 
             PointBox[{93.7, 167.70234551977774`}], 
             PointBox[{93.8, 166.1174515375751}], 
             PointBox[{93.9, 167.35437702259514`}], 
             PointBox[{94., 169.39350933187234`}], 
             PointBox[{94.1, 169.22897917903902`}], 
             PointBox[{94.2, 168.2311827069061}], 
             PointBox[{94.3, 169.95213230604713`}], 
             PointBox[{94.4, 167.8100559567829}], 
             PointBox[{94.5, 165.1259441266302}], 
             PointBox[{94.6, 164.35780060628895`}], 
             PointBox[{94.7, 165.9250366915221}], 
             PointBox[{94.8, 164.26547532105178`}], 
             PointBox[{94.9, 164.96018883955549`}], 
             PointBox[{95., 166.91450864821672`}], 
             PointBox[{95.1, 167.18972516941722`}], 
             PointBox[{95.2, 165.72998428546998`}], 
             PointBox[{95.3, 167.4252917018166}], 
             PointBox[{95.4, 165.76079165266128`}], 
             PointBox[{95.5, 163.15325501751795`}], 
             PointBox[{95.6, 161.842060342693}], 
             PointBox[{95.7, 163.36597901800997`}], 
             PointBox[{95.8, 161.83890198217705`}], 
             PointBox[{95.9, 162.01110705919564`}], 
             PointBox[{96., 163.772506670226}], 
             PointBox[{96.1, 164.3144711420464}], 
             PointBox[{96.2, 162.66510429359914`}], 
             PointBox[{96.3, 164.06208320824953`}], 
             PointBox[{96.4, 162.8240653879766}], 
             PointBox[{96.5, 160.36193984826969`}], 
             PointBox[{96.6, 158.7160141835193}], 
             PointBox[{96.7, 159.94873839787033`}], 
             PointBox[{96.8, 158.62207008479163`}], 
             PointBox[{96.9, 158.3328739454737}], 
             PointBox[{97., 159.8283840281656}], 
             PointBox[{97.1, 160.44867526835878`}], 
             PointBox[{97.2, 158.7578023502574}], 
             PointBox[{97.3, 159.73216331732692`}], 
             PointBox[{97.4, 158.78627138835145`}], 
             PointBox[{97.5, 156.53334452169656`}], 
             PointBox[{97.6, 154.71753574554168`}], 
             PointBox[{97.7, 155.55535897279333`}], 
             PointBox[{97.8, 154.3437872317736}], 
             PointBox[{97.9, 153.68345304141985`}], 
             PointBox[{98., 154.86654806751176`}], 
             PointBox[{98.1, 155.38298428582493`}], 
             PointBox[{98.2, 153.66096594354894`}], 
             PointBox[{98.3, 154.22611552960007`}], 
             PointBox[{98.4, 153.38472887266835`}], 
             PointBox[{98.5, 151.4006443284743}], 
             PointBox[{98.6, 149.5123393771355}], 
             PointBox[{98.7, 149.96390674891882`}], 
             PointBox[{98.8, 148.6628304989281}], 
             PointBox[{98.9, 147.73979876947124`}], 
             PointBox[{99., 148.5768258688331}], 
             PointBox[{99.1, 148.81817333716026`}], 
             PointBox[{99.2, 146.97005502929096`}], 
             PointBox[{99.3, 147.23295783529466`}], 
             PointBox[{99.4, 146.31348379465635`}], 
             PointBox[{99.5, 144.6123737537855}], 
             PointBox[{99.6, 142.6790133942559}], 
             PointBox[{99.7, 142.8101643195987}], 
             PointBox[{99.8, 141.1499200255348}], 
             PointBox[{99.9, 140.09049231544486`}], 
             PointBox[{100., 140.5429149765696}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {-180, 180}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-328., 0}},
       PlotRangePadding->{6, 5}], {190, -880.}, ImageScaled[{0.5, 0.5}], {360, 312.},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0.6}, {100, 0.6}, {100, 0.65}, {0, 0.65}, {0, 0.6}}], 
            {Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.610592}], 
             PointBox[{0.1, 0.6125389993455937}], 
             PointBox[{0.2, 0.6139550788236566}], 
             PointBox[{0.3, 0.6150123269288509}], 
             PointBox[{0.4, 0.617103824886392}], 
             PointBox[{0.5, 0.6187989247449442}], 
             PointBox[{0.6, 0.6154377945321506}], 
             PointBox[{0.7, 0.6140540236547561}], 
             PointBox[{0.8, 0.6131242459516499}], 
             PointBox[{0.9, 0.6115623564717139}], 
             PointBox[{1., 0.6115251976302931}], 
             PointBox[{1.1, 0.6140585588996277}], 
             PointBox[{1.2, 0.615199187641102}], 
             PointBox[{1.3, 0.6164726200271676}], 
             PointBox[{1.4, 0.6190038255542829}], 
             PointBox[{1.5, 0.6170676588575594}], 
             PointBox[{1.6, 0.6145343304997509}], 
             PointBox[{1.7, 0.6136802310539865}], 
             PointBox[{1.8, 0.6129017420365447}], 
             PointBox[{1.9, 0.6116539609457533}], 
             PointBox[{2., 0.6139521250526869}], 
             PointBox[{2.1, 0.615789282922376}], 
             PointBox[{2.2, 0.6167903824046534}], 
             PointBox[{2.3, 0.6183424960713789}], 
             PointBox[{2.4, 0.6196857987564537}], 
             PointBox[{2.5, 0.6157878285001183}], 
             PointBox[{2.6, 0.6144567892710601}], 
             PointBox[{2.7, 0.614048370622393}], 
             PointBox[{2.8, 0.6136677422954637}], 
             PointBox[{2.9, 0.6132424376581082}], 
             PointBox[{3., 0.6165426378735465}], 
             PointBox[{3.1, 0.6177307079712592}], 
             PointBox[{3.2, 0.6187058864403464}], 
             PointBox[{3.3, 0.6203484859896197}], 
             PointBox[{3.4, 0.618851735101862}], 
             PointBox[{3.5, 0.6157013220655945}], 
             PointBox[{3.6, 0.6152545415655523}], 
             PointBox[{3.7, 0.6154340745558392}], 
             PointBox[{3.8, 0.6149793745799592}], 
             PointBox[{3.9, 0.6166021737568605}], 
             PointBox[{4., 0.619085288241464}], 
             PointBox[{4.1, 0.6199253078072509}], 
             PointBox[{4.2, 0.6209016088268712}], 
             PointBox[{4.3, 0.6219782466896115}], 
             PointBox[{4.4, 0.618363611594125}], 
             PointBox[{4.5, 0.6167031082578741}], 
             PointBox[{4.6, 0.617016874662271}], 
             PointBox[{4.7, 0.61793668402}], 
             PointBox[{4.8, 0.6167842450570538}], 
             PointBox[{4.9, 0.6201037226659422}], 
             PointBox[{5., 0.6216896936052938}], 
             PointBox[{5.1, 0.6223520108304182}], 
             PointBox[{5.2, 0.6232548262686061}], 
             PointBox[{5.3, 0.6230572961395411}], 
             PointBox[{5.4, 0.6190925054198521}], 
             PointBox[{5.5, 0.6185708159450891}], 
             PointBox[{5.6, 0.6197264108912399}], 
             PointBox[{5.7, 0.6203918120423081}], 
             PointBox[{5.8, 0.619702227746976}], 
             PointBox[{5.9, 0.6232449839199719}], 
             PointBox[{6., 0.6243115673539309}], 
             PointBox[{6.1, 0.6248583783024309}], 
             PointBox[{6.2, 0.6255550164608555}], 
             PointBox[{6.3, 0.6240856119792233}], 
             PointBox[{6.4, 0.62069287287043}], 
             PointBox[{6.5, 0.6209625997833219}], 
             PointBox[{6.6, 0.6229009030826673}], 
             PointBox[{6.7, 0.6222194233641075}], 
             PointBox[{6.8, 0.6227033767315933}], 
             PointBox[{6.9, 0.6259366109294627}], 
             PointBox[{7., 0.6267381259005411}], 
             PointBox[{7.1, 0.6271801740439014}], 
             PointBox[{7.2, 0.6275912753064341}], 
             PointBox[{7.3, 0.6253706259225179}], 
             PointBox[{7.4, 0.6225699362767642}], 
             PointBox[{7.5, 0.6233953486663911}], 
             PointBox[{7.6, 0.6256000153281509}], 
             PointBox[{7.7, 0.6238814370146264}], 
             PointBox[{7.8, 0.6251016527559936}], 
             PointBox[{7.9, 0.6280798387830282}], 
             PointBox[{8., 0.6287491952553041}], 
             PointBox[{8.1, 0.6290869163426817}], 
             PointBox[{8.2, 0.629240953682147}], 
             PointBox[{8.3, 0.6267400680499516}], 
             PointBox[{8.4, 0.6242644082092877}], 
             PointBox[{8.5, 0.6254383107589859}], 
             PointBox[{8.6, 0.6273962047380517}], 
             PointBox[{8.7, 0.6252680898059365}], 
             PointBox[{8.8, 0.6267491555023199}], 
             PointBox[{8.9, 0.6296386049402879}], 
             PointBox[{9., 0.6302501484104256}], 
             PointBox[{9.1, 0.6304911716695587}], 
             PointBox[{9.2, 0.6304704386438991}], 
             PointBox[{9.3, 0.6279596857612562}], 
             PointBox[{9.4, 0.6255611941623894}], 
             PointBox[{9.5, 0.6268985315038891}], 
             PointBox[{9.6, 0.6285054127726699}], 
             PointBox[{9.7, 0.6262672303796093}], 
             PointBox[{9.8, 0.627726741370056}], 
             PointBox[{9.9, 0.6306548505160936}], 
             PointBox[{10., 0.6312587528531822}], 
             PointBox[{10.1, 0.6314155052394171}], 
             PointBox[{10.2, 0.6312953525547257}], 
             PointBox[{10.3, 0.6289122017662375}], 
             PointBox[{10.4, 0.6264260160986707}], 
             PointBox[{10.5, 0.627787561203083}], 
             PointBox[{10.6, 0.6291523687744136}], 
             PointBox[{10.7, 0.6268744071913317}], 
             PointBox[{10.8, 0.6281602724108628}], 
             PointBox[{10.9, 0.6311970082918738}], 
             PointBox[{11., 0.6318307482258785}], 
             PointBox[{11.1, 0.6319144366776346}], 
             PointBox[{11.2, 0.6317410407101777}], 
             PointBox[{11.3, 0.6295502573497699}], 
             PointBox[{11.4, 0.626893741306247}], 
             PointBox[{11.5, 0.6281931648109742}], 
             PointBox[{11.6, 0.6294248905934163}], 
             PointBox[{11.7, 0.6271128750399843}], 
             PointBox[{11.8, 0.6281558156292035}], 
             PointBox[{11.9, 0.6313240830854016}], 
             PointBox[{12., 0.6320122523270909}], 
             PointBox[{12.1, 0.6320276872859566}], 
             PointBox[{12.2, 0.6318208664268434}], 
             PointBox[{12.3, 0.629838970358772}], 
             PointBox[{12.4, 0.6269944114955714}], 
             PointBox[{12.5, 0.6281987059654173}], 
             PointBox[{12.6, 0.6293260470024187}], 
             PointBox[{12.7, 0.6269848787543562}], 
             PointBox[{12.8, 0.627783455377996}], 
             PointBox[{12.9, 0.6310748657811034}], 
             PointBox[{13., 0.6318211056884544}], 
             PointBox[{13.1, 0.6317646565696882}], 
             PointBox[{13.2, 0.6315261242218454}], 
             PointBox[{13.3, 0.629728989243674}], 
             PointBox[{13.4, 0.6267220897001446}], 
             PointBox[{13.5, 0.6278560502983505}], 
             PointBox[{13.6, 0.6288045652215322}], 
             PointBox[{13.7, 0.6264576459344414}], 
             PointBox[{13.8, 0.6270748452651863}], 
             PointBox[{13.9, 0.6304720231507083}], 
             PointBox[{14., 0.6312443498311319}], 
             PointBox[{14.1, 0.6311021354509421}], 
             PointBox[{14.2, 0.6308217262852628}], 
             PointBox[{14.3, 0.6291524792905674}], 
             PointBox[{14.4, 0.6260276839644638}], 
             PointBox[{14.5, 0.6271860314284842}], 
             PointBox[{14.6, 0.6277604404491381}], 
             PointBox[{14.7, 0.6254726211931098}], 
             PointBox[{14.8, 0.6260306170408432}], 
             PointBox[{14.9, 0.6295313008822073}], 
             PointBox[{15., 0.6302417907553189}], 
             PointBox[{15.1, 0.6299910615333055}], 
             PointBox[{15.2, 0.6296521299825136}], 
             PointBox[{15.3, 0.6280168453872602}], 
             PointBox[{15.4, 0.624833923282965}], 
             PointBox[{15.5, 0.6261795318229592}], 
             PointBox[{15.6, 0.6260649113463377}], 
             PointBox[{15.7, 0.6239840838340875}], 
             PointBox[{15.8, 0.624671105186547}], 
             PointBox[{15.9, 0.6282778647219647}], 
             PointBox[{16., 0.6287645253319014}], 
             PointBox[{16.1, 0.6283802261038203}], 
             PointBox[{16.2, 0.6279626271064821}], 
             PointBox[{16.3, 0.6262214495112927}], 
             PointBox[{16.4, 0.6230957123365991}], 
             PointBox[{16.5, 0.6247588929467123}], 
             PointBox[{16.6, 0.6236818343791152}], 
             PointBox[{16.7, 0.6220458599244116}], 
             PointBox[{16.8, 0.6231265260061891}], 
             PointBox[{16.9, 0.6267596484113421}], 
             PointBox[{17., 0.6268043026466292}], 
             PointBox[{17.1, 0.6262765506430413}], 
             PointBox[{17.2, 0.6257501451871283}], 
             PointBox[{17.3, 0.6236933538282613}], 
             PointBox[{17.4, 0.6209479003526289}], 
             PointBox[{17.5, 0.6226043040667102}], 
             PointBox[{17.6, 0.6208827179923494}], 
             PointBox[{17.7, 0.6199124659599969}], 
             PointBox[{17.8, 0.62174640011062}], 
             PointBox[{17.9, 0.6250209999554347}], 
             PointBox[{18., 0.6244699051888546}], 
             PointBox[{18.1, 0.6238190959193609}], 
             PointBox[{18.2, 0.6231267385920326}], 
             PointBox[{18.3, 0.6204642088174936}], 
             PointBox[{18.4, 0.618861496306806}], 
             PointBox[{18.5, 0.619544105292779}], 
             PointBox[{18.6, 0.6182367155001902}], 
             PointBox[{18.7, 0.6180436807977691}], 
             PointBox[{18.8, 0.6210131103061044}], 
             PointBox[{18.9, 0.6230510192735427}], 
             PointBox[{19., 0.6220007026148322}], 
             PointBox[{19.1, 0.6212621475891896}], 
             PointBox[{19.2, 0.6202690853455993}], 
             PointBox[{19.3, 0.6168692746323675}], 
             PointBox[{19.4, 0.617079450969987}], 
             PointBox[{19.5, 0.6166872261209535}], 
             PointBox[{19.6, 0.6162468623198135}], 
             PointBox[{19.7, 0.6169522415878262}], 
             PointBox[{19.8, 0.6209325314060165}], 
             PointBox[{19.9, 0.620889732866591}], 
             PointBox[{20., 0.619648509836758}], 
             PointBox[{20.1, 0.6188245180206159}], 
             PointBox[{20.2, 0.6172484590122923}], 
             PointBox[{20.3, 0.6140200128491785}], 
             PointBox[{20.4, 0.614976433964512}], 
             PointBox[{20.5, 0.6148864772609741}], 
             PointBox[{20.6, 0.6151465900856314}], 
             PointBox[{20.7, 0.6170657035410109}], 
             PointBox[{20.8, 0.6204452838139812}], 
             PointBox[{20.9, 0.6187442701810092}], 
             PointBox[{21., 0.6175541022015351}], 
             PointBox[{21.1, 0.6165672803827597}], 
             PointBox[{21.2, 0.6140462550526805}], 
             PointBox[{21.3, 0.6128823453996083}], 
             PointBox[{21.4, 0.6136465162734319}], 
             PointBox[{21.5, 0.6141148699267448}], 
             PointBox[{21.6, 0.6150106723562283}], 
             PointBox[{21.7, 0.6183676747576674}], 
             PointBox[{21.8, 0.6188521068384671}], 
             PointBox[{21.9, 0.6168348942736306}], 
             PointBox[{22., 0.6157489245810166}], 
             PointBox[{22.1, 0.6144163235601247}], 
             PointBox[{22.2, 0.6114467401540867}], 
             PointBox[{22.3, 0.6123385154895911}], 
             PointBox[{22.4, 0.6133840362311207}], 
             PointBox[{22.5, 0.6141817300319239}], 
             PointBox[{22.6, 0.6158992418992412}], 
             PointBox[{22.7, 0.619286948622408}], 
             PointBox[{22.8, 0.6168961797905068}], 
             PointBox[{22.9, 0.6152729211707432}], 
             PointBox[{23., 0.6142225109038315}], 
             PointBox[{23.1, 0.612334033222346}], 
             PointBox[{23.2, 0.6109031705669058}], 
             PointBox[{23.3, 0.6127579835167497}], 
             PointBox[{23.4, 0.6138485259436512}], 
             PointBox[{23.5, 0.6149622808976043}], 
             PointBox[{23.6, 0.6176883836107218}], 
             PointBox[{23.7, 0.6181157558636282}], 
             PointBox[{23.8, 0.6153071353233517}], 
             PointBox[{23.9, 0.6141101023632337}], 
             PointBox[{24., 0.6129939375500582}], 
             PointBox[{24.1, 0.6109177975206156}], 
             PointBox[{24.2, 0.6118718141866347}], 
             PointBox[{24.3, 0.6137913124069446}], 
             PointBox[{24.4, 0.6148380982808115}], 
             PointBox[{24.5, 0.6163916481280686}], 
             PointBox[{24.6, 0.6191680322598201}], 
             PointBox[{24.7, 0.6162166336631368}], 
             PointBox[{24.8, 0.6143103791178905}], 
             PointBox[{24.9, 0.6134170917947469}], 
             PointBox[{25., 0.6122432395693894}], 
             PointBox[{25.1, 0.6110269385239399}], 
             PointBox[{25.2, 0.6137609327718139}], 
             PointBox[{25.3, 0.615174113231973}], 
             PointBox[{25.4, 0.6162608916464557}], 
             PointBox[{25.5, 0.6183002867362175}], 
             PointBox[{25.6, 0.6185514332832426}], 
             PointBox[{25.7, 0.6150481347425568}], 
             PointBox[{25.8, 0.6139770931902935}], 
             PointBox[{25.9, 0.6133538703684379}], 
             PointBox[{26., 0.6124259967604442}], 
             PointBox[{26.1, 0.6131603140378115}], 
             PointBox[{26.2, 0.6158020904661414}], 
             PointBox[{26.3, 0.6168502153383579}], 
             PointBox[{26.4, 0.6180616720258345}], 
             PointBox[{26.5, 0.6200245768457869}], 
             PointBox[{26.6, 0.6170460593974095}], 
             PointBox[{26.7, 0.6148681511697484}], 
             PointBox[{26.8, 0.6144173408620507}], 
             PointBox[{26.9, 0.6142427550743695}], 
             PointBox[{27., 0.6132784654493211}], 
             PointBox[{27.1, 0.6162482051631102}], 
             PointBox[{27.2, 0.6179461665258228}], 
             PointBox[{27.3, 0.6188208542465604}], 
             PointBox[{27.4, 0.6201387231296824}], 
             PointBox[{27.5, 0.6205849878153622}], 
             PointBox[{27.6, 0.6165598492771919}], 
             PointBox[{27.7, 0.6156443470848676}], 
             PointBox[{27.8, 0.6158249307070315}], 
             PointBox[{27.9, 0.6161301025817938}], 
             PointBox[{28., 0.6157869880455654}], 
             PointBox[{28.1, 0.619218001259257}], 
             PointBox[{28.2, 0.620277831323489}], 
             PointBox[{28.3, 0.6210737003564437}], 
             PointBox[{28.4, 0.6222658708529528}], 
             PointBox[{28.5, 0.6204210352220182}], 
             PointBox[{28.6, 0.6173392491988292}], 
             PointBox[{28.7, 0.617347826036612}], 
             PointBox[{28.8, 0.6183576975583309}], 
             PointBox[{28.9, 0.6178637981196274}], 
             PointBox[{29., 0.6194003159348557}], 
             PointBox[{29.1, 0.6220586346809547}], 
             PointBox[{29.2, 0.6227880764229468}], 
             PointBox[{29.3, 0.6235106695231708}], 
             PointBox[{29.4, 0.6241920856311407}], 
             PointBox[{29.5, 0.6208557971914176}], 
             PointBox[{29.6, 0.6190386879776093}], 
             PointBox[{29.7, 0.6198523312080837}], 
             PointBox[{29.8, 0.6214486341148462}], 
             PointBox[{29.9, 0.6199288303238479}], 
             PointBox[{30., 0.6228105562670679}], 
             PointBox[{30.1, 0.6247604728041267}], 
             PointBox[{30.2, 0.6253108622016375}], 
             PointBox[{30.3, 0.6259154261982517}], 
             PointBox[{30.4, 0.6258798242388237}], 
             PointBox[{30.5, 0.6221194800204762}], 
             PointBox[{30.6, 0.6211932543687294}], 
             PointBox[{30.7, 0.6227506684460705}], 
             PointBox[{30.8, 0.6237898908831964}], 
             PointBox[{30.9, 0.6222832384618421}], 
             PointBox[{31., 0.625592387214073}], 
             PointBox[{31.1, 0.6271482685561228}], 
             PointBox[{31.2, 0.6275813268091157}], 
             PointBox[{31.3, 0.6280300628770286}], 
             PointBox[{31.4, 0.6274091806529773}], 
             PointBox[{31.5, 0.6237218941939875}], 
             PointBox[{31.6, 0.6233103274578444}], 
             PointBox[{31.7, 0.6254082963331472}], 
             PointBox[{31.8, 0.6253532845666555}], 
             PointBox[{31.9, 0.62430672222907}], 
             PointBox[{32., 0.6276661782673165}], 
             PointBox[{32.1, 0.6290565291415845}], 
             PointBox[{32.2, 0.6293998682963797}], 
             PointBox[{32.3, 0.6296937446622198}], 
             PointBox[{32.4, 0.6287569415142826}], 
             PointBox[{32.5, 0.6252163796809919}], 
             PointBox[{32.6, 0.6250386204423355}], 
             PointBox[{32.7, 0.6273900954147762}], 
             PointBox[{32.8, 0.6265074626924706}], 
             PointBox[{32.9, 0.6257536405163633}], 
             PointBox[{33., 0.6290686128558269}], 
             PointBox[{33.1, 0.6304391964163731}], 
             PointBox[{33.2, 0.6307108969498217}], 
             PointBox[{33.3, 0.6308782190882958}], 
             PointBox[{33.4, 0.6298422972843448}], 
             PointBox[{33.5, 0.6264005631406645}], 
             PointBox[{33.6, 0.6262505812031101}], 
             PointBox[{33.7, 0.6286636227909298}], 
             PointBox[{33.8, 0.6273260491187292}], 
             PointBox[{33.9, 0.6266404892996964}], 
             PointBox[{34., 0.6298854266163828}], 
             PointBox[{34.1, 0.6313348997164612}], 
             PointBox[{34.2, 0.6315501493334861}], 
             PointBox[{34.3, 0.6316211751783464}], 
             PointBox[{34.4, 0.6306142888161941}], 
             PointBox[{34.5, 0.6272339070617633}], 
             PointBox[{34.6, 0.6269673103119826}], 
             PointBox[{34.7, 0.629368759845037}], 
             PointBox[{34.8, 0.6278151447153622}], 
             PointBox[{34.9, 0.6270592237812758}], 
             PointBox[{35., 0.6302066715822955}], 
             PointBox[{35.1, 0.6318030104503108}], 
             PointBox[{35.2, 0.6319727760448961}], 
             PointBox[{35.3, 0.6319691777325998}], 
             PointBox[{35.4, 0.6310453797878506}], 
             PointBox[{35.5, 0.6277249140198731}], 
             PointBox[{35.6, 0.6272546616785643}], 
             PointBox[{35.7, 0.6296250287683801}], 
             PointBox[{35.8, 0.6279661395879962}], 
             PointBox[{35.9, 0.6270851298688833}], 
             PointBox[{36., 0.6301051739116938}], 
             PointBox[{36.1, 0.6318870702502195}], 
             PointBox[{36.2, 0.632013769968654}], 
             PointBox[{36.3, 0.6319444069998673}], 
             PointBox[{36.4, 0.6311116976245339}], 
             PointBox[{36.5, 0.6278660903690695}], 
             PointBox[{36.6, 0.627164939215427}], 
             PointBox[{36.7, 0.629493926391096}], 
             PointBox[{36.8, 0.6277447807046861}], 
             PointBox[{36.9, 0.6267504602595999}], 
             PointBox[{37., 0.6296340479018383}], 
             PointBox[{37.1, 0.6316039194076425}], 
             PointBox[{37.2, 0.6316772952951559}], 
             PointBox[{37.3, 0.6315420140366312}], 
             PointBox[{37.4, 0.6307780385848606}], 
             PointBox[{37.5, 0.6276109521991741}], 
             PointBox[{37.6, 0.6267173672306944}], 
             PointBox[{37.7, 0.628981159961672}], 
             PointBox[{37.8, 0.6270847917811578}], 
             PointBox[{37.9, 0.6260449641201801}], 
             PointBox[{38., 0.6288318123244663}], 
             PointBox[{38.1, 0.6309451310973002}], 
             PointBox[{38.2, 0.6309349896113761}], 
             PointBox[{38.3, 0.6307252360641499}], 
             PointBox[{38.4, 0.6299901787843657}], 
             PointBox[{38.5, 0.6268688209457922}], 
             PointBox[{38.6, 0.6259037690647885}], 
             PointBox[{38.7, 0.6280194837962081}], 
             PointBox[{38.8, 0.6259006259002178}], 
             PointBox[{38.9, 0.6249353925629171}], 
             PointBox[{39., 0.6277371344382137}], 
             PointBox[{39.1, 0.6298818567053595}], 
             PointBox[{39.2, 0.6297345061946062}], 
             PointBox[{39.3, 0.6294386709606657}], 
             PointBox[{39.4, 0.6286781940659459}], 
             PointBox[{39.5, 0.6255188897371072}], 
             PointBox[{39.6, 0.6247179371341978}], 
             PointBox[{39.7, 0.6264295972094236}], 
             PointBox[{39.8, 0.6241412524426769}], 
             PointBox[{39.9, 0.6234200909295928}], 
             PointBox[{40., 0.6264282110456575}], 
             PointBox[{40.1, 0.628383316398518}], 
             PointBox[{40.2, 0.6280315389609141}], 
             PointBox[{40.3, 0.6276392779085586}], 
             PointBox[{40.4, 0.6267770116092951}], 
             PointBox[{40.5, 0.6234572915270233}], 
             PointBox[{40.6, 0.6232148775111994}], 
             PointBox[{40.7, 0.6239913666759291}], 
             PointBox[{40.8, 0.6218976114493953}], 
             PointBox[{40.9, 0.621629372505358}], 
             PointBox[{41., 0.6250711463722428}], 
             PointBox[{41.1, 0.6264550068068246}], 
             PointBox[{41.2, 0.6258577018426664}], 
             PointBox[{41.3, 0.6253627141387285}], 
             PointBox[{41.4, 0.6242736131487278}], 
             PointBox[{41.5, 0.6207397490120048}], 
             PointBox[{41.6, 0.6214747001734267}], 
             PointBox[{41.7, 0.6209063558830664}], 
             PointBox[{41.8, 0.619499076966302}], 
             PointBox[{41.9, 0.6199311028545412}], 
             PointBox[{42., 0.623846451301645}], 
             PointBox[{42.1, 0.624193274306875}], 
             PointBox[{42.2, 0.6233877110238428}], 
             PointBox[{42.3, 0.6227774697023638}], 
             PointBox[{42.4, 0.621233069274277}], 
             PointBox[{42.5, 0.617860377126834}], 
             PointBox[{42.6, 0.6191303131200466}], 
             PointBox[{42.7, 0.6179884205093937}], 
             PointBox[{42.8, 0.617428582624354}], 
             PointBox[{42.9, 0.6189028342526781}], 
             PointBox[{43., 0.6226310276174021}], 
             PointBox[{43.1, 0.6218020339513622}], 
             PointBox[{43.2, 0.6208915352998196}], 
             PointBox[{43.3, 0.62011496601047}], 
             PointBox[{43.4, 0.6177533277250683}], 
             PointBox[{43.5, 0.6157903487662009}], 
             PointBox[{43.6, 0.6163556045760974}], 
             PointBox[{43.7, 0.615880840407474}], 
             PointBox[{43.8, 0.6161085534218239}], 
             PointBox[{43.9, 0.6190182703269816}], 
             PointBox[{44., 0.6210141436852347}], 
             PointBox[{44.1, 0.61951259861292}], 
             PointBox[{44.2, 0.6185775318502048}], 
             PointBox[{44.3, 0.6174869168274634}], 
             PointBox[{44.4, 0.6142078321487526}], 
             PointBox[{44.5, 0.614368111110336}], 
             PointBox[{44.6, 0.6145226902329386}], 
             PointBox[{44.7, 0.6147368705566124}], 
             PointBox[{44.8, 0.6158302268068897}], 
             PointBox[{44.9, 0.6197830175120449}], 
             PointBox[{45., 0.6190106218793233}], 
             PointBox[{45.1, 0.6174768035407295}], 
             PointBox[{45.2, 0.6165101798584292}], 
             PointBox[{45.3, 0.6148129665109795}], 
             PointBox[{45.4, 0.6120682123225619}], 
             PointBox[{45.5, 0.6131814839247226}], 
             PointBox[{45.6, 0.6137968830576677}], 
             PointBox[{45.7, 0.6145043533518736}], 
             PointBox[{45.8, 0.6167804947293296}], 
             PointBox[{45.9, 0.6194164684468482}], 
             PointBox[{46., 0.6170546248381632}], 
             PointBox[{46.1, 0.6157510452535828}], 
             PointBox[{46.2, 0.6146538366116493}], 
             PointBox[{46.3, 0.6121432336266436}], 
             PointBox[{46.4, 0.6116558228355345}], 
             PointBox[{46.5, 0.6130452759395135}], 
             PointBox[{46.6, 0.6139015844087758}], 
             PointBox[{46.7, 0.6151381361796012}], 
             PointBox[{46.8, 0.6185253276836945}], 
             PointBox[{46.9, 0.6176360548215131}], 
             PointBox[{47., 0.6154479739109198}], 
             PointBox[{47.1, 0.6143521763838051}], 
             PointBox[{47.2, 0.612967598130455}], 
             PointBox[{47.3, 0.6106585967109985}], 
             PointBox[{47.4, 0.612227814662504}], 
             PointBox[{47.5, 0.6136427483930591}], 
             PointBox[{47.6, 0.6146499574994009}], 
             PointBox[{47.7, 0.6166084835463759}], 
             PointBox[{47.8, 0.6190145217862063}], 
             PointBox[{47.9, 0.6158223333803353}], 
             PointBox[{48., 0.6143010217518329}], 
             PointBox[{48.1, 0.6133186682199182}], 
             PointBox[{48.2, 0.611645125359546}], 
             PointBox[{48.3, 0.6110777057249428}], 
             PointBox[{48.4, 0.6135401229219547}], 
             PointBox[{48.5, 0.6147159549886843}], 
             PointBox[{48.6, 0.6159454431640585}], 
             PointBox[{48.7, 0.6185525914439284}], 
             PointBox[{48.8, 0.617433446283495}], 
             PointBox[{48.9, 0.6146730745551321}], 
             PointBox[{49., 0.6136850717248828}], 
             PointBox[{49.1, 0.6127876909554493}], 
             PointBox[{49.2, 0.6113647099935547}], 
             PointBox[{49.3, 0.6131667395762387}], 
             PointBox[{49.4, 0.6151348160197756}], 
             PointBox[{49.5, 0.6161653817867646}], 
             PointBox[{49.6, 0.6177080637004296}], 
             PointBox[{49.7, 0.6195825212458136}], 
             PointBox[{49.8, 0.6158769639408805}], 
             PointBox[{49.9, 0.6143047483233716}], 
             PointBox[{50., 0.6137295663324025}], 
             PointBox[{50.1, 0.6131129749458696}], 
             PointBox[{50.2, 0.6124154426916655}], 
             PointBox[{50.3, 0.6156555428486153}], 
             PointBox[{50.4, 0.6169488953436383}], 
             PointBox[{50.5, 0.6179552016307832}], 
             PointBox[{50.6, 0.6197059378134586}], 
             PointBox[{50.7, 0.6188138040603929}], 
             PointBox[{50.8, 0.6154289897395974}], 
             PointBox[{50.9, 0.6147663265362907}], 
             PointBox[{51., 0.614683528872736}], 
             PointBox[{51.1, 0.6142590753098458}], 
             PointBox[{51.2, 0.6154825269537572}], 
             PointBox[{51.3, 0.6181075075624576}], 
             PointBox[{51.4, 0.6190163737035319}], 
             PointBox[{51.5, 0.6200481834415991}], 
             PointBox[{51.6, 0.6213860667896548}], 
             PointBox[{51.7, 0.6179799441237122}], 
             PointBox[{51.8, 0.6160904332179872}], 
             PointBox[{51.9, 0.6161622507646657}], 
             PointBox[{52., 0.616802110785002}], 
             PointBox[{52.1, 0.6157664267890165}], 
             PointBox[{52.2, 0.618963332510259}], 
             PointBox[{52.3, 0.620626703633638}], 
             PointBox[{52.4, 0.6213442477301259}], 
             PointBox[{52.5, 0.6223414063631807}], 
             PointBox[{52.6, 0.6223703917456299}], 
             PointBox[{52.7, 0.6183573732681292}], 
             PointBox[{52.8, 0.6176938956230537}], 
             PointBox[{52.9, 0.6185721032581029}], 
             PointBox[{53., 0.6192988234800872}], 
             PointBox[{53.1, 0.6186039997555784}], 
             PointBox[{53.2, 0.6221564232551536}], 
             PointBox[{53.3, 0.6232335440366594}], 
             PointBox[{53.4, 0.6238360404541133}], 
             PointBox[{53.5, 0.6246438780837551}], 
             PointBox[{53.6, 0.6231646910969689}], 
             PointBox[{53.7, 0.619781917125119}], 
             PointBox[{53.8, 0.6199872020469238}], 
             PointBox[{53.9, 0.6217168125031156}], 
             PointBox[{54., 0.621188479662491}], 
             PointBox[{54.1, 0.6218331619031224}], 
             PointBox[{54.2, 0.6249879234710685}], 
             PointBox[{54.3, 0.6257622804105264}], 
             PointBox[{54.4, 0.6262610708892261}], 
             PointBox[{54.5, 0.6267475148891682}], 
             PointBox[{54.6, 0.6243088316186705}], 
             PointBox[{54.7, 0.6216856780345364}], 
             PointBox[{54.8, 0.6225391946439828}], 
             PointBox[{54.9, 0.6246487590046209}], 
             PointBox[{55., 0.6229827164285902}], 
             PointBox[{55.1, 0.6245606299863274}], 
             PointBox[{55.2, 0.627349848504513}], 
             PointBox[{55.3, 0.6279661128770491}], 
             PointBox[{55.4, 0.6283550848652363}], 
             PointBox[{55.5, 0.628518990531239}], 
             PointBox[{55.6, 0.6256987446686634}], 
             PointBox[{55.7, 0.6235434923950756}], 
             PointBox[{55.8, 0.6248503819273065}], 
             PointBox[{55.9, 0.6266630952127251}], 
             PointBox[{56., 0.6245809338260956}], 
             PointBox[{56.1, 0.6265290341511804}], 
             PointBox[{56.2, 0.6291536145156854}], 
             PointBox[{56.3, 0.6296866089470525}], 
             PointBox[{56.4, 0.6299681814168895}], 
             PointBox[{56.5, 0.6299037692197621}], 
             PointBox[{56.6, 0.6270291799463781}], 
             PointBox[{56.7, 0.6250443317146884}], 
             PointBox[{56.8, 0.6266076493026875}], 
             PointBox[{56.9, 0.6279240113631466}], 
             PointBox[{57., 0.6257887771559472}], 
             PointBox[{57.1, 0.6277766543086342}], 
             PointBox[{57.2, 0.630403865373437}], 
             PointBox[{57.3, 0.6309002072156523}], 
             PointBox[{57.4, 0.6310868785813657}], 
             PointBox[{57.5, 0.6308967411994186}], 
             PointBox[{57.6, 0.6281229495843684}], 
             PointBox[{57.7, 0.6260956154771748}], 
             PointBox[{57.8, 0.6277537581391568}], 
             PointBox[{57.9, 0.6287068518479212}], 
             PointBox[{58., 0.6265738812508412}], 
             PointBox[{58.1, 0.6284240537321338}], 
             PointBox[{58.2, 0.6311596069650295}], 
             PointBox[{58.3, 0.6316536671745256}], 
             PointBox[{58.4, 0.6317597140936904}], 
             PointBox[{58.5, 0.6315123913013503}], 
             PointBox[{58.6, 0.6289161046830613}], 
             PointBox[{58.7, 0.6267191339148157}], 
             PointBox[{58.8, 0.6283664500998315}], 
             PointBox[{58.9, 0.6291224574848127}], 
             PointBox[{59., 0.6269681790195246}], 
             PointBox[{59.1, 0.628586702555568}], 
             PointBox[{59.2, 0.6314839657306799}], 
             PointBox[{59.3, 0.6320007069955113}], 
             PointBox[{59.4, 0.6320346733510166}], 
             PointBox[{59.5, 0.6317639612041278}], 
             PointBox[{59.6, 0.6293793228898729}], 
             PointBox[{59.7, 0.6269588745433138}], 
             PointBox[{59.8, 0.6285422153117635}], 
             PointBox[{59.9, 0.6291858495194222}], 
             PointBox[{60., 0.6269961813556494}], 
             PointBox[{60.1, 0.6283532588691444}], 
             PointBox[{60.2, 0.6314222612986087}], 
             PointBox[{60.3, 0.631971921721805}], 
             PointBox[{60.4, 0.6319354897885915}], 
             PointBox[{60.5, 0.6316488993901658}], 
             PointBox[{60.6, 0.6294735488393753}], 
             PointBox[{60.7, 0.6268334284109535}], 
             PointBox[{60.8, 0.628351671806388}], 
             PointBox[{60.9, 0.6288575638864476}], 
             PointBox[{61., 0.6266481568017025}], 
             PointBox[{61.1, 0.6277738432640688}], 
             PointBox[{61.2, 0.6309992235666336}], 
             PointBox[{61.3, 0.6315669897757342}], 
             PointBox[{61.4, 0.6314527064870898}], 
             PointBox[{61.5, 0.6311423235498614}], 
             PointBox[{61.6, 0.6291352244194556}], 
             PointBox[{61.7, 0.6263203858607261}], 
             PointBox[{61.8, 0.6278293946680583}], 
             PointBox[{61.9, 0.6280543092006133}], 
             PointBox[{62., 0.6258801008433404}], 
             PointBox[{62.1, 0.6268683286694834}], 
             PointBox[{62.2, 0.6302250114744063}], 
             PointBox[{62.3, 0.6307548683038736}], 
             PointBox[{62.4, 0.6305463936713167}], 
             PointBox[{62.5, 0.6301947525045596}], 
             PointBox[{62.6, 0.6282763165997758}], 
             PointBox[{62.7, 0.6253619394611523}], 
             PointBox[{62.8, 0.6269723483220724}], 
             PointBox[{62.9, 0.6266603417879486}], 
             PointBox[{63., 0.624637256238734}], 
             PointBox[{63.1, 0.625649279626297}], 
             PointBox[{63.2, 0.6291071148212569}], 
             PointBox[{63.3, 0.6294845357149798}], 
             PointBox[{63.4, 0.6291605436308683}], 
             PointBox[{63.5, 0.628745057183692}], 
             PointBox[{63.6, 0.6267890102215401}], 
             PointBox[{63.7, 0.6239026938516464}], 
             PointBox[{63.8, 0.6257113915558462}], 
             PointBox[{63.9, 0.6245958988324883}], 
             PointBox[{64., 0.6229176839114003}], 
             PointBox[{64.1, 0.6241930304357634}], 
             PointBox[{64.2, 0.627666357923974}], 
             PointBox[{64.3, 0.6277206846647658}], 
             PointBox[{64.4, 0.627266507583609}], 
             PointBox[{64.5, 0.6267560100190267}], 
             PointBox[{64.6, 0.6245736478013347}], 
             PointBox[{64.7, 0.6219932419828805}], 
             PointBox[{64.8, 0.6237844359356943}], 
             PointBox[{64.9, 0.6219885292893647}], 
             PointBox[{65., 0.6208763176678608}], 
             PointBox[{65.1, 0.6227467387236878}], 
             PointBox[{65.2, 0.6259393996732413}], 
             PointBox[{65.3, 0.6255141022499009}], 
             PointBox[{65.4, 0.6249358090189592}], 
             PointBox[{65.5, 0.6242766007688471}], 
             PointBox[{65.6, 0.6216071054069813}], 
             PointBox[{65.7, 0.6199499869036796}], 
             PointBox[{65.8, 0.6208872657140985}], 
             PointBox[{65.9, 0.6192834896788596}], 
             PointBox[{66., 0.6188939553282217}], 
             PointBox[{66.1, 0.6217397330745105}], 
             PointBox[{66.2, 0.623955118662238}], 
             PointBox[{66.3, 0.6230577218285981}], 
             PointBox[{66.4, 0.6223803219841196}], 
             PointBox[{66.5, 0.6214570009944114}], 
             PointBox[{66.6, 0.6181168544600256}], 
             PointBox[{66.7, 0.6181250741542826}], 
             PointBox[{66.8, 0.6177828574743928}], 
             PointBox[{66.9, 0.6170281746674704}], 
             PointBox[{67., 0.6174951937896496}], 
             PointBox[{67.1, 0.6213691964930147}], 
             PointBox[{67.2, 0.6217697224640725}], 
             PointBox[{67.3, 0.6206206493469792}], 
             PointBox[{67.4, 0.619852226452332}], 
             PointBox[{67.5, 0.6184170581764438}], 
             PointBox[{67.6, 0.61498153718204}], 
             PointBox[{67.7, 0.6159456316217025}], 
             PointBox[{67.8, 0.6155548589663005}], 
             PointBox[{67.9, 0.6155768389827833}], 
             PointBox[{68., 0.6171836208335415}], 
             PointBox[{68.1, 0.6209100327962591}], 
             PointBox[{68.2, 0.6195579966472263}], 
             PointBox[{68.3, 0.6183976267241461}], 
             PointBox[{68.4, 0.6174818527894069}], 
             PointBox[{68.5, 0.6151509455303593}], 
             PointBox[{68.6, 0.6134426727687585}], 
             PointBox[{68.7, 0.6141354801339435}], 
             PointBox[{68.8, 0.6143932651432273}], 
             PointBox[{68.9, 0.6150760372694883}], 
             PointBox[{69., 0.6181603577295407}], 
             PointBox[{69.1, 0.6194894536712409}], 
             PointBox[{69.2, 0.617535750334287}], 
             PointBox[{69.3, 0.6164551761170775}], 
             PointBox[{69.4, 0.6152291008899735}], 
             PointBox[{69.5, 0.6121338402174952}], 
             PointBox[{69.6, 0.6126097113314253}], 
             PointBox[{69.7, 0.6134682483382609}], 
             PointBox[{69.8, 0.6141385060542923}], 
             PointBox[{69.9, 0.6156133790243021}], 
             PointBox[{70., 0.6193203606234052}], 
             PointBox[{70.1, 0.6175252634986423}], 
             PointBox[{70.2, 0.6158303876827256}], 
             PointBox[{70.3, 0.6147860013184336}], 
             PointBox[{70.4, 0.6130017026100887}], 
             PointBox[{70.5, 0.6110155407742774}], 
             PointBox[{70.6, 0.6126087809771771}], 
             PointBox[{70.7, 0.6136489166998536}], 
             PointBox[{70.8, 0.6146526260316079}], 
             PointBox[{70.9, 0.6171826734676414}], 
             PointBox[{71., 0.6186113545922616}], 
             PointBox[{71.1, 0.6157815897283}], 
             PointBox[{71.2, 0.614494668113717}], 
             PointBox[{71.3, 0.613380918827894}], 
             PointBox[{71.4, 0.6111463769452028}], 
             PointBox[{71.5, 0.6114849746691764}], 
             PointBox[{71.6, 0.6133937595723568}], 
             PointBox[{71.7, 0.6144271490573987}], 
             PointBox[{71.8, 0.6158663769939087}], 
             PointBox[{71.9, 0.6189289650159348}], 
             PointBox[{72., 0.6166902493388003}], 
             PointBox[{72.1, 0.614565652095283}], 
             PointBox[{72.2, 0.613580900077012}], 
             PointBox[{72.3, 0.6123359435971505}], 
             PointBox[{72.4, 0.610756876387778}], 
             PointBox[{72.5, 0.6130991808687406}], 
             PointBox[{72.6, 0.6146070948281432}], 
             PointBox[{72.7, 0.6156813498121921}], 
             PointBox[{72.8, 0.6176715762108612}], 
             PointBox[{72.9, 0.6188198014805539}], 
             PointBox[{73., 0.6152356491899965}], 
             PointBox[{73.1, 0.613962530965086}], 
             PointBox[{73.2, 0.6132071122816357}], 
             PointBox[{73.3, 0.6120719750272924}], 
             PointBox[{73.4, 0.61226123056458}], 
             PointBox[{73.5, 0.6150175417284626}], 
             PointBox[{73.6, 0.6161388393257524}], 
             PointBox[{73.7, 0.6173466453053821}], 
             PointBox[{73.8, 0.619535211897296}], 
             PointBox[{73.9, 0.617222772028172}], 
             PointBox[{74., 0.6147140810042628}], 
             PointBox[{74.1, 0.6140645980418648}], 
             PointBox[{74.2, 0.6136419632488921}], 
             PointBox[{74.3, 0.6126476198283964}], 
             PointBox[{74.4, 0.6151687331880923}], 
             PointBox[{74.5, 0.6170453463154697}], 
             PointBox[{74.6, 0.6179723294964281}], 
             PointBox[{74.7, 0.6193379401457076}], 
             PointBox[{74.8, 0.620325919438914}], 
             PointBox[{74.9, 0.6163214309866969}], 
             PointBox[{75., 0.6151295950115833}], 
             PointBox[{75.1, 0.615049307874316}], 
             PointBox[{75.2, 0.615170200650018}], 
             PointBox[{75.3, 0.6146254407606663}], 
             PointBox[{75.4, 0.618088389256925}], 
             PointBox[{75.5, 0.6192542684543008}], 
             PointBox[{75.6, 0.6201028343600647}], 
             PointBox[{75.7, 0.6214405555948475}], 
             PointBox[{75.8, 0.6200102440305183}], 
             PointBox[{75.9, 0.6167081893957426}], 
             PointBox[{76., 0.6164788162728491}], 
             PointBox[{76.1, 0.6171466476400788}], 
             PointBox[{76.2, 0.6168752307309104}], 
             PointBox[{76.3, 0.6181408711403711}], 
             PointBox[{76.4, 0.6208885268444879}], 
             PointBox[{76.5, 0.6216781476844374}], 
             PointBox[{76.6, 0.6224709162465859}], 
             PointBox[{76.7, 0.6233453910191521}], 
             PointBox[{76.8, 0.6200769352512105}], 
             PointBox[{76.9, 0.6181403038001596}], 
             PointBox[{77., 0.6187259554155522}], 
             PointBox[{77.1, 0.6201389766977683}], 
             PointBox[{77.2, 0.6188033832373844}], 
             PointBox[{77.3, 0.6216927900234218}], 
             PointBox[{77.4, 0.6236238621045302}], 
             PointBox[{77.5, 0.6242154891141425}], 
             PointBox[{77.6, 0.6249058877569635}], 
             PointBox[{77.7, 0.6249624009837605}], 
             PointBox[{77.8, 0.6211201977401026}], 
             PointBox[{77.9, 0.6202213585665391}], 
             PointBox[{78., 0.6216056669440565}], 
             PointBox[{78.1, 0.6227033483542116}], 
             PointBox[{78.2, 0.6212995212648692}], 
             PointBox[{78.3, 0.6247129467538841}], 
             PointBox[{78.4, 0.6261601271772967}], 
             PointBox[{78.5, 0.6266257836447934}], 
             PointBox[{78.6, 0.6271553073071241}], 
             PointBox[{78.7, 0.6264517162607837}], 
             PointBox[{78.8, 0.6227226885752241}], 
             PointBox[{78.9, 0.6224695121650081}], 
             PointBox[{79., 0.6245028404182634}], 
             PointBox[{79.1, 0.6244318001098588}], 
             PointBox[{79.2, 0.6236293982534681}], 
             PointBox[{79.3, 0.627074321526477}], 
             PointBox[{79.4, 0.6282920993768076}], 
             PointBox[{79.5, 0.6286593027216789}], 
             PointBox[{79.6, 0.6290093292805646}], 
             PointBox[{79.7, 0.6278552065609367}], 
             PointBox[{79.8, 0.6243494491541639}], 
             PointBox[{79.9, 0.6244474318066998}], 
             PointBox[{80., 0.6268015599973349}], 
             PointBox[{80.1, 0.6257506963820302}], 
             PointBox[{80.2, 0.6253820913501463}], 
             PointBox[{80.3, 0.6287676427530795}], 
             PointBox[{80.4, 0.6299114693690383}], 
             PointBox[{80.5, 0.6301958367249298}], 
             PointBox[{80.6, 0.6303937261770773}], 
             PointBox[{80.7, 0.629072512644911}], 
             PointBox[{80.8, 0.625698894979136}], 
             PointBox[{80.9, 0.625925792201191}], 
             PointBox[{81., 0.6283364758467332}], 
             PointBox[{81.1, 0.6267407278925176}], 
             PointBox[{81.2, 0.6265139592550035}], 
             PointBox[{81.3, 0.629852992414389}], 
             PointBox[{81.4, 0.6310239145654576}], 
             PointBox[{81.5, 0.6312395096327522}], 
             PointBox[{81.6, 0.6313255384989368}], 
             PointBox[{81.7, 0.6300151983709132}], 
             PointBox[{81.8, 0.6266832868874201}], 
             PointBox[{81.9, 0.6268743156834828}], 
             PointBox[{82., 0.6292459909156125}], 
             PointBox[{82.1, 0.6273947448970227}], 
             PointBox[{82.2, 0.6271168027167192}], 
             PointBox[{82.3, 0.6304153046940484}], 
             PointBox[{82.4, 0.6316856126823197}], 
             PointBox[{82.5, 0.6318442422983348}], 
             PointBox[{82.6, 0.6318486201180886}], 
             PointBox[{82.7, 0.6306376557382001}], 
             PointBox[{82.8, 0.6273092464428731}], 
             PointBox[{82.9, 0.6273540947609574}], 
             PointBox[{83., 0.6296785374278255}], 
             PointBox[{83.1, 0.6277119064071395}], 
             PointBox[{83.2, 0.6272899307497671}], 
             PointBox[{83.3, 0.6305304441708857}], 
             PointBox[{83.4, 0.6319491369407243}], 
             PointBox[{83.5, 0.6320567354881089}], 
             PointBox[{83.6, 0.6319968664363766}], 
             PointBox[{83.7, 0.6309112353086155}], 
             PointBox[{83.8, 0.6275897260122504}], 
             PointBox[{83.9, 0.6274333010441725}], 
             PointBox[{84., 0.629711346286019}], 
             PointBox[{84.1, 0.6276762456021547}], 
             PointBox[{84.2, 0.6270943503813089}], 
             PointBox[{84.3, 0.6302552250045033}], 
             PointBox[{84.4, 0.6318423110370558}], 
             PointBox[{84.5, 0.6318952916792765}], 
             PointBox[{84.6, 0.6317757418333257}], 
             PointBox[{84.7, 0.630802013582242}], 
             PointBox[{84.8, 0.6275051738196935}], 
             PointBox[{84.9, 0.6271536288739804}], 
             PointBox[{85., 0.6293605430400817}], 
             PointBox[{85.1, 0.6272419015996857}], 
             PointBox[{85.2, 0.6265454760795138}], 
             PointBox[{85.3, 0.6296306774030104}], 
             PointBox[{85.4, 0.6313660359597385}], 
             PointBox[{85.5, 0.6313464490983393}], 
             PointBox[{85.6, 0.6311622588772896}], 
             PointBox[{85.7, 0.6302617008115047}], 
             PointBox[{85.8, 0.6269899579502048}], 
             PointBox[{85.9, 0.6265244186021521}], 
             PointBox[{86., 0.628579463426529}], 
             PointBox[{86.1, 0.6263345064668896}], 
             PointBox[{86.2, 0.6256224913792209}], 
             PointBox[{86.3, 0.6286900128987656}], 
             PointBox[{86.4, 0.6304950016485723}], 
             PointBox[{86.5, 0.6303661302180714}], 
             PointBox[{86.6, 0.6301068635805223}], 
             PointBox[{86.7, 0.6292233440828793}], 
             PointBox[{86.8, 0.6259385076219228}], 
             PointBox[{86.9, 0.625540263812748}], 
             PointBox[{87., 0.6272331076361809}], 
             PointBox[{87.1, 0.6248817901060806}], 
             PointBox[{87.2, 0.6243046169302517}], 
             PointBox[{87.3, 0.6274845980557205}], 
             PointBox[{87.4, 0.62919084919656}], 
             PointBox[{87.5, 0.6289000399164365}], 
             PointBox[{87.6, 0.6285537198786704}], 
             PointBox[{87.7, 0.6276106870225716}], 
             PointBox[{87.8, 0.6242364066946432}], 
             PointBox[{87.9, 0.6242196586048068}], 
             PointBox[{88., 0.6251169339966535}], 
             PointBox[{88.1, 0.6228929396206392}], 
             PointBox[{88.2, 0.6226495922015173}], 
             PointBox[{88.3, 0.6261219723623576}], 
             PointBox[{88.4, 0.6274313700490047}], 
             PointBox[{88.5, 0.6269328784387518}], 
             PointBox[{88.6, 0.6264890422066559}], 
             PointBox[{88.7, 0.6253702620673743}], 
             PointBox[{88.8, 0.6218596238786571}], 
             PointBox[{88.9, 0.6226110322259991}], 
             PointBox[{89., 0.6222442154528738}], 
             PointBox[{89.1, 0.6205744545850175}], 
             PointBox[{89.2, 0.6209124015325251}], 
             PointBox[{89.3, 0.6247609243206684}], 
             PointBox[{89.4, 0.6252694138699221}], 
             PointBox[{89.5, 0.624567167212689}], 
             PointBox[{89.6, 0.6240126034200303}], 
             PointBox[{89.7, 0.6225184609972175}], 
             PointBox[{89.8, 0.6191036928858374}], 
             PointBox[{89.9, 0.6204747366139793}], 
             PointBox[{90., 0.6192064733321949}], 
             PointBox[{90.1, 0.6183514430860234}], 
             PointBox[{90.2, 0.6195992647203693}], 
             PointBox[{90.3, 0.623418085454173}], 
             PointBox[{90.4, 0.6228783952818246}], 
             PointBox[{90.5, 0.6220425339700306}], 
             PointBox[{90.6, 0.6213367003222439}], 
             PointBox[{90.7, 0.6191388904212283}], 
             PointBox[{90.8, 0.6167773961646527}], 
             PointBox[{90.9, 0.6175844660802923}], 
             PointBox[{91., 0.616746528987988}], 
             PointBox[{91.1, 0.61670057927348}], 
             PointBox[{91.2, 0.6192729499385603}], 
             PointBox[{91.3, 0.6218143530869367}], 
             PointBox[{91.4, 0.6205032403932654}], 
             PointBox[{91.5, 0.6196143250401548}], 
             PointBox[{91.6, 0.6186390074272169}], 
             PointBox[{91.7, 0.6154907089106344}], 
             PointBox[{91.8, 0.6152419836741493}], 
             PointBox[{91.9, 0.6152494571015492}], 
             PointBox[{92., 0.6151984615452772}], 
             PointBox[{92.1, 0.6159932789055955}], 
             PointBox[{92.2, 0.6198493012195188}], 
             PointBox[{92.3, 0.6198341559717818}], 
             PointBox[{92.4, 0.618336417058025}], 
             PointBox[{92.5, 0.6174114955014732}], 
             PointBox[{92.6, 0.6159059651237068}], 
             PointBox[{92.7, 0.612724102360111}], 
             PointBox[{92.8, 0.6136938068677457}], 
             PointBox[{92.9, 0.6140721629513696}], 
             PointBox[{93., 0.6145868725212187}], 
             PointBox[{93.1, 0.6164975766371876}], 
             PointBox[{93.2, 0.619837961076946}], 
             PointBox[{93.3, 0.6178003512197181}], 
             PointBox[{93.4, 0.6164637689149698}], 
             PointBox[{93.5, 0.6154273953528562}], 
             PointBox[{93.6, 0.6130739130146475}], 
             PointBox[{93.7, 0.6119100323145967}], 
             PointBox[{93.8, 0.6130878466050501}], 
             PointBox[{93.9, 0.6138333736562904}], 
             PointBox[{94., 0.6148744309904183}], 
             PointBox[{94.1, 0.6180940568741555}], 
             PointBox[{94.2, 0.6183133833423614}], 
             PointBox[{94.3, 0.6160404671210375}], 
             PointBox[{94.4, 0.6149037206450908}], 
             PointBox[{94.5, 0.6135994997388791}], 
             PointBox[{94.6, 0.6109411996131487}], 
             PointBox[{94.7, 0.6119976250894886}], 
             PointBox[{94.8, 0.6133780823120409}], 
             PointBox[{94.9, 0.6143125070673631}], 
             PointBox[{95., 0.6160535074801597}], 
             PointBox[{95.1, 0.619149308553331}], 
             PointBox[{95.2, 0.6163863429847721}], 
             PointBox[{95.3, 0.6146956269646935}], 
             PointBox[{95.4, 0.6136738875564844}], 
             PointBox[{95.5, 0.6119836196336238}], 
             PointBox[{95.6, 0.6107630739330111}], 
             PointBox[{95.7, 0.6130207965075809}], 
             PointBox[{95.8, 0.6142354907300149}], 
             PointBox[{95.9, 0.6153901065710161}], 
             PointBox[{96., 0.6179377755557289}], 
             PointBox[{96.1, 0.6179756064711064}], 
             PointBox[{96.2, 0.6149738888223032}], 
             PointBox[{96.3, 0.6138326930596065}], 
             PointBox[{96.4, 0.6128552644318297}], 
             PointBox[{96.5, 0.6111970179029708}], 
             PointBox[{96.6, 0.6123265452756138}], 
             PointBox[{96.7, 0.6144525378187324}], 
             PointBox[{96.8, 0.615512840251084}], 
             PointBox[{96.9, 0.6169931815744756}], 
             PointBox[{97., 0.6194035620448729}], 
             PointBox[{97.1, 0.6161811638072295}], 
             PointBox[{97.2, 0.6142901534851578}], 
             PointBox[{97.3, 0.6135511738622467}], 
             PointBox[{97.4, 0.6127166533394269}], 
             PointBox[{97.5, 0.6116702740009791}], 
             PointBox[{97.6, 0.6146811235203796}], 
             PointBox[{97.7, 0.6161260233536382}], 
             PointBox[{97.8, 0.6171526677512033}], 
             PointBox[{97.9, 0.6189517181773476}], 
             PointBox[{98., 0.6189697163184479}], 
             PointBox[{98.1, 0.6153137139545458}], 
             PointBox[{98.2, 0.6143865010435098}], 
             PointBox[{98.3, 0.6140544988210647}], 
             PointBox[{98.4, 0.6135643353718485}], 
             PointBox[{98.5, 0.6142056375872248}], 
             PointBox[{98.6, 0.6170484075998854}], 
             PointBox[{98.7, 0.6180506144131271}], 
             PointBox[{98.8, 0.6191191577923963}], 
             PointBox[{98.9, 0.6207506883788795}], 
             PointBox[{99., 0.6178222532781518}], 
             PointBox[{99.1, 0.6155617536941077}], 
             PointBox[{99.2, 0.6153614017705533}], 
             PointBox[{99.3, 0.6156582177598812}], 
             PointBox[{99.4, 0.6147571083426454}], 
             PointBox[{99.5, 0.6176284168456798}], 
             PointBox[{99.6, 0.6194661687778446}], 
             PointBox[{99.7, 0.6202484874690819}], 
             PointBox[{99.8, 0.6213311378381174}], 
             PointBox[{99.9, 0.6217758555052438}], 
             PointBox[{100., 0.617731007285496}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0.6, 0.65}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.61}]], {189., -41.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 0.2}, {0, 0.2}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], 
             PointBox[{0, 0.19750000000000006`}], 
             PointBox[{0.1, 0.20155456748567904`}], 
             PointBox[{0.2, 0.20090651594250322`}], 
             PointBox[{0.3, 0.19908019719619066`}], 
             PointBox[{0.4, 0.19977832318423097`}], 
             PointBox[{0.5, 0.2031253120329808}], 
             PointBox[{0.6, 0.19872201322858168`}], 
             PointBox[{0.7, 0.2000081752191914}], 
             PointBox[{0.8, 0.20141438593212027`}], 
             PointBox[{0.9, 0.19926777711117152`}], 
             PointBox[{1., 0.19811412479023593`}], 
             PointBox[{1.1, 0.20036234848317458`}], 
             PointBox[{1.2, 0.19841163312038398`}], 
             PointBox[{1.3, 0.19721732980882656`}], 
             PointBox[{1.4, 0.20096089249287283`}], 
             PointBox[{1.5, 0.19869091033389863`}], 
             PointBox[{1.6, 0.1977050274599771}], 
             PointBox[{1.7, 0.1992951798805628}], 
             PointBox[{1.8, 0.19918254887938405`}], 
             PointBox[{1.9, 0.19428456025144544`}], 
             PointBox[{2., 0.1973480067848776}], 
             PointBox[{2.1, 0.1964226892373944}], 
             PointBox[{2.2, 0.19441851167853785`}], 
             PointBox[{2.3, 0.1949150448979892}], 
             PointBox[{2.4, 0.1989505195467981}], 
             PointBox[{2.5, 0.19418584145662965`}], 
             PointBox[{2.6, 0.19550057054362416`}], 
             PointBox[{2.7, 0.19616454389644458`}], 
             PointBox[{2.8, 0.19342812839634052`}], 
             PointBox[{2.9, 0.18958933817912116`}], 
             PointBox[{3., 0.19269831320026556`}], 
             PointBox[{3.1, 0.19038136147278403`}], 
             PointBox[{3.2, 0.18912552434238952`}], 
             PointBox[{3.3, 0.19188841923111957`}], 
             PointBox[{3.4, 0.19175123517332793`}], 
             PointBox[{3.5, 0.1896046423720966}], 
             PointBox[{3.6, 0.19105108895412598`}], 
             PointBox[{3.7, 0.18978643521999922`}], 
             PointBox[{3.8, 0.183998765037925}], 
             PointBox[{3.9, 0.18477954327494184`}], 
             PointBox[{4., 0.18482834994656264`}], 
             PointBox[{4.1, 0.18246697093603562`}], 
             PointBox[{4.2, 0.18245221433455291`}], 
             PointBox[{4.3, 0.18647079883531534`}], 
             PointBox[{4.4, 0.18262656425024926`}], 
             PointBox[{4.5, 0.18337020356723968`}], 
             PointBox[{4.6, 0.1836179596059109}], 
             PointBox[{4.7, 0.17958075446523314`}], 
             PointBox[{4.8, 0.17307684206882054`}], 
             PointBox[{4.9, 0.1766388815770932}], 
             PointBox[{5., 0.17464438477001176`}], 
             PointBox[{5.1, 0.1728011823442515}], 
             PointBox[{5.2, 0.174151601784906}], 
             PointBox[{5.3, 0.17723459661139523`}], 
             PointBox[{5.4, 0.1729289303876947}], 
             PointBox[{5.5, 0.17472123472734258`}], 
             PointBox[{5.6, 0.17302683259741883`}], 
             PointBox[{5.7, 0.16663080564848373`}], 
             PointBox[{5.8, 0.16243437997181473`}], 
             PointBox[{5.9, 0.16580527013285618`}], 
             PointBox[{6., 0.16306614742447803`}], 
             PointBox[{6.1, 0.16186396839548475`}], 
             PointBox[{6.2, 0.16427315172706855`}], 
             PointBox[{6.3, 0.16538400348346582`}], 
             PointBox[{6.4, 0.16233433932314317`}], 
             PointBox[{6.5, 0.16408233195952057`}], 
             PointBox[{6.6, 0.16037400688561632`}], 
             PointBox[{6.7, 0.15375997799282312`}], 
             PointBox[{6.8, 0.15196714537839506`}], 
             PointBox[{6.9, 0.15433666124687487`}], 
             PointBox[{7., 0.1514092401221702}], 
             PointBox[{7.1, 0.15073392559460577`}], 
             PointBox[{7.2, 0.15369734547368116`}], 
             PointBox[{7.3, 0.1533427601127046}], 
             PointBox[{7.4, 0.15143950894232783`}], 
             PointBox[{7.5, 0.15291485498077642`}], 
             PointBox[{7.6, 0.14818135179913614`}], 
             PointBox[{7.7, 0.14276186985913983`}], 
             PointBox[{7.8, 0.14229683393317488`}], 
             PointBox[{7.9, 0.1440446247174054}], 
             PointBox[{8., 0.14106234059305445`}], 
             PointBox[{8.1, 0.14069335901739416`}], 
             PointBox[{8.2, 0.14383428079283525`}], 
             PointBox[{8.3, 0.1428627965599429}], 
             PointBox[{8.4, 0.14148680361394936`}], 
             PointBox[{8.5, 0.14289819369922294`}], 
             PointBox[{8.6, 0.13848619102911214`}], 
             PointBox[{8.7, 0.1343344622517878}], 
             PointBox[{8.8, 0.1343086755424601}], 
             PointBox[{8.9, 0.13596419554569497`}], 
             PointBox[{9., 0.13292049141114998`}], 
             PointBox[{9.1, 0.13262952667483652`}], 
             PointBox[{9.2, 0.13576410979587566`}], 
             PointBox[{9.3, 0.13479937034021383`}], 
             PointBox[{9.4, 0.133424634941013}], 
             PointBox[{9.5, 0.13506625744024253`}], 
             PointBox[{9.6, 0.13172994795385956`}], 
             PointBox[{9.7, 0.12861190643103557`}], 
             PointBox[{9.8, 0.12847457824406938`}], 
             PointBox[{9.9, 0.1304224619564916}], 
             PointBox[{10., 0.12730340470845003`}], 
             PointBox[{10.1, 0.1269088042147929}], 
             PointBox[{10.2, 0.12994738417802934`}], 
             PointBox[{10.3, 0.12937818577887333`}], 
             PointBox[{10.4, 0.12765732464798055`}], 
             PointBox[{10.5, 0.12971775919844677`}], 
             PointBox[{10.6, 0.12767579337464355`}], 
             PointBox[{10.7, 0.12548428457235447`}], 
             PointBox[{10.8, 0.12493753662164414`}], 
             PointBox[{10.9, 0.1273816599583602}], 
             PointBox[{11., 0.12421240718282643`}], 
             PointBox[{11.1, 0.12359594478873569`}], 
             PointBox[{11.2, 0.12647392615215095`}], 
             PointBox[{11.3, 0.12650978702145427`}], 
             PointBox[{11.4, 0.12427431193069895`}], 
             PointBox[{11.5, 0.126798132139433}], 
             PointBox[{11.6, 0.12607053496257656`}], 
             PointBox[{11.7, 0.12480028360639041`}], 
             PointBox[{11.8, 0.12374454035945669`}], 
             PointBox[{11.9, 0.12671837383352524`}], 
             PointBox[{12., 0.12356089287669213`}], 
             PointBox[{12.1, 0.12267114999691771`}], 
             PointBox[{12.2, 0.12533818461370366`}], 
             PointBox[{12.3, 0.12603055708315342`}], 
             PointBox[{12.4, 0.12327954877922308`}], 
             PointBox[{12.5, 0.12621194088868504`}], 
             PointBox[{12.6, 0.12680526217236834`}], 
             PointBox[{12.7, 0.1264623363829413}], 
             PointBox[{12.8, 0.12496031718828526`}], 
             PointBox[{12.9, 0.12836620005823715`}], 
             PointBox[{13., 0.12528524592994514`}], 
             PointBox[{13.1, 0.1241354315632503}], 
             PointBox[{13.2, 0.12657319562857616`}], 
             PointBox[{13.3, 0.12783686939967123`}], 
             PointBox[{13.4, 0.12469359188584427`}], 
             PointBox[{13.5, 0.12796104211320397`}], 
             PointBox[{13.6, 0.12993260879582336`}], 
             PointBox[{13.7, 0.13045497826647365`}], 
             PointBox[{13.8, 0.12867353124233658`}], 
             PointBox[{13.9, 0.13236135012148426`}], 
             PointBox[{14., 0.1293706590412328}], 
             PointBox[{14.1, 0.1280371133823656}], 
             PointBox[{14.2, 0.13027776427468674`}], 
             PointBox[{14.3, 0.13193238300936785`}], 
             PointBox[{14.4, 0.1285657385745884}], 
             PointBox[{14.5, 0.13217052941127402`}], 
             PointBox[{14.6, 0.135628952319955}], 
             PointBox[{14.7, 0.13679942229249376`}], 
             PointBox[{14.8, 0.13493692777684216`}], 
             PointBox[{14.9, 0.13879000539266284`}], 
             PointBox[{15., 0.13580232177065127`}], 
             PointBox[{15.1, 0.13442533290318992`}], 
             PointBox[{15.2, 0.13655984924155554`}], 
             PointBox[{15.3, 0.13836336180102193`}], 
             PointBox[{15.4, 0.13493538624374077`}], 
             PointBox[{15.5, 0.1390462799884106}], 
             PointBox[{15.6, 0.1440315649644135}], 
             PointBox[{15.7, 0.14538930206040895`}], 
             PointBox[{15.8, 0.1436517156904993}], 
             PointBox[{15.9, 0.14759365604458302`}], 
             PointBox[{16., 0.1444199081665068}], 
             PointBox[{16.1, 0.1432124742416003}], 
             PointBox[{16.2, 0.1453795319059383}], 
             PointBox[{16.3, 0.1470208378270004}], 
             PointBox[{16.4, 0.14374538563723308`}], 
             PointBox[{16.5, 0.148747191686348}], 
             PointBox[{16.6, 0.1548091951281065}], 
             PointBox[{16.7, 0.1556868730547735}], 
             PointBox[{16.8, 0.15437262456259854`}], 
             PointBox[{16.9, 0.15819126423141824`}], 
             PointBox[{17., 0.1546773463743283}], 
             PointBox[{17.1, 0.15392400614326665`}], 
             PointBox[{17.2, 0.15627303116287553`}], 
             PointBox[{17.3, 0.15726929141681537`}], 
             PointBox[{17.4, 0.15471485657421852`}], 
             PointBox[{17.5, 0.16103050055072518`}], 
             PointBox[{17.6, 0.16665525129173664`}], 
             PointBox[{17.7, 0.16649690603122308`}], 
             PointBox[{17.8, 0.1662287762776428}], 
             PointBox[{17.9, 0.16914025082169998`}], 
             PointBox[{18., 0.16550922145378402`}], 
             PointBox[{18.1, 0.16550982475980244`}], 
             PointBox[{18.2, 0.16810882008346506`}], 
             PointBox[{18.3, 0.1676530320850301}], 
             PointBox[{18.4, 0.16722143437888126`}], 
             PointBox[{18.5, 0.17419413748965482`}], 
             PointBox[{18.6, 0.17758060336427095`}], 
             PointBox[{18.7, 0.17633520285248136`}], 
             PointBox[{18.8, 0.17817129336919518`}], 
             PointBox[{18.9, 0.17859762769392096`}], 
             PointBox[{19., 0.17567038908250016`}], 
             PointBox[{19.1, 0.1766048710208544}], 
             PointBox[{19.2, 0.1792580680782258}], 
             PointBox[{19.3, 0.1765572931066152}], 
             PointBox[{19.4, 0.17997862997306235`}], 
             PointBox[{19.5, 0.18521421001037058`}], 
             PointBox[{19.6, 0.1860924947164493}], 
             PointBox[{19.7, 0.18443021059177678`}], 
             PointBox[{19.8, 0.18870600058142276`}], 
             PointBox[{19.9, 0.1857181910416481}], 
             PointBox[{20., 0.18436545273160773`}], 
             PointBox[{20.1, 0.18616550117363162`}], 
             PointBox[{20.2, 0.18806586576166448`}], 
             PointBox[{20.3, 0.18442481814898065`}], 
             PointBox[{20.4, 0.19046531528999527`}], 
             PointBox[{20.5, 0.1927154083813147}], 
             PointBox[{20.6, 0.19183385761309582`}], 
             PointBox[{20.7, 0.19140788394836655`}], 
             PointBox[{20.8, 0.19524198284111527`}], 
             PointBox[{20.9, 0.19102042291936275`}], 
             PointBox[{21., 0.1913936646379956}], 
             PointBox[{21.1, 0.19366712227166857`}], 
             PointBox[{21.2, 0.19312193308067524`}], 
             PointBox[{21.3, 0.19278747815725678`}], 
             PointBox[{21.4, 0.19708051013732628`}], 
             PointBox[{21.5, 0.19699064744168562`}], 
             PointBox[{21.6, 0.19539218147202123`}], 
             PointBox[{21.7, 0.1983206535745417}], 
             PointBox[{21.8, 0.1974326631831065}], 
             PointBox[{21.9, 0.19520574371266883`}], 
             PointBox[{22., 0.19678225897654844`}], 
             PointBox[{22.1, 0.19864914337723757`}], 
             PointBox[{22.2, 0.1950348028856219}], 
             PointBox[{22.3, 0.19900152919793918`}], 
             PointBox[{22.4, 0.2002097424409477}], 
             PointBox[{22.5, 0.19879892862442855`}], 
             PointBox[{22.6, 0.19805091120201387`}], 
             PointBox[{22.7, 0.20280970064259568`}], 
             PointBox[{22.8, 0.19816925293730014`}], 
             PointBox[{22.9, 0.19844866932633498`}], 
             PointBox[{23., 0.2004175160076783}], 
             PointBox[{23.1, 0.2002832049065693}], 
             PointBox[{23.2, 0.19778066334717906`}], 
             PointBox[{23.3, 0.20167752244290177`}], 
             PointBox[{23.4, 0.20069359920511487`}], 
             PointBox[{23.5, 0.19901751135697357`}], 
             PointBox[{23.6, 0.2011849312511887}], 
             PointBox[{23.7, 0.20177250103549543`}], 
             PointBox[{23.8, 0.1989118700490223}], 
             PointBox[{23.9, 0.2004910098795919}], 
             PointBox[{24., 0.20184203411705354`}], 
             PointBox[{24.1, 0.19848348710812813`}], 
             PointBox[{24.2, 0.2003840016689513}], 
             PointBox[{24.3, 0.20118285139060713`}], 
             PointBox[{24.4, 0.1992937192312384}], 
             PointBox[{24.5, 0.1986118695145425}], 
             PointBox[{24.6, 0.2033365564798368}], 
             PointBox[{24.7, 0.19891430437961047`}], 
             PointBox[{24.8, 0.19921579719583118`}], 
             PointBox[{24.9, 0.20082127858702045`}], 
             PointBox[{25., 0.20026205050226423`}], 
             PointBox[{25.1, 0.19604402481613295`}], 
             PointBox[{25.2, 0.19989055990887747`}], 
             PointBox[{25.3, 0.1983319193344563}], 
             PointBox[{25.4, 0.19660618608276653`}], 
             PointBox[{25.5, 0.1983027761053009}], 
             PointBox[{25.6, 0.2001799980327151}], 
             PointBox[{25.7, 0.196602424226969}], 
             PointBox[{25.8, 0.19817816913331693`}], 
             PointBox[{25.9, 0.19873477404623632`}], 
             PointBox[{26., 0.1951735218926001}], 
             PointBox[{26.1, 0.19476840988359256`}], 
             PointBox[{26.2, 0.19593308955503308`}], 
             PointBox[{26.3, 0.19368804866298095`}], 
             PointBox[{26.4, 0.19301643688748102`}], 
             PointBox[{26.5, 0.19712147024311533`}], 
             PointBox[{26.6, 0.19380036029226141`}], 
             PointBox[{26.7, 0.19376027257780806`}], 
             PointBox[{26.8, 0.19492505338841093`}], 
             PointBox[{26.9, 0.19339228956230964`}], 
             PointBox[{27., 0.1875316737611147}], 
             PointBox[{27.1, 0.19097313518196637`}], 
             PointBox[{27.2, 0.18936241256450032`}], 
             PointBox[{27.3, 0.1874579799077812}], 
             PointBox[{27.4, 0.18851762299008978`}], 
             PointBox[{27.5, 0.1919231399223567}], 
             PointBox[{27.6, 0.1874249275927573}], 
             PointBox[{27.7, 0.18901035774141542`}], 
             PointBox[{27.8, 0.18864598718173822`}], 
             PointBox[{27.9, 0.18416651505569095`}], 
             PointBox[{28., 0.18033441490039667`}], 
             PointBox[{28.1, 0.1832421742669431}], 
             PointBox[{28.2, 0.18066531331063915`}], 
             PointBox[{28.3, 0.1796120812146263}], 
             PointBox[{28.4, 0.1824402987408776}], 
             PointBox[{28.5, 0.1822497997419004}], 
             PointBox[{28.6, 0.18021691460562336`}], 
             PointBox[{28.7, 0.18153791599450692`}], 
             PointBox[{28.8, 0.1787709163055313}], 
             PointBox[{28.9, 0.1719733078934021}], 
             PointBox[{29., 0.1723232187003224}], 
             PointBox[{29.1, 0.172749227749939}], 
             PointBox[{29.2, 0.17019837592035103`}], 
             PointBox[{29.3, 0.17016574000245244`}], 
             PointBox[{29.4, 0.17386934565415624`}], 
             PointBox[{29.5, 0.170794256969242}], 
             PointBox[{29.6, 0.17114564462795887`}], 
             PointBox[{29.7, 0.17130097631010682`}], 
             PointBox[{29.8, 0.16597108381973627`}], 
             PointBox[{29.9, 0.15941840684392855`}], 
             PointBox[{30., 0.1622265448643908}], 
             PointBox[{30.1, 0.16095954759288264`}], 
             PointBox[{30.2, 0.15872775433812453`}], 
             PointBox[{30.3, 0.15959447645760771`}], 
             PointBox[{30.4, 0.16310071635842815`}], 
             PointBox[{30.5, 0.1590367382791005}], 
             PointBox[{30.6, 0.16055408033423257`}], 
             PointBox[{30.7, 0.15938761878724925`}], 
             PointBox[{30.8, 0.1530656805621622}], 
             PointBox[{30.9, 0.14797534118525668`}], 
             PointBox[{31., 0.15152238230960433`}], 
             PointBox[{31.1, 0.14947986052451392`}], 
             PointBox[{31.2, 0.14753306985274534`}], 
             PointBox[{31.3, 0.14899498926945948`}], 
             PointBox[{31.4, 0.15193541321513368`}], 
             PointBox[{31.5, 0.1478579459865001}], 
             PointBox[{31.6, 0.14982747154838058`}], 
             PointBox[{31.7, 0.14782288328822252`}], 
             PointBox[{31.8, 0.14233570353084532`}], 
             PointBox[{31.9, 0.1383373567518215}], 
             PointBox[{32., 0.1419901349854418}], 
             PointBox[{32.1, 0.1396750076996668}], 
             PointBox[{32.2, 0.1378577370218321}], 
             PointBox[{32.3, 0.13959536380186974`}], 
             PointBox[{32.4, 0.1421768327325916}], 
             PointBox[{32.5, 0.13824648904565662`}], 
             PointBox[{32.6, 0.14040678214547367`}], 
             PointBox[{32.7, 0.13835127946773113`}], 
             PointBox[{32.8, 0.13437015949823367`}], 
             PointBox[{32.9, 0.1309353719913537}], 
             PointBox[{33., 0.13458096394168312`}], 
             PointBox[{33.1, 0.13227224697597242`}], 
             PointBox[{33.2, 0.13041670636422045`}], 
             PointBox[{33.3, 0.1321856851701902}], 
             PointBox[{33.4, 0.134720841354505}], 
             PointBox[{33.5, 0.13087358006311017`}], 
             PointBox[{33.6, 0.1331039964165806}], 
             PointBox[{33.7, 0.13161859165376494`}], 
             PointBox[{33.8, 0.12913648809700778`}], 
             PointBox[{33.9, 0.12595235569500432`}], 
             PointBox[{34., 0.129547860123832}], 
             PointBox[{34.1, 0.12745521484820715`}], 
             PointBox[{34.2, 0.12543302197363418`}], 
             PointBox[{34.3, 0.12706925095712296`}], 
             PointBox[{34.4, 0.12975510811271843`}], 
             PointBox[{34.5, 0.1259884471109877}], 
             PointBox[{34.6, 0.1281534358897646}], 
             PointBox[{34.7, 0.12755629441987315`}], 
             PointBox[{34.8, 0.1264440578140664}], 
             PointBox[{34.9, 0.12341560887405313`}], 
             PointBox[{35., 0.12684908370833808`}], 
             PointBox[{35.1, 0.12515757691697577`}], 
             PointBox[{35.2, 0.12289861288887025`}], 
             PointBox[{35.3, 0.12430169423472673`}], 
             PointBox[{35.4, 0.12718991272121966`}], 
             PointBox[{35.5, 0.12360784466875205`}], 
             PointBox[{35.6, 0.12554385695048934`}], 
             PointBox[{35.7, 0.1259505367754758}], 
             PointBox[{35.8, 0.12612687802212816`}], 
             PointBox[{35.9, 0.12330194796126621`}], 
             PointBox[{36., 0.1264230512480691}], 
             PointBox[{36.1, 0.12526914235810288`}], 
             PointBox[{36.2, 0.12276251841573506`}], 
             PointBox[{36.3, 0.12389142615515632`}], 
             PointBox[{36.4, 0.12693173923956205`}], 
             PointBox[{36.5, 0.12367466609948642`}], 
             PointBox[{36.6, 0.12525395282504415`}], 
             PointBox[{36.7, 0.12668844010979421`}], 
             PointBox[{36.8, 0.12812351236760924`}], 
             PointBox[{36.9, 0.12559598436795263`}], 
             PointBox[{37., 0.12830749324729898`}], 
             PointBox[{37.1, 0.12772677541196256`}], 
             PointBox[{37.2, 0.12500902282475385`}], 
             PointBox[{37.3, 0.12588330884233015`}], 
             PointBox[{37.4, 0.12898754133977627`}], 
             PointBox[{37.5, 0.1261305614755169}], 
             PointBox[{37.6, 0.12734394893244388`}], 
             PointBox[{37.7, 0.12981924676330853`}], 
             PointBox[{37.8, 0.13248321895820397`}], 
             PointBox[{37.9, 0.13030011870706668`}], 
             PointBox[{38., 0.13264392355509041`}], 
             PointBox[{38.1, 0.13252204125382214`}], 
             PointBox[{38.2, 0.1296637409142577}], 
             PointBox[{38.3, 0.13036875910648868`}], 
             PointBox[{38.4, 0.13346031747297124`}], 
             PointBox[{38.5, 0.13093095157435844`}], 
             PointBox[{38.6, 0.13195814243513582`}], 
             PointBox[{38.7, 0.1355539471013503}], 
             PointBox[{38.8, 0.139286395955174}], 
             PointBox[{38.9, 0.13738167728968134`}], 
             PointBox[{39., 0.13958513485592866`}], 
             PointBox[{39.1, 0.13962290787858941`}], 
             PointBox[{39.2, 0.13672719455008006`}], 
             PointBox[{39.3, 0.13741193014796504`}], 
             PointBox[{39.4, 0.1404495956752382}], 
             PointBox[{39.5, 0.1379923386789162}], 
             PointBox[{39.6, 0.13925701355214043`}], 
             PointBox[{39.7, 0.1441637875747048}], 
             PointBox[{39.8, 0.14841497092599862`}], 
             PointBox[{39.9, 0.14660767919158582`}], 
             PointBox[{40., 0.14908605825378304`}], 
             PointBox[{40.1, 0.1487673044851178}], 
             PointBox[{40.2, 0.14600567232287973`}], 
             PointBox[{40.3, 0.1468724871666044}], 
             PointBox[{40.4, 0.1498251887472252}], 
             PointBox[{40.5, 0.14703317026204588`}], 
             PointBox[{40.6, 0.14925811595827335`}], 
             PointBox[{40.7, 0.1555167836174165}], 
             PointBox[{40.8, 0.15918282567358527`}], 
             PointBox[{40.9, 0.1572943649739029}], 
             PointBox[{41., 0.16056661095834043`}], 
             PointBox[{41.1, 0.15917944165412923`}], 
             PointBox[{41.2, 0.15686220803955794`}], 
             PointBox[{41.3, 0.15812969752800995`}], 
             PointBox[{41.4, 0.16087358482058153`}], 
             PointBox[{41.5, 0.15741465576961375`}], 
             PointBox[{41.6, 0.16154912322018558`}], 
             PointBox[{41.7, 0.16816053052173024`}], 
             PointBox[{41.8, 0.17015138956649736`}], 
             PointBox[{41.9, 0.16829990226941305`}], 
             PointBox[{42., 0.17254440201981439`}], 
             PointBox[{42.1, 0.1695638214000533}], 
             PointBox[{42.2, 0.16813213934391943`}], 
             PointBox[{42.3, 0.1699544598615606}], 
             PointBox[{42.4, 0.17203573896923616`}], 
             PointBox[{42.5, 0.1684331837664705}], 
             PointBox[{42.6, 0.17479887631068386`}], 
             PointBox[{42.7, 0.1796029239807965}], 
             PointBox[{42.8, 0.1796840306645451}], 
             PointBox[{42.9, 0.1787138812450275}], 
             PointBox[{43., 0.1826999347265116}], 
             PointBox[{43.1, 0.17874540709832026`}], 
             PointBox[{43.2, 0.17854911955514371`}], 
             PointBox[{43.3, 0.18089004794365207`}], 
             PointBox[{43.4, 0.18120085375190473`}], 
             PointBox[{43.5, 0.17986561818878907`}], 
             PointBox[{43.6, 0.18623118634486763`}], 
             PointBox[{43.7, 0.18820353230282205`}], 
             PointBox[{43.8, 0.18691746073658297`}], 
             PointBox[{43.9, 0.18850479890186134`}], 
             PointBox[{44., 0.18936792514856504`}], 
             PointBox[{44.1, 0.1862985601787527}], 
             PointBox[{44.2, 0.18734052066416867`}], 
             PointBox[{44.3, 0.189783705646494}], 
             PointBox[{44.4, 0.18712822609721627`}], 
             PointBox[{44.5, 0.19039139347186412`}], 
             PointBox[{44.6, 0.19394934255367627`}], 
             PointBox[{44.7, 0.19373100994389494`}], 
             PointBox[{44.8, 0.19222657776907506`}], 
             PointBox[{44.9, 0.19676438984713468`}], 
             PointBox[{45., 0.1932887822308414}], 
             PointBox[{45.1, 0.19234006779716437`}], 
             PointBox[{45.2, 0.1942529023613562}], 
             PointBox[{45.3, 0.19565724195706832`}], 
             PointBox[{45.4, 0.19217490978502402`}], 
             PointBox[{45.5, 0.19746078838315392`}], 
             PointBox[{45.6, 0.1981892879437563}], 
             PointBox[{45.7, 0.19675527786313293`}], 
             PointBox[{45.8, 0.19705580115414742`}], 
             PointBox[{45.9, 0.20026461486619318`}], 
             PointBox[{46., 0.19611630605963026`}], 
             PointBox[{46.1, 0.19701096431292317`}], 
             PointBox[{46.2, 0.19910515449613067`}], 
             PointBox[{46.3, 0.19760683064441945`}], 
             PointBox[{46.4, 0.19793082778687413`}], 
             PointBox[{46.5, 0.2008355755138139}], 
             PointBox[{46.6, 0.199755483487782}], 
             PointBox[{46.7, 0.1982635249388989}], 
             PointBox[{46.8, 0.20211748173033797`}], 
             PointBox[{46.9, 0.19978442798939738`}], 
             PointBox[{47., 0.19843747619215782`}], 
             PointBox[{47.1, 0.20022284005378344`}], 
             PointBox[{47.2, 0.20136291818259075`}], 
             PointBox[{47.3, 0.1973646201481926}], 
             PointBox[{47.4, 0.20131570868251936`}], 
             PointBox[{47.5, 0.20124576246447495`}], 
             PointBox[{47.6, 0.19945498298102932`}], 
             PointBox[{47.7, 0.199545106616157}], 
             PointBox[{47.8, 0.20368852975476318`}], 
             PointBox[{47.9, 0.1989584967972892}], 
             PointBox[{48., 0.19994148158756114`}], 
             PointBox[{48.1, 0.20159319748370413`}], 
             PointBox[{48.2, 0.20020676140689284`}], 
             PointBox[{48.3, 0.19826993687896308`}], 
             PointBox[{48.4, 0.2012197887517432}], 
             PointBox[{48.5, 0.19949177531673}], 
             PointBox[{48.6, 0.19805304259671622`}], 
             PointBox[{48.7, 0.20123319246786964`}], 
             PointBox[{48.8, 0.200093029764353}], 
             PointBox[{48.9, 0.1983466000996931}], 
             PointBox[{49., 0.20000751230689523`}], 
             PointBox[{49.1, 0.2004397241012189}], 
             PointBox[{49.2, 0.1960604365033129}], 
             PointBox[{49.3, 0.19855261153837098`}], 
             PointBox[{49.4, 0.1982073079808246}], 
             PointBox[{49.5, 0.19615793015694288`}], 
             PointBox[{49.6, 0.1961975183557546}], 
             PointBox[{49.7, 0.2006362036156182}], 
             PointBox[{49.8, 0.19584883021081945`}], 
             PointBox[{49.9, 0.19686577004575617`}], 
             PointBox[{50., 0.19790367356967853`}], 
             PointBox[{50.1, 0.19595105344349278`}], 
             PointBox[{50.2, 0.19164755280231924`}], 
             PointBox[{50.3, 0.19514958875167188`}], 
             PointBox[{50.4, 0.1930200213957711}], 
             PointBox[{50.5, 0.19155780165035574`}], 
             PointBox[{50.6, 0.19392198352732187`}], 
             PointBox[{50.7, 0.19464711759751913`}], 
             PointBox[{50.8, 0.19186908868231684`}], 
             PointBox[{50.9, 0.1934252214478495}], 
             PointBox[{51., 0.19280970203351552`}], 
             PointBox[{51.1, 0.18774490487056184`}], 
             PointBox[{51.2, 0.18783080889230566`}], 
             PointBox[{51.3, 0.188351917059882}], 
             PointBox[{51.4, 0.1859766917685182}], 
             PointBox[{51.5, 0.18571168131523996`}], 
             PointBox[{51.6, 0.18973633039800297`}], 
             PointBox[{51.7, 0.18617172321005887`}], 
             PointBox[{51.8, 0.18659227682587837`}], 
             PointBox[{51.9, 0.1871816608269307}], 
             PointBox[{52., 0.1839684803575254}], 
             PointBox[{52.1, 0.1774320610183038}], 
             PointBox[{52.2, 0.18088163485302503`}], 
             PointBox[{52.3, 0.17904908970411534`}], 
             PointBox[{52.4, 0.1771515065874489}], 
             PointBox[{52.5, 0.1783519354696345}], 
             PointBox[{52.6, 0.18162941127235843`}], 
             PointBox[{52.7, 0.17722611281891834`}], 
             PointBox[{52.8, 0.17894544213061478`}], 
             PointBox[{52.9, 0.17766495192387194`}], 
             PointBox[{53., 0.17171119662192905`}], 
             PointBox[{53.1, 0.16732867952881378`}], 
             PointBox[{53.2, 0.17067547188289836`}], 
             PointBox[{53.3, 0.16797582140811138`}], 
             PointBox[{53.4, 0.16678250340814496`}], 
             PointBox[{53.5, 0.16922331149806946`}], 
             PointBox[{53.6, 0.17019744312023496`}], 
             PointBox[{53.7, 0.1672670638526678}], 
             PointBox[{53.8, 0.1689146798440348}], 
             PointBox[{53.9, 0.16539243613374974`}], 
             PointBox[{54., 0.15855044252163952`}], 
             PointBox[{54.1, 0.1570646742834542}], 
             PointBox[{54.2, 0.15908098566974024`}], 
             PointBox[{54.3, 0.15621026283712142`}], 
             PointBox[{54.4, 0.15566565353608394`}], 
             PointBox[{54.5, 0.15878486570711692`}], 
             PointBox[{54.6, 0.15787188606895186`}], 
             PointBox[{54.7, 0.15645177799472185`}], 
             PointBox[{54.8, 0.15762649915923926`}], 
             PointBox[{54.9, 0.15259837443867857`}], 
             PointBox[{55., 0.14670871640426725`}], 
             PointBox[{55.1, 0.1469616982878523}], 
             PointBox[{55.2, 0.14803466335420049`}], 
             PointBox[{55.3, 0.1451643760900656}], 
             PointBox[{55.4, 0.1450590786512186}], 
             PointBox[{55.5, 0.1483847313700294}], 
             PointBox[{55.6, 0.14658122832634243`}], 
             PointBox[{55.7, 0.14596561127061075`}], 
             PointBox[{55.8, 0.14684718715541858`}], 
             PointBox[{55.9, 0.14184035577342644`}], 
             PointBox[{56., 0.137192249129921}], 
             PointBox[{56.1, 0.1381280153258635}], 
             PointBox[{56.2, 0.1388834597445878}], 
             PointBox[{56.3, 0.13598677127658332`}], 
             PointBox[{56.4, 0.13607192555116393`}], 
             PointBox[{56.5, 0.13939396629117748`}], 
             PointBox[{56.6, 0.13742184609409902`}], 
             PointBox[{56.7, 0.13700405721353026`}], 
             PointBox[{56.8, 0.1379747383484669}], 
             PointBox[{56.9, 0.1340069525526488}], 
             PointBox[{57., 0.1303254643427426}], 
             PointBox[{57.1, 0.13129304401709205`}], 
             PointBox[{57.2, 0.13221151603436257`}], 
             PointBox[{57.3, 0.12922790573619536`}], 
             PointBox[{57.4, 0.12928974510911753`}], 
             PointBox[{57.5, 0.1325445388949297}], 
             PointBox[{57.6, 0.1308421718086312}], 
             PointBox[{57.7, 0.13020124968638774`}], 
             PointBox[{57.8, 0.13157828284387296`}], 
             PointBox[{57.9, 0.1289623798774362}], 
             PointBox[{58., 0.12608887247814068`}], 
             PointBox[{58.1, 0.12670391784451537`}], 
             PointBox[{58.2, 0.12809616992673215`}], 
             PointBox[{58.3, 0.12499840687924799`}], 
             PointBox[{58.4, 0.1248854545698692}], 
             PointBox[{58.5, 0.12803397086794707`}], 
             PointBox[{58.6, 0.12687576096326939`}], 
             PointBox[{58.7, 0.12574287374192583`}], 
             PointBox[{58.8, 0.1276808207912464}], 
             PointBox[{58.9, 0.12643273988817527`}], 
             PointBox[{59., 0.12435109586975346`}], 
             PointBox[{59.1, 0.12440984216923681`}], 
             PointBox[{59.2, 0.12642614120571816`}], 
             PointBox[{59.3, 0.12323510454278452`}], 
             PointBox[{59.4, 0.12286408995858829`}], 
             PointBox[{59.5, 0.12585831782488116`}], 
             PointBox[{59.6, 0.12538668907513903`}], 
             PointBox[{59.7, 0.12364540245067489`}], 
             PointBox[{59.8, 0.1261584078970839}], 
             PointBox[{59.9, 0.1262522262128119}], 
             PointBox[{60., 0.12499468611939236`}], 
             PointBox[{60.1, 0.12445977689241941`}], 
             PointBox[{60.2, 0.12709425437083813`}], 
             PointBox[{60.3, 0.12386359435110515`}], 
             PointBox[{60.4, 0.12321622731311432`}], 
             PointBox[{60.5, 0.12601615471324057`}], 
             PointBox[{60.6, 0.12623390801665738`}], 
             PointBox[{60.7, 0.12392028641474837`}], 
             PointBox[{60.8, 0.12694858058116712`}], 
             PointBox[{60.9, 0.1284081408785632}], 
             PointBox[{61., 0.12796833216961748`}], 
             PointBox[{61.1, 0.12694708634200755`}], 
             PointBox[{61.2, 0.13007804326690828`}], 
             PointBox[{61.3, 0.12685338315151573`}], 
             PointBox[{61.4, 0.1259764694410278}], 
             PointBox[{61.5, 0.12857737251371798`}], 
             PointBox[{61.6, 0.12935464196567695`}], 
             PointBox[{61.7, 0.12662259968112868`}], 
             PointBox[{61.8, 0.13011882226080282`}], 
             PointBox[{61.9, 0.13302554695031293`}], 
             PointBox[{62., 0.13328035921382234`}], 
             PointBox[{62.1, 0.1319788954477058}], 
             PointBox[{62.2, 0.1354335220879826}], 
             PointBox[{62.3, 0.1322058316956305}], 
             PointBox[{62.4, 0.13121143179953224`}], 
             PointBox[{62.5, 0.1336617655095008}], 
             PointBox[{62.6, 0.13476571487909306`}], 
             PointBox[{62.7, 0.13183276534347313`}], 
             PointBox[{62.8, 0.13585624035485994`}], 
             PointBox[{62.9, 0.14026820376879215`}], 
             PointBox[{63., 0.14090149348068534`}], 
             PointBox[{63.1, 0.13957802815050088`}], 
             PointBox[{63.2, 0.1431769631842278}], 
             PointBox[{63.3, 0.1398604073662897}], 
             PointBox[{63.4, 0.1389294320758731}], 
             PointBox[{63.5, 0.14133097773150372`}], 
             PointBox[{63.6, 0.14243841268755267`}], 
             PointBox[{63.7, 0.13959018853632504`}], 
             PointBox[{63.8, 0.1443889761332822}], 
             PointBox[{63.9, 0.15004298150852197`}], 
             PointBox[{64., 0.15052662062945119`}], 
             PointBox[{64.1, 0.1495152844722785}], 
             PointBox[{64.2, 0.1529926832247257}], 
             PointBox[{64.3, 0.14949246759496493`}], 
             PointBox[{64.4, 0.14887465840755706`}], 
             PointBox[{64.5, 0.15135847756842075`}], 
             PointBox[{64.6, 0.15200781296038154`}], 
             PointBox[{64.7, 0.14977001035758553`}], 
             PointBox[{64.8, 0.15574363361089963`}], 
             PointBox[{64.9, 0.1614995397728268}], 
             PointBox[{65., 0.16127219164895693`}], 
             PointBox[{65.1, 0.1611305271858598}], 
             PointBox[{65.2, 0.16384306849358224`}], 
             PointBox[{65.3, 0.16028521218022618`}], 
             PointBox[{65.4, 0.16026779279927014`}], 
             PointBox[{65.5, 0.16292328889139776`}], 
             PointBox[{65.6, 0.16240528264633977`}], 
             PointBox[{65.7, 0.1619086413188616}], 
             PointBox[{65.8, 0.168870472233585}], 
             PointBox[{65.9, 0.17289549582227154`}], 
             PointBox[{66., 0.17172527859559608`}], 
             PointBox[{66.1, 0.17336320225846877`}], 
             PointBox[{66.2, 0.1740248113691063}], 
             PointBox[{66.3, 0.17100464052457032`}], 
             PointBox[{66.4, 0.1718112844327615}], 
             PointBox[{66.5, 0.17453240782528287`}], 
             PointBox[{66.6, 0.17206819562250755`}], 
             PointBox[{66.7, 0.17494462089819343`}], 
             PointBox[{66.8, 0.18093386050398844`}], 
             PointBox[{66.9, 0.18244921409737525`}], 
             PointBox[{67., 0.18074413307074452`}], 
             PointBox[{67.1, 0.184705578754117}], 
             PointBox[{67.2, 0.18223822039129345`}], 
             PointBox[{67.3, 0.1805642399806351}], 
             PointBox[{67.4, 0.18222431754268859`}], 
             PointBox[{67.5, 0.18440219478091283`}], 
             PointBox[{67.6, 0.18066046371735872`}], 
             PointBox[{67.7, 0.18665170630136982`}], 
             PointBox[{67.8, 0.1897989489292857}], 
             PointBox[{67.9, 0.18932242895342108`}], 
             PointBox[{68., 0.18843000774078275`}], 
             PointBox[{68.1, 0.19269929458938131`}], 
             PointBox[{68.2, 0.18847704406546717`}], 
             PointBox[{68.3, 0.18847963261703687`}], 
             PointBox[{68.4, 0.19072790714165888`}], 
             PointBox[{68.5, 0.19088156328788497`}], 
             PointBox[{68.6, 0.18961496979454484`}], 
             PointBox[{68.7, 0.19474981018622414`}], 
             PointBox[{68.8, 0.19528737456078488`}], 
             PointBox[{68.9, 0.193763973426801}], 
             PointBox[{69., 0.19584369696363357`}], 
             PointBox[{69.1, 0.19617810045745612`}], 
             PointBox[{69.2, 0.19335657154073546`}], 
             PointBox[{69.3, 0.1946984891539715}], 
             PointBox[{69.4, 0.1968295043182642}], 
             PointBox[{69.5, 0.1937176770376222}], 
             PointBox[{69.6, 0.19709491067662022`}], 
             PointBox[{69.7, 0.19912890833973212`}], 
             PointBox[{69.8, 0.198033574872948}], 
             PointBox[{69.9, 0.1968695219516506}], 
             PointBox[{70., 0.2016903547471728}], 
             PointBox[{70.1, 0.19747312806877929`}], 
             PointBox[{70.2, 0.1972026862191047}], 
             PointBox[{70.3, 0.1991784732439856}], 
             PointBox[{70.4, 0.19976572339455295`}], 
             PointBox[{70.5, 0.19661783192845758`}], 
             PointBox[{70.6, 0.20104729559332923`}], 
             PointBox[{70.7, 0.20058601872261858`}], 
             PointBox[{70.8, 0.1988881840587607}], 
             PointBox[{70.9, 0.20018020260942582`}], 
             PointBox[{71., 0.20217454762486525`}], 
             PointBox[{71.1, 0.19854210901172126`}], 
             PointBox[{71.2, 0.1999081083908911}], 
             PointBox[{71.3, 0.20158979513034592`}], 
             PointBox[{71.4, 0.19900384100166946`}], 
             PointBox[{71.5, 0.1999873968437294}], 
             PointBox[{71.6, 0.20164544588847524`}], 
             PointBox[{71.7, 0.19992994320282553`}], 
             PointBox[{71.8, 0.1988410203388193}], 
             PointBox[{71.9, 0.20333010560081802`}], 
             PointBox[{72., 0.1996937694831786}], 
             PointBox[{72.1, 0.19933106227441807`}], 
             PointBox[{72.2, 0.20106862139034717`}], 
             PointBox[{72.3, 0.20121002457335269`}], 
             PointBox[{72.4, 0.1968759481451437}], 
             PointBox[{72.5, 0.20076328844907892`}], 
             PointBox[{72.6, 0.19967955204019314`}], 
             PointBox[{72.7, 0.19783250904257238`}], 
             PointBox[{72.8, 0.19883700717141012`}], 
             PointBox[{72.9, 0.20188987937262529`}], 
             PointBox[{73., 0.1976108107085843}], 
             PointBox[{73.1, 0.19904374791908316`}], 
             PointBox[{73.2, 0.20005406842621087`}], 
             PointBox[{73.3, 0.19736678149536446`}], 
             PointBox[{73.4, 0.195980005752273}], 
             PointBox[{73.5, 0.1979759491149351}], 
             PointBox[{73.6, 0.19582120412070733`}], 
             PointBox[{73.7, 0.19480133588912496`}], 
             PointBox[{73.8, 0.1985537049018948}], 
             PointBox[{73.9, 0.19616983121375342`}], 
             PointBox[{74., 0.19540519842720533`}], 
             PointBox[{74.1, 0.19682697249566566`}], 
             PointBox[{74.2, 0.19605600870239323`}], 
             PointBox[{74.3, 0.19060007010988508`}], 
             PointBox[{74.4, 0.19355744290803306`}], 
             PointBox[{74.5, 0.19242272701242427`}], 
             PointBox[{74.6, 0.19039644323636862`}], 
             PointBox[{74.7, 0.1910231124197284}], 
             PointBox[{74.8, 0.19495172374112424`}], 
             PointBox[{74.9, 0.19025194976267715`}], 
             PointBox[{75., 0.19166109726431266`}], 
             PointBox[{75.1, 0.19185333815658726`}], 
             PointBox[{75.2, 0.18831192077801964`}], 
             PointBox[{75.3, 0.18386610580459212`}], 
             PointBox[{75.4, 0.18714031541682644`}], 
             PointBox[{75.5, 0.18468666114277704`}], 
             PointBox[{75.6, 0.1834390654690365}], 
             PointBox[{75.7, 0.18600704569783147`}], 
             PointBox[{75.8, 0.1864268142661771}], 
             PointBox[{75.9, 0.18391971562866816`}], 
             PointBox[{76., 0.18537576921828178`}], 
             PointBox[{76.1, 0.18338717031726767`}], 
             PointBox[{76.2, 0.17703760711549466`}], 
             PointBox[{76.3, 0.17690957467389692`}], 
             PointBox[{76.4, 0.17757955401906753`}], 
             PointBox[{76.5, 0.1750427509240687}], 
             PointBox[{76.6, 0.17486559547517028`}], 
             PointBox[{76.7, 0.17859435389278963`}], 
             PointBox[{76.8, 0.17560950279113824`}], 
             PointBox[{76.9, 0.17581462127706415`}], 
             PointBox[{77., 0.17615357958638958`}], 
             PointBox[{77.1, 0.17143299139493917`}], 
             PointBox[{77.2, 0.1646458604111418}], 
             PointBox[{77.3, 0.16748352064131392`}], 
             PointBox[{77.4, 0.16615754817624262`}], 
             PointBox[{77.5, 0.1639764787932023}], 
             PointBox[{77.6, 0.16484108628499952`}], 
             PointBox[{77.7, 0.16839309039379124`}], 
             PointBox[{77.8, 0.1641999526616541}], 
             PointBox[{77.9, 0.16576025657545987`}], 
             PointBox[{78., 0.1645694120103874}], 
             PointBox[{78.1, 0.15817929231641925`}], 
             PointBox[{78.2, 0.15293390871420393`}], 
             PointBox[{78.3, 0.15658935816424754`}], 
             PointBox[{78.4, 0.15433642782719165`}], 
             PointBox[{78.5, 0.15254205265360357`}], 
             PointBox[{78.6, 0.15416419610665064`}], 
             PointBox[{78.7, 0.1568987421899299}], 
             PointBox[{78.8, 0.1528212114542135}], 
             PointBox[{78.9, 0.15484502073241818`}], 
             PointBox[{79., 0.15241989555524743`}], 
             PointBox[{79.1, 0.14642517130106752`}], 
             PointBox[{79.2, 0.14259200075077708`}], 
             PointBox[{79.3, 0.14623335258125747`}], 
             PointBox[{79.4, 0.14362370147480044`}], 
             PointBox[{79.5, 0.14207306544689904`}], 
             PointBox[{79.6, 0.14409758559268127`}], 
             PointBox[{79.7, 0.14620727148625995`}], 
             PointBox[{79.8, 0.14244383943912292`}], 
             PointBox[{79.9, 0.14465051979173646`}], 
             PointBox[{80., 0.14183353762694975`}], 
             PointBox[{80.1, 0.1372536552521969}], 
             PointBox[{80.2, 0.1341718674514672}], 
             PointBox[{80.3, 0.13775157673340993`}], 
             PointBox[{80.4, 0.13504627388279047`}], 
             PointBox[{80.5, 0.1335517212679816}], 
             PointBox[{80.6, 0.1356952400506675}], 
             PointBox[{80.7, 0.1376172212045529}], 
             PointBox[{80.8, 0.13397267029578053`}], 
             PointBox[{80.9, 0.1363221059303675}], 
             PointBox[{81., 0.13392609239586853`}], 
             PointBox[{81.1, 0.13084043221187908`}], 
             PointBox[{81.2, 0.12802189850817705`}], 
             PointBox[{81.3, 0.13164133068131742`}], 
             PointBox[{81.4, 0.12900474808187698`}], 
             PointBox[{81.5, 0.12740336444384748`}], 
             PointBox[{81.6, 0.1294760408628015}], 
             PointBox[{81.7, 0.13154366602880227`}], 
             PointBox[{81.8, 0.12785873502639616`}], 
             PointBox[{81.9, 0.1303122350477772}], 
             PointBox[{82., 0.12879126844936434`}], 
             PointBox[{82.1, 0.12705469635718722`}], 
             PointBox[{82.2, 0.12426459589638855`}], 
             PointBox[{82.3, 0.12793192233930603`}], 
             PointBox[{82.4, 0.12551852211883022`}], 
             PointBox[{82.5, 0.12370175754271123`}], 
             PointBox[{82.6, 0.12558260696372692`}], 
             PointBox[{82.7, 0.1279496886998004}], 
             PointBox[{82.8, 0.12421690984626187`}], 
             PointBox[{82.9, 0.12666691952641246`}], 
             PointBox[{83., 0.1261971354662088}], 
             PointBox[{83.1, 0.1257094561512724}], 
             PointBox[{83.2, 0.12291779104957104`}], 
             PointBox[{83.3, 0.1265267239420324}], 
             PointBox[{83.4, 0.12448438681680503`}], 
             PointBox[{83.5, 0.12240579145638872`}], 
             PointBox[{83.6, 0.12402725136833057`}], 
             PointBox[{83.7, 0.1266979739360762}], 
             PointBox[{83.8, 0.12303000056219951`}], 
             PointBox[{83.9, 0.1253355625199614}], 
             PointBox[{84., 0.12596775674263905`}], 
             PointBox[{84.1, 0.12668636195744207`}], 
             PointBox[{84.2, 0.12398154989431717`}], 
             PointBox[{84.3, 0.12738805143792786`}], 
             PointBox[{84.4, 0.12581407573732142`}], 
             PointBox[{84.5, 0.12348490935095431`}], 
             PointBox[{84.6, 0.1248345069596544}], 
             PointBox[{84.7, 0.12772229604894764`}], 
             PointBox[{84.8, 0.12425720344785905`}], 
             PointBox[{84.9, 0.12632740318387273`}], 
             PointBox[{85., 0.12808420466854772`}], 
             PointBox[{85.1, 0.1299771921254712}], 
             PointBox[{85.2, 0.12746789258939822`}], 
             PointBox[{85.3, 0.1305967078147018}], 
             PointBox[{85.4, 0.12947645049269213`}], 
             PointBox[{85.5, 0.12695521289838926`}], 
             PointBox[{85.6, 0.12808202575036337`}], 
             PointBox[{85.7, 0.1310738587943081}], 
             PointBox[{85.8, 0.12786637568843326`}], 
             PointBox[{85.9, 0.12975161704786387`}], 
             PointBox[{86., 0.13269566622396886`}], 
             PointBox[{86.1, 0.13565110304041947`}], 
             PointBox[{86.2, 0.13338140633553217`}], 
             PointBox[{86.3, 0.1363111551257937}], 
             PointBox[{86.4, 0.13546428698343246`}], 
             PointBox[{86.5, 0.13285120127128738`}], 
             PointBox[{86.6, 0.13386798849893583`}], 
             PointBox[{86.7, 0.13686709629411664`}], 
             PointBox[{86.8, 0.133815625116436}], 
             PointBox[{86.9, 0.13578320770361674`}], 
             PointBox[{87., 0.14006587279688903`}], 
             PointBox[{87.1, 0.14370966847610464`}], 
             PointBox[{87.2, 0.14161804594247324`}], 
             PointBox[{87.3, 0.14461645864164516`}], 
             PointBox[{87.4, 0.14365970094070366`}], 
             PointBox[{87.5, 0.14111107011383384`}], 
             PointBox[{87.6, 0.14218909356999213`}], 
             PointBox[{87.7, 0.1451172860619298}], 
             PointBox[{87.8, 0.14196070392418123`}], 
             PointBox[{87.9, 0.14454974990140407`}], 
             PointBox[{88., 0.15028608288446493`}], 
             PointBox[{88.1, 0.15378022211255268`}], 
             PointBox[{88.2, 0.1517526045470983}], 
             PointBox[{88.3, 0.15522113965158224`}], 
             PointBox[{88.4, 0.15358020487699936`}], 
             PointBox[{88.5, 0.15135254209512342`}], 
             PointBox[{88.6, 0.1526981526603215}], 
             PointBox[{88.7, 0.15542867572177993`}], 
             PointBox[{88.8, 0.15189670246645975`}], 
             PointBox[{88.9, 0.1559026834208314}], 
             PointBox[{89., 0.16251723854620453`}], 
             PointBox[{89.1, 0.16478558259252818`}], 
             PointBox[{89.2, 0.16286601456092847`}], 
             PointBox[{89.3, 0.16703672755699248`}], 
             PointBox[{89.4, 0.16418238300626106`}], 
             PointBox[{89.5, 0.16265471243314164`}], 
             PointBox[{89.6, 0.16444889012175856`}], 
             PointBox[{89.7, 0.16662520255360747`}], 
             PointBox[{89.8, 0.16298292084801527`}], 
             PointBox[{89.9, 0.16901231015049473`}], 
             PointBox[{90., 0.17460892611764836`}], 
             PointBox[{90.1, 0.17510441748288774`}], 
             PointBox[{90.2, 0.17388190198201314`}], 
             PointBox[{90.3, 0.17800378072084122`}], 
             PointBox[{90.4, 0.1741622870402964}], 
             PointBox[{90.5, 0.17370973742444004`}], 
             PointBox[{90.6, 0.17600020863206048`}], 
             PointBox[{90.7, 0.17673117560276588`}], 
             PointBox[{90.8, 0.1747454377722232}], 
             PointBox[{90.9, 0.18155918336013885`}], 
             PointBox[{91., 0.18446487796949476`}], 
             PointBox[{91.1, 0.18345082229143989`}], 
             PointBox[{91.2, 0.18434646991711442`}], 
             PointBox[{91.3, 0.18607460038748297`}], 
             PointBox[{91.4, 0.18268285059667855`}], 
             PointBox[{91.5, 0.1834350720942284}], 
             PointBox[{91.6, 0.18596349775939863`}], 
             PointBox[{91.7, 0.18398096696954086`}], 
             PointBox[{91.8, 0.18625703354970977`}], 
             PointBox[{91.9, 0.19086183338610954`}], 
             PointBox[{92., 0.1912907600905606}], 
             PointBox[{92.1, 0.18967615179933808`}], 
             PointBox[{92.2, 0.19368337561183688`}], 
             PointBox[{92.3, 0.1911294862871005}], 
             PointBox[{92.4, 0.1896009492759873}], 
             PointBox[{92.5, 0.1913345595520855}], 
             PointBox[{92.6, 0.1932233031227459}], 
             PointBox[{92.7, 0.18946489468573796`}], 
             PointBox[{92.8, 0.1949028240000729}], 
             PointBox[{92.9, 0.1964895317020652}], 
             PointBox[{93., 0.19535944862820837`}], 
             PointBox[{93.1, 0.19490207294827422`}], 
             PointBox[{93.2, 0.19903257272871297`}], 
             PointBox[{93.3, 0.19460883447105576`}], 
             PointBox[{93.4, 0.19504992358309636`}], 
             PointBox[{93.5, 0.19721481553398315`}], 
             PointBox[{93.6, 0.19669864477122362`}], 
             PointBox[{93.7, 0.1958496230131061}], 
             PointBox[{93.8, 0.19970667854223348`}], 
             PointBox[{93.9, 0.19913426792451364`}], 
             PointBox[{94., 0.19751978215970592`}], 
             PointBox[{94.1, 0.20041214787664796`}], 
             PointBox[{94.2, 0.19963939852885}], 
             PointBox[{94.3, 0.19742022681508917`}], 
             PointBox[{94.4, 0.19904877023578962`}], 
             PointBox[{94.5, 0.20067446031946587`}], 
             PointBox[{94.6, 0.19702105545972368`}], 
             PointBox[{94.7, 0.20049290342698933`}], 
             PointBox[{94.8, 0.20126149688501294`}], 
             PointBox[{94.9, 0.19961637519573855`}], 
             PointBox[{95., 0.19903046754991982`}], 
             PointBox[{95.1, 0.20378254381554967`}], 
             PointBox[{95.2, 0.1990523600289812}], 
             PointBox[{95.3, 0.19950844232852313`}], 
             PointBox[{95.4, 0.20134487893257083`}], 
             PointBox[{95.5, 0.20089855936538972`}], 
             PointBox[{95.6, 0.19802998749247877`}], 
             PointBox[{95.7, 0.20173380047106765`}], 
             PointBox[{95.8, 0.2003981690774932}], 
             PointBox[{95.9, 0.1987416150936976}], 
             PointBox[{96., 0.20100917207112293`}], 
             PointBox[{96.1, 0.20154697960062393`}], 
             PointBox[{96.2, 0.19875248061414316`}], 
             PointBox[{96.3, 0.20037053343716146`}], 
             PointBox[{96.4, 0.20136508402995446`}], 
             PointBox[{96.5, 0.19777342008729046`}], 
             PointBox[{96.6, 0.19928174512861868`}], 
             PointBox[{96.7, 0.199829886337786}], 
             PointBox[{96.8, 0.19779622394878432`}], 
             PointBox[{96.9, 0.1972754948572135}], 
             PointBox[{97., 0.20189091399751283`}], 
             PointBox[{97.1, 0.19750133413920504`}], 
             PointBox[{97.2, 0.19795221996244725`}], 
             PointBox[{97.3, 0.1993388691741916}], 
             PointBox[{97.4, 0.19829875506879677`}], 
             PointBox[{97.5, 0.19357208286085933`}], 
             PointBox[{97.6, 0.1973730402869033}], 
             PointBox[{97.7, 0.19559364493060316`}], 
             PointBox[{97.8, 0.1938923179068565}], 
             PointBox[{97.9, 0.19560102835845622`}], 
             PointBox[{98., 0.19762814144893798`}], 
             PointBox[{98.1, 0.19396097394819312`}], 
             PointBox[{98.2, 0.19555137749624946`}], 
             PointBox[{98.3, 0.19563054804178978`}], 
             PointBox[{98.4, 0.1915809051201797}], 
             PointBox[{98.5, 0.19051826592674256`}], 
             PointBox[{98.6, 0.19185639275418573`}], 
             PointBox[{98.7, 0.1894839883384756}], 
             PointBox[{98.8, 0.1888473435980965}], 
             PointBox[{98.9, 0.19269537545930052`}], 
             PointBox[{99., 0.1898511014434508}], 
             PointBox[{99.1, 0.1896376732964108}], 
             PointBox[{99.2, 0.19063191884928116`}], 
             PointBox[{99.3, 0.18841378185753735`}], 
             PointBox[{99.4, 0.18202703378779345`}], 
             PointBox[{99.5, 0.1850870541171185}], 
             PointBox[{99.6, 0.18363333344263988`}], 
             PointBox[{99.7, 0.18161325826160127`}], 
             PointBox[{99.8, 0.1824811086289345}], 
             PointBox[{99.9, 0.18615184120078968`}], 
             PointBox[{100., 0.18160538084540306`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 0.2}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"e\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"e\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, 0.03}]], {189., -123.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, 0}, {100, 0}, {100, 360}, {0, 360}, {0, 0}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
             PointBox[{0.1, 359.21781137132655`}], 
             PointBox[{0.2, 359.8024276455997}], 
             PointBox[{0.3, 359.63712260837957`}], 
             PointBox[{0.4, 358.7464296439937}], 
             PointBox[{0.5, 359.82609383675833`}], 
             PointBox[{0.6, 359.47090620914275`}], 
             PointBox[{0.7, 358.9377977671755}], 
             PointBox[{0.8, 359.17764964713575`}], 
             PointBox[{0.9, 359.64773967545034`}], 
             PointBox[{1., 357.727981951683}], 
             PointBox[{1.1, 358.3755144427768}], 
             PointBox[{1.2, 358.5775342347513}], 
             PointBox[{1.3, 357.98968673086074`}], 
             PointBox[{1.4, 357.4622766951599}], 
             PointBox[{1.5, 358.76293530362227`}], 
             PointBox[{1.6, 357.83136496253474`}], 
             PointBox[{1.7, 357.7887457531664}], 
             PointBox[{1.8, 358.26043780010457`}], 
             PointBox[{1.9, 357.62319757391083`}], 
             PointBox[{2., 356.6802451557663}], 
             PointBox[{2.1, 357.43060831109887`}], 
             PointBox[{2.2, 357.18768317298793`}], 
             PointBox[{2.3, 356.3353297503363}], 
             PointBox[{2.4, 357.0591281789123}], 
             PointBox[{2.5, 357.07788693382537`}], 
             PointBox[{2.6, 356.56508834959754`}], 
             PointBox[{2.7, 356.89103614010077`}], 
             PointBox[{2.8, 357.154887175481}], 
             PointBox[{2.9, 355.54187015086353`}], 
             PointBox[{3., 356.1213252152849}], 
             PointBox[{3.1, 356.4025470569756}], 
             PointBox[{3.2, 355.79049915230644`}], 
             PointBox[{3.3, 355.1152880334188}], 
             PointBox[{3.4, 356.56321543820036`}], 
             PointBox[{3.5, 355.6472193291618}], 
             PointBox[{3.6, 355.7243693684022}], 
             PointBox[{3.7, 356.18747306022027`}], 
             PointBox[{3.8, 355.929545697189}], 
             PointBox[{3.9, 354.6594395711025}], 
             PointBox[{4., 355.7107051341758}], 
             PointBox[{4.1, 355.5210059014419}], 
             PointBox[{4.2, 354.6851710227223}], 
             PointBox[{4.3, 354.75861924508837`}], 
             PointBox[{4.4, 355.6222607901276}], 
             PointBox[{4.5, 354.8573508112386}], 
             PointBox[{4.6, 355.3944560815056}], 
             PointBox[{4.7, 355.75928452362245`}], 
             PointBox[{4.8, 355.2190229610484}], 
             PointBox[{4.9, 354.9356785471909}], 
             PointBox[{5., 355.7184691900523}], 
             PointBox[{5.1, 355.17235431735725`}], 
             PointBox[{5.2, 354.31276664009425`}], 
             PointBox[{5.3, 355.2648110307792}], 
             PointBox[{5.4, 355.13212875249917`}], 
             PointBox[{5.5, 354.93318836001936`}], 
             PointBox[{5.6, 355.8127695224405}], 
             PointBox[{5.7, 356.39428574151395`}], 
             PointBox[{5.8, 355.60742106640015`}], 
             PointBox[{5.9, 356.23032586959084`}], 
             PointBox[{6., 356.6440669500789}], 
             PointBox[{6.1, 355.84849648714135`}], 
             PointBox[{6.2, 355.14618117616027`}], 
             PointBox[{6.3, 356.588246811552}], 
             PointBox[{6.4, 355.82173544882426`}], 
             PointBox[{6.5, 356.17125478819446`}], 
             PointBox[{6.6, 357.4291104347298}], 
             PointBox[{6.7, 358.714856818989}], 
             PointBox[{6.8, 357.6637555175113}], 
             PointBox[{6.9, 358.7846126183302}], 
             PointBox[{7., 358.9333086473461}], 
             PointBox[{7.1, 357.9677475873575}], 
             PointBox[{7.2, 357.48419025609394`}], 
             PointBox[{7.3, 359.06222009321164`}], 
             PointBox[{7.4, 358.0389136348743}], 
             PointBox[{7.5, 358.83308995963665`}], 
             PointBox[{7.6, 0.6795405940831594}], 
             PointBox[{7.7, 2.5388364914736448`}], 
             PointBox[{7.8, 1.376777997481578}], 
             PointBox[{7.9, 2.727584837782603}], 
             PointBox[{8., 2.739835158222333}], 
             PointBox[{8.1, 1.655183691408477}], 
             PointBox[{8.2, 1.3250739233356368`}], 
             PointBox[{8.3, 2.9357117411613296`}], 
             PointBox[{8.4, 1.8156735655655882`}], 
             PointBox[{8.5, 2.9333492220850363`}], 
             PointBox[{8.6, 5.481414466474178}], 
             PointBox[{8.7, 7.648684946721344}], 
             PointBox[{8.8, 6.44651305340044}], 
             PointBox[{8.9, 7.899495268344854}], 
             PointBox[{9., 7.89579174457779}], 
             PointBox[{9.1, 6.723945829108461}], 
             PointBox[{9.2, 6.430588717283759}], 
             PointBox[{9.3, 8.091263047129283}], 
             PointBox[{9.4, 6.929338981556621}], 
             PointBox[{9.5, 8.221585339739121}], 
             PointBox[{9.6, 11.35717176312144}], 
             PointBox[{9.7, 13.728496377055196`}], 
             PointBox[{9.8, 12.5142106638594}], 
             PointBox[{9.9, 13.973136335269283`}], 
             PointBox[{10., 14.060332002256953`}], 
             PointBox[{10.1, 12.830000749068377`}], 
             PointBox[{10.2, 12.469841438808071`}], 
             PointBox[{10.3, 14.189909544693371`}], 
             PointBox[{10.4, 13.042621503715663`}], 
             PointBox[{10.5, 14.34312997779681}], 
             PointBox[{10.6, 17.861723454021945`}], 
             PointBox[{10.7, 20.411364880418784`}], 
             PointBox[{10.8, 19.23915866038339}], 
             PointBox[{10.9, 20.59383782637548}], 
             PointBox[{11., 20.85482321335284}], 
             PointBox[{11.1, 19.601310880883158`}], 
             PointBox[{11.2, 19.113702693906717`}], 
             PointBox[{11.3, 20.84958534881895}], 
             PointBox[{11.4, 19.805595300488733`}], 
             PointBox[{11.5, 20.965294328600187`}], 
             PointBox[{11.6, 24.666900739225714`}], 
             PointBox[{11.7, 27.346315263926027`}], 
             PointBox[{11.8, 26.297749315170343`}], 
             PointBox[{11.9, 27.438716466759995`}], 
             PointBox[{12., 27.917011946872407`}], 
             PointBox[{12.1, 26.680476987598304`}], 
             PointBox[{12.2, 26.054188034510318`}], 
             PointBox[{12.3, 27.72609187886264}], 
             PointBox[{12.4, 26.877573023649386`}], 
             PointBox[{12.5, 27.802682092485387`}], 
             PointBox[{12.6, 31.508255988918286`}], 
             PointBox[{12.7, 34.214867169566595`}], 
             PointBox[{12.8, 33.35643003832596}], 
             PointBox[{12.9, 34.218653134482935`}], 
             PointBox[{13., 34.90561789435937}], 
             PointBox[{13.1, 33.72037667059271}], 
             PointBox[{13.2, 32.98636593220634}], 
             PointBox[{13.3, 34.52244008716385}], 
             PointBox[{13.4, 33.91359212435967}], 
             PointBox[{13.5, 34.59068423738288}], 
             PointBox[{13.6, 38.12989140504941}], 
             PointBox[{13.7, 40.71546725386745}], 
             PointBox[{13.8, 40.052207985138956`}], 
             PointBox[{13.9, 40.65332398328228}], 
             PointBox[{14., 41.485938199580225`}], 
             PointBox[{14.1, 40.3681064184908}], 
             PointBox[{14.2, 39.58556530119437}], 
             PointBox[{14.3, 40.95871939369569}], 
             PointBox[{14.4, 40.54953555815857}], 
             PointBox[{14.5, 41.05051761433154}], 
             PointBox[{14.6, 44.23604613747651}], 
             PointBox[{14.7, 46.5359735648044}], 
             PointBox[{14.8, 45.995807424351455`}], 
             PointBox[{14.9, 46.44301654541912}], 
             PointBox[{15., 47.31135709816169}], 
             PointBox[{15.1, 46.253588828565704`}], 
             PointBox[{15.2, 45.494252469074645`}], 
             PointBox[{15.3, 46.73853150688514}], 
             PointBox[{15.4, 46.398143359445555`}], 
             PointBox[{15.5, 46.86005066706219}], 
             PointBox[{15.6, 49.46004431886519}], 
             PointBox[{15.7, 51.339391998136044`}], 
             PointBox[{15.8, 50.7901019154181}], 
             PointBox[{15.9, 51.26679282253099}], 
             PointBox[{16., 52.02006682849391}], 
             PointBox[{16.1, 51.001134499401424`}], 
             PointBox[{16.2, 50.340474921105944`}], 
             PointBox[{16.3, 51.536703807413694`}], 
             PointBox[{16.4, 51.06657495578808}], 
             PointBox[{16.5, 51.625087531779236`}], 
             PointBox[{16.6, 53.41089065228135}], 
             PointBox[{16.7, 54.80793400934958}], 
             PointBox[{16.8, 54.104493375491245`}], 
             PointBox[{16.9, 54.840817878496075`}], 
             PointBox[{17., 55.288620726632416`}], 
             PointBox[{17.1, 54.301051945466206`}], 
             PointBox[{17.2, 53.8205472860762}], 
             PointBox[{17.3, 55.049792086094065`}], 
             PointBox[{17.4, 54.24608137105365}], 
             PointBox[{17.5, 54.84078959611901}], 
             PointBox[{17.6, 55.86288078358799}], 
             PointBox[{17.7, 56.77311981313276}], 
             PointBox[{17.8, 55.84365085562225}], 
             PointBox[{17.9, 57.02084310640504}], 
             PointBox[{18., 56.977375455909225`}], 
             PointBox[{18.1, 56.06008435753647}], 
             PointBox[{18.2, 55.855027953762765`}], 
             PointBox[{18.3, 57.08542779292202}], 
             PointBox[{18.4, 55.91088942743291}], 
             PointBox[{18.5, 56.22930399540496}], 
             PointBox[{18.6, 56.93069371834512}], 
             PointBox[{18.7, 57.32523913466135}], 
             PointBox[{18.8, 56.36437304301668}], 
             PointBox[{18.9, 57.83649633836106}], 
             PointBox[{19., 57.27401208469706}], 
             PointBox[{19.1, 56.51931229605449}], 
             PointBox[{19.2, 56.70605296703875}], 
             PointBox[{19.3, 57.553227898497326`}], 
             PointBox[{19.4, 56.27798686526657}], 
             PointBox[{19.5, 56.38743089480005}], 
             PointBox[{19.6, 56.95554080704849}], 
             PointBox[{19.7, 56.746594405080636`}], 
             PointBox[{19.8, 56.42373982518918}], 
             PointBox[{19.9, 57.470196805057626`}], 
             PointBox[{20., 56.628096686534946`}], 
             PointBox[{20.1, 56.15582333898459}], 
             PointBox[{20.2, 56.82466986088719}], 
             PointBox[{20.3, 56.543101135341054`}], 
             PointBox[{20.4, 55.59484772049265}], 
             PointBox[{20.5, 55.95307355798599}], 
             PointBox[{20.6, 56.24489284588244}], 
             PointBox[{20.7, 55.43581087011611}], 
             PointBox[{20.8, 56.3466532453447}], 
             PointBox[{20.9, 56.29398866970785}], 
             PointBox[{21., 55.518730339584124`}], 
             PointBox[{21.1, 55.44852329531399}], 
             PointBox[{21.2, 56.39449610032007}], 
             PointBox[{21.3, 54.84222659112205}], 
             PointBox[{21.4, 54.72636482117434}], 
             PointBox[{21.5, 55.138528277944104`}], 
             PointBox[{21.6, 54.96752470595993}], 
             PointBox[{21.7, 54.15331560253005}], 
             PointBox[{21.8, 55.572140017714055`}], 
             PointBox[{21.9, 54.76631541015996}], 
             PointBox[{22., 54.301896932847804`}], 
             PointBox[{22.1, 54.713256398108236`}], 
             PointBox[{22.2, 54.90325767177173}], 
             PointBox[{22.3, 53.33373763862484}], 
             PointBox[{22.4, 53.836028629367604`}], 
             PointBox[{22.5, 53.983327865889066`}], 
             PointBox[{22.6, 53.26812842258202}], 
             PointBox[{22.7, 53.669247348765396`}], 
             PointBox[{22.8, 54.02407633286319}], 
             PointBox[{22.9, 53.23470953282856}], 
             PointBox[{23., 53.18839599211989}], 
             PointBox[{23.1, 53.93255662871941}], 
             PointBox[{23.2, 52.43437853768795}], 
             PointBox[{23.3, 52.34342532506809}], 
             PointBox[{23.4, 52.77414256036616}], 
             PointBox[{23.5, 52.494068424045466`}], 
             PointBox[{23.6, 51.614893349017336`}], 
             PointBox[{23.7, 53.057671554274414`}], 
             PointBox[{23.8, 52.270167886124625`}], 
             PointBox[{23.9, 51.88080541400691}], 
             PointBox[{24., 52.245514683145096`}], 
             PointBox[{24.1, 52.45205460010428}], 
             PointBox[{24.2, 50.70570516664276}], 
             PointBox[{24.3, 51.42044977617013}], 
             PointBox[{24.4, 51.47393786736316}], 
             PointBox[{24.5, 50.75350190975565}], 
             PointBox[{24.6, 50.82824943218841}], 
             PointBox[{24.7, 51.51270557136481}], 
             PointBox[{24.8, 50.70779672363142}], 
             PointBox[{24.9, 50.760598142875395`}], 
             PointBox[{25., 51.315365615293395`}], 
             PointBox[{25.1, 49.96641367927522}], 
             PointBox[{25.2, 49.83658869686818}], 
             PointBox[{25.3, 50.33353816283744}], 
             PointBox[{25.4, 49.959978690828514`}], 
             PointBox[{25.5, 49.09886803911884}], 
             PointBox[{25.6, 50.431601696787126`}], 
             PointBox[{25.7, 49.753731309798624`}], 
             PointBox[{25.8, 49.458542592505864`}], 
             PointBox[{25.9, 49.830830466159476`}], 
             PointBox[{26., 49.91013879783403}], 
             PointBox[{26.1, 48.18162312572547}], 
             PointBox[{26.2, 49.07379721116059}], 
             PointBox[{26.3, 49.097025947522354`}], 
             PointBox[{26.4, 48.37204076526248}], 
             PointBox[{26.5, 48.13412025955516}], 
             PointBox[{26.6, 49.218089005787306`}], 
             PointBox[{26.7, 48.340437780380284`}], 
             PointBox[{26.8, 48.53137413421765}], 
             PointBox[{26.9, 48.938660704656826`}], 
             PointBox[{27., 48.06058511301281}], 
             PointBox[{27.1, 47.54992799995783}], 
             PointBox[{27.2, 48.271550351718304`}], 
             PointBox[{27.3, 47.87048848240396}], 
             PointBox[{27.4, 47.01671745691563}], 
             PointBox[{27.5, 47.93692140674997}], 
             PointBox[{27.6, 47.75503354837267}], 
             PointBox[{27.7, 47.43548049629868}], 
             PointBox[{27.8, 47.9316045182227}], 
             PointBox[{27.9, 48.03745408750964}], 
             PointBox[{28., 46.683949978025105`}], 
             PointBox[{28.1, 47.432543169161264`}], 
             PointBox[{28.2, 47.66233496378106}], 
             PointBox[{28.3, 46.951971341398576`}], 
             PointBox[{28.4, 46.343505381887624`}], 
             PointBox[{28.5, 47.806826656474335`}], 
             PointBox[{28.6, 46.869845376369646`}], 
             PointBox[{28.7, 47.161840716118775`}], 
             PointBox[{28.8, 47.77145133569167}], 
             PointBox[{28.9, 47.880647236140206`}], 
             PointBox[{29., 46.67891037506644}], 
             PointBox[{29.1, 47.86513100877192}], 
             PointBox[{29.2, 47.6717044671845}], 
             PointBox[{29.3, 46.782240725189446`}], 
             PointBox[{29.4, 46.74048412754353}], 
             PointBox[{29.5, 47.86665462548455}], 
             PointBox[{29.6, 46.971126407008335`}], 
             PointBox[{29.7, 47.77519430187584}], 
             PointBox[{29.8, 48.563050636144645`}], 
             PointBox[{29.9, 48.877035464599224`}], 
             PointBox[{30., 48.16956558620497}], 
             PointBox[{30.1, 49.30124739863383}], 
             PointBox[{30.2, 48.80197833330081}], 
             PointBox[{30.3, 47.84930200754883}], 
             PointBox[{30.4, 48.39692792602911}], 
             PointBox[{30.5, 48.943504467823814`}], 
             PointBox[{30.6, 48.364667947172975`}], 
             PointBox[{30.7, 49.64463668317714}], 
             PointBox[{30.8, 51.101577877540635`}], 
             PointBox[{30.9, 51.331389177248184`}], 
             PointBox[{31., 51.109382769036834`}], 
             PointBox[{31.1, 52.12719904297426}], 
             PointBox[{31.2, 51.41805488283691}], 
             PointBox[{31.3, 50.46320524537864}], 
             PointBox[{31.4, 51.4031975809052}], 
             PointBox[{31.5, 51.55552080397773}], 
             PointBox[{31.6, 51.24159721335815}], 
             PointBox[{31.7, 53.02627438873094}], 
             PointBox[{31.8, 55.33172313459001}], 
             PointBox[{31.9, 55.3737214929115}], 
             PointBox[{32., 55.40810269363087}], 
             PointBox[{32.1, 56.40522762191881}], 
             PointBox[{32.2, 55.56261241359584}], 
             PointBox[{32.3, 54.6022346472784}], 
             PointBox[{32.4, 55.72499243542612}], 
             PointBox[{32.5, 55.73970221989393}], 
             PointBox[{32.6, 55.53792731213002}], 
             PointBox[{32.7, 57.82231651179373}], 
             PointBox[{32.8, 60.76706454039856}], 
             PointBox[{32.9, 60.761534589521936`}], 
             PointBox[{33., 60.81688060229109}], 
             PointBox[{33.1, 61.90423021220204}], 
             PointBox[{33.2, 60.99592979761058}], 
             PointBox[{33.3, 59.99448347864239}], 
             PointBox[{33.4, 61.14313514247659}], 
             PointBox[{33.5, 61.23178023693113}], 
             PointBox[{33.6, 60.97783924932844}], 
             PointBox[{33.7, 63.66092741304887}], 
             PointBox[{33.8, 67.00451314418163}], 
             PointBox[{33.9, 67.1146428881387}], 
             PointBox[{34., 67.00884117039665}], 
             PointBox[{34.1, 68.2654674850076}], 
             PointBox[{34.2, 67.35728186286963}], 
             PointBox[{34.3, 66.28592083455425}], 
             PointBox[{34.4, 67.33903252891312}], 
             PointBox[{34.5, 67.65592101769953}], 
             PointBox[{34.6, 67.2212446850437}], 
             PointBox[{34.7, 70.1415667358757}], 
             PointBox[{34.8, 73.70168584476397}], 
             PointBox[{34.9, 74.04248570563838}], 
             PointBox[{35., 73.66832031709002}], 
             PointBox[{35.1, 75.11839211063096}], 
             PointBox[{35.2, 74.27161772106325}], 
             PointBox[{35.3, 73.12685879600147}], 
             PointBox[{35.4, 73.99641546376772}], 
             PointBox[{35.5, 74.62308242458208}], 
             PointBox[{35.6, 73.94833317944244}], 
             PointBox[{35.7, 76.94018521139412}], 
             PointBox[{35.8, 80.55931746363983}], 
             PointBox[{35.9, 81.172305462}], 
             PointBox[{36., 80.51189772381294}], 
             PointBox[{36.1, 82.12060120503924}], 
             PointBox[{36.2, 81.3804550493893}], 
             PointBox[{36.3, 80.1865357624101}], 
             PointBox[{36.4, 80.82875380564757}], 
             PointBox[{36.5, 81.75899811160853}], 
             PointBox[{36.6, 80.86398609633034}], 
             PointBox[{36.7, 83.79166187106642}], 
             PointBox[{36.8, 87.30497886245685}], 
             PointBox[{36.9, 88.14714982115962}], 
             PointBox[{37., 87.26273517372205}], 
             PointBox[{37.1, 88.95547463566908}], 
             PointBox[{37.2, 88.33609998265564}], 
             PointBox[{37.3, 87.13311091572338}], 
             PointBox[{37.4, 87.55947109836721}], 
             PointBox[{37.5, 88.71010017696612}], 
             PointBox[{37.6, 87.67039502573704}], 
             PointBox[{37.7, 90.44116947299528}], 
             PointBox[{37.8, 93.66319400183897}], 
             PointBox[{37.9, 94.6170588766822}], 
             PointBox[{38., 93.61297918002445}], 
             PointBox[{38.1, 95.31301011908266}], 
             PointBox[{38.2, 94.785490447124}], 
             PointBox[{38.3, 93.61758327344242}], 
             PointBox[{38.4, 93.89046811801174}], 
             PointBox[{38.5, 95.13621370502733}], 
             PointBox[{38.6, 94.0428343543939}], 
             PointBox[{38.7, 96.58975046023977}], 
             PointBox[{38.8, 99.32375324451269}], 
             PointBox[{38.9, 100.22774194234471`}], 
             PointBox[{39., 99.20893315807152}], 
             PointBox[{39.1, 100.8681239877638}], 
             PointBox[{39.2, 100.36014169076071`}], 
             PointBox[{39.3, 99.26690656192443}], 
             PointBox[{39.4, 99.48564874612985}], 
             PointBox[{39.5, 100.69128224550285`}], 
             PointBox[{39.6, 99.62689743256527}], 
             PointBox[{39.7, 101.83894518692739`}], 
             PointBox[{39.8, 103.9375457875182}], 
             PointBox[{39.9, 104.62333571930434`}], 
             PointBox[{40., 103.6907449693044}], 
             PointBox[{40.1, 105.27840535568427`}], 
             PointBox[{40.2, 104.69323603144431`}], 
             PointBox[{40.3, 103.71266187627121`}], 
             PointBox[{40.4, 103.9986609901965}], 
             PointBox[{40.5, 105.00891604232943`}], 
             PointBox[{40.6, 104.07573857780346`}], 
             PointBox[{40.7, 105.71267216076845`}], 
             PointBox[{40.8, 107.19446720754989`}], 
             PointBox[{40.9, 107.51259622227548`}], 
             PointBox[{41., 106.82619907382794`}], 
             PointBox[{41.1, 108.24593271291084`}], 
             PointBox[{41.2, 107.51087186525265`}], 
             PointBox[{41.3, 106.6910930028752}], 
             PointBox[{41.4, 107.17617844438932`}], 
             PointBox[{41.5, 107.74746652679563`}], 
             PointBox[{41.6, 107.09503651192108`}], 
             PointBox[{41.7, 107.95440748404093`}], 
             PointBox[{41.8, 108.98291742515944`}], 
             PointBox[{41.9, 108.80945817791363`}], 
             PointBox[{42., 108.68151306474194`}], 
             PointBox[{42.1, 109.65905254875506`}], 
             PointBox[{42.2, 108.79349058083508`}], 
             PointBox[{42.3, 108.20539560171086`}], 
             PointBox[{42.4, 109.0034977860049}], 
             PointBox[{42.5, 108.78525251813623`}], 
             PointBox[{42.6, 108.38956988915893`}], 
             PointBox[{42.7, 108.81651780599148`}], 
             PointBox[{42.8, 109.47136583577719`}], 
             PointBox[{42.9, 108.75767591430268`}], 
             PointBox[{43., 109.52890278606006`}], 
             PointBox[{43.1, 109.71627276062799`}], 
             PointBox[{43.2, 108.85412438936548`}], 
             PointBox[{43.3, 108.59643293616925`}], 
             PointBox[{43.4, 109.66665843440704`}], 
             PointBox[{43.5, 108.53195838857884`}], 
             PointBox[{43.6, 108.27951141953594`}], 
             PointBox[{43.7, 108.75578111365353`}], 
             PointBox[{43.8, 108.96016123052257`}], 
             PointBox[{43.9, 108.00448841435166`}], 
             PointBox[{44., 109.43933402633314`}], 
             PointBox[{44.1, 108.86077359123271`}], 
             PointBox[{44.2, 108.1837168964827}], 
             PointBox[{44.3, 108.37389239884106`}], 
             PointBox[{44.4, 109.13933735186026`}], 
             PointBox[{44.5, 107.55327463847797`}], 
             PointBox[{44.6, 107.69145338731374`}], 
             PointBox[{44.7, 108.08700924041312`}], 
             PointBox[{44.8, 107.70733743489177`}], 
             PointBox[{44.9, 107.4792189072565}], 
             PointBox[{45., 108.42568600717769`}], 
             PointBox[{45.1, 107.56621889098912`}], 
             PointBox[{45.2, 107.22692655343867`}], 
             PointBox[{45.3, 107.91448162324986`}], 
             PointBox[{45.4, 107.31597488737539`}], 
             PointBox[{45.5, 106.41655091582393`}], 
             PointBox[{45.6, 106.87727964837634`}], 
             PointBox[{45.7, 106.94888192916085`}], 
             PointBox[{45.8, 106.05266076336333`}], 
             PointBox[{45.9, 107.17472101858132`}], 
             PointBox[{46., 106.85722522437655`}], 
             PointBox[{46.1, 106.18438615475603`}], 
             PointBox[{46.2, 106.28109780016139`}], 
             PointBox[{46.3, 107.07188252624456`}], 
             PointBox[{46.4, 105.2115478452498}], 
             PointBox[{46.5, 105.49094625311193`}], 
             PointBox[{46.6, 105.80996678027878`}], 
             PointBox[{46.7, 105.39941665503076`}], 
             PointBox[{46.8, 104.80745428252675`}], 
             PointBox[{46.9, 106.088107173004}], 
             PointBox[{47., 105.19555788729738`}], 
             PointBox[{47.1, 104.9201967029376}], 
             PointBox[{47.2, 105.44796214857611`}], 
             PointBox[{47.3, 105.06985210831016`}], 
             PointBox[{47.4, 103.90273208001275`}], 
             PointBox[{47.5, 104.51298623197431`}], 
             PointBox[{47.6, 104.45802360780945`}], 
             PointBox[{47.7, 103.60831543867145`}], 
             PointBox[{47.8, 104.42358281411339`}], 
             PointBox[{47.9, 104.35265235458252`}], 
             PointBox[{48., 103.70718448581357`}], 
             PointBox[{48.1, 103.85458268521509`}], 
             PointBox[{48.2, 104.45679264544587`}], 
             PointBox[{48.3, 102.60390440990365`}], 
             PointBox[{48.4, 103.03418567115853`}], 
             PointBox[{48.5, 103.33672375188047`}], 
             PointBox[{48.6, 102.84678141898296`}], 
             PointBox[{48.7, 102.14667208188047`}], 
             PointBox[{48.8, 103.56272527782369`}], 
             PointBox[{48.9, 102.64299150445794`}], 
             PointBox[{49., 102.48073045672453`}], 
             PointBox[{49.1, 102.93282091104216`}], 
             PointBox[{49.2, 102.6014157841606}], 
             PointBox[{49.3, 101.31345564663657`}], 
             PointBox[{49.4, 102.10329993141653`}], 
             PointBox[{49.5, 101.96303992499047`}], 
             PointBox[{49.6, 101.14091679093045`}], 
             PointBox[{49.7, 101.60344036084757`}], 
             PointBox[{49.8, 101.90253840583381`}], 
             PointBox[{49.9, 101.26259618180723`}], 
             PointBox[{50., 101.50724244748419`}], 
             PointBox[{50.1, 101.88878007184913`}], 
             PointBox[{50.2, 100.32850901343772`}], 
             PointBox[{50.3, 100.66500259662592`}], 
             PointBox[{50.4, 101.04269561297178`}], 
             PointBox[{50.5, 100.50632750724758`}], 
             PointBox[{50.6, 99.7449272934613}], 
             PointBox[{50.7, 101.16886243012617`}], 
             PointBox[{50.8, 100.3304182604744}], 
             PointBox[{50.9, 100.27584868226143`}], 
             PointBox[{51., 100.7211249545217}], 
             PointBox[{51.1, 100.5331288103187}], 
             PointBox[{51.2, 99.10386551663092}], 
             PointBox[{51.3, 100.12629904708143`}], 
             PointBox[{51.4, 100.01647169192324`}], 
             PointBox[{51.5, 99.21427372175334}], 
             PointBox[{51.6, 99.145738596238}], 
             PointBox[{51.7, 100.13334039592647`}], 
             PointBox[{51.8, 99.30703689292818}], 
             PointBox[{51.9, 99.72992401418725}], 
             PointBox[{52., 100.08922100514675`}], 
             PointBox[{52.1, 99.45114120992137}], 
             PointBox[{52.2, 99.04743673268533}], 
             PointBox[{52.3, 99.83991437420099}], 
             PointBox[{52.4, 99.34682933531796}], 
             PointBox[{52.5, 98.48702920048977}], 
             PointBox[{52.6, 99.37638575892261}], 
             PointBox[{52.7, 99.29206308268938}], 
             PointBox[{52.8, 99.03325809237907}], 
             PointBox[{52.9, 99.78462392003522}], 
             PointBox[{53., 100.15482091417037`}], 
             PointBox[{53.1, 99.2563247026401}], 
             PointBox[{53.2, 99.8745406531599}], 
             PointBox[{53.3, 100.25504538799476`}], 
             PointBox[{53.4, 99.49238686147905}], 
             PointBox[{53.5, 98.80138300749744}], 
             PointBox[{53.6, 100.24327102802526`}], 
             PointBox[{53.7, 99.44313436269323}], 
             PointBox[{53.8, 99.77209672029699}], 
             PointBox[{53.9, 100.82424554593035`}], 
             PointBox[{54., 101.77000747378528`}], 
             PointBox[{54.1, 100.6480783012147}], 
             PointBox[{54.2, 101.81519892073112`}], 
             PointBox[{54.3, 101.87351549341338`}], 
             PointBox[{54.4, 100.93211203098723`}], 
             PointBox[{54.5, 100.52615108119257`}], 
             PointBox[{54.6, 102.05999251115401`}], 
             PointBox[{54.7, 101.00969275114369`}], 
             PointBox[{54.8, 101.83668850297141`}], 
             PointBox[{54.9, 103.40428951797479`}], 
             PointBox[{55., 104.90883216868617`}], 
             PointBox[{55.1, 103.7344740900715}], 
             PointBox[{55.2, 105.13301298623801`}], 
             PointBox[{55.3, 104.99387362039752`}], 
             PointBox[{55.4, 103.93284238783757`}], 
             PointBox[{55.5, 103.76769659538402`}], 
             PointBox[{55.6, 105.25450039490448`}], 
             PointBox[{55.7, 104.14014218039753`}], 
             PointBox[{55.8, 105.37267024696493`}], 
             PointBox[{55.9, 107.67627869978944`}], 
             PointBox[{56., 109.45028274218166`}], 
             PointBox[{56.1, 108.2768495951748}], 
             PointBox[{56.2, 109.79652907524681`}], 
             PointBox[{56.3, 109.57601415275423`}], 
             PointBox[{56.4, 108.42567904132713`}], 
             PointBox[{56.5, 108.37103113878311`}], 
             PointBox[{56.6, 109.86707832271131`}], 
             PointBox[{56.7, 108.70603978068414`}], 
             PointBox[{56.8, 110.22713687968326`}], 
             PointBox[{56.9, 113.2103004199229}], 
             PointBox[{57., 115.14242756199693`}], 
             PointBox[{57.1, 113.93665512235339`}], 
             PointBox[{57.2, 115.53023659669705`}], 
             PointBox[{57.3, 115.33446887704321`}], 
             PointBox[{57.4, 114.11304750137808`}], 
             PointBox[{57.5, 114.03605903522124`}], 
             PointBox[{57.6, 115.61845568446593`}], 
             PointBox[{57.7, 114.405277761652}], 
             PointBox[{57.8, 116.06188731117723`}], 
             PointBox[{57.9, 119.5183127480426}], 
             PointBox[{58., 121.62295691017648`}], 
             PointBox[{58.1, 120.37510904552421`}], 
             PointBox[{58.2, 121.97577615933372`}], 
             PointBox[{58.3, 121.89708447994613`}], 
             PointBox[{58.4, 120.62762051138976`}], 
             PointBox[{58.5, 120.43397140278358`}], 
             PointBox[{58.6, 122.11940000953638`}], 
             PointBox[{58.7, 120.89271265522987`}], 
             PointBox[{58.8, 122.52212362957994`}], 
             PointBox[{58.9, 126.23898861380505`}], 
             PointBox[{59., 128.5201905716442}], 
             PointBox[{59.1, 127.27876586880332`}], 
             PointBox[{59.2, 128.78780500704565`}], 
             PointBox[{59.3, 128.89235350163136`}], 
             PointBox[{59.4, 127.60843313433593`}], 
             PointBox[{59.5, 127.25543858822563`}], 
             PointBox[{59.6, 128.99156549964562`}], 
             PointBox[{59.7, 127.83433644450281`}], 
             PointBox[{59.8, 129.30407186022427`}], 
             PointBox[{59.9, 133.09264200875094`}], 
             PointBox[{60., 135.49211635231305`}], 
             PointBox[{60.1, 134.33834181525205`}], 
             PointBox[{60.2, 135.65808113607275`}], 
             PointBox[{60.3, 135.96981108799076`}], 
             PointBox[{60.4, 134.70915089279507`}], 
             PointBox[{60.5, 134.20529771628367`}], 
             PointBox[{60.6, 135.90501461781298`}], 
             PointBox[{60.7, 134.90034277235642`}], 
             PointBox[{60.8, 136.143074624489}], 
             PointBox[{60.9, 139.8267285813478}], 
             PointBox[{61., 142.22405861116664`}], 
             PointBox[{61.1, 141.2188106535552}], 
             PointBox[{61.2, 142.3022573871515}], 
             PointBox[{61.3, 142.7918102312361}], 
             PointBox[{61.4, 141.58403715355882`}], 
             PointBox[{61.5, 140.97735297980847`}], 
             PointBox[{61.6, 142.56897763108037`}], 
             PointBox[{61.7, 141.74516669320158`}], 
             PointBox[{61.8, 142.77711291915762`}], 
             PointBox[{61.9, 146.16915465078705`}], 
             PointBox[{62., 148.40643198659302`}], 
             PointBox[{62.1, 147.54598210646964`}], 
             PointBox[{62.2, 148.43237940558274`}], 
             PointBox[{62.3, 149.01597175151213`}], 
             PointBox[{62.4, 147.872950954899}], 
             PointBox[{62.5, 147.2356071555819}], 
             PointBox[{62.6, 148.69782873437157`}], 
             PointBox[{62.7, 147.99629311711163`}], 
             PointBox[{62.8, 148.91033368281936`}], 
             PointBox[{62.9, 151.79008780886193`}], 
             PointBox[{63., 153.71123294184056`}], 
             PointBox[{63.1, 152.9189386728959}], 
             PointBox[{63.2, 153.73727065780602`}], 
             PointBox[{63.3, 154.28266153853824`}], 
             PointBox[{63.4, 153.19931950845282`}], 
             PointBox[{63.5, 152.6134330161072}], 
             PointBox[{63.6, 153.9808288073602}], 
             PointBox[{63.7, 153.26092944131923`}], 
             PointBox[{63.8, 154.17459807173097`}], 
             PointBox[{63.9, 156.30635645426796`}], 
             PointBox[{64., 157.8018028370725}], 
             PointBox[{64.1, 156.96008285541453`}], 
             PointBox[{64.2, 157.90205331535628`}], 
             PointBox[{64.3, 158.23772434839276`}], 
             PointBox[{64.4, 157.20900425885952`}], 
             PointBox[{64.5, 156.76199402095426`}], 
             PointBox[{64.6, 158.09156704491218`}], 
             PointBox[{64.7, 157.18347575237976`}], 
             PointBox[{64.8, 158.0807278978661}], 
             PointBox[{64.9, 159.40209096577303`}], 
             PointBox[{65., 160.4232887063868}], 
             PointBox[{65.1, 159.4510135736924}], 
             PointBox[{65.2, 160.69076282266346`}], 
             PointBox[{65.3, 160.63970822592015`}], 
             PointBox[{65.4, 159.68888177755795`}], 
             PointBox[{65.5, 159.47811867543933`}], 
             PointBox[{65.6, 160.75669787172558`}], 
             PointBox[{65.7, 159.59858295166978`}], 
             PointBox[{65.8, 160.18971655350182`}], 
             PointBox[{65.9, 161.03214295443038`}], 
             PointBox[{66., 161.54297250618256`}], 
             PointBox[{66.1, 160.5568468337516}], 
             PointBox[{66.2, 162.03832540923986`}], 
             PointBox[{66.3, 161.52755194991107`}], 
             PointBox[{66.4, 160.7242657957064}], 
             PointBox[{66.5, 160.86431714894212`}], 
             PointBox[{66.6, 161.8125857688772}], 
             PointBox[{66.7, 160.60571059069568`}], 
             PointBox[{66.8, 160.79893838129277`}], 
             PointBox[{66.9, 161.45384876370136`}], 
             PointBox[{67., 161.3770637125011}], 
             PointBox[{67.1, 160.90322020609327`}], 
             PointBox[{67.2, 162.0805839520588}], 
             PointBox[{67.3, 161.2627340070817}], 
             PointBox[{67.4, 160.71261744062693`}], 
             PointBox[{67.5, 161.31057488564804`}], 
             PointBox[{67.6, 161.28450652341658`}], 
             PointBox[{67.7, 160.30600925570272`}], 
             PointBox[{67.8, 160.59997376915211`}], 
             PointBox[{67.9, 161.00428335674982`}], 
             PointBox[{68., 160.30152544724703`}], 
             PointBox[{68.1, 160.97981588916147`}], 
             PointBox[{68.2, 161.15986545727685`}], 
             PointBox[{68.3, 160.3394185590511}], 
             PointBox[{68.4, 160.16090721549816`}], 
             PointBox[{68.5, 161.12283265190845`}], 
             PointBox[{68.6, 159.81962799119822`}], 
             PointBox[{68.7, 159.49747170423822`}], 
             PointBox[{68.8, 159.9337927285088}], 
             PointBox[{68.9, 159.90936724887703`}], 
             PointBox[{69., 158.99237717123435`}], 
             PointBox[{69.1, 160.43757012504364`}], 
             PointBox[{69.2, 159.7382964180475}], 
             PointBox[{69.3, 159.17509302310867`}], 
             PointBox[{69.4, 159.47035839246095`}], 
             PointBox[{69.5, 159.98430971779328`}], 
             PointBox[{69.6, 158.2583114577892}], 
             PointBox[{69.7, 158.65023462792573`}], 
             PointBox[{69.8, 158.89741669970113`}], 
             PointBox[{69.9, 158.3153763755473}], 
             PointBox[{70., 158.36146109084876`}], 
             PointBox[{70.1, 159.05460862989835`}], 
             PointBox[{70.2, 158.20821905514384`}], 
             PointBox[{70.3, 158.04171609728667`}], 
             PointBox[{70.4, 158.7623098613138}], 
             PointBox[{70.5, 157.65831717717052`}], 
             PointBox[{70.6, 157.17008415454086`}], 
             PointBox[{70.7, 157.65639438050397`}], 
             PointBox[{70.8, 157.5080419889018}], 
             PointBox[{70.9, 156.5843775316895}], 
             PointBox[{71., 157.92187559010202`}], 
             PointBox[{71.1, 157.31537404341088`}], 
             PointBox[{71.2, 156.8016442029218}], 
             PointBox[{71.3, 157.06631706198482`}], 
             PointBox[{71.4, 157.56229625878575`}], 
             PointBox[{71.5, 155.64289074517444`}], 
             PointBox[{71.6, 156.25944509318649`}], 
             PointBox[{71.7, 156.42788403951886`}], 
             PointBox[{71.8, 155.81482056408052`}], 
             PointBox[{71.9, 155.55417353027957`}], 
             PointBox[{72., 156.56313119639506`}], 
             PointBox[{72.1, 155.68168751586876`}], 
             PointBox[{72.2, 155.61391377366655`}], 
             PointBox[{72.3, 156.17698795086793`}], 
             PointBox[{72.4, 155.20491378177812`}], 
             PointBox[{72.5, 154.6280275979418}], 
             PointBox[{72.6, 155.21587911856417`}], 
             PointBox[{72.7, 154.95906226336334`}], 
             PointBox[{72.8, 154.0738537494865}], 
             PointBox[{72.9, 155.2091616734291}], 
             PointBox[{73., 154.77603986157686`}], 
             PointBox[{73.1, 154.33243447393224`}], 
             PointBox[{73.2, 154.6350730496069}], 
             PointBox[{73.3, 154.94074601744904`}], 
             PointBox[{73.4, 153.08234464088451`}], 
             PointBox[{73.5, 153.84885321953604`}], 
             PointBox[{73.6, 153.99197634424016`}], 
             PointBox[{73.7, 153.34578480543655`}], 
             PointBox[{73.8, 152.88129833355967`}], 
             PointBox[{73.9, 154.16227261728991`}], 
             PointBox[{74., 153.22900758178736`}], 
             PointBox[{74.1, 153.293851671546}], 
             PointBox[{74.2, 153.7367815922313}], 
             PointBox[{74.3, 153.0491755704712}], 
             PointBox[{74.4, 152.20330705374312`}], 
             PointBox[{74.5, 152.99746160367565`}], 
             PointBox[{74.6, 152.69466946256057`}], 
             PointBox[{74.7, 151.84172658657093`}], 
             PointBox[{74.8, 152.54017800094553`}], 
             PointBox[{74.9, 152.6048473467434}], 
             PointBox[{75., 152.1378892315301}], 
             PointBox[{75.1, 152.5533359367048}], 
             PointBox[{75.2, 152.73528475542264`}], 
             PointBox[{75.3, 151.33225663408513`}], 
             PointBox[{75.4, 151.8932311686851}], 
             PointBox[{75.5, 152.2078260827307}], 
             PointBox[{75.6, 151.56192599189444`}], 
             PointBox[{75.7, 150.87544594358093`}], 
             PointBox[{75.8, 152.31819019746047`}], 
             PointBox[{75.9, 151.44034782964317`}], 
             PointBox[{76., 151.59376535230777`}], 
             PointBox[{76.1, 152.14455292476705`}], 
             PointBox[{76.2, 152.11235444288832`}], 
             PointBox[{76.3, 150.83609270332545`}], 
             PointBox[{76.4, 151.97483203137145`}], 
             PointBox[{76.5, 151.8333035258055}], 
             PointBox[{76.6, 150.9783926698767}], 
             PointBox[{76.7, 150.86562862366156`}], 
             PointBox[{76.8, 152.01727958785276`}], 
             PointBox[{76.9, 151.1164579183046}], 
             PointBox[{77., 151.78526407731562`}], 
             PointBox[{77.1, 152.39244619519457`}], 
             PointBox[{77.2, 152.46657690747915`}], 
             PointBox[{77.3, 151.77012064492695`}], 
             PointBox[{77.4, 152.8385075006112}], 
             PointBox[{77.5, 152.35838217071205`}], 
             PointBox[{77.6, 151.4330270869178}], 
             PointBox[{77.7, 152.0032225475931}], 
             PointBox[{77.8, 152.45799562474488`}], 
             PointBox[{77.9, 151.93554602241753`}], 
             PointBox[{78., 153.0572363433955}], 
             PointBox[{78.1, 154.1608573917049}], 
             PointBox[{78.2, 154.14158358928984`}], 
             PointBox[{78.3, 154.08054066122494`}], 
             PointBox[{78.4, 154.958048335828}], 
             PointBox[{78.5, 154.23997690103658`}], 
             PointBox[{78.6, 153.33714585345183`}], 
             PointBox[{78.7, 154.3913822221569}], 
             PointBox[{78.8, 154.31571060843046`}], 
             PointBox[{78.9, 154.16291593383409`}], 
             PointBox[{79., 155.7758515976181}], 
             PointBox[{79.1, 157.727602751343}], 
             PointBox[{79.2, 157.44989759262162`}], 
             PointBox[{79.3, 157.78250699136106`}], 
             PointBox[{79.4, 158.55732585865303`}], 
             PointBox[{79.5, 157.6774891973888}], 
             PointBox[{79.6, 156.81223865200627`}], 
             PointBox[{79.7, 158.11234602444767`}], 
             PointBox[{79.8, 157.78625313247912`}], 
             PointBox[{79.9, 157.86210238382324`}], 
             PointBox[{80., 160.0221887511411}], 
             PointBox[{80.1, 162.6683811690761}], 
             PointBox[{80.2, 162.25655050062917`}], 
             PointBox[{80.3, 162.723466917943}], 
             PointBox[{80.4, 163.52183410222776`}], 
             PointBox[{80.5, 162.54197899787698`}], 
             PointBox[{80.6, 161.67156231689407`}], 
             PointBox[{80.7, 163.05710218087293`}], 
             PointBox[{80.8, 162.70395516340326`}], 
             PointBox[{80.9, 162.83572672884765`}], 
             PointBox[{81., 165.49612746275918`}], 
             PointBox[{81.1, 168.58462866092626`}], 
             PointBox[{81.2, 168.20743551518146`}], 
             PointBox[{81.3, 168.60073078489677`}], 
             PointBox[{81.4, 169.53225951309582`}], 
             PointBox[{81.5, 168.51044566974736`}], 
             PointBox[{81.6, 167.5831289135428}], 
             PointBox[{81.7, 168.93839108175828`}], 
             PointBox[{81.8, 168.73077749576078`}], 
             PointBox[{81.9, 168.75464179109295`}], 
             PointBox[{82., 171.76936700149884`}], 
             PointBox[{82.1, 175.12067612331248`}], 
             PointBox[{82.2, 174.9161796949705}], 
             PointBox[{82.3, 175.08130401924808`}], 
             PointBox[{82.4, 176.21442190077929`}], 
             PointBox[{82.5, 175.208622931149}], 
             PointBox[{82.6, 174.19702992209162`}], 
             PointBox[{82.7, 175.4227218404559}], 
             PointBox[{82.8, 175.48791288462323`}], 
             PointBox[{82.9, 175.28622004258116`}], 
             PointBox[{83., 178.47947952919733`}], 
             PointBox[{83.1, 181.95396786585886`}], 
             PointBox[{83.2, 182.01063126147938`}], 
             PointBox[{83.3, 181.8630164496831}], 
             PointBox[{83.4, 183.2096946685658}], 
             PointBox[{83.5, 182.27192148534564`}], 
             PointBox[{83.6, 181.1811727714992}], 
             PointBox[{83.7, 182.20368028934416`}], 
             PointBox[{83.8, 182.6017407232065}], 
             PointBox[{83.9, 182.13150555331197`}], 
             PointBox[{84., 185.34321267245875`}], 
             PointBox[{84.1, 188.79600685773133`}], 
             PointBox[{84.2, 189.12991556798247`}], 
             PointBox[{84.3, 188.67159631838427`}], 
             PointBox[{84.4, 190.18770594800034`}], 
             PointBox[{84.5, 189.35104226763391`}], 
             PointBox[{84.6, 188.21399259283132`}], 
             PointBox[{84.7, 189.00519906647398`}], 
             PointBox[{84.8, 189.71001876571646`}], 
             PointBox[{84.9, 189.00669119493887`}], 
             PointBox[{85., 192.109256904504}], 
             PointBox[{85.1, 195.37264107390877`}], 
             PointBox[{85.2, 195.9172402607483}], 
             PointBox[{85.3, 195.2270825248405}], 
             PointBox[{85.4, 196.8340712133558}], 
             PointBox[{85.5, 196.09816917064632`}], 
             PointBox[{85.6, 194.96170958056564`}], 
             PointBox[{85.7, 195.54976944007296`}], 
             PointBox[{85.8, 196.4601459211577}], 
             PointBox[{85.9, 195.61359925139647`}], 
             PointBox[{86., 198.50559142471934`}], 
             PointBox[{86.1, 201.393093121782}], 
             PointBox[{86.2, 202.0139240974567}], 
             PointBox[{86.3, 201.212602486568}], 
             PointBox[{86.4, 202.82890631160254`}], 
             PointBox[{86.5, 202.15308193157716`}], 
             PointBox[{86.6, 201.06589240160167`}], 
             PointBox[{86.7, 201.52895450655438`}], 
             PointBox[{86.8, 202.4988376876732}], 
             PointBox[{86.9, 201.62160527575094`}], 
             PointBox[{87., 204.18349809006165`}], 
             PointBox[{87.1, 206.5267940411941}], 
             PointBox[{87.2, 207.05440040394305`}], 
             PointBox[{87.3, 206.27654099959048`}], 
             PointBox[{87.4, 207.83070478331206`}], 
             PointBox[{87.5, 207.14217141594833`}], 
             PointBox[{87.6, 206.15038322870902`}], 
             PointBox[{87.7, 206.6014469703644}], 
             PointBox[{87.8, 207.4569701238378}], 
             PointBox[{87.9, 206.67844033061306`}], 
             PointBox[{88., 208.69749327469813`}], 
             PointBox[{88.1, 210.43393252284162`}], 
             PointBox[{88.2, 210.69860532235214`}], 
             PointBox[{88.3, 210.11193261312806`}], 
             PointBox[{88.4, 211.50389518022803`}], 
             PointBox[{88.5, 210.73039289638973`}], 
             PointBox[{88.6, 209.88319124320734`}], 
             PointBox[{88.7, 210.45358747762748`}], 
             PointBox[{88.8, 210.96565880124172`}], 
             PointBox[{88.9, 210.4426444298664}], 
             PointBox[{89., 211.66973966093818`}], 
             PointBox[{89.1, 212.88960774345094`}], 
             PointBox[{89.2, 212.74384300857227`}], 
             PointBox[{89.3, 212.61338336866356`}], 
             PointBox[{89.4, 213.62963886394286`}], 
             PointBox[{89.5, 212.75632199163852`}], 
             PointBox[{89.6, 212.1178872830098}], 
             PointBox[{89.7, 212.9312529027863}], 
             PointBox[{89.8, 212.79254659911211`}], 
             PointBox[{89.9, 212.54820502931813`}], 
             PointBox[{90., 213.1241390794616}], 
             PointBox[{90.1, 213.92868931725877`}], 
             PointBox[{90.2, 213.28683918509546`}], 
             PointBox[{90.3, 213.93339822872133`}], 
             PointBox[{90.4, 214.266484831421}], 
             PointBox[{90.5, 213.37806297785764`}], 
             PointBox[{90.6, 213.03777151870938`}], 
             PointBox[{90.7, 214.11295806009335`}], 
             PointBox[{90.8, 213.1403675325349}], 
             PointBox[{90.9, 212.9561407191966}], 
             PointBox[{91., 213.44724813954045`}], 
             PointBox[{91.1, 213.80954029435907`}], 
             PointBox[{91.2, 212.8408461775766}], 
             PointBox[{91.3, 214.2135181703657}], 
             PointBox[{91.4, 213.7799758258911}], 
             PointBox[{91.5, 213.03165603675217`}], 
             PointBox[{91.6, 213.10413322189973`}], 
             PointBox[{91.7, 214.05138782478744`}], 
             PointBox[{91.8, 212.55062903250345`}], 
             PointBox[{91.9, 212.55716026869908`}], 
             PointBox[{92., 213.02134414648287`}], 
             PointBox[{92.1, 212.82039733938396`}], 
             PointBox[{92.2, 212.3088452472129}], 
             PointBox[{92.3, 213.49657146862248`}], 
             PointBox[{92.4, 212.65973901867798`}], 
             PointBox[{92.5, 212.2065504539487}], 
             PointBox[{92.6, 212.78221387591037`}], 
             PointBox[{92.7, 212.6179459960576}], 
             PointBox[{92.8, 211.45082920122002`}], 
             PointBox[{92.9, 211.85537153903206`}], 
             PointBox[{93., 212.05894160925556`}], 
             PointBox[{93.1, 211.26609658079622`}], 
             PointBox[{93.2, 212.07487853401148`}], 
             PointBox[{93.3, 212.07846954992388`}], 
             PointBox[{93.4, 211.31762806424416`}], 
             PointBox[{93.5, 211.276705222871}], 
             PointBox[{93.6, 212.15105769264645`}], 
             PointBox[{93.7, 210.52468137938683`}], 
             PointBox[{93.8, 210.49668051926722`}], 
             PointBox[{93.9, 210.89249160395605`}], 
             PointBox[{94., 210.64489688104788`}], 
             PointBox[{94.1, 209.830018342263}], 
             PointBox[{94.2, 211.2599257159131}], 
             PointBox[{94.3, 210.4286822478283}], 
             PointBox[{94.4, 210.01842353012006`}], 
             PointBox[{94.5, 210.43661807241273`}], 
             PointBox[{94.6, 210.5486891827193}], 
             PointBox[{94.7, 208.9717682054002}], 
             PointBox[{94.8, 209.56248594260836`}], 
             PointBox[{94.9, 209.64119546472918`}], 
             PointBox[{95., 208.8934779739066}], 
             PointBox[{95.1, 209.29299450308844`}], 
             PointBox[{95.2, 209.64307527700774`}], 
             PointBox[{95.3, 208.87632781081888`}], 
             PointBox[{95.4, 208.89380333395306`}], 
             PointBox[{95.5, 209.57065583423065`}], 
             PointBox[{95.6, 207.9966062674805}], 
             PointBox[{95.7, 208.03600956315069`}], 
             PointBox[{95.8, 208.45477820556647`}], 
             PointBox[{95.9, 208.10194535314682`}], 
             PointBox[{96., 207.25036223046223`}], 
             PointBox[{96.1, 208.6934165853014}], 
             PointBox[{96.2, 207.87706746189966`}], 
             PointBox[{96.3, 207.56029831474112`}], 
             PointBox[{96.4, 207.9465715285104}], 
             PointBox[{96.5, 208.01722792452026`}], 
             PointBox[{96.6, 206.34080507235015`}], 
             PointBox[{96.7, 207.13353172164645`}], 
             PointBox[{96.8, 207.12978038342416`}], 
             PointBox[{96.9, 206.38132484207787`}], 
             PointBox[{97., 206.46017412556347`}], 
             PointBox[{97.1, 207.15817117818278`}], 
             PointBox[{97.2, 206.37299278174117`}], 
             PointBox[{97.3, 206.50011912144402`}], 
             PointBox[{97.4, 206.98041211377384`}], 
             PointBox[{97.5, 205.65007779894665`}], 
             PointBox[{97.6, 205.57150876515223`}], 
             PointBox[{97.7, 206.0803905412753}], 
             PointBox[{97.8, 205.6556670218656}], 
             PointBox[{97.9, 204.81396871933023`}], 
             PointBox[{98., 206.11484250528483`}], 
             PointBox[{98.1, 205.4648933891639}], 
             PointBox[{98.2, 205.23591581903406`}], 
             PointBox[{98.3, 205.64099839014935`}], 
             PointBox[{98.4, 205.6365193114395}], 
             PointBox[{98.5, 204.00301271109092`}], 
             PointBox[{98.6, 204.95228991994753`}], 
             PointBox[{98.7, 204.96566674229643`}], 
             PointBox[{98.8, 204.22307660880296`}], 
             PointBox[{98.9, 203.92886586784067`}], 
             PointBox[{99., 205.11927153919254`}], 
             PointBox[{99.1, 204.2101743133103}], 
             PointBox[{99.2, 204.49193871927898`}], 
             PointBox[{99.3, 204.88898003995882`}], 
             PointBox[{99.4, 204.25759811515806`}], 
             PointBox[{99.5, 203.59328991879818`}], 
             PointBox[{99.6, 204.44414239994617`}], 
             PointBox[{99.7, 204.0398036601062}], 
             PointBox[{99.8, 203.17680785522919`}], 
             PointBox[{99.9, 203.89269698219982`}], 
             PointBox[{100., 203.99253974531428`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {0, 360}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[\\\"\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\
\\\" -> \\\"\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {3, 
             40}]], {189., -205.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[
           {Thickness[0.006], 
            LineBox[{{0, -180}, {100, -180}, {100, 180}, {0, 180}, {
             0, -180}}], 
            {RGBColor[0.368417, 0.506779, 0.709798], PointBox[{0, 0.}], 
             PointBox[{0.1, -1.8807459156163873`}], 
             PointBox[{0.2, -5.30704639258505}], 
             PointBox[{0.3, -7.896141271188071}], 
             PointBox[{0.4, -9.647811548602476}], 
             PointBox[{0.5, -13.373926932476252`}], 
             PointBox[{0.6, -15.650084802775723`}], 
             PointBox[{0.7, -17.826749314018855`}], 
             PointBox[{0.8, -20.873504445849562`}], 
             PointBox[{0.9, -24.126256634429637`}], 
             PointBox[{1., -24.69861900896143}], 
             PointBox[{1.1, -28.12562257581868}], 
             PointBox[{1.2, -31.062746341615366`}], 
             PointBox[{1.3, -33.09618186112061}], 
             PointBox[{1.4, -35.11781748867725}], 
             PointBox[{1.5, -39.01830859868119}], 
             PointBox[{1.6, -40.68977514559333}], 
             PointBox[{1.7, -43.35267965827961}], 
             PointBox[{1.8, -46.55512759241435}], 
             PointBox[{1.9, -48.37432900390388}], 
             PointBox[{2., -49.94975879048411}], 
             PointBox[{2.1, -53.35005412799728}], 
             PointBox[{2.2, -55.643128195808}], 
             PointBox[{2.3, -57.22614314724888}], 
             PointBox[{2.4, -60.39645848162377}], 
             PointBox[{2.5, -62.88865702530984}], 
             PointBox[{2.6, -64.90861548564658}], 
             PointBox[{2.7, -67.8158981115514}], 
             PointBox[{2.8, -70.50906339792368}], 
             PointBox[{2.9, -71.03470464724433}], 
             PointBox[{3., -74.0589910163319}], 
             PointBox[{3.1, -76.72403471033203}], 
             PointBox[{3.2, -78.38329257081796}], 
             PointBox[{3.3, -79.92103935769933}], 
             PointBox[{3.4, -83.65438753099897}], 
             PointBox[{3.5, -85.03150414383254}], 
             PointBox[{3.6, -87.46452002076057}], 
             PointBox[{3.7, -90.20058749276177}], 
             PointBox[{3.8, -91.80038630881427}], 
             PointBox[{3.9, -92.53422864868344}], 
             PointBox[{4., -95.74295489531596}], 
             PointBox[{4.1, -97.59184735700092}], 
             PointBox[{4.2, -98.70724256517315}], 
             PointBox[{4.3, -100.73429787604528`}], 
             PointBox[{4.4, -103.62558913069961`}], 
             PointBox[{4.5, -104.90686796568343`}], 
             PointBox[{4.6, -107.46977672334242`}], 
             PointBox[{4.7, -109.52386745826198`}], 
             PointBox[{4.8, -110.36535381225167`}], 
             PointBox[{4.9, -111.84758717511204`}], 
             PointBox[{5., -114.38599064765458`}], 
             PointBox[{5.1, -115.48029309377125`}], 
             PointBox[{5.2, -116.20646536268578`}], 
             PointBox[{5.3, -118.8000946408165}], 
             PointBox[{5.4, -120.35762846555053`}], 
             PointBox[{5.5, -121.86069111713005`}], 
             PointBox[{5.6, -124.25877925601617`}], 
             PointBox[{5.7, -125.74597575911184`}], 
             PointBox[{5.8, -126.08270468813407`}], 
             PointBox[{5.9, -128.10265410456577`}], 
             PointBox[{6., -129.83419562708787`}], 
             PointBox[{6.1, -130.26028129043198`}], 
             PointBox[{6.2, -130.75664461414726`}], 
             PointBox[{6.3, -133.4814616465119}], 
             PointBox[{6.4, -134.02757377816033`}], 
             PointBox[{6.5, -135.6574145022405}], 
             PointBox[{6.6, -137.78076653741573`}], 
             PointBox[{6.7, -139.3761798543528}], 
             PointBox[{6.8, -139.19438539412295`}], 
             PointBox[{6.9, -141.32389085671548`}], 
             PointBox[{7., -142.37978051672144`}], 
             PointBox[{7.1, -142.24309093678585`}], 
             PointBox[{7.2, -142.58974532521825`}], 
             PointBox[{7.3, -145.09134286502558`}], 
             PointBox[{7.4, -145.01251802590923`}], 
             PointBox[{7.5, -146.65606909517646`}], 
             PointBox[{7.6, -148.71124510822847`}], 
             PointBox[{7.7, -150.56657795968113`}], 
             PointBox[{7.8, -150.0063595858801}], 
             PointBox[{7.9, -152.03136229843494`}], 
             PointBox[{8., -152.61234568466443`}], 
             PointBox[{8.1, -152.03037165427668`}], 
             PointBox[{8.2, -152.21919669264844`}], 
             PointBox[{8.3, -154.4443456783847}], 
             PointBox[{8.4, -153.95604696909777`}], 
             PointBox[{8.5, -155.55469784901015`}], 
             PointBox[{8.6, -157.81003718264674`}], 
             PointBox[{8.7, -159.80482745383415`}], 
             PointBox[{8.8, -158.98292090283667`}], 
             PointBox[{8.9, -160.85927678643566`}], 
             PointBox[{9., -161.17508631488363`}], 
             PointBox[{9.1, -160.26325853823164`}], 
             PointBox[{9.2, -160.25331264639317`}], 
             PointBox[{9.3, -162.2938661981707}], 
             PointBox[{9.4, -161.52932506322122`}], 
             PointBox[{9.5, -163.03365741561083`}], 
             PointBox[{9.6, -165.56088452430413`}], 
             PointBox[{9.7, -167.64849894344025`}], 
             PointBox[{9.8, -166.65864679985316`}], 
             PointBox[{9.9, -168.3742571411085}], 
             PointBox[{10., -168.61757457534713`}], 
             PointBox[{10.1, -167.48592091177125`}], 
             PointBox[{10.2, -167.24982718164847`}], 
             PointBox[{10.3, -169.19112084555582`}], 
             PointBox[{10.4, -168.2864290465941}], 
             PointBox[{10.5, -169.63080686759258`}], 
             PointBox[{10.6, -172.36663847552518`}], 
             PointBox[{10.7, -174.5607301770906}], 
             PointBox[{10.8, -173.52293031301087`}], 
             PointBox[{10.9, -175.0425112820585}], 
             PointBox[{11., -175.37211411352473`}], 
             PointBox[{11.1, -174.12878069505496`}], 
             PointBox[{11.2, -173.67589039631002`}], 
             PointBox[{11.3, -175.5438447853976}], 
             PointBox[{11.4, -174.65974301727147`}], 
             PointBox[{11.5, -175.7804036077805}], 
             PointBox[{11.6, -178.62375065387278`}], 
             PointBox[{11.7, 179.07920676723188`}], 
             PointBox[{11.8, -179.97915524452947`}], 
             PointBox[{11.9, 178.74009857588135`}], 
             PointBox[{12., 178.2130363073229}], 
             PointBox[{12.1, 179.461850004609}], 
             PointBox[{12.2, -179.92219226936322`}], 
             PointBox[{12.3, 178.2985824309726}], 
             PointBox[{12.4, 179.0044495278962}], 
             PointBox[{12.5, 178.13231313622236`}], 
             PointBox[{12.6, 175.28598815823898`}], 
             PointBox[{12.7, 172.92946073563326`}], 
             PointBox[{12.8, 173.64570365621694`}], 
             PointBox[{12.9, 172.60536472161766`}], 
             PointBox[{13., 171.82533989558215`}], 
             PointBox[{13.1, 172.98140696442533`}], 
             PointBox[{13.2, 173.66511746048855`}], 
             PointBox[{13.3, 171.98216170734486`}], 
             PointBox[{13.4, 172.40213024379773`}], 
             PointBox[{13.5, 171.73400584262163`}], 
             PointBox[{13.6, 168.98993653140678`}], 
             PointBox[{13.7, 166.64154612484344`}], 
             PointBox[{13.8, 167.05909097805306`}], 
             PointBox[{13.9, 166.17554687482152`}], 
             PointBox[{14., 165.13990735338666`}], 
             PointBox[{14.1, 166.12028064021615`}], 
             PointBox[{14.2, 166.74384206761533`}], 
             PointBox[{14.3, 165.11459688453397`}], 
             PointBox[{14.4, 165.2218902302575}], 
             PointBox[{14.5, 164.63415635139427`}], 
             PointBox[{14.6, 162.10671599083798`}], 
             PointBox[{14.7, 159.82361447406402`}], 
             PointBox[{14.8, 159.93647233784213`}], 
             PointBox[{14.9, 159.02984553216265`}], 
             PointBox[{15., 157.77755252153656`}], 
             PointBox[{15.1, 158.5158366250762}], 
             PointBox[{15.2, 158.9302737768412}], 
             PointBox[{15.3, 157.24121090943663`}], 
             PointBox[{15.4, 157.09344101272472`}], 
             PointBox[{15.5, 156.40364596958534`}], 
             PointBox[{15.6, 154.2133006955246}], 
             PointBox[{15.7, 152.00160000277356`}], 
             PointBox[{15.8, 151.85622137773498`}], 
             PointBox[{15.9, 150.66404066462928`}], 
             PointBox[{16., 149.27052587967592`}], 
             PointBox[{16.1, 149.70734967756835`}], 
             PointBox[{16.2, 149.75133337549414`}], 
             PointBox[{16.3, 147.83261611091257`}], 
             PointBox[{16.4, 147.5516571123626}], 
             PointBox[{16.5, 146.59241903285692`}], 
             PointBox[{16.6, 144.7757475912622}], 
             PointBox[{16.7, 142.5792727374701}], 
             PointBox[{16.8, 142.24277196674848`}], 
             PointBox[{16.9, 140.4608346411078}], 
             PointBox[{17., 139.04769602573288`}], 
             PointBox[{17.1, 139.1125852985424}], 
             PointBox[{17.2, 138.6200771445474}], 
             PointBox[{17.3, 136.30388701955962`}], 
             PointBox[{17.4, 136.03230160427483`}], 
             PointBox[{17.5, 134.82882829602931`}], 
             PointBox[{17.6, 133.08632629457497`}], 
             PointBox[{17.7, 130.85807932985153`}], 
             PointBox[{17.8, 130.3618497034895}], 
             PointBox[{17.9, 127.76516812908449`}], 
             PointBox[{18., 126.47781009458413`}], 
             PointBox[{18.1, 126.07803731856075`}], 
             PointBox[{18.2, 124.89344085073208`}], 
             PointBox[{18.3, 122.1563635742059}], 
             PointBox[{18.4, 121.9297252008837}], 
             PointBox[{18.5, 120.62883385016175`}], 
             PointBox[{18.6, 118.43656655750601`}], 
             PointBox[{18.7, 116.25064204906084`}], 
             PointBox[{18.8, 115.41694082057256`}], 
             PointBox[{18.9, 112.16383008022422`}], 
             PointBox[{19., 111.03203771749213`}], 
             PointBox[{19.1, 110.06511163651703`}], 
             PointBox[{19.2, 108.05845546819364`}], 
             PointBox[{19.3, 105.29948079628048`}], 
             PointBox[{19.4, 104.94063187766915`}], 
             PointBox[{19.5, 103.19166407512603`}], 
             PointBox[{19.6, 100.54934566394877`}], 
             PointBox[{19.7, 98.60821972046688}], 
             PointBox[{19.8, 96.8231497504421}], 
             PointBox[{19.9, 93.70165660157181}], 
             PointBox[{20., 92.5189246168029}], 
             PointBox[{20.1, 90.89602464765449}], 
             PointBox[{20.2, 88.01328186462706}], 
             PointBox[{20.3, 86.09113747794436}], 
             PointBox[{20.4, 85.13666134680352}], 
             PointBox[{20.5, 82.49598160689129}], 
             PointBox[{20.6, 79.77681215630037}], 
             PointBox[{20.7, 78.20706830252311}], 
             PointBox[{20.8, 74.94209918435809}], 
             PointBox[{20.9, 72.70481029975417}], 
             PointBox[{21., 71.16865283045445}], 
             PointBox[{21.1, 68.82435776931015}], 
             PointBox[{21.2, 65.35586193258678}], 
             PointBox[{21.3, 64.61093071047435}], 
             PointBox[{21.4, 62.348604887847614`}], 
             PointBox[{21.5, 59.31095094149896}], 
             PointBox[{21.6, 56.8781998184586}], 
             PointBox[{21.7, 55.17860465441663}], 
             PointBox[{21.8, 51.24452380933326}], 
             PointBox[{21.9, 49.587110712654976`}], 
             PointBox[{22., 47.50228025518118}], 
             PointBox[{22.1, 44.426008698637816`}], 
             PointBox[{22.2, 41.57158800121033}], 
             PointBox[{22.3, 40.724440425741705`}], 
             PointBox[{22.4, 37.48253398666202}], 
             PointBox[{22.5, 34.583011487415206`}], 
             PointBox[{22.6, 32.64188153390205}], 
             PointBox[{22.7, 29.6303752272579}], 
             PointBox[{22.8, 26.686281210646484`}], 
             PointBox[{22.9, 24.859744212069927`}], 
             PointBox[{23., 22.17710840973814}], 
             PointBox[{23.1, 18.618452744107344`}], 
             PointBox[{23.2, 17.544207355233084`}], 
             PointBox[{23.3, 14.921675932579092`}], 
             PointBox[{23.4, 11.658626615058893`}], 
             PointBox[{23.5, 9.19163260019559}], 
             PointBox[{23.6, 7.4301211782803875`}], 
             PointBox[{23.7, 3.3252247157106467`}], 
             PointBox[{23.8, 1.482073034687346}], 
             PointBox[{23.9, -0.8583156394452089}], 
             PointBox[{24., -4.051679116430023}], 
             PointBox[{24.1, -7.031377726558276}], 
             PointBox[{24.2, -7.8402860869973665`}], 
             PointBox[{24.3, -11.390316686218284`}], 
             PointBox[{24.4, -14.2159862203589}], 
             PointBox[{24.5, -16.154434320480505`}], 
             PointBox[{24.6, -18.841407439813338`}], 
             PointBox[{24.7, -22.161707328643388`}], 
             PointBox[{24.8, -24.022873146503116`}], 
             PointBox[{24.9, -26.847703052008}], 
             PointBox[{25., -30.200884695768764`}], 
             PointBox[{25.1, -31.35194945006515}], 
             PointBox[{25.2, -33.9075715708168}], 
             PointBox[{25.3, -37.13893777326666}], 
             PointBox[{25.4, -39.38702996186112}], 
             PointBox[{25.5, -41.05054310463311}], 
             PointBox[{25.6, -44.94634623365346}], 
             PointBox[{25.7, -46.82737387466477}], 
             PointBox[{25.8, -49.18117201558562}], 
             PointBox[{25.9, -52.25318490173959}], 
             PointBox[{26., -54.86138960176686}], 
             PointBox[{26.1, -55.48231267851588}], 
             PointBox[{26.2, -58.987612919008825`}], 
             PointBox[{26.3, -61.52870734998942}], 
             PointBox[{26.4, -63.21274359450763}], 
             PointBox[{26.5, -65.34572438115356}], 
             PointBox[{26.6, -68.86430892859062}], 
             PointBox[{26.7, -70.44025494353264}], 
             PointBox[{26.8, -73.15473446677424}], 
             PointBox[{26.9, -76.0024796766993}], 
             PointBox[{27., -77.18586756048171}], 
             PointBox[{27.1, -78.97887874822118}], 
             PointBox[{27.2, -82.04804324168072}], 
             PointBox[{27.3, -83.87435788149014}], 
             PointBox[{27.4, -85.16805508299512}], 
             PointBox[{27.5, -88.27436827261408}], 
             PointBox[{27.6, -90.31285583803401}], 
             PointBox[{27.7, -92.2622071556325}], 
             PointBox[{27.8, -94.99474369303425}], 
             PointBox[{27.9, -96.98726495831943}], 
             PointBox[{28., -97.39716159074305}], 
             PointBox[{28.1, -100.21087403282218`}], 
             PointBox[{28.2, -102.42192793431241`}], 
             PointBox[{28.3, -103.58962398034419`}], 
             PointBox[{28.4, -104.82305191683918`}], 
             PointBox[{28.5, -108.21164679098365`}], 
             PointBox[{28.6, -109.21299421018557`}], 
             PointBox[{28.7, -111.46018385850039`}], 
             PointBox[{28.8, -113.7945190731225}], 
             PointBox[{28.9, -115.11514996533515`}], 
             PointBox[{29., -115.47164385307042`}], 
             PointBox[{29.1, -118.33833670365857`}], 
             PointBox[{29.2, -119.70761051921}], 
             PointBox[{29.3, -120.30430156134389`}], 
             PointBox[{29.4, -121.75874702579313`}], 
             PointBox[{29.5, -124.46757432738013`}], 
             PointBox[{29.6, -125.16263747739504`}], 
             PointBox[{29.7, -127.47292485450453`}], 
             PointBox[{29.8, -129.23761119575647`}], 
             PointBox[{29.9, -130.3400603888731}], 
             PointBox[{30., -130.8740557592937}], 
             PointBox[{30.1, -133.25665591039797`}], 
             PointBox[{30.2, -133.8934987391549}], 
             PointBox[{30.3, -134.02560012087997`}], 
             PointBox[{30.4, -135.7027782034238}], 
             PointBox[{30.5, -137.45357658206922`}], 
             PointBox[{30.6, -138.07481779199952`}], 
             PointBox[{30.7, -140.32464169191007`}], 
             PointBox[{30.8, -142.01298749065245`}], 
             PointBox[{30.9, -142.8027636559309}], 
             PointBox[{31., -143.47565434561693`}], 
             PointBox[{31.1, -145.34901071778222`}], 
             PointBox[{31.2, -145.39108639107872`}], 
             PointBox[{31.3, -145.15537258751283`}], 
             PointBox[{31.4, -146.87861461820648`}], 
             PointBox[{31.5, -147.88027909618177`}], 
             PointBox[{31.6, -148.39103781136873`}], 
             PointBox[{31.7, -150.61959220180142`}], 
             PointBox[{31.8, -152.66072342285042`}], 
             PointBox[{31.9, -153.06829054161062`}], 
             PointBox[{32., -153.69957252523818`}], 
             PointBox[{32.1, -155.23591447462604`}], 
             PointBox[{32.2, -154.83643143341033`}], 
             PointBox[{32.3, -154.29921263918732`}], 
             PointBox[{32.4, -155.91753608709405`}], 
             PointBox[{32.5, -156.4920551851792}], 
             PointBox[{32.6, -156.80677912912506`}], 
             PointBox[{32.7, -159.11377249914585`}], 
             PointBox[{32.8, -161.5175974778649}], 
             PointBox[{32.9, -161.70932205482313`}], 
             PointBox[{33., -162.14004015563842`}], 
             PointBox[{33.1, -163.54092216845675`}], 
             PointBox[{33.2, -162.85431315738242`}], 
             PointBox[{33.3, -162.060605529241}], 
             PointBox[{33.4, -163.4916583278973}], 
             PointBox[{33.5, -163.92998873564648`}], 
             PointBox[{33.6, -163.972014918083}], 
             PointBox[{33.7, -166.39590374206819`}], 
             PointBox[{33.8, -169.04462506504933`}], 
             PointBox[{33.9, -169.23014651714766`}], 
             PointBox[{34., -169.3553098426637}], 
             PointBox[{34.1, -170.78392358032943`}], 
             PointBox[{34.2, -169.95689080206284`}], 
             PointBox[{34.3, -168.95444722235334`}], 
             PointBox[{34.4, -170.15015057272103`}], 
             PointBox[{34.5, -170.68284634084557`}], 
             PointBox[{34.6, -170.40773079800783`}], 
             PointBox[{34.7, -172.91096581948295`}], 
             PointBox[{34.8, -175.69421058187072`}], 
             PointBox[{34.9, -176.04190569576895`}], 
             PointBox[{35., -175.82422018056604`}], 
             PointBox[{35.1, -177.37826088246584`}], 
             PointBox[{35.2, -176.54373014479643`}], 
             PointBox[{35.3, -175.39817584164848`}], 
             PointBox[{35.4, -176.338027677044}], 
             PointBox[{35.5, -177.11526892341863`}], 
             PointBox[{35.6, -176.53675782457867`}], 
             PointBox[{35.7, -179.04766278048191`}], 
             PointBox[{35.8, 178.13236200104438`}], 
             PointBox[{35.9, 177.52440259818104`}], 
             PointBox[{36., 178.03836521222547`}], 
             PointBox[{36.1, 176.32774633407462`}], 
             PointBox[{36.2, 177.0592011065237}], 
             PointBox[{36.3, 178.2592629195642}], 
             PointBox[{36.4, 177.55498232338869`}], 
             PointBox[{36.5, 176.47559836281653`}], 
             PointBox[{36.6, 177.27331760178276`}], 
             PointBox[{36.7, 174.8223174051709}], 
             PointBox[{36.8, 172.06279681876913`}], 
             PointBox[{36.9, 171.1742657630857}], 
             PointBox[{37., 171.85844579250988`}], 
             PointBox[{37.1, 170.0021773109911}], 
             PointBox[{37.2, 170.5524294990646}], 
             PointBox[{37.3, 171.70243207875683`}], 
             PointBox[{37.4, 171.15686597997774`}], 
             PointBox[{37.5, 169.79415912982586`}], 
             PointBox[{37.6, 170.67443921033555`}], 
             PointBox[{37.7, 168.32563249878513`}], 
             PointBox[{37.8, 165.72294460022022`}], 
             PointBox[{37.9, 164.5955685791596}], 
             PointBox[{38., 165.27727949347172`}], 
             PointBox[{38.1, 163.2854716711554}], 
             PointBox[{38.2, 163.61599339247914`}], 
             PointBox[{38.3, 164.60224582103547`}], 
             PointBox[{38.4, 164.08111819156693`}], 
             PointBox[{38.5, 162.48999962447851`}], 
             PointBox[{38.6, 163.2994272169817}], 
             PointBox[{38.7, 161.07704209627627`}], 
             PointBox[{38.8, 158.70341418803218`}], 
             PointBox[{38.9, 157.40765744307646`}], 
             PointBox[{39., 157.90584450176175`}], 
             PointBox[{39.1, 155.75361435111336`}], 
             PointBox[{39.2, 155.86269954754607`}], 
             PointBox[{39.3, 156.56749494575342`}], 
             PointBox[{39.4, 155.88956302543374`}], 
             PointBox[{39.5, 154.12577810834046`}], 
             PointBox[{39.6, 154.71807023576912`}], 
             PointBox[{39.7, 152.6773795396548}], 
             PointBox[{39.8, 150.51403413819207`}], 
             PointBox[{39.9, 149.11929769951166`}], 
             PointBox[{40., 149.25266114420447`}], 
             PointBox[{40.1, 146.89446773121017`}], 
             PointBox[{40.2, 146.80067331693135`}], 
             PointBox[{40.3, 147.10140764555763`}], 
             PointBox[{40.4, 146.05549162283933`}], 
             PointBox[{40.5, 144.1898893925645}], 
             PointBox[{40.6, 144.41055559212327`}], 
             PointBox[{40.7, 142.66779739115736`}], 
             PointBox[{40.8, 140.53145916953144`}], 
             PointBox[{40.9, 139.10657027910202`}], 
             PointBox[{41., 138.6461347168697}], 
             PointBox[{41.1, 136.11500303546927`}], 
             PointBox[{41.2, 135.82174634166222`}], 
             PointBox[{41.3, 135.59254529234022`}], 
             PointBox[{41.4, 133.96350812886521`}], 
             PointBox[{41.5, 132.17121281899745`}], 
             PointBox[{41.6, 131.8623931428956}], 
             PointBox[{41.7, 130.36485640884348`}], 
             PointBox[{41.8, 128.0379413856208}], 
             PointBox[{41.9, 126.68233177393267`}], 
             PointBox[{42., 125.28335433385655`}], 
             PointBox[{42.1, 122.8299760525806}], 
             PointBox[{42.2, 122.27923561758143`}], 
             PointBox[{42.3, 121.40256684583437`}], 
             PointBox[{42.4, 119.02703834620115`}], 
             PointBox[{42.5, 117.6467334581721}], 
             PointBox[{42.6, 116.8380900646298}], 
             PointBox[{42.7, 114.99297734647553`}], 
             PointBox[{42.8, 112.4906427543865}], 
             PointBox[{42.9, 111.30094710547564`}], 
             PointBox[{43., 108.64242833312528`}], 
             PointBox[{43.1, 106.64193208736833`}], 
             PointBox[{43.2, 105.70429340128248`}], 
             PointBox[{43.3, 104.08232653279265`}], 
             PointBox[{43.4, 101.01179123527982`}], 
             PointBox[{43.5, 100.26106208333294`}], 
             PointBox[{43.6, 98.87880984343428}], 
             PointBox[{43.7, 96.31125896270532}], 
             PointBox[{43.8, 93.87238892901223}], 
             PointBox[{43.9, 92.63903285454944}], 
             PointBox[{44., 89.02445900533712}], 
             PointBox[{44.1, 87.50223453460785}], 
             PointBox[{44.2, 86.0336686237315}], 
             PointBox[{44.3, 83.59032426154226}], 
             PointBox[{44.4, 80.48993600334506}], 
             PointBox[{44.5, 80.0415059944753}], 
             PointBox[{44.6, 77.65529521317876}], 
             PointBox[{44.7, 74.77861555831623}], 
             PointBox[{44.8, 72.69524037822339}], 
             PointBox[{44.9, 70.52324148302796}], 
             PointBox[{45., 67.20039911281492}], 
             PointBox[{45.1, 65.71308267342101}], 
             PointBox[{45.2, 63.61408707758892}], 
             PointBox[{45.3, 60.36999530940011}], 
             PointBox[{45.4, 58.48606984601429}], 
             PointBox[{45.5, 57.06655495754967}], 
             PointBox[{45.6, 53.956535960162}], 
             PointBox[{45.7, 51.22189747716402}], 
             PointBox[{45.8, 49.54802943550021}], 
             PointBox[{45.9, 45.87115423085197}], 
             PointBox[{46., 43.68753277344513}], 
             PointBox[{46.1, 41.80501950672624}], 
             PointBox[{46.2, 39.03960206210468}], 
             PointBox[{46.3, 35.50557441930869}], 
             PointBox[{46.4, 34.9056790666873}], 
             PointBox[{46.5, 31.920295481591893`}], 
             PointBox[{46.6, 28.811887127805676`}], 
             PointBox[{46.7, 26.514923210677807`}], 
             PointBox[{46.8, 24.489690889327903`}], 
             PointBox[{46.9, 20.577720177796436`}], 
             PointBox[{47., 18.8617914300994}], 
             PointBox[{47.1, 16.42154921324982}], 
             PointBox[{47.2, 13.0767594080462}], 
             PointBox[{47.3, 10.746672295339522`}], 
             PointBox[{47.4, 9.312753242687904}], 
             PointBox[{47.5, 5.857615150991478}], 
             PointBox[{47.6, 3.1340894542299793`}], 
             PointBox[{47.7, 1.3180930151502253`}], 
             PointBox[{47.8, -2.1470065115499892`}], 
             PointBox[{47.9, -4.711983270739438}], 
             PointBox[{48., -6.76446841465804}], 
             PointBox[{48.1, -9.716996443574317}], 
             PointBox[{48.2, -13.14614686560526}], 
             PointBox[{48.3, -13.818936235540605`}], 
             PointBox[{48.4, -17.03765001957072}], 
             PointBox[{48.5, -20.12579148995428}], 
             PointBox[{48.6, -22.310771503325668`}], 
             PointBox[{48.7, -24.197745653749735`}], 
             PointBox[{48.8, -28.245454552787123`}], 
             PointBox[{48.9, -29.948746684960497`}], 
             PointBox[{49., -32.5156404345762}], 
             PointBox[{49.1, -35.752264652910526`}], 
             PointBox[{49.2, -38.00331412545347}], 
             PointBox[{49.3, -39.24746358597622}], 
             PointBox[{49.4, -42.76194931772625}], 
             PointBox[{49.5, -45.2414525460772}], 
             PointBox[{49.6, -46.931346125471464`}], 
             PointBox[{49.7, -49.896547849952185`}], 
             PointBox[{49.8, -52.72881869986304}], 
             PointBox[{49.9, -54.67291999152803}], 
             PointBox[{50., -57.57422068570304}], 
             PointBox[{50.1, -60.52937251566618}], 
             PointBox[{50.2, -61.21207461877202}], 
             PointBox[{50.3, -64.07942682167777}], 
             PointBox[{50.4, -66.95646453401423}], 
             PointBox[{50.5, -68.80354670123052}], 
             PointBox[{50.6, -70.35367686448444}], 
             PointBox[{50.7, -74.15230543067446}], 
             PointBox[{50.8, -75.69457146539935}], 
             PointBox[{50.9, -78.09551171937346}], 
             PointBox[{51., -80.96380296344432}], 
             PointBox[{51.1, -82.84985072987911}], 
             PointBox[{51.2, -83.52159655137075}], 
             PointBox[{51.3, -86.84351391086966}], 
             PointBox[{51.4, -88.91889099876425}], 
             PointBox[{51.5, -90.20689976491849}], 
             PointBox[{51.6, -92.21761216261075}], 
             PointBox[{51.7, -95.35854916679818}], 
             PointBox[{51.8, -96.70444033351669}], 
             PointBox[{51.9, -99.31166072584165}], 
             PointBox[{52., -101.6080029712466}], 
             PointBox[{52.1, -102.53251936644665`}], 
             PointBox[{52.2, -104.04839404796803`}], 
             PointBox[{52.3, -106.76861978341913`}], 
             PointBox[{52.4, -108.08537423123198`}], 
             PointBox[{52.5, -108.9731699397089}], 
             PointBox[{52.6, -111.65969515807228`}], 
             PointBox[{52.7, -113.42020087200217`}], 
             PointBox[{52.8, -115.02777592820348`}], 
             PointBox[{52.9, -117.51192189422}], 
             PointBox[{53., -119.06752629816037`}], 
             PointBox[{53.1, -119.45068865078792`}], 
             PointBox[{53.2, -121.6437321662379}], 
             PointBox[{53.3, -123.52078229311155`}], 
             PointBox[{53.4, -124.15604762678413`}], 
             PointBox[{53.5, -124.83574416589545`}], 
             PointBox[{53.6, -127.73195884939923`}], 
             PointBox[{53.7, -128.41217461193446`}], 
             PointBox[{53.8, -130.20145369105012`}], 
             PointBox[{53.9, -132.35160011449625`}], 
             PointBox[{54., -133.82676348730456`}], 
             PointBox[{54.1, -133.7366851890838}], 
             PointBox[{54.2, -136.0778301908722}], 
             PointBox[{54.3, -137.20453056076803`}], 
             PointBox[{54.4, -137.25337669732107`}], 
             PointBox[{54.5, -137.839626130306}], 
             PointBox[{54.6, -140.45946606293728`}], 
             PointBox[{54.7, -140.51063095784775`}], 
             PointBox[{54.8, -142.3460338367222}], 
             PointBox[{54.9, -144.30516548646847`}], 
             PointBox[{55., -145.9800133025492}], 
             PointBox[{55.1, -145.54896976933378`}], 
             PointBox[{55.2, -147.7531253066918}], 
             PointBox[{55.3, -148.30965775337245`}], 
             PointBox[{55.4, -147.88155443655705`}], 
             PointBox[{55.5, -148.37042472988105`}], 
             PointBox[{55.6, -150.6061775171911}], 
             PointBox[{55.7, -150.2501595518188}], 
             PointBox[{55.8, -152.07352431994514`}], 
             PointBox[{55.9, -154.1900203284531}], 
             PointBox[{56., -155.94659687483363`}], 
             PointBox[{56.1, -155.26118825772573`}], 
             PointBox[{56.2, -157.29612553551124`}], 
             PointBox[{56.3, -157.48300574057794`}], 
             PointBox[{56.4, -156.68657801318477`}], 
             PointBox[{56.5, -157.01678816928325`}], 
             PointBox[{56.6, -158.99298935725528`}], 
             PointBox[{56.7, -158.3186212737637}], 
             PointBox[{56.8, -160.10531199698744`}], 
             PointBox[{56.9, -162.5260862148425}], 
             PointBox[{57., -164.31337291812815`}], 
             PointBox[{57.1, -163.40592886188824`}], 
             PointBox[{57.2, -165.31170319992816`}], 
             PointBox[{57.3, -165.32330617999105`}], 
             PointBox[{57.4, -164.25981632229377`}], 
             PointBox[{57.5, -164.37524678732007`}], 
             PointBox[{57.6, -166.24655662198347`}], 
             PointBox[{57.7, -165.32980707872048`}], 
             PointBox[{57.8, -167.03515942212107`}], 
             PointBox[{57.9, -169.7139026068544}], 
             PointBox[{58., -171.58308840236714`}], 
             PointBox[{58.1, -170.51297099643125`}], 
             PointBox[{58.2, -172.30258571041486`}], 
             PointBox[{58.3, -172.31114452505426`}], 
             PointBox[{58.4, -171.07980547408806`}], 
             PointBox[{58.5, -170.95853342564078`}], 
             PointBox[{58.6, -172.8144405234343}], 
             PointBox[{58.7, -171.77009135206754`}], 
             PointBox[{58.8, -173.32809431086207`}], 
             PointBox[{58.9, -176.16044253498694`}], 
             PointBox[{59., -178.15692513158865`}], 
             PointBox[{59.1, -177.03754712448426`}], 
             PointBox[{59.2, -178.68230390636745`}], 
             PointBox[{59.3, -178.8244809291864}], 
             PointBox[{59.4, -177.52710931986803`}], 
             PointBox[{59.5, -177.19296463322826`}], 
             PointBox[{59.6, -179.0472268524536}], 
             PointBox[{59.7, -178.02630339506868`}], 
             PointBox[{59.8, -179.38199981588696`}], 
             PointBox[{59.9, 177.7412635951332}], 
             PointBox[{60., 175.62356829582131`}], 
             PointBox[{60.1, 176.6486189658899}], 
             PointBox[{60.2, 175.1823117873646}], 
             PointBox[{60.3, 174.8178244493829}], 
             PointBox[{60.4, 176.07957706824527`}], 
             PointBox[{60.5, 176.55434693471034`}], 
             PointBox[{60.6, 174.7255407532066}], 
             PointBox[{60.7, 175.57648841338232`}], 
             PointBox[{60.8, 174.4286630054703}], 
             PointBox[{60.9, 171.61563745608873`}], 
             PointBox[{61., 169.42826571581827`}], 
             PointBox[{61.1, 170.23332353233855`}], 
             PointBox[{61.2, 168.92866885990952`}], 
             PointBox[{61.3, 168.30702942483913`}], 
             PointBox[{61.4, 169.43877420163335`}], 
             PointBox[{61.5, 169.94007731952297`}], 
             PointBox[{61.6, 168.14226797502488`}], 
             PointBox[{61.7, 168.73083828940435`}], 
             PointBox[{61.8, 167.7228580592273}], 
             PointBox[{61.9, 165.08719294118782`}], 
             PointBox[{62., 162.89627524070966`}], 
             PointBox[{62.1, 163.41279086903523`}], 
             PointBox[{62.2, 162.161683623126}], 
             PointBox[{62.3, 161.29848730764206`}], 
             PointBox[{62.4, 162.2180241014139}], 
             PointBox[{62.5, 162.60057285164658`}], 
             PointBox[{62.6, 160.7807759031566}], 
             PointBox[{62.7, 161.09632580416655`}], 
             PointBox[{62.8, 160.09063852447434`}], 
             PointBox[{62.9, 157.75193045919877`}], 
             PointBox[{63., 155.5983209217302}], 
             PointBox[{63.1, 155.82140352409624`}], 
             PointBox[{63.2, 154.41855696398852`}], 
             PointBox[{63.3, 153.37202257594618`}], 
             PointBox[{63.4, 154.0061111806208}], 
             PointBox[{63.5, 154.1050817843934}], 
             PointBox[{63.6, 152.1438867741963}], 
             PointBox[{63.7, 152.25259291843395`}], 
             PointBox[{63.8, 151.09669956279686`}], 
             PointBox[{63.9, 149.12569271838584`}], 
             PointBox[{64., 146.99784288997762`}], 
             PointBox[{64.1, 146.96234213677963`}], 
             PointBox[{64.2, 145.13794418128236`}], 
             PointBox[{64.3, 144.00529501105484`}], 
             PointBox[{64.4, 144.27721877998556`}], 
             PointBox[{64.5, 143.9174648774424}], 
             PointBox[{64.6, 141.6683089443104}], 
             PointBox[{64.7, 141.67123000033462`}], 
             PointBox[{64.8, 140.3456142052164}], 
             PointBox[{64.9, 138.57067615727283`}], 
             PointBox[{65., 136.43364159456542`}], 
             PointBox[{65.1, 136.159805197698}], 
             PointBox[{65.2, 133.6792339633903}], 
             PointBox[{65.3, 132.58004438879289`}], 
             PointBox[{65.4, 132.39774181699613`}], 
             PointBox[{65.5, 131.40652151550603`}], 
             PointBox[{65.6, 128.81019573229423`}], 
             PointBox[{65.7, 128.74019444632722`}], 
             PointBox[{65.8, 127.40303964257328`}], 
             PointBox[{65.9, 125.34388460207992`}], 
             PointBox[{66., 123.23287170551339`}], 
             PointBox[{66.1, 122.59217777222511`}], 
             PointBox[{66.2, 119.49769744035439`}], 
             PointBox[{66.3, 118.48498650426336`}], 
             PointBox[{66.4, 117.74652301397145`}], 
             PointBox[{66.5, 115.972008448196}], 
             PointBox[{66.6, 113.29083147873462`}], 
             PointBox[{66.7, 113.00722780144861`}], 
             PointBox[{66.8, 111.46348468219367`}], 
             PointBox[{66.9, 108.94025558634166`}], 
             PointBox[{67., 107.0155836827762}], 
             PointBox[{67.1, 105.51955149193236`}], 
             PointBox[{67.2, 102.4031928286131}], 
             PointBox[{67.3, 101.34361595009977`}], 
             PointBox[{67.4, 99.95704300261423}], 
             PointBox[{67.5, 97.3071565971768}], 
             PointBox[{67.6, 95.25991209984932}], 
             PointBox[{67.7, 94.50677004219324}], 
             PointBox[{67.8, 92.14590120720823}], 
             PointBox[{67.9, 89.44431796694698}], 
             PointBox[{68., 87.86730201850878}], 
             PointBox[{68.1, 84.93848533071287}], 
             PointBox[{68.2, 82.56998895537981}], 
             PointBox[{68.3, 81.19972731026792}], 
             PointBox[{68.4, 79.09275070661533}], 
             PointBox[{68.5, 75.72833321063808}], 
             PointBox[{68.6, 74.7973946008351}], 
             PointBox[{68.7, 72.93668362121389}], 
             PointBox[{68.8, 69.98563455809926}], 
             PointBox[{68.9, 67.47482997085172}], 
             PointBox[{69., 65.94015085769206}], 
             PointBox[{69.1, 62.045953121931234`}], 
             PointBox[{69.2, 60.360346410176135`}], 
             PointBox[{69.3, 58.46792736536736}], 
             PointBox[{69.4, 55.60196813901712}], 
             PointBox[{69.5, 52.473286865373666`}], 
             PointBox[{69.6, 51.873806935807806`}], 
             PointBox[{69.7, 48.84226013272564}], 
             PointBox[{69.8, 45.884382404809}], 
             PointBox[{69.9, 43.83392979305063}], 
             PointBox[{70., 41.21724462706334}], 
             PointBox[{70.1, 37.969697286847804`}], 
             PointBox[{70.2, 36.259570527327014`}], 
             PointBox[{70.3, 33.760755418101326`}], 
             PointBox[{70.4, 30.27192634002131}], 
             PointBox[{70.5, 28.78455419396778}], 
             PointBox[{70.6, 26.65898078790633}], 
             PointBox[{70.7, 23.357852097244177`}], 
             PointBox[{70.8, 20.754233262145135`}], 
             PointBox[{70.9, 19.035258163356048`}], 
             PointBox[{71., 15.048404064320493`}], 
             PointBox[{71.1, 13.044604718474147`}], 
             PointBox[{71.2, 10.863056412592414`}], 
             PointBox[{71.3, 7.794406676883227}], 
             PointBox[{71.4, 4.48960258027364}], 
             PointBox[{71.5, 3.8743364072433906`}], 
             PointBox[{71.6, 0.4274339640469407}], 
             PointBox[{71.7, -2.5453222750220448`}], 
             PointBox[{71.8, -4.627443425299134}], 
             PointBox[{71.9, -6.993270743645553}], 
             PointBox[{72., -10.654887734126532`}], 
             PointBox[{72.1, -12.435423296301451`}], 
             PointBox[{72.2, -15.14123760786606}], 
             PointBox[{72.3, -18.537946441392705`}], 
             PointBox[{72.4, -20.15879802199197}], 
             PointBox[{72.5, -22.254964417705196`}], 
             PointBox[{72.6, -25.63567097621126}], 
             PointBox[{72.7, -28.06703655529418}], 
             PointBox[{72.8, -29.763293268675625`}], 
             PointBox[{72.9, -33.498532460398565`}], 
             PointBox[{73., -35.66091906012298}], 
             PointBox[{73.1, -37.89540912720986}], 
             PointBox[{73.2, -40.952375649758324`}], 
             PointBox[{73.3, -43.922012816641654`}], 
             PointBox[{73.4, -44.4626219325437}], 
             PointBox[{73.5, -47.91691254358011}], 
             PointBox[{73.6, -50.67641231782909}], 
             PointBox[{73.7, -52.53331115926267}], 
             PointBox[{73.8, -54.51361938064656}], 
             PointBox[{73.9, -58.3012040412068}], 
             PointBox[{74., -59.88384357441828}], 
             PointBox[{74.1, -62.55230758908874}], 
             PointBox[{74.2, -65.57301853897661}], 
             PointBox[{74.3, -67.12088634724932}], 
             PointBox[{74.4, -68.65451708852925}], 
             PointBox[{74.5, -71.92602234841615}], 
             PointBox[{74.6, -73.98126468641567}], 
             PointBox[{74.7, -75.39556635695044}], 
             PointBox[{74.8, -78.38218927084381}], 
             PointBox[{74.9, -80.77329831834504}], 
             PointBox[{75., -82.68250959906436}], 
             PointBox[{75.1, -85.48409519274719}], 
             PointBox[{75.2, -87.80217039394483}], 
             PointBox[{75.3, -88.2919873933206}], 
             PointBox[{75.4, -91.06585687861661}], 
             PointBox[{75.5, -93.52673846071411}], 
             PointBox[{75.6, -94.91793754660466}], 
             PointBox[{75.7, -96.21982363003917}], 
             PointBox[{75.8, -99.72814082406694}], 
             PointBox[{75.9, -100.92909683265316`}], 
             PointBox[{76., -103.19915020436747`}], 
             PointBox[{76.1, -105.71177114547754`}], 
             PointBox[{76.2, -107.1489423108942}], 
             PointBox[{76.3, -107.58185914826754`}], 
             PointBox[{76.4, -110.58563677178608`}], 
             PointBox[{76.5, -112.19246416782698`}], 
             PointBox[{76.6, -113.00290553694504`}], 
             PointBox[{76.7, -114.55709084099362`}], 
             PointBox[{76.8, -117.4610362940075}], 
             PointBox[{76.9, -118.32265302251471`}], 
             PointBox[{77., -120.70286274545651`}], 
             PointBox[{77.1, -122.5854267191171}], 
             PointBox[{77.2, -123.64134400518378`}], 
             PointBox[{77.3, -124.36647678106965`}], 
             PointBox[{77.4, -126.87309137058037`}], 
             PointBox[{77.5, -127.71465358058776`}], 
             PointBox[{77.6, -128.0557297569976}], 
             PointBox[{77.7, -129.9355805048981}], 
             PointBox[{77.8, -131.7708946897692}], 
             PointBox[{77.9, -132.62958478224027`}], 
             PointBox[{78., -134.93277764485538`}], 
             PointBox[{78.1, -136.523594557264}], 
             PointBox[{78.2, -137.22982403618516`}], 
             PointBox[{78.3, -138.23159817470878`}], 
             PointBox[{78.4, -140.1268772133626}], 
             PointBox[{78.5, -140.3224910456047}], 
             PointBox[{78.6, -140.30115850685252`}], 
             PointBox[{78.7, -142.30440321544302`}], 
             PointBox[{78.8, -143.23608619104198`}], 
             PointBox[{78.9, -144.06668606877793`}], 
             PointBox[{79., -146.28887777977798`}], 
             PointBox[{79.1, -148.15923519124044`}], 
             PointBox[{79.2, -148.39439193333237`}], 
             PointBox[{79.3, -149.4573489944887}], 
             PointBox[{79.4, -150.8938676055477}], 
             PointBox[{79.5, -150.5826475576614}], 
             PointBox[{79.6, -150.2695504908188}], 
             PointBox[{79.7, -152.20018306381826`}], 
             PointBox[{79.8, -152.55808729171986`}], 
             PointBox[{79.9, -153.26672031890485`}], 
             PointBox[{80., -155.53748952739988`}], 
             PointBox[{80.1, -157.78518274049566`}], 
             PointBox[{80.2, -157.68918350283639`}], 
             PointBox[{80.3, -158.6255154031969}], 
             PointBox[{80.4, -159.8181866420564}], 
             PointBox[{80.5, -159.14602349288907`}], 
             PointBox[{80.6, -158.57553843306232`}], 
             PointBox[{80.7, -160.34303425114194`}], 
             PointBox[{80.8, -160.42648499566712`}], 
             PointBox[{80.9, -160.92492554386263`}], 
             PointBox[{81., -163.34046913644852`}], 
             PointBox[{81.1, -165.85627426900464`}], 
             PointBox[{81.2, -165.64280725571734`}], 
             PointBox[{81.3, -166.32487253240834`}], 
             PointBox[{81.4, -167.47149044313846`}], 
             PointBox[{81.5, -166.58047170160717`}], 
             PointBox[{81.6, -165.77963431684475`}], 
             PointBox[{81.7, -167.343373427575}], 
             PointBox[{81.8, -167.40402610455203`}], 
             PointBox[{81.9, -167.61844752040633`}], 
             PointBox[{82., -170.1743263703902}], 
             PointBox[{82.1, -172.8530968894338}], 
             PointBox[{82.2, -172.7156942852016}], 
             PointBox[{82.3, -173.063043161339}], 
             PointBox[{82.4, -174.31017260476074`}], 
             PointBox[{82.5, -173.3335451929015}], 
             PointBox[{82.6, -172.34689710173552`}], 
             PointBox[{82.7, -173.67760594074934`}], 
             PointBox[{82.8, -173.91488240085891`}], 
             PointBox[{82.9, -173.8074610700496}], 
             PointBox[{83., -176.4381852373408}], 
             PointBox[{83.1, -179.19465516002674`}], 
             PointBox[{83.2, -179.2787744826055}], 
             PointBox[{83.3, -179.2733935111828}], 
             PointBox[{83.4, 179.29827011829911`}], 
             PointBox[{83.5, -179.75879943971086`}], 
             PointBox[{83.6, -178.65714203593961`}], 
             PointBox[{83.7, -179.74599415189732`}], 
             PointBox[{83.8, 179.71458067748608`}], 
             PointBox[{83.9, -179.88138696129317`}], 
             PointBox[{84., 177.49315120450046`}], 
             PointBox[{84.1, 174.7447065959568}], 
             PointBox[{84.2, 174.36307709031098`}], 
             PointBox[{84.3, 174.65597114740376`}], 
             PointBox[{84.4, 173.02665744732076`}], 
             PointBox[{84.5, 173.83913881748595`}], 
             PointBox[{84.6, 174.95941207862052`}], 
             PointBox[{84.7, 174.0767352899711}], 
             PointBox[{84.8, 173.19821276589937`}], 
             PointBox[{84.9, 173.80222106915608`}], 
             PointBox[{85., 171.2512618161054}], 
             PointBox[{85.1, 168.6012163695923}], 
             PointBox[{85.2, 167.9206099770454}], 
             PointBox[{85.3, 168.35699661294348`}], 
             PointBox[{85.4, 166.54090572339192`}], 
             PointBox[{85.5, 167.15824678780336`}], 
             PointBox[{85.6, 168.1838487970963}], 
             PointBox[{85.7, 167.41119950560824`}], 
             PointBox[{85.8, 166.22841865345254`}], 
             PointBox[{85.9, 166.88279816408613`}], 
             PointBox[{86., 164.46055496495683`}], 
             PointBox[{86.1, 161.98823326011916`}], 
             PointBox[{86.2, 161.06182500846626`}], 
             PointBox[{86.3, 161.44929519235302`}], 
             PointBox[{86.4, 159.45851441318518`}], 
             PointBox[{86.5, 159.8506234882807}], 
             PointBox[{86.6, 160.65899606150197`}], 
             PointBox[{86.7, 159.84138887353765`}], 
             PointBox[{86.8, 158.42626132378064`}], 
             PointBox[{86.9, 158.95780246571667`}], 
             PointBox[{87., 156.73024289226305`}], 
             PointBox[{87.1, 154.45891210139234`}], 
             PointBox[{87.2, 153.36266043975047`}], 
             PointBox[{87.3, 153.487720227924}], 
             PointBox[{87.4, 151.31856615684228`}], 
             PointBox[{87.5, 151.48088437067054`}], 
             PointBox[{87.6, 151.94336433088029`}], 
             PointBox[{87.7, 150.88084091364}], 
             PointBox[{87.8, 149.32529695986887`}], 
             PointBox[{87.9, 149.54913026418217`}], 
             PointBox[{88., 147.62742020194128`}], 
             PointBox[{88.1, 145.4560800932377}], 
             PointBox[{88.2, 144.2690523814963}], 
             PointBox[{88.3, 143.88669063713314`}], 
             PointBox[{88.4, 141.56728576662135`}], 
             PointBox[{88.5, 141.49521190714586`}], 
             PointBox[{88.6, 141.47845456247887`}], 
             PointBox[{88.7, 139.95030226596282`}], 
             PointBox[{88.8, 138.4056787849695}], 
             PointBox[{88.9, 138.13820339856466`}], 
             PointBox[{89., 136.55689776365762`}], 
             PointBox[{89.1, 134.2919209318934}], 
             PointBox[{89.2, 133.1068188685167}], 
             PointBox[{89.3, 131.89814747429773`}], 
             PointBox[{89.4, 129.59603347042867`}], 
             PointBox[{89.5, 129.2469357302325}], 
             PointBox[{89.6, 128.62118852307322`}], 
             PointBox[{89.7, 126.43423693035584`}], 
             PointBox[{89.8, 125.16683945114346`}], 
             PointBox[{89.9, 124.39057820387825`}], 
             PointBox[{90., 122.72815136413556`}], 
             PointBox[{90.1, 120.29902138611214`}], 
             PointBox[{90.2, 119.21334570491308`}], 
             PointBox[{90.3, 116.8511804677837}], 
             PointBox[{90.4, 114.87558350268955`}], 
             PointBox[{90.5, 114.1470107461937}], 
             PointBox[{90.6, 112.79944117017294`}], 
             PointBox[{90.7, 109.91574208235397`}], 
             PointBox[{90.8, 109.15287723697838`}], 
             PointBox[{90.9, 107.9532506892574}], 
             PointBox[{91., 105.62015491099737`}], 
             PointBox[{91.1, 103.18524369761872`}], 
             PointBox[{91.2, 102.09985663510452`}], 
             PointBox[{91.3, 98.68365800337779}], 
             PointBox[{91.4, 97.15742091317225}], 
             PointBox[{91.5, 95.91776510428463}], 
             PointBox[{91.6, 93.7574034101417}], 
             PointBox[{91.7, 90.62233100742742}], 
             PointBox[{91.8, 90.19945628287678}], 
             PointBox[{91.9, 88.19773963406624}], 
             PointBox[{92., 85.39845347053779}], 
             PointBox[{92.1, 83.23590348425205}], 
             PointBox[{92.2, 81.44577101101459}], 
             PointBox[{92.3, 77.9755262935214}], 
             PointBox[{92.4, 76.57974801048113}], 
             PointBox[{92.5, 74.72202504995221}], 
             PointBox[{92.6, 71.7168380895746}], 
             PointBox[{92.7, 69.46431686678261}], 
             PointBox[{92.8, 68.47456188416982}], 
             PointBox[{92.9, 65.55314691986132}], 
             PointBox[{93., 62.75729537650477}], 
             PointBox[{93.1, 61.03146102394385}], 
             PointBox[{93.2, 57.7339701949968}], 
             PointBox[{93.3, 55.29363686568104}], 
             PointBox[{93.4, 53.58850080447155}], 
             PointBox[{93.5, 51.05463330200291}], 
             PointBox[{93.6, 47.50601939072658}], 
             PointBox[{93.7, 46.69944504686282}], 
             PointBox[{93.8, 44.155106783349765`}], 
             PointBox[{93.9, 41.01399583466991}], 
             PointBox[{94., 38.57196783783729}], 
             PointBox[{94.1, 36.795544711480034`}], 
             PointBox[{94.2, 32.76421397703234}], 
             PointBox[{94.3, 31.036486455399427`}], 
             PointBox[{94.4, 28.79220849617559}], 
             PointBox[{94.5, 25.608249785393127`}], 
             PointBox[{94.6, 22.760314045808627`}], 
             PointBox[{94.7, 21.81730656666332}], 
             PointBox[{94.8, 18.407094676600536`}], 
             PointBox[{94.9, 15.538804288735264`}], 
             PointBox[{95., 13.6043831743591}], 
             PointBox[{95.1, 10.564391966327094`}], 
             PointBox[{95.2, 7.582024077724782}], 
             PointBox[{95.3, 5.680270441400353}], 
             PointBox[{95.4, 2.881316838102066}], 
             PointBox[{95.5, -0.6395529195724521}], 
             PointBox[{95.6, -1.6373549974523485`}], 
             PointBox[{95.7, -4.433955323780538}], 
             PointBox[{95.8, -7.67743087427516}], 
             PointBox[{95.9, -10.048037380634923`}], 
             PointBox[{96., -11.81730697992316}], 
             PointBox[{96.1, -15.913289703777991`}], 
             PointBox[{96.2, -17.729202117800014`}], 
             PointBox[{96.3, -20.14669255905028}], 
             PointBox[{96.4, -23.349025669143884`}], 
             PointBox[{96.5, -26.126585392601555`}], 
             PointBox[{96.6, -26.97723120759474}], 
             PointBox[{96.7, -30.555187318561366`}], 
             PointBox[{96.8, -33.25155860003724}], 
             PointBox[{96.9, -35.09038121601043}], 
             PointBox[{97., -37.719662279312615`}], 
             PointBox[{97.1, -41.00451577290369}], 
             PointBox[{97.2, -42.83978754017153}], 
             PointBox[{97.3, -45.68082980236795}], 
             PointBox[{97.4, -48.857630915241316`}], 
             PointBox[{97.5, -49.89301888846967}], 
             PointBox[{97.6, -52.40538759138144}], 
             PointBox[{97.7, -55.527403560932726`}], 
             PointBox[{97.8, -57.598861933511216`}], 
             PointBox[{97.9, -59.165798586444}], 
             PointBox[{98., -62.92191396851558}], 
             PointBox[{98.1, -64.73308438679669}], 
             PointBox[{98.2, -67.04539537755772}], 
             PointBox[{98.3, -70.00769806551398}], 
             PointBox[{98.4, -72.31099940784043}], 
             PointBox[{98.5, -72.85972099681385}], 
             PointBox[{98.6, -76.24740817269776}], 
             PointBox[{98.7, -78.59719427861273}], 
             PointBox[{98.8, -80.08717252437782}], 
             PointBox[{98.9, -81.994784064329}], 
             PointBox[{99., -85.4613304255763}], 
             PointBox[{99.1, -86.84334898671659}], 
             PointBox[{99.2, -89.46157768722333}], 
             PointBox[{99.3, -92.04269238220877}], 
             PointBox[{99.4, -93.1825637549482}], 
             PointBox[{99.5, -94.582953938836}], 
             PointBox[{99.6, -97.54515927587636}], 
             PointBox[{99.7, -99.13144866116636}], 
             PointBox[{99.8, -100.18584812700283`}], 
             PointBox[{99.9, -102.85547130712075`}], 
             PointBox[{100., -104.95974599244073`}]}},
           AspectRatio->0.2,
           DisplayFunction->Identity,
           ImagePadding->{{0., 0.}, {0., 0.}},
           PlotRange->{{0, 100}, {-180, 180}},
           Prolog->InsetBox[
             FormBox[
             "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", TraditionalForm], {
             3, -140}]], {189., -287.}, ImageScaled[{0.5, 0.5}], {360, 72.},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-328., 0}},
       PlotRangePadding->{6, 5}], {570, -880.}, ImageScaled[{0.5, 0.5}], {360, 312.},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}}, {}},
  
  ImageSize->{
    UpTo[600], 
    UpTo[700]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.8804638287580137`*^9, {3.880463861521323*^9, 3.880463900353298*^9}, 
   3.8804640882192297`*^9, 3.880464229768796*^9, 3.880612987773464*^9, 
   3.8806131192733*^9, 3.880655535574394*^9, 3.880702756835305*^9, 
   3.88070347237606*^9, 3.890982093757069*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"6fe643b1-bc44-4581-987e-a28f7309dc7d"]
}, Open  ]],

Cell["Combine the labelled plots.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, 3.880462891878394*^9, {
   3.8804634457063847`*^9, 3.880463448195674*^9}, {3.8806141679440327`*^9, 
   3.8806142112342987`*^9}, {3.880614251525114*^9, 3.880614256294714*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ab998cd1-5961-4d1a-828c-99e05898f7fa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"gcA", ",", "gcB"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"gcC", ",", "gcD"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"gcE", ",", "gcF"}], "}"}]}], "}"}], ",", 
   RowBox[{"Spacings", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "20"}], ",", "40"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.880458414000092*^9, 3.880458450895536*^9}, {
  3.880458494770495*^9, 3.880458497710331*^9}, {3.880459081934146*^9, 
  3.880459106562767*^9}, {3.880463461831705*^9, 3.880463471235745*^9}, {
  3.880463587892694*^9, 3.880463716815377*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"36705bcf-3682-44e0-a7e6-5271f5a5fd58"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.0055000000000000005`], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxFm3dYU1nXxRHp0kEkgNIjSO9VsmihJEB6ghVxROwoYsOCDgoqVqyICqjY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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0.6000000000000013},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0.6, 
                FormBox["0.6`", TraditionalForm]}, {0.62, 
                FormBox["0.62`", TraditionalForm]}, {0.64, 
                FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0.6, 0.65}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Prolog->{
             Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]},
           Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
          ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.0055000000000000005`], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxFe3c8lf//vgqlNERKhBQpEtnzXPbm7HNKOw0toT2kSEsqlUgiq2SUKKMl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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"\
", BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], None}, {
             
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {0.1, 
                FormBox["0.1`", TraditionalForm]}, {0.2, 
                FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
           
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 0.2}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -159.99}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.0055000000000000005`], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxd12lczfsb7vEkIYlUyI5Kc5FqaS7rap5WteZWaRKiRIjMCclQEpnKsFNE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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\
\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}, {360, 
                FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 360.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.0055000000000000005`], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxdm3lcjen/xh+hsWRsGbJmy06EwaBji0hClkwRY1dIxjo4BmmIicaS7RuS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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{-180, 
                FormBox[
                 RowBox[{"-", "180"}], TraditionalForm]}, {0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {-180., 180.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -383.19}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-438.99, 0}},
       PlotRangePadding->{6, 5}], {146.3509209559233, -200}, 
      ImageScaled[{0.5, 0.5}], {312.7018419118466, 360},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJw9W3k8VO//lUS0SgstIhEh2Xdz7NtgFmZGVFS0L5+kfVG0ay+l/dO+l7Qv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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0.6000000000000013},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0.6, 
                FormBox["0.6`", TraditionalForm]}, {0.62, 
                FormBox["0.62`", TraditionalForm]}, {0.64, 
                FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0.6, 0.65}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Prolog->{
             Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]},
           Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
          ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJw9m3lcjVvYvwkpMkZkapA0a55rf5vn2u2hXaYyhWTMcIpIZOwoMo85EpEj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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"\
", BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], None}, {
             
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {0.1, 
                FormBox["0.1`", TraditionalForm]}, {0.2, 
                FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
           
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 0.2}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -159.99}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.0055000000000000005`], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxd13c8FQzY/3EtLUrpJiqJkqSyZX/tzdnn6FZJRsNWUipaWtpTJC0tDWlp
0R6ktKlERUsTJa2f57mv6/nj559e5+Wc9/mez7le912DQmNF4e2VlJTedlBS
+p8///+fLZn/81PkNL489N4PzyT89/iG07PzKU9fjE+C+f/+3HPqafi0qmUc
/77Sye3hzQEJNkn4T6lxmm32IafCn5//0mlgsVvG2KgkRPzvT71T9pPHB3L+
z3/rdGGW3uVjjkm4VfY/Pw1OC7YeyZsTxN5np8HDMi/PtuTnf3GaZjfm6qtP
08lvdLpdOz+oWolf3+S0eMH4ceGd+f2+OSU2pD07+Go6eS1Oom2LjWI/TCfv
h1PKmYBLUeq896fT06uh5098nU7eL6e6I+Fpy19MJ++P0/CfQf6+v9hTQpPp
7nzjBn6+EoYVau/W3sV+OxRv71WvfoBf3x67Bncy/Pck7++Ag0vVziZsYa8j
PhgMuXZ/E3sdMQdN+19fYK8TXHc6ZU7aw54yvhT+0+fSGvY648Ozb+uW7GGv
C0Z2l2bm7mGvC8YenPg0LoK9rqi7pWtwO5S9bjCdVnZkVQJ73eF1fP8b3bHs
qUDl0POHykL2VPBZsrrqaQp7qjg9rqPT1Ens9cDJ8AlFCwPZ64khH944XhnP
nhqSXndVi57Kz1dD+Nq5cfct2FeDNPplc/Awfn0vyB2ao4Jt+f16oVznZIeV
xuz1xt9bSwNearHXG9fH9Yu47cJebyxK67JO1Yo9ddgWJu793o89dcx4m3Mi
w4C9Plg2yGalxIa9PmjOOr12ggp7fZD65pDm9t/TyPsHiye3G2reg71/0Nkg
1KdFmT0N6LfaFN35PI08DXz9rbXSQoM9DZyaqxz5pgfv08RhjYWLhjdPI08T
NRH9ZjW3TiOvL0yrKsRuvXhfX1Q5NUcdfj+NvL6Y/Udyocsz3qeFScubE30a
2NOC/rEnfz6/ZU8bCSPclC7f5X3amCrTmWDVxJ42igZembz7M3v9YNPrxA2j
x+z1w8O12aLVVez1R+bnsN8fv7DXHzslcWt3VrDXH9kR+8/HX2ZvAE5HZrZY
32VvAFarDha8vcueDnrKZ/1rfpY9HQiqh9uMqWJPBwsP1I3e8Ji9gXipffaf
KxfYG4iASeYKv4vs6WLa7oYESSU/Xxeff6etHPd/vi70LPKHPTzCr9dFZPXb
oRHn+P108XR5t/dTi9kbhDxv7x/l+9gbhEPKG2f8ucLeIFx2CZH1uszeIDR2
7NSkcpi9QWjpeMBE7zB7eqh51dBv8BX29PBvfUXyxn3s6SH16+nn+dvY08PH
gp9qUw6wp4eT6+0dPA6yp4+/6eHP321mTx+yJ+K4rcfY00ewY1F90f99Xn08
vjojY9NW9vShm9j8e3YOe4Mx/k2l1e+j7A3G2LffYww3sTcYT68mf++1ir3B
iIieaeiwhb3B8HP7rZ6zhb0hmPLLMvrhYvaGoKaz56TWnewNwfXMmGvHstkb
Ao1v+4sOLmdvCGxj/KtnrmTPAB0P7Bq5Lpc9AyToqqWFL2DPAN/3xE1/Noc9
A4QvGtElZAl7Brip1bNQLZ29oeikGb+qSxJ7Q2H07FC94Vr2hsLPsL+wKp29
ocjt/Xl4SDJ7Q3HmXNh65bnsGaLml7rD4eXsGWLw/iTB0Gj2DGF0MmHE6qns
GeKJT5J31TT2DJGgVnbpYgx7w2AWNPuadhh7w+DYyaxo6xz2hqFrad6N6zHs
DcNr4aKSuRPZG4ZLHbIunIxizwgGnzeXCRLYM8LD1yHb5knYM0LUdtvMjgr2
jDDujry2/3j2jKBzuC5+uoS94dCNeBwwUMzecCzPOBk4LZy94bi1rVf5bQl7
w5ET9ywt1p+94ZioNN4hbAx7xjiXMkW28P88Y5QfsK6cbseeMR7ZRwoGubJn
DNnBhQ8ferBnjJRBAwXXrdkbgQEnXq757cLeCBTXNmle8mZvBMRfEhwLbNgb
gb7n3r98Z8XeCLTMjSka58HeSAhC8gV5JuyNxA3hB50z+uyNxE6D3p9PGLPX
9rj3jPqnw9kbiXUPZgSe0GZvFJY3BmZamrI3CtLQeS82D2dvFF7/zvqk0GFv
FIq1iy7v1WVvFD6vWJ6xZCR7JmhfbrhSU5Wer2WCZtMHk3RU2TfBR481gxf1
odf7meCOesgp8x78fiaYvm6C6mEl8tJM8Hixf/58bX5/E+ztuqzvTBXyCk1Q
5zhCc2sH3mOC4qJpfZW6k1dvgtAr3z3ievI+U5Tcvrb62IdE2meK+oCUe8u+
JdI+U8zzchvr35pI+0xhWTu8c8jHRNpnCpP6s2PnNiTSPlNknbSfOvAPeZmm
8HMcMOLGB/IKTfHVZ4mNxjvyykxRrLTizIRm8upNIV+tEdf/DXlKZrBvig/t
cZ/3mWG5qkZx5+e8z6ztv38Lun16xvvM0O3Ivthft3ifGURL1Ry0nvI+M7h9
0gm3qeZ9Zpiqe3Rcyh3eZwarwz1U2t/lfWbQHurwKv8Z7zNDUnhg9MvzvM8c
X2P6ytPO8T5z7Du7dFGnq7zPHH/OG99eWcz7zKFY8buf6hHeZ44ZUYs2/bzO
+8yhcmFWh9PsZZrj1pzGL52P8z5zPNA/Ezr4DO8zx6rtY1RcSnifOfob5tvN
z+Z9Fpho1jFi6h7eZ4Ep++74jz3A+ywQ+7zD4dvbeJ8FksZkD7q/ifdZYIbi
X0fhYd5ngRa1V7dzc3ifBSxNP65dlMX7LHDqTWjF1l28zwLDqlUHLM3ifRaI
yeqeGT6f91kiLc81dNlq3meJG1N9t3it4n2WeNdv5KnfqbzPEgu/eYZlLOJ9
lvjxPnBj+zW8zxJ+99elVMzjfZbYOclWeHkB77OEp3OQcWUG77PE6MxB69Om
8T5L3FydIn0YxfusUJ36/dreZN5nhZDvGkODEnifFX7FX5qrHMr7rDD/sO2a
rtN5nxVCuyXvqo3nfVYYYNXpelok77OCa2iXceHRvM8KetpL3a0SeJ8VrMeo
bsoW8j4rZCxdeaRMwfus8eJw6BmLEN5njUvazZ6xUt5nDbPxhdNLPXmfNQyf
WY38MIH3WUP/rvWCRRLeZ420FxNzNwfyPmt0MJ46+puc91kD62Z/tpDyvrbX
229rf8qS91nDPEoUYOnO+0ZjRcn9rx89ed9o+Er/ubfZhveNRtV6yZWBZrxv
NC45F1Qf8+V9ozHzxZI5f21432g8W5SZ+cGG943GqqPZ2QNded9o3DZq0lCy
4X2jsWXhgzvnB/K+0dizWcXTwIz32cAn5JHHPhPeZ4OGFdLftwbyPht06x3c
3VeX99lAu+bEqXUWvM8GM17a+abo8T4bHBiRUuZrwPts0Kiz9lXtSN5ng8AH
Z2fLBvI+G+Ru0J4Socr7bLBpdSfPzrq8zxZBKRsGKvfjfbZ4GWXwcUsX3meL
q8NEwefUeJ8t5kXtuH1Qh/fZwrZ5YdMeVd5ni0gDs/QJfXifLWz2RdZt68f7
bNF3jHBAYhfeZ4uURXdUbv1KoH222F/ZHPqjB++zg0xzdKxZZ95nhyc5hlfv
NibQPjsEq1pv/N6O99nBfUCszvtuvM8OklCbqrLWBNpnB7Pu8XPXd+B9dnho
rj8muyvvs4PBIM9n39v8//bZwU6rRXdcA++zg6Dsss+cP+Qp2eN+h9tfjzQl
0D57eL8sWjajhvfZ42JpZfq+r+T52cOodZriWwt5EfZoPLEm8/wb3mePdsN/
brvzlbxMe2Tds2/v2kJeoT1eLAmat7mG97W939QJ/YRVvM8ei7NKst0/8D4H
HMludXN+wfsc4PV3g+mdMt7ngIReSq2utbzPAb6zXTNTX/M+B8S5fo549ID3
OeDRv9pzJ9fwPgf46QUqadfzPgf8c6/muncZ73PA7pVVzgmXeZ8D9ljqdbWs
5H2OmCOs69xwi/c5ooPjKOXsE7zPEY5Kf4z2lPI+R3Tuk+UYd5/3OaLpvu6b
LiW8zxGzYlw6DbrJ+xxhMP73Re0K3ufYdt8JtVnHeJ8jCux8Rtns5X2O6DHC
tyGtmPc5YZFyp1aD47zPCbtC1IJ8s3ifE2o2nltsfJj3OaFII9ta5Rzvc8K9
JxrtOuzmfU44fdXMMfAg73MCbo03esaft9AJU/Kit/TcxPucEHZfs7P2At7n
hOCOjx5/zeZ9wKSb6Q1dNtDzVQANi/N59sm8F5BvCdH+voRebwAkml882ieH
96Pt7+cpN8PmkwcgP3uP2ojF/HkAC/katdj15AUBR+/dOTojnj8f0NivW/ff
IvISgcryikX/xvDnBS7c3TVh0xTyMoB3vRdlqvjy52/bWzW15zQZeXmA0+fX
BZrTuAfw/Wvw+59S8kra9o2ZM9pdyn2A9tZqFxMjyKsE0g1PTTjqwr2Ar49l
XZ5qkNcIDHi6YIm/KfdzRt+52b6e5tzPGf0tdd069eZ+zjALfx/VXoP7OeOh
vkprX3vu54y6Nz0ODNDhfs4I3nnJpIcG93PG6pFx0/sacT9nGAa/fmXRnfs5
467NueS42/HUzxnzNDycteriqZ8zPtV2vFv+IZ76OWO0Y4/c62Xx1M8ZSrpj
B1y4Fk/9nLHlltf9HU3kFTpjnKtzlHUVeSXOuGbbvjX/Bnllznj1fb9naDV5
lc542T2maE4pefXOWHfx1oaKVPIanRH7TaWlYjl5Si74YDBhjEEWeSouSD/0
ab7SHPK0XFDyYbu2OIY8AxdUf1Lt9zGHPHMXHPPo+nIpe3CBYtPyc/sTyPNz
wdmbTwo9FpEX5AK76Om9hswnL8IF2ff1Powfwf1c0DRxY2qREfdzwVWr2T42
TtzPBbdb398+bsD9XBDw59chnZ7czwV6qVkec524nwsuGy8sPGrJ/VzQTXrh
vJ4G93OB8+QrR37rcz8XaKz+MUI0ivu5IOHg3IB/quOonwtmrFe6G3ojjvq5
IujhH9XEmjjq5wpJ7R75gdtx1M8VAbE1WRML4qifK0Z9ub8+8hl55q7Imid6
419NHlzxrdXL/sFp8vxccabU8nDPi+QFueJ5q/DvvkfkRbjiTdPtAS4byEt0
xZKUndbrYslLc0XuzMPLO6STl+EK87xOn0vnkJfpiu7Rf9SHB5OX54pXn3Uv
idLIK3RFkmXXacnLyStxxe+td1/ZRZJX5gr9hXXikZHkVbpic7js29D55NW7
QvP7z+7nRdzPFTtmVV9r0ON+bpD96eN42pL7uWH88BiDOZbczw2zgxWvRvbh
fm6I/uszw2sk93PDXUHaVGUX7ueG15lnlY4P5H5uOP6ktOBHX+7nhpaYi0N+
WHA/N2yJNViuo8n93HDV/vSSwNJY6ueGjUEef7fUxVI/N9jmjGm98yWW+rnB
fXTUyObjsdTPDfNDuh1TfhBL/dwQIdkWPr8j93ND/q5ZVdtLyStzw+Uoddu7
heRVumGSsHzwgdfk1bvB50+fYeevk9foBjXnj+HiaNqn5I53dQVXt6WQp+KO
Y9VdtCasJk/LHZO8K66WjiPPwB1m92pd3k4hz9wducITwfF55MEdA5sqREvj
yfNzhyxVfKK3mLwgdxxY9SBscyp5Ee6ICdN5GplEXqI7Qn4Fbt4zhPu5I335
zu0lRtzPHTq383OHunE/dxwVWOalD+B+7oiTHHuk1o/7uWOr7ZSqK0HklbTt
/STKuWjM/dzxwSP7a//u3M8dytq9AkpHcT939HF/lye25H7uaPnbrF32IYb6
ecDGVCVJ5WMM9fNAbejh/VpduZ8HUh5/G1r5Pob6eaDklamwU00M9fPAQqNB
o3bocD8PGGR3OnTsO3l+HpCsDE7MehBD/TywqERScrORvAgPrNz1KDKvHffz
wOXZg3qVl9C+NA+Yz9q/6ngxeRkeeP4oTDe+irxMD8SeVbc5cYm8PA/4u+bn
LSykfYUeePFxd0vtJ/JKPJB3+fm6PWXklXlgps3ihb3yyav0wNYHFbM0rpJX
74Edy4O/Fj8kr9EDp+7Ybt26hft5omXu3m+Dt3A/Twx1PHJ+fCF5Wp44ub3O
7tE27ueJjtuv+Zes4n6eeJNX/drnOnnwxLW0Gp9JedzPExtOjW8uXsL9PPHg
6OIY6+3czxMG1ksfXzlMXqInXnrv9xs+g/t54q7ttpacZO7niTLv1cvSV3E/
T9TFri14n8L92ryjr3c4x3E/T2yelumuvJP7eSJg+PXQM2nczxMNhw4VG0dy
P09o9nt8dU0a9/OEam5RWucl3K9tT82rhlMi7ueF3OfLD+TKuZ8XIiO+9pNM
5X5e6FdVOfOqhPt54dWQVTuEIu7nhVR5rKvybO7nhdkrrzWeVHA/L/waWqsd
7cb9vHDlXezt0yHczwuzWjucX/ov9/NCcHinP81G3M8LDZFr3r+34H5eOH49
0XAUe5leyLulnZhlyP28INmaHrXZgvt5oczXSBgj4H5ebf+eunq72Zj7eWGx
NHGBxUDu54XyDvPzg5y4nxcWjNPc1s2Q+3lhjOVuEzMl7ueN0bKxO/x6cj9v
7AxG99i+3M8bBROFHxO+R1M/b9ScSq458Q/384bT5WEHvutwP2/8HX7z7Kzf
0dTPG+KGUNftba//r5833OS+UW7a3M8bOcFp5V8+RFM/byz3bqqcdD+a+nnD
Yvq9I4b15GV440C/OeMGvyYv0xsqG9K3VVyifXnekJh2sCv4Sl6hNwJSFjr3
eUNeiTeOdX74c2wpeWVt75dUvO9IOXmV3sgzSMtT+0hevTd2xH5elXiYvEZv
HH+f+a14L3lKPvDadejSwCLyVHzQctk4reUweVo+eHzkd3bLWu7nA8OC9e/n
XSPP3Ac3ywVfVhwkDz6IMz+dis3czwfpQ0/mL9jN/XyQnKb3cPZx8iJ84LJw
UERFPPfzwcja6OTi2dzPB0bKZe73F3M/H+j8HpEzKZH7+aB9eeSscVO4nw+G
H6/o7LyW+/ngk1WL5cV47ueDzccq3EvDuZ8PlFJ0cgxncz8f9IhOnhAfzf18
sOqZ2uJCO+7ngxNK+nEmgdzPFyej+5d9EHI/X2zbvn7vGXPu54urKi46Pb25
ny8c+18O05JyP194VveRv7Tifr4QxGgFuFtyP19M0roT3lvA/Xwh+bli5o7+
3M8XUP7bd5oK9/PF6ZU/sxp0uJ8vbDwvaQg1uZ8vLKSVmm7foqifL6rWfIx8
OZj7+eJy6WGNrD7czxf1rtuuLfgTRf18YWv0NXRIZ+7niySLgtcl2tzPF+Wv
Zk3ccTeK+vliz4NhX/Y9j6J+vrhQu6i32XvylPzw3vO6bM3jKOrnh3/nlR5b
fZH2afkhP3e6TnwTeQZ+8Ij7dqrpPnnmfug7p0fP2TfIgx+2DERZZhV5fn74
sOhkgfID8oL8sEvz6OoHm8mL8MPNcaLq5gLyEv1glWcxoayQvDQ/lNeb3t67
ibwMP7jN0KzXyOZ+frhne8ch9RR5eX449ttw0OHN5BX6ocsaA+nnTdzPDyoZ
uxPL88lr+wd62LnKepMF5FX6Yf3j5vC4KdzPD0uzc7wr5nE/P3wuv3PKaCb3
88dN57lnFiq4nz9evJ+31y2F+/nj876sIQOTuZ8/XqW+X3M7hPv54/KTRu0x
k7mfP/6ZV7q0Npn7+aMwqzDV0Yr7+WP2mh65XcD9/CF/UKcxKJD7+aN97sdP
afbczx91rsvGButyP3/0enW84YWY+/lD//ok4TQb7uePNGnN8/gR3M8fzvsG
3lnDXknb89tt221mx/380X+9pFT9x1Tq1/b4QGjItX+4nz8qbc80FWtzP3/M
8F/57e7fqdQvALdLMiqufp1K/QKQMLSkzEaP+wWgfOYO8dK25//XLwCrnlx5
4flnKvULQIPrst/t1LhfAGyuG7yVtpDnFwDrhEKL3zdoX1AA4jufHPj7HXkR
AQhSj/gyqJ68xABoZpUanrlC+9ICYLpqbsS6cvIyAjBCqHJg0nvyMgMQGz28
zKuUvLwAtEt8u6P+LnmFAfhwsniT6AV5JQFQJJdrqJ0irywALn2vWX7ewf0C
IFYfundjCXn1ASi2P7iuUyF5jQHwabchPH819wuE+fGvI14e4n6BcLDt1674
OHlagbCwGn98ezb3C0T1z2FjP+3nfoHoste7W0sheQhE6IrMpwfmcr9AOJ7Y
Gfw5lfsFQmm5seDLJu4XiMU5IZYdFnC/QDzKbJ7cNZT7BeJPYfLWc6u4XyBW
yxMqKxdyv0CEiJ/rdUvkfoH44nQorHs69wtEtF537ZOLuV8gfMYf39w5gPsF
4sWQpwutx3O/QHSf/u1BpwTuFwhDA6+wrnLuF4hs4QiTFBvuJ0D8uipnozh6
vrIAU7red9obxD0F8Ll0LHWWP71eXYBr839ePDGR+wpwse+ylGfjydMVwHxT
7qyVg7m3AJpDnq6c5USesQBKet9vXgzg/gIUmpxadX8keTYCuH3vOKW+D38f
AmxZVqkSLyDPQ4AYT9lXa3P+fgToIa5aMMyIPLEAw1VHaJe58PclwO+Few2T
7cgLEUD8seL8jD9T6PsTIFNtbt8cHfKiBOiW422Qa8zfpwD75tYVb+9C3kwB
DJuPn3z0eQp9vwLc3rozumIU7UsX4Mrz/knWPfn7FmDMpNHzZcrkrRNgb/Ki
rqqD+PsXIK/T1lSBJu3LbdtTGl9r+oj25QmgvTFDMfTHlP+8fAHC3741SevC
9yGAZ4jEzb52yn9ekQBH1VPLm67TvhIBdlYvuDirO+27KsAKQfVF63fklbU9
9jTJs6ue8p93TwCDhf3Mn7WSVynA20bVU8JP5NUIMDpyxptP+2hfvQB6x1e/
dbhJXoMAj+fOSrrwjLxGAQLE624YHyPvhwBBfyvvuW0mT0mIda8+v9tSTZ6y
EPUOOvNfFJOnIsSFQX3GeB0kT12IG/0jTRSl5GkJ4dTOt/OYYvJ0heh98M6S
3/HkGQjhXjEg3iCDPOO21+dENW/II89ciFbDUU8tZpNnI8Rdn5sxS4PIgxAD
x20NatlBnocQ8y1WPh60nDw/IYxiAjOXxJAnFqL2h6fOsQzygoS413WD4cMF
5IUI8UreOKjPcL4/ISQ152/1tCEvSgjPKw8GLw4mL1EI+7B7b86ZkzdTiLdV
x2OLOvP9CeG9peFnnZC8dCEa3uxMlniQl9G2v3jVR7MB5K0TQlntjn7TaPIy
23oU7N81xIa83LYen7yU3ldMpvsTYmxCwXmfssl0f0LoxD/cE/JjMt2fEJvw
ec6yB5Pp/oQYNi41/1LOZLo/IR4rPdTfUkfeVSFsDkk2XnxPXpkQLxzKjk89
Tt49IR4MDvZVLSWvUgiHO3p3z1WSVyPEMzMzF6dw8uqFKEsWfH/hSl6DEGpH
Vm4vTiavUQj/4toNFWPJ+9HW46/JxJP9yVMSwT5u/praMeQpi2DWua6yJIk8
FRGWpxr88rYkT12EHk8295sB8rRE0Bw6FZ3Gk6crwqvcTRF6ryfR/Ymg8W7M
8jE7JtH9iaBT0NfZpGoS3Z8IZ1tzPjwrnUT3J4Jk48bLVgsm0f2JsGh0zpB2
heR5iNBniOfVgjry/ERt/z/0i+yfQ55YBHndv5c/biEvSISvvzSv97pKXogI
/f21e78IJi+ibZ9RcemjT5F0fyKI67bmDNQnL1GEtGZ7/SP65M0UQbDUdPnG
x5F0fyLk2k5806s5ku5PhFvKaSeN7Wlfhgh3av8JTGn7/X/3J0JPyxe2JbWR
dH8i6A2KW2CrTvtyRcj77Oa55yZ5eSL86JAsy7Khfflt/r9fLziMJ69QhFa9
YUnbY8grEiFp2IoeR4bSvpK2fisDpn0cQd5VEQ6v7TLy2wLyykRwbj+/NdKd
vHsiCFXK9BcOIq9SBNeDMcr6IvJqREgZJdvS3ZS8ehE8CkddWr8ygu5PhOTG
3MSvWyPo/kR4NLv41tqiCLo/ESrap3axnRNB9yfGWJWwDU7REXR/Yjyfc/DY
rZvkqYgxvqKpu+oW8tTFWCDr+qnTZPK0xGj6PvVJzFrydNsed4iymbOePAMx
ND1d9Lb8CKf7E6PozuKXNz6E0/2JEVI59vuoXuTZiFFbeazx78twuj8x1qve
GqR9IZzuT4zjJUu3T9ChfX5i2AU410X/IU8shv+cypGtl8Pp/sSY+0/tnB8v
yAtp21Ne2qf+D3kRYnTuJCzLnU37osR46/Fy/3wFeYliLLVtHbt6LnkzxTDu
UZumF0pemhii+52emZqRly6GWl2WdswS8jLEqFu8yjNpJnnrxEgb8/PpZnvy
MsXYrRETcsafvFwxRlcEfFk2k7w8MRIt/nazVicvX4zvHUa2W1kbRvcnxsiE
uY9udiKvSIyfTatcn7WE0f2J4bxyuuWpi2F0f2KcO70nXaZKXpkYHVMPzvBR
pX33xIjy6vlkQEUY3V/b93FowsWoh+TViDFzl3z4yq60r17c9vet/i4/TofR
/YmRMexR7M902tcoRvMjp9Ob8sj70ba3bAO655GnJMGo3qp9N8XSPmUJ3sye
vu1hPnkqEtzMrgx1PkWeugTe6U7NwankaUnQPeiqSWoKeboSZDmKz1ccJs9A
gj7n1K48TyTPWIIAz5x1ia7kmUswyfZPdMFY8mwkGBvr8+tgOHmQwHzq03MH
zcjzkOCnemH6monk+UmgpjeoT2gSeWIJ3vd8ubvKmbwgCQzqI0d0G01eSNve
sfomQ6eQFyFBQVB9u1o78qIkOLgt+vwUNfISJTirYb3BxoC8mRJ82Rnm3M+c
vDQJUmq2a1Z3JC9dgrmzU3usMCYvQ4KnPmNbsl3IWyfBs3hRj6m9ycuU4IPN
qaQrncjLlcC/+tiMVRbk5UlgsUM78HgP8vIlSNstmnPp9US6Pwms79zfUNE6
ke6v7fcTo/yXdOX7k2BLN6Vdyc8n0v1J0LOi8KiiPXllbd/PjGsquzVp3z0J
ho9wX2b6nrxKCTp3ubB4XPVEuj8JVHIzhjp0o331Emg+vKsY17bnv/uTIH3i
j5sTL9O+RgmM+8w+F/yQvB8SuAgCwuJekackhd6yZR+bz9I+ZSn832murHxO
nooU690n/5j7mTx1KXqemldveo08LSmOLq3rFHmWPF0pdPdmThPVk2cgxfbq
zcpWF8gzlsIybcVvxQ7yzKWY3tVqYsYx8mykeLjo2vj6YvIghfnCuiGhmeR5
SBG1o67wTAl5flKUrPcw/XWdPLEU85IF8qM7yAuS4lRBrxUPssgLkeLgS63D
Uy6TFyFF0Aud6YWbyYuSIiE69IJWKnmJUpzd12BstJa8mVI8+f6svmIzeWlS
jF88Z8iZBPLSpTg+ZmTJhO3kZUihb3q6emgOeeuk2G+5uWlaCnmZUvSqjrZy
nkVebtueR+tnr8klL0+Kk4sGiC5NJS9fCtetB94XBfH9SdH/+ZuFutF8f209
rapde0WTVyLFpdqxzyZ48/1J0eHS7oplc8krk+K1SdK27Bjy7rV9Py56h64I
+P6k2L1WPeuejO9PirxpQbvLk8irl2LRwxjDyTZ8f1JEWk6pHmPG9yeF3bsv
veDG9yfF40vDXZLs+P5kCPt7PGaILt+fDCf6+VyzlvL9yXBZJE5KteX7k+HB
UM2qUfp8fzI8Hu836owp358M8/cnFzxx4fuT4c3Vcoem9nx/Mmg2nZxu2JXv
T4YFVk+OvtDg+5Oh16UXjdUd+P5kqP8qCbjUGkr3J8NOx6M2ufp8fzL0VA3e
bdCB70+GQjzM69kUSvcng+/Svvfsu/P9yRDZ2E0+pD3fnwwVneJLH98KpfuT
IXVf4aInz0Lp/mQw9BwyZtsr8mbKMK9vbY9z10Lp/mSw6htXtq+S9qXLoDXE
5864d+RlyPDq7xbh7JvkrZPBJSz+0t/L5GXKUJCic1H9BXm5MkyRnrH+cJK8
PBkMDm3eF7aVvHwZTpc7j7p/mLxCGZJ1+z0ZdZC8IhlGhnbz91hOXokMd9fN
npZ1gryrbb22hN73zievrK3X5w3zI9eSd0+GLxeCgn03kVcpg798U+3aAvJq
ZJDYH4jfE01evQyNgrObvseS1yDDVvfO88Lmktcog3NBz78n4sj7IcMR0fmX
h6TkKclxqVynSrKUPGU5pg5+1qslijwVOc68UURGBpOnLofv3ztyx6nkacmx
5sQVN/ME8nTlGLR+ct2xkeQZyPFxXk3rDhfyjOUYEPFodBdv8szlWJ3baBNp
Qp6NHB2NlFYXGpMHOY6f7H67m4DvT46q13GzhaPI85NjycHsOWOGkSeWoyBm
VpyzE9+fHDcL9y2T65EXIkeOZMBR+a8JdH9t77fxk7qvOt+fHKmiKzNyevL9
ySFQ29iy6dMEuj851MKPn6rtzvcnh0HfXHl1T74/OTbOW3ijZ/MEuj85rglm
CEJ/TKD7kyO9u+qy8h58f22fr/dBJ8s7E+j+5FDd6qj88zbty5Mjwv5BcmsN
efly2IVNOJ9/l7xCOZZ1S1uocYz2Fckhel/+5V0deSVy/Jux9Uc/9q7K8T18
XcTz8+SVyVHc9duis6Xk3ZNDHuM6xPEeeZVy/O76LnhPBnk1cuhaKHeW7CKv
Xo4OesmRBQfIa5DjQVbvCQXryGuU44RV/7+HFpD3Qw5l3QjjiELylBQQl9qp
Fq0hT1mBMO/6HiczyFNRQHuOY8bmHPLUFQjYpZMrXU6elgJvzeasnhBEnq4C
SzfXdcYM8gwUeNS3c63VNPKMFSgdmXYsUEqeuQIvVuzRzxpHno0Cz1t9XfyS
yYMCZlGB2/2CyPNQ4N3XkZr648jzU+C1/e8Wu1jyxAr4LLvj1wzyghRY1PRT
Zj2KvBAFgq8k37/qxfenwJv4qNhGO/KiFBBmDcv4oE1eogIWwoOtrx34/hS4
t37Ow7725KUpYLRCYK9rQF66ApLb/wbPN+P7U+CX4En/w3Z8f22PsapD1z8h
dH8KnL/v8HRnF74/BU6ZjA79R5vvT4EWL72/5zvy/bV9vjj7A6tfh9D9KWAt
L+owRZvvT4HmpE9rLnbg+1Ng3nqRc+v3ELo/BTq271Zo15XvTwFXz327Oirz
/Slg4m3S1e8a7atUIEjj08EzL0Po/hToVlQlvdBAXr0C39103qbdCaH7U6D3
puftFGdpX2Nbr/07I1q/kvdDgcC3a464VZCnFIR5Ra2NieUh+H/nxQww
              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\
\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}, {360, 
                FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 360.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxdm3lcTev3xw+hVJdouEXlNJ2SSlQapHbzoHlSCVESN1MZynAddElCKPMQ
EpExQ2XoIJmSUiii3EvKGIUS+n3296znn1//9Hq/nn0+e+111n72sz77OTrT
5gZN7y0QCFplBAL+////27WT/yt2lLjGJnU9GsxJ+Y6j4ENss26CEmfxv78a
R0G680XZYBUar3fk/ggbqfdSyElVmhzFG+foGiwR0vH/OYo/OzwZdkiLi/vf
X7Nj08ZVxvOXGdDnWx3FunE115cacfcr+L/3juINuypHvRKRXpsjd/fPEqs0
Uzr+s6NE3sJy1V+WpN/uGG16pKTKyZI+3+Eo5BRW2RVZ0vm+OebEunecrLMm
vU5H7mDc25fBNqTX5Rj9u8jyj17WpNftyKWsC7dStiO9n45izegxeX3tSe+3
o0T52sEEl7GkJ+ByGrZMPWs1jo4XcAK1Z8tcVjuRfi+OK3vhWlLqRJ/vzUk+
tCmNKHOi88lwgvov4s4hLqTXhxNXV6XtzHchvT4cdyVbf/gTZ9Lrywluf3iw
08iV9PpxOZxAr4+XG+nJcjlyIy5m9nIjPTlO3Bi96tJMN9KT44T6SzS8B3qS
Xn9OPDGloOKgJ+nJc4I/erakij1JT4ETqGyca7nBi/QUOUHbrPgbEd6kp8hJ
9ioYL1jgRXp/cOLHo2IEq71JbwDHlR5bs/fceNIbyIkHrw5p3jSe9JQ4wVZH
J8eM8XQ8eKDW8EW3fEkfPNY0W3O3H31+ECfItnw2aJofnW8QJ07/OzpF6E96
gznBoMXbBHIBpDeYE29+v8p8uD/pYdxFs2lWuz/pKXNNo8pqL2YGkJ4yJzmS
YZC6MYD0VDiu4LSofAbTU+GE9pX2KwMDSQ9s12P0pjyQ9FSh90e0JDeQ9FQ5
7u+vBacaA0lPjRO+LWjoPzGI9NQ4weRzZza+Y3oYV9BPnzUqiPT+5MSJJc/n
Xg0iPfCNRW6/yoNIT50Ten0qWJPG9MBDTv565x5MeupcU3fOxJ0XgklPgxPG
715oujmY9DQ4LqHWLv5EMOkN4XKOb5ispRNCekM4iSi07vh5pjeEE9/lHs19
yfSGcoLg5tR3k0NIbygn1ln2XDIrhPQ0OUlfNX85LaanyQlKvfqkFIWQniYn
tjr3dYxGKOlpceKv4ZM3fmJ6WhyXMvWsRzvT0+a4Z67ebuGhpKfNSWb66vX7
wPTAEy5M/tWH6Q3D9a0vypkbSnrDOHGe5GXzolDSE3Lisw+61bXZ8UKOKzze
lbKP6WNeGy3fE/WefR7j+/yr3S+F0vkwvvy5mUcB09PhJKtylxj3MD0dTnCl
W/R8A9MDB20/dX0H0wPL1qw7/JHp6XDiJb93it4yPV2Oe5QVWbKW6elyYpkx
kW0dTE+XE+SvcdxvGkZ6OP5y49CAz0wP4w/cdxbXMj09TpwWdCpGJYz0wNaO
DzdtY3p6nKBn9cvPu1h8GFf9PvHcU6aH8asK7WPKmJ4+xy3b+sowgsUHPhwX
u6GE6elzkuMK964/ZXrgSSPKkzKZnj4nWD/V0uQvpmfAibeujfXaxvQMOEHo
p4HD5JgexienVCUqMD3wFJmNWRZMD8c3myb+7Mv0RJwko+318uwQ0sNzpcO9
8VAbq0cRx03o8Tv3hdUbxm82H1TfxeoJ46HiTo/5rP4MOXHXn9Y5q5meIcdJ
Li2c/SaY9Aw5Sc+/Jv+8Z/cXOKa4Tqub3T/4/MPuu7Fn2f1mxHHc/gXqbux+
MsL9Xum1cjfTA+faTl2xmOkZcYL9F4/sVWZ6GM//27niPZsPhuP7XPilooHN
H8Mxn+7wV3Jg8wP4TFtgsgubT8DtiakRY4JIDxxXWCxbxeYrY05QEvNKZxGb
34w5seylc1GlgaSH8Zqw3+fnsfkOnPIpJlWWzWc4PipD/+IbNp+OwHz3bF1j
XgDpjeDEG+2LF2uw+RXjx64Mt9Bg8zF41fXZBxrY/A1+Kaq//ciP9ExQj9aH
vySy5wP40+3SF5f9SA9sGLjPsN6X9MBWbav+UWDPF/Dgszuin/uQnikn+DIh
zfM/9rwC/76iVT+IPZ/Abn9K1L56kx5444H3rdHseQh2GXe5xpQ9L804QWv6
Mm9bL9IDt21Wd5X1Ij3w5ilTd/z2ID3wEd9nF9w8SA9cJi/xHupBeiM5wZNz
q3ZdYM978NXhypNs3EgPvCrhnEqbK+mBZ0nijLVcSQ/MWaorvnYmPXNOULGz
KMLHRXq8Bvjm637hG51JH7zFYtvIVU7Sz/uAh/0saHrH0fnAfR584nZzUj0x
eF6P4g6hA50fHLfi5c9N46R6heDbx7XvZ9tTPGD57Z8/LrWT6jWDL2ueDcmy
ofhGcYKHN+c3htlSfOAdlYVRWmy9BlabM+mAuRXFBzaqmh40ga3/wPHVcfqf
RlN84NpLuxT9zSk+sGez7wjkSRofeM/YT7J3TCg+cIC5lcM7Q4oPfHq8asY8
tj6FbmavlavaaT2rAfa5sPawqg7FB05+fNzi1FCKD9y2Ii8yXIPiA0v+vFqF
dZE0Pj5Ove6/7vai+MA54w+l3/juKI0PLA60GmdRWyqND8yptPiG9ZNI4+PH
y9ZvX9dbIo3PAuPVqkMHD5RI4wOnzejaslddIo0PnPw6/v5mLYk0PvDtZ5e0
G4ZJ9eLAGVOzFxmKpHpicNH4mORHhlK9nbzexP35MsZSvUJwH+GdEDszqV4F
OOBoh86QURQf+Pd6yw3O5hSfJSfISvjSfmg0xQeW1HYe32BJ8YFtMtxmxFhR
fGD5xAMFU8ZQfOCGh0arJtpSfOACq78dnthSfODoJd+vu4+l+MCWnzjTteMo
PrDcw6X7ZztQfOA8t7JwdweKz4oTyERm/jedo/jAx0a0iXSdKD6w/Oxkl2gn
ig9cdb8wwsmZ4gMX7VwbHepC8YFHjn71cqcLxQc2OTYhMsmV4gPH5uiPSHWj
+MCO+65+muRG8YGjg41C69wovjFYn3z/mv3dneIDv/q0s2axB8UHHsLdK9/t
QfGB/x5h+2eDJ8UHthGa5832ovjAGUt6lVR6UXzgrNakT8XeFB948OfBrzPG
U3zg1sgJoj/GU3xgvZSWqI7xFB/6rtJ/c+bW+1B84Na68GJtX4oP7PfvnEIX
X4oPrFy6OKLAj+IDa5+6POqZH8UHNjvrvTTcn+IDX//QJacTQPGBH6xpswgP
oPjAc0wDp6gGUHzgPTfVfuwPoPgwz9ysdwv/EkDxgcPP7zzURXoW4Ht6BxM0
Aik+8CaVQtlrgRQf+FmEudOVQIoP3Poioq5PEMUHTpv9ct2cIIoPbHv6eZ/E
IIoPLDwoO8EpiOIDW25NHXs3iOKz5QR/vvry4yfpaYDnvhvb7z3pWYAXHh9j
OCyY4gOLr600PxxM8YEt/7o3JiuY4gNfXzjl7xfBFB94sEqhk2UIxQcW7bXW
HBBC8YHj9m3U+Ex6zWCvCy9f/hVC8dlhPRJnrrYyhOIDaw40lZ9Iehbgxr27
7faTng/4XH9d298hFB+4e+qIBa9ITwzukHnYOiKU4gPf3aJsMjOU4gO/jVi4
US+U4gP/Oa3kL+VQig+8eF2v+mWhFB/69J+rwiIXk54GuNi6O96B9CzAfWWV
ZmSQng/4nXiwyh3SiwPreFt/yCU9MXjC/RUrXrP4wI1VNzQVwig+cI3B98wC
Fh/YLbtbZj+LD6zWsLS7k8VnzwkCe8aPaWDxgSvmKMtsZvGB3yoKLzWx+MB3
+mi59wmj+MCf97ycXc3iAwdVHAqXC6P4wLdL5duGsPjAfZ2HyOWx+MDFgvyW
TSw+sKCOq3nB4huH/K7P+Pckiw/8qdVxXwCLD/zvVR2D3Sw+sPwpf4vTLH/g
0YHdmTNZfOD5j5YcyGL5A+ett92+i32/4KPDnK0GsvjAa9WLp7ymemkG/3qU
Em/G4nPgBHazYmPbWP2BvTuMVy5n9Qc+eMnhzWVWf+DIM3ZHKln9gZ/Gbj8x
l9UfeN/Hac4ZpLfTgc/n3T4b2P0B9q3vV9JK91sF2KI8sy2H3R/gHRNGLm2h
+03giHovu3rvIN1vGmCD1zt7NIIpPnAz9y7ak92/4JqA3r+nsvsXbH4rRqOF
5gMxuLB6gt0XNr+AlZyWF39l8wv4iXnmZVs2v4DfbS9ILaf5qhl87fC5+AFs
fsG6zafd99Vtmt8UwaUjKwOMAyle8KCXYisn+jzaIUGK565dCYEUP/jJi8Fv
6mg+RTcjWPzCru0uzb8+4Ijsg2lPaH6NAKv4ue3uR/NxHDjS4N67Ej+pXhJY
Xv9ThLs/XS84Govc+35SvQxw24EVPTN96frB8aYlvyN9pXp54MSopvP/0vOl
ENy5/LtXlo9UTwJ2Doo/b+dD+QEvUax5PpOeT/XgH6qFriXelC9wXM6Jrlee
Ur128KrE78sm0vNS4IT5fbetSl8vyh94Sc+gEWkelD9wQN9B50Z6UP7AnOu7
oHfs+QzOmvjgrw3ulD9w23HZ+lZ6/vvwer2cNxjS8z0CnDxvwbgDrpQ/sNEz
ztDSmfIHvluh45/iTPkDW26smBXoTPkDPxwzqaqS1jM7wW/D5ixBWy7NH/jj
pJab8rS+KQRrqve8SHak/IGjuDlqm9n6CSwYpXpGzoHyB1Y/PKS+YizlD9yw
q9bpnhXlD9xys77kiBXlz5kT2L+YMamE1neK4FiLlrIGth4EH01pXfOfOeUP
HP3xhfrz0ZQ/sKa8dds+Wk9yYHGaS5SDCeUPbOS8eXWNCeUP7Fl9ZPtiY8of
eF7291kBQyh/4ICo0Z13VSl//PnehE2f+CflDyypW1V5TJ7yBxb0XtEvq7VU
mj/++LHFCq19KX98PHsDHdrbSqX54493Pbsl8bejNH9gbsHj6z9/O0rzx+tb
hqk49aJ+AywM967VoX6iHXx7beDCGgNOmj8XXF9iZf4ZfWl/oQjeEdz3Tb4R
9SNg8R9GA1eaSfVEYDmdmOl6I6g/AavrHosYbirV4/jPn+035v4o6lfArn2b
UpxGS/UiwOY/r129PYr6F/D7octmGVA/lgTWnx3b/4idVE8MLgo0eqJOfnoG
2LL14vylY6m/AUenGL1c7yDVy+PPJ1Ow0Zf1i+AOf/foQ+OkehJwePWHnPkc
9Wfg5tvay//jpHr14PIqUb+F1J82gz+aPri9kPrZdnDWchujTFfKH/63BZmu
nkr9sSJYtyH/6i3qnzXA53QttJzcKX/gsnX/xr5h/Tf46Djh+DLy2zmww+Gc
377Uv/uAQyaN6fWJ+vsIsPeiR85zPSh/4FT72Pz75LcngbnFauXt3pQ/Xn/u
7pAP5C9kgOtiJv8aPJ7yB94SPHTzVB/KH3hHy4IoXx/KH7jlrmn6W/LbJeDr
X+tbxjP/A5zctUJGkfz0enBl9Y7uTF/KH1jFIHvuDPJX2sGrYsSpo5ifg+tO
E59Y4RJA+QMfqHpuMo78Gw1wm/a85HLyd0TgzLJTP+qY/wMeWnp37ybS48CD
4rvTDck/8gHXHlE5t4H8pQjw25Y8lwnMfwLXOcmkZ5A/lQR+rG2/bBb5YWLw
at9OtfXkb2WAj4d0uyUy/wvsM8Oq7in5Y3ngW3k/D/aQf1YILnfM5g6TngSc
lP1tvx7z3/jjq350rCF/rh7svLzrRRj5d83gR9ay62PI32vn45ntq6DL/ER3
rJ++nYx0J79REfxzxZo7w8iP1ABHiiZlzSS/UgReqZvUksX8R3BOrus6M9Lj
+PH9Asds0vMBK8/6kvCR9CLAl08+5yTM/wQPLhLpnCa9JHBr76awYPJPxeDD
O00M5pO/mgHOHxEe7Mj8V/Dvx6Nk5pI/mwc+0Df2QTb5t4X89bjMyBaRngTc
fsyrO5n5teA60fnE66RXz+s3//NmE+k1gyc7zehJIL12sNnbM887mb/rgftn
wdJ9cmGUP3DZ89yoCtLTAMflF956Q3oisFnTsQgB87/Bp8Oy96WTHgc+OaN/
ZAXF5wPWPWrf1ov89Qhw7oQnM8qYHw0W/nG7eDvFlwRWSqyRHxhG+QMv2Nr/
oDzFlwGuTC2zLmP5A9tH306qZvkD79ubevMhyx/4+rapqpEsf2DPu5t/bGD5
A29c0Ti1gOUPHDVYsXESyx9//JEbqqNY/sDqm1KKslj+PNHvaY0WLiI9RbC8
4fgtIpY/cO8H4sUjWP7AC5q/yioyfx5sPiVKbzurP/A5+ekjrrL6Axu1uG+6
zuoPvMtObdtkVn/gC2rtkeNY/YG3GBoopZOeGBzmtTDdh/QywCa5V7Z+Y344
WHPr7gGddL/lgffdP9R2gu63QnC/VwdNPchvl3jy/mjwkyns/uWvJ2fxaQ92
/4LFC7atq6D5oBkcv+DCoRs0H7SD/R6rJ35ifrsX6tenNWcrzS+K4KitagJ7
ml80wLnaw13tSU8EdvC+9VTC/HT+85f3Pkgkv50DJ8u2zUxh8x/vI5+fnOHM
5j/wsZtNbwuZXw4OCFTbW0HzaRK4vL/K79s0n4rBZwUDm8Jofs4A347JbpVh
/jo4ZLJ37C9/yh+4am/qrRM03xeCxdo/P3qT3y4BFykNv2XsR/kDqwzfcWMZ
+ev14NNdVx8F0/OoGdxR511QRs+jdnDnlldHPZjfjudc+MwIVf/xlD+wyY9H
mhLy1zV4fjH5v/X0PlkEVtLNildmfjo46kWCzVNPyh+46Nmg26melD9wRWW0
ZBt7/oLTbp0z3UXP8zjwT9V7X5Q9KH/g6N4670a4U/74+NYeFVnT+/MMng9F
5t1h/jpYvGjsVBt6H5/Hn3/hfbnXtN4oBF/+68C+c86UP15f9r/FBs6UP/78
n6cn9rD1Czh180TDZLZ+4c+3zj4km6P88ecTjLnS4kD5w3M903zYDzPaf6AI
brvS3WubPeUPfDpFXSWB/HUR+GhXfstmG8ofuCrBXqkX+e0cf7yNe8zcMZQ/
cLL3b/lmC8ofWN3X11+B+etgz8r8zwILyh/YJke/5aw55Q8coHuxbIMZ5Q9s
njT66Cq2n4M/v8KQlyvIX8/jxzUumCcbUP7G836w1q/DepQ/cFPbypCYYZQ/
sFDxyXJFNcofz92CcTPIX28G5zQph3+j/Svt/DooZrnVyF6UP74O1zgsy/gs
XY8r8tzmY76jUroe1wCLf5ysGCBL/QdYklYz+pAC9R/gHLvDM/oqS6T5Awvj
9lroa1L/AW6aqyr6KaT+Axx9OitGV0j9BzjT5fwAMwPqP8CnT6WnHzGS6onB
5o3ThvU3pv6DP98YmT2RptR/8OcLujiH+et5vF6BpPXEKOo/wEapSV9DLKR6
El6/9UB8IfVbaNAFt0f6/nhsRf0bf/0222v2kL/eDK4qTvre15b6N557ZnaF
2kn1BL6oT4MdZvfsqH8DHy0f+iNyHPVvYLnV7WVXyF8XgdteRbtsdqT8gc2t
//51maP8gX/aT7t8i/np4Pgr6q+nOFH+wIpJvX/4MX8d3GfdL71gF8ofWP2k
Pned+e3gzn9fzxG4Uv54fZ+i7JVulD9wVHu3bAX563lgm6HqTya6U/7Ar5Zn
7JnsQfkD+6hs15LzpPyBlx139N9O/X49WPjn9cnl5K83gz2nq1ps8KL88fEG
NMSVM/8A82qf7Yc9zL0pf+Ai3bqYLeMpf+C66Q3dJ8lfF4Gj564+FOVD+QNX
NQWNDPWl/IFjP2SuX878dHCGUvSbUPJLIsCuJ9T0VjJ/HaxZ9rBE1p/yBxYn
bfJRZv4LuCO5d/Y1f8of+Oyg0z+mkZ+zE2z5UWvgHPJz8sANBw+0VjA/Hizv
XZ5hRf64BOx+xLp2EPlNFeD08/v9mN9UD7bb4/78OPOrwFdHJt1+QH5TO/ip
/IJdZaQn8OcEf6s+mDWW/C5F8EeLrxZrmF8Ovu3vej+L/HUROFzux5wO5p/z
n0/P/GJPfh0HnjZb26aD9HzAr14O/mRG/l0EuC70y9htzJ8Duxf0LNlDfl4S
uHddyOA1zG8Hxy8WeQ4k/zEDXHvPuHQ48xf5eJxUV9uRH5kHjm4UlWYxvxF8
dlfDjSLyJyVgkXhQRyTz58FrJitbHyW9enCDnenir8wvBf8IVzFrIr12sNmH
yoHXmX+PdcJjpyuJ/uTX9gMnv13U7Er+qyJ4jt9LnWDyZ5XBTz8vajrE/GBw
5qmajUfIjxWCU9V3n7cjPRG4qu71N+avm4CF5vUbbjD/GGw39ELvbNKzBScc
WDZ9Lulx4IqyzIGdpOcO3jfx5v1q5jeD80bJND4hvWD+ekZMS9ci/zsCrH9K
Ya5smFQvGvwtriw/nfnTYMUjlZV1pJfAc5Fy4y/SSwLHGnlPLaL4UsCaS8Tr
0pifzeufD9/Yn/z4NWC/2v4OlaSXAT7ZaRBRTnpbwc0vdszuxfx5/voeLL3/
mPRywFkzi2a6U3x5/PVt7e+QTnoFYJOXt7RymV8OnsWd4LwpvmKw/eFf2Qqk
J+Hz9XTR/n9ID324IHqzseZY5q+DR8fsGj+M9GrAd4/uMQ0kvXrwot7Vm9VI
r4mPv8+eC7NZfYHNWieGH6B6fA9+2LJe9yKrN3CJwnFjH6rPLvCAFQcXdzF/
HOveBp3RrUyvH7hokDB2KOkpgn+aD9/wmu4vZbDl6XCFgczvB0eOHnzlLukJ
wWWJ96/J0P0pAncu+DyXvR8zAcft/Rxqw/x38NPyzHYJzRe24INVDVNCyR/n
wO5VCYIymj/cwfr3cx2T2PwAFlnOuqhF80kweEhj+flxpBfBj988mvCD5qto
8ItRCx8PYO8PwXUeJWdlaT5MAJvMrykeTvNdEn9952qyC2i+RV8guC6pOaNP
frsYfLl/rW86zb9rwMLTHnM9yH/PACefzTi3h+b3rWB7bYHKdfb+FHxb8WVV
JM33OWD1tNI1o5ifDt7RsKf0GvnlBby+JPsP9v62kP8+YjtLhpN/XgyObjE7
0OhN9cezSrtaBj2/ynk9k3z1sez9MViifPhRL3q/XAPOHPuzuYfeP9fz8azM
c66i52UTOGpfi/ZU8tOb+Xrx+yGc5071x+tbn7nWRM/vdrBcdXNMP/LPu8Cn
H/jJpLlS/aGPu/zhzew+9PzvBxZebijppvWCItjmb8vra2h9oQwuuvso3I/e
32uAd2hsU42i9YYQnNvUvbWe/HQRWC7M6PomB6o/8LzYRW4pbP0TxD9vF7tr
k39uC04e3tewjtZXHDj8ziNDH/LT3cHm5v+OahhL9Qf2NGy8k29D9Qduurf0
+Blrqj/+81HeNqY2VH/gui+uLfkWVH9gpalqW61pv0YCWCJj+OX4SKo/vs8d
kBHwnNabKby+YMUXHUOqP/56xD7NN0RUf/z4kD43Bg2n+gOfvtJr9W5dqj9+
fHpjTv9hVH/89Y80/1EvpPoDc//ccjZSofrjzx+6bNeXFun6vIDnXjbpE5to
PwzPFzLH9/4oXa8X85//75HDfiVOWn+8Prdt/TAVaT/A75vlmo27pytQ/8CP
L6s/VqQh7Q9q+Ovpm/C6rw71E3w9PByWIR4m1WsCR5c7KNbqUX8RxPurr2Qm
mEv1+H144uXatyrMqd8AB+TLHauk/UZdPH99Up9rIdUTBOP7s1p8ysRKqtcP
nGM/0Mjfgvo5cMvB0O1NVlI9ZXD80HyDKbR/XQMsN04l+QvtbxeCqwQX79+x
oX4PzEmub//kINUzAe/QV6jXp37SAlx0NmRUj6NUzxZsYxbZS99JqseB2+4s
cDR2luq5g/tMOvPMku0H48/3qLXTkvrdYLBRivWoLbSfLAKsmFp9J5X2t0eD
1S/8p7rchfpHsI+p11hNd6leAn89g/+uNGf9OPho/IYf392leingBp8nShW0
H04Mrq0u1eui/etrwHWnvlcqU/+fAe5cK//7JvnrW8EBGvoPjdj+PT4f5yLO
upPfnsPnu8qp4Avtz8vj89Oofb6/j1SvAJzrteTqBF/qT8FZA7xKh5L/UQxO
0D15+oAv1R///Y5dcOQx7UcsB6dtDc4dyPwT/nwXudLF5LfUgG/Hrkq850/1
x1/PwrLQfuTnNIGVsjtSM8ivaea/n3VnHbLJ33kP3hK1rtiB/KV2Pt68Zhl9
8o+6wM5afV66sv2dIXj++Xx+/4j89H7gjeNqx68m/0kRrN25yHI76SmDtyya
Yjua+VvgH49MuUnkhwnBd99YdQ9ifhd4tExdxUnyx0zABcPWLfNm+13BV++d
WWxB/pstf74ZiYU25Ndx/Pi3K/EXyd9zB+86aK+WSP6dD3jWrg6rBNILBtdG
m/p1kF4EeEfy0sk65CdG4390V71hFdtfC1aZnFvkSv5iAjjXcoVjBfMjwerz
z/qfJ/8yBSyebPQrl/mT+B+nE7P1D/JH14Dtp5zsvM/8SnDmdxWD86S3Fdwv
ur7AiPm/4BJ9uWv+5MfmgNsc5J27yB/NAzfVBvHj0voDlxWnHb3G/GHw5LrA
X7mkVwz21L4il8r8Yj7fj1OuPab4ysH/Rq9U2cr8Y/76FSJs5pBeDR9PT+43
5p/X8/WxJt/0Dek1gX3WbjJYx/xl8LYXldrML38P7nSt7mdE/jq/b//ukj6L
ekgP1yWQl11aUs38Z/wPCZQzGxRG9QfOXbpFp5T50eCPUxsC2PsEZbCzl2hG
I/OnwaLkmcosPiH+Zy3g4v9mfjV48ooVfkWkZwJ+HPj20E/mX4Ov3lJSuEF6
tuCfJQdkMtj7APyfcyXS6xLpuYM9d865HMjeD4CTI0baGJMe/97kS8xljymk
F8GPT60uY99vNP7X3U1Le8r8b/C/Zm4NKqSXAF50y3HtOPY+Adwx2MumjdUf
eIBSXG0hqz+webUgppb01oBzshw/+bL6A4cXvhGOZPUXyvtFetW+bL87uCVV
P1CP9HLAJZoqEw8xPx38VOHbx1d0v/G/cwjpaTvxlvnr4IKhZV/T6X4rBr+d
UiP0Y347WHv9qm9RpFfO693yH3CZ7TcHvxoZPTCf/PUacFzoOc1TNL/U8/Fv
kD0aR/NLE3jaH9PkX9N81QwOux86biTpvQeX/1xyXI759WDjwFiNPWz+A19W
adkdy+a/MPSDeaX67H1iP7D8n7oLjrH3mWDX4ksTc8hfVwbXjVI3Xc/eb4KP
9jok0qP5WQjO3D5/XhzNzyLwZb0pTh20f90EzN00mubOfn8Ebrt2zDiW3r/a
ghMGzj0sT347x4+3/6zYQu9j3cEds0wdwuh55BPG70cufexE/nowH98C2y0N
9H44AhxSlvDmAT3fosE7tM7oe7HfZ4GjvZpHb6b3ywngBWOVu3eSv57Ex/vk
2zMJ/V4sBVzrq3dUTH67GBwlX313Pb3PXgPe892scz89zzPAlh9ORS1wp/oD
x3b4V1W7Uf3x+ald4reD3sfngMUTEy9tZn46WH+kaE0QvZ8v4K/HNO3IWBeq
Pz5e7uOKZfT7uGJw2dxQQw9nqj9w6nnvVY3kp5eDszY9w7KG6g8cHnzRpduR
6g8s0e5aNI72r9eDhcni4Jv0e78m/r3eME3ldPo9YDO4aXLjlFe0v+E9OGer
hbyE/PV2/vtLDG7cZE31x/PlMWr/jaH6m4D8HppoK7Gg+gOfLt+TrsfWfzxP
ij2vNJrqDyz8Gn7twUiqP3COQXxvRROqP549Zv+zyJTqbwK/Hl0fdYt+X2kC
jo6/Z96hT/XH6+01ynDTo/rjj0932jSLfs/J8fG5HHGwVqP643n92z0DVKj+
+ONfHckZp0j1BxaItQemfZauxyN4VtpS2frMUVp//xufK6y86CitP56v2Eb3
lqH+g2cr9dq1A6n/4M+3LXW/wmDqP/jxe8b25UMl0voDN4mC9O10qP/gr/9U
o951Xeo/+OuztsqbL6L+g9cLd57mMIL6D/54Z/tcY2OpXg6fn84Htomm1H/w
13eu+vRXc+p/wUrXne9r0f6jQnBAv92HjtF+pWL+eIW+8aW0v0nC6318q7SR
/PRycKZwZM5Ra+p/+fFgYZOE/PUa/vqmP1faMZb6X3CbSdOyS9QPNoHnXW15
rz2O+l/+fOv2j+yg/vI9fz1WysPPUn/ZzutlKPn7036vLnCafIjDHSepniAc
8bxtS+lxov4XfHu6ntl52i+mCD6afnrsPdb/gnNuGbaYuFL/C543yClqEPXT
QnDb0dK1/tRPi8CCrwtUftN+NhOw0uYj60ZSf24BrjoTHPyb+nNbXj/NZ5Ky
p1SPAwunzRk3nvx0d3DLiXdxWrTfzgfMec5Q0yT/IJi/HlWt+Z/IP4gAJyf0
cwsiPyIarP72n9JZ5EfEgXeUW4ufkR+RADb39dz/aTzVH1jOLneOKvnnKfx4
yuCzx8lvF4Ntbqp/7SK/ZA3Y0zhjdh3brxjO91dv5mxn/gt/PfOW91Fm/gvY
6Ld7UD3zX/jrE/xVO5H56eDTr1c4LCI/pwCseFoStoz56+A9A0yHG5B/Xszn
0z1zqz3z28FNVV/3zyG/qZz/fEG+9TPmv/PXt1Rdokj+VQ249vt+zVLmx4M7
L01eakd+WBP/faruC0xn+9XBmtNPXUsjP+w9WJJ/1zSL9Nr5/D+0umND/nkX
X0+ioEwz5v9FYL01+vCpuGDJ/wHu0Xdx
              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{-180, 
                FormBox[
                 RowBox[{"-", "180"}], TraditionalForm]}, {0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {-180., 180.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -383.19}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-438.99, 0}},
       PlotRangePadding->{6, 5}], {439.0527628677699, -200}, 
      ImageScaled[{0.5, 0.5}], {312.7018419118466, 360},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {
     InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxFm3dcjX/8/jMKlaiIzPaSNGmfq73r7HMyE0LChyiFZGWVvbL5fGSVlRUi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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0.6000000000000013},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0.6, 
                FormBox["0.6`", TraditionalForm]}, {0.62, 
                FormBox["0.62`", TraditionalForm]}, {0.64, 
                FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0.6, 0.65}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Prolog->{
             Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]},
           Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
          ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJw9m3lcjO37/lMkJCmhbEWiEq0qbUf7NtVMzZY1JEtZk2QrJCTSQrtSCZV2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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"\
", BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], None}, {
             
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {0.1, 
                FormBox["0.1`", TraditionalForm]}, {0.2, 
                FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
           
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 0.2}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -159.99}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxdmnc81e///6XQ0KRBEpKV7L3Ow96c6Ryld5OmkhUtUimlIUU7LS1K0dBU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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\
\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}, {360, 
                FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 360.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxdm3k81O/3/odKiqQokXdN9kQlJSTuUGSJ7LshSaWVFq3Tpk1alNKqTQtp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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{-180, 
                FormBox[
                 RowBox[{"-", "180"}], TraditionalForm]}, {0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {-180., 180.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -383.19}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-438.99, 0}},
       PlotRangePadding->{6, 5}], {146.3509209559233, -600}, 
      ImageScaled[{0.5, 0.5}], {312.7018419118466, 360},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.0055000000000000005`], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxFe3c81f/7vgYamkRaZCUjeybnstfB2ecYldEmZFQqUnZp0V6K3opUJBVS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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0.6000000000000013},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0.6, 
                FormBox["0.6`", TraditionalForm]}, {0.62, 
                FormBox["0.62`", TraditionalForm]}, {0.64, 
                FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0.6, 0.65}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Prolog->{
             Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]},
           Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
          ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.0055000000000000005`], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJw9m3c81WH7x6XS0kAyUokiK7NsPvbmHGcKkXZpUtKioUlLQyqrkF0p0lRK
IaW0aEsilFIkjZ/n+d3X459e53XO+ZzPdX3v731d1/t7NzFkme9cSQkJiZb+
EhL/+Zf+ri75+Sq8Kt828eh//kpsj7/TKRWm0usK2yO3WpISNubZGv/3r9b2
y+MXd69KF7D362xbh9kurdqXb/v/am9ta4fMdncbS59/b5vqPU3j7Ls823n/
/WuyTUr4sniLG32/xbZjjWLR3dd5ttX3/vPXZms1f9BfN2nS67DduucAJ7ee
/Hy1ParpvfhWaT7T77S1/3zfYN56+v5320V2JS1c3Xz2e122Rx7+spD8RHo/
becOGbuv0y6P6fXYZuxwPmwznvz22noGlXXLVOYzvd+2g965Trg+h/T+2p54
WrtP2j+P6UmgKX62KDeJPi8BRN0rbg4iv/0w23phzZwMil8Sw85aDGhQoN/r
j+eqM+VkM8jfAEjY6trWRFA8A3A4qizwyspcpjcQjQu0ciRLSU8KwwKkWtfv
o3wMgpYbL0inPZfpDcZnlzp5lXukNxi7q9TGTumm+Ifg0NWpCdcTSW8oCqI2
dc53zWV6w1DHaU2wOEnxSuP9C90DibtITxpeT8TRid9zmN5wbCz/eL0mPJfp
jcCX61kBJVLkbyQGdUrPnPeS/I1CzVqdpX5H6fOjMKXn3vPyfaQ/Chvnd5vu
kqV8ySDK8dBlqXr6PRmUwVDztBLpyWLzt7rhLwwoHlmcvSySX5Kaw/Rksebo
kuSlWjlMTw79DFd9ar5L+ZWDn0P4S7ka0huN1S39hkxfmcP0RmNlZ8ibvJRc
pjcafs7rbirZUr7k4b90iqBzK/mTx7eeRVOq92UzvTGwTMpMCtageMfAdfXw
1ql+5G8Mwgt+JMUOy2Z6Cligcrj3oCLpKSBFZZfjQQfyp4iHlimXYs9kMz1F
3Dqad7hlPOkpQuX4yqL7+yheJege5Y5IbsxmekqYkpioc3ZVFtNTxpIRX5+E
LiA9ZbTB0HJofTbTU8a5xp6scoMspjcWiV2iIUNds5jeWGxaPcyj/0+KVwXW
E5THaTiSngqabZ41jl6WxfRUEKfQlalykOIdh3naTt2K9aQ3DiOa7+mdvH6a
6Y2HbZW20uGQ00xvPLZz915ZVkN64/F2cOAmhT2nmd4EhMe+2Raaksn0JmDX
x/yzb0ZRvKoYmXonXT+X4lHFsHfTZ26TIX1VrJxT7fr7y2n2fVUc/DntouHr
0+z3VDHfZv7FB0PJ30Tw8qvfTT6fwfQmYmeaKG3DCNKbiEFtBaqidvIzEQGn
frxXEGQwvYkQ1cw1XdqcwfTUsHdP/Y3IFRSPGgwrVvxKtc1kemp9+Rx5ruVr
BtNTQ4eujZHsm0ymp4Yzr/K77f+SnjoyAoKTKtLTmZ46LvS8hcGzdKanDvM9
xuMav5OeOqy/Xd1wNjyd6alDXnKL7PHGU0xvEg7I7xl8ZCfFOwnOj1WK+UkZ
TG8Sgo/fX//DMJ3pTYJq8uATlY4U7ySUSr3KdH6RzvQmo6HWkMf/eorpTUaW
1mjnsJcnmd5kHPj0wGi4P+lNhoMJJ2rm01NMbzJGyyvo6AeeZHoauP7g84Ic
d9LTQNOsMwsXHqJ4NbDILSLCUfMU09NA5a6f3q8sSE8DvNER/oWfKV5NHHba
PnuTEulpolDp26/sM2lMTxOSi0d2eNufZHqacAhKztwwlvQ0cWJvv/PNUWlM
bwqGXxgyQXl6GtObgolXshtPtlK8U5A+aFrAzXTSm4Lyd8W7/JekMb0psK86
0co7SPFqYceQkhlzFU4yPS00LDxyTc+c/GlBuubcj5chqUxPC/qPRj7hN5Ge
FpYPyS6onEr+tBHS46zLv5fC9LShWXex16wtlelpo/lEZa/vQPKnjavzyvzr
YlKZnjaWRmxyUa9JZXo66Gz7e1ZqMcWrA7uE85c+vCY9HVSPGTv51tYUpqeD
dwmBJyqcSE8HzsdEGXF/SU8Xl6P+bRWKyZ8uhg7qepVkkML0dOHcIr07ooni
1UXrH6XRvyNJTxfLPrbf/BucwvT04M/t4h44lMr09DCjZMY5QwH500PkoPhd
oafJnx7e5Te829SezPT0YGd9b9rw9eRvKtIPyMbrFpG/qVjowjOwP5fE9Kbi
4EAN94c7SG8qDnUY3vTaQ/6mYtT8rfrrR5E/fWTckO3KCiM9feRIr9siP4n8
6WPtuoG1I8dQvPpo17s/68tp8qePb7l8vV8ZpGeAXQV/N5gGsM8rGYAvXFa8
fXYy0zfA5ZiDR25PYN/3NICX65nJLfb0ewZ4fOVGddZDphdtgHtO66f7xCaz
3zfAodzn/hdGsHwWGmCbanZ3jiPFZ4DQqAPLPj1g16vJAB5hprJDjcifIUZ9
itZ1vUr+DGGcZaQl+43iN4TAsCyxQJf8GcJvb2Bjbzldf0NsL710YPRddj2i
DXHsQfOidi/KtyG4I0cPFZczvUJDLNz2cGBWOvkzRJhT+ZAlo9j902QIz67A
YIO35M8IH44YfXxzi/wZofSTk976FbS+jdD+8n78ixspzJ8REmYrO93NIX9G
UHu8yO76DHa/RRvhxqIF/f68oetnhNjJ3/w7P5I/I0h7Zb/iuNH92qe/bJBr
Ujv5M8KF81J3Du+g+9cYQeo/6x4NSmP+jPvq5xCt0CO0PxiDlyj7pT2P6Xka
Y3r+9uc/59H1NcZD9bd/20+RP2PsVpbMv7yf7ndjXNN+YNMrw+ItNEY5X62+
4yL569PT8+sZUMT2syZjTDnleGuQiPZTE2wsephwTZfpKZlgoGI/hUYr2l9N
0Kn55UZdCds/PU1wduvk5VX9aX80wajGimo/Fbb/RZtAuktnGL+M9nMTrMqN
eZClzPQKTXB5rLvZZuFJ5s8EM/LW/Iq8e4r5M4HJIcdpd09RPZqGoJ0bq+8r
snqjNA2OraZZCx+Tv2l4XT16/Xoxq2eefa/LTncW6FF9mYbnLx7u1BnP4o2e
hg0Xeg8Ni6L6NQ1xzxL2jzBi9bNwGnTMnP+G5FC9mIaE5Qf2aKUwvaZpuDTd
uvPeQarn07Fn3/nixyqsn1CaDqeOjD8bf1N9nw6ONW95FYf1A57TkZ60fdzX
+dQ/TIeZ9ii1D5dYvNHTcUI+tTVRg+p/n15C+m6F4kzmbzqSwz+1mpZQ/Z4O
geneyskBrN43TUdkc7Wi+/VM5s8U4it/AytOsP5JyRSfJWPcq+8wPWNTyBZe
qY1oI3+m+Ns+zDfUPIv5M8WSa5fizpYyvWhTXHu4Ktl1FPVPpuDKlYzff5z1
R4WmuLFt/JGjjdSfmeJjsFWqVASLt8kUj4wfj2u+Sv2aGW5PG6AqF8v6TaW+
1wu/Kd8opn7QDF0KlkHKZUzP0wwd0YYbvwupnzXDvV8r/y6uZ/1ktBnKhFpl
1QHUL5rBSXN08U1Dpldohs3+piGNO6ifNsNKtcyLslos3iYzBC69/HzeXOpP
zbHcqNCMv53160rmEAa/iftsTf28OczVm16lTmB6nubweHpv9dRn5M8cjTP4
W65m5DB/5rij1jY4/xf11+YY+Wbm3I9V5M8ck25NV24Po/nBHN9PhOZvmsDm
nyZzzJt0csV1OervLSCOuDO+K4rNJ0oWCF8qV5U/juYhCyydoHwm4RrT87TA
p/LzSWun0zxlgfyIqoo3NG9FW2DmXk275cU071jAcd/LYQuPsfmg0AKpibtV
c+rJnwV0ctIvzbjG5qkmC3ywP13QpcHilbDEk9OtS2oGsflOyRL1SyyPxpSS
P0tkzM561U+dzZuelrBd4H7tZzv5s8TS8BL3j1Zs/o22RPsG69vOnjQ/W2Jw
ZeLu+6fZ9Si0RPHsd2tsRtJ8aImiypvxpelsHm2yxKHI3lXLkml+s8KCbq7p
WlfyZ4XdJifuxm2ledcKBhHyVs7fyJ8VZJY/abvdn+ZbK1yaNuHMWAPyZ4X3
GQYWdguJP1ihhL+4wv01i7fQCmukE/5k+ZA/K3R5Fn+b9Jb8WeF4ZLvB+OHE
I6yxPXefaHgG+bOG1NbJN/p9JX/WWH9lgbe0PeMfntY4JnfH2kaFeIk1uHU3
paumkj9rnDT5OTqyhvxZY9X3tETFkYwPFFpD3HjB7UAJ+et7XSex7N858meN
mR8ibOLayZ8NsjZOdpScw66Hkg06vrgNXPyO/NmgRbRh/MwT5M8GkiEWU9Y8
IH82OOM3W/PJLvJng/ibXg1zY8ifDZ6ZK79q+UX+bPD4T173FW/iEzawVFXp
d2Uu+bNB8vUGrS0jC5g/W1SO+LH3fTDTU7JFUL+7OxalkD9baKgl5Bz6QP5s
Ue3+z/nEZ/Jni016PcXzJ7N4o20x+dua2GtNtP5sEaAfNNPGr4D5s0WT/fbq
nB7y1/d7EnLKl6eQP1sc0tZcNjaB8gfktogdnqoV/P/npYHxCldKh+2lfAJ1
ZS9HOZ1mfjSA7Zf7dSy9TzwH+OpiF/sliemh7/Oabu0KYbRegbeyhmM0eln8
fsCUr2pdbXEUH3BWWSajiPhOGHBROFU78T5dDyD+44XqiTbMXyww6kde6u4X
FD9QPHx1t89PFl8GUJ/Gz5a4R9cLMO8dc8g+lfkrBaQl5bc/CqT8AJfPrxiU
8ofp1QFxZcVXFlYwf03AuK+jiiLVmb9OILBsTFp2J92/dtjwMHZdGfE/aTss
e6ji0eNK19sOE0xUvy0zZP407PoEQm7tC6P82UEs29L8TIvyZ4d0ie3Dj66g
/Nlh7LrSx3Nq2f3nZ4djd7mPxs2l/PX9vqXLihJ7yp8dDBcUuMka035qhzGL
RdfnrWF6sXb4odxauE1I69sOz/ZPFO45x/bPDDusr0w1OLqF6RXaYZ2cwp7E
8+x6lNphe2dDSogn5c8OOw8HL6rqZPt1nR2mG4o3FtvTerPDEymZoBQryp8d
fPLFO0zTaH+2h87nIndVeXa/S9sjTvKs4oNcWn/2qBDqXlq/j/nT6Hv/okrM
YHPav+2R5q7+S8GM+YM9whe/SY7MYXqe9rip/ueS4mrmz88e98Kz3ApSaH+3
R52U/DL9cqYXZo/7MbN3dFtTvex7LTVPMriI1ddYe3S2fCq6wCVeaA/unsQz
D0Mpf/Zw++1u90yS6oE9/NNiBG7a7HqU2uNBjKZ3URXVL3uodweX3hxB+bOH
+x3z44FDWf1uske9ZuGWB8eZXqc9dI/3e6PXSPXXAfuezny6ZRfjX9IOuL3k
4qzyndQvOKBWUWPkqjIWr4YDrB1OSC4yI97mgBWe0k9j9jI9OGDbXOUiR1mq
1w4oPDxhyEE/pufngCPnZisvbCGe5QDDB5PsXW6z/iHMATffucx/4sP0oh2g
7j6+pSeD9U+xDnBP/p06N4v6IweE9N/oke3P4s1wQHP+zzURpdSPOMB/rdqj
749Yv1bqgHcrmtW+9BLvc4B+VoO1lD3rZ+ockDd384JsPeavyQHylwXr28+z
frPTASNH1Uvl6FJ/5YilmyQ7J/9l/ae0Iy79uP38aC/rf5UcUTfzqGtAENPT
cITD59FDIkZTf+gIjcYnMk9Xs/4UjigM8sv+bUv9oiPGDXp87oAzi9fPEUH7
Ju68t5T6b0e8XbRcbsJw1v+HOaJ1OL9QgU/9riP0NObv+Mhn/mIdkfl4l8Gy
8zQ/OGKqeOTjND3Wf2c44um1sLZHN6lfd0T84YMjMrPZvFDqiMVFq2d8M6f+
3RHGlR1jY81YP13niD8f5vAS/aifd0TU+XDPJdJsnuh0xK3F/1qmK9J85ISP
MXYOYm+mJ+0EY57dzRVv2Pyl5ATuKL5VsAGbrzScIP3g/cmWKppP+l4fyNZ+
M5D5gxP2nh6TN3UnzXtOeLdW2cU3lsXr54SGfW/fKtnRfOWEcyfEhcNnsXks
zAk5RcuTyk1oHnRCzYDuz8szmV6sE0ocW+11PWk+dMKtj1sCjG6w+TnDCfJz
dq803cvm40InrNs9tzLgG5vfSp3QtrE9tfIYzY9OWJo3n3NsK5tf65xgf2dS
7kERzZNO+HG3u2BoHNPrdEKX1w3zREOaz50xNv7+p4DDbF6WdgYn+++0uEM0
DzujRH2c1PfBzJ+GM+rUHJMU/8en+l5HiExLnVi8cMbPgSbtO/SZP09nqMfL
hS6vZzzBzxktZ96oDflJPNAZE77fuhaZzOb3MGfkTD46sPAV8RJnWBvdNX/X
yPhFrDNuuE73r5rNeMJRZ+zfej4k7iXjBRnO2FNpZlMURLzCGX/1lZvCZzC9
UmdM7VUpKjhCfMAZFe8s92frMX91znh4SHOCmQvTa3KGyqJAbWdp5q/TGTIr
/OzLEoivucBrg2hNkRfzJ+2CJcOW3ep5yfiOkgvm14R+L7zN9DRcsN76SOaQ
qcSPXLBPYuuK5PRklj8X+Mj2Xz9wO+M/ni54olPd8YdL+XOBVcrPHOfRxG9c
cD527pcEB3Y9wlxgmn4l87wO5c8Fep4XR77Oofy5wHzGVIWkk8TH+t5fOvRG
tJDy54L6Ka+bFG9T/lxw59Tr8q3xSSx/Ltj4eWXXMA7Tu+eCL92XXshFU/5c
8OjFqur3Y4in9b2vnZUkcGZ6nS6wl8yR+atO+XOFgp3XgmJTFq+0K34/LZOr
Gkj5c0VTXuKg7+lMT8MVA2fuLNwWR+vPFf6hpxvbGih/rnhmG9B1z4R4nCtU
zg1ZGuxJ+XPFGx/76jQ54kuumLtC5pRWGeONYa4wafP28NOg/Llib2+stHAj
8xfrivsLV1X9tSA+5gqbp7/lrVcxfxmu8Onl3L7ej3iUK9RWxfuYzaf15wqL
6b94vq+Jh7pi5o3RV7J+snjrXKHp4hh6XY14miu+DFt85nEJ5c8V7y7WVAok
KX9uGB5Z9VdViu5fNxxe7CQns5d4mxu4KlMfWS6i9eeGibcdDo1SJz7oBotL
exWm/mH7Adywyyz2420RrT83xLveXiQcTflzwxLFnLgFZXT/umHrorwxQZF0
/7rhSf7sR48DKH9u8PK4r3bsCvMX64YG3rJfPiuJ37lhw8nR9sqmjKdluGHE
wtKzN/dT/tzQdQ4fKzRo/3ODePB29dgQ2v/ckFiy71qPJIu3zg1Tl0amSaoT
7+vTg5lLjDHbnzvd8K41SmLlFdr/3LF9jsmg79ZMT9od1yQ9BizlUP1wx/AZ
wzeuG8T2ew13zH13LEDuLfFLd2i8T/F7/4D5gzuWaY14m72SPa/ydEfNgYxf
B6+zeP3ckZvZ41dzgfihO7SNap9fDWb1KMwdv9oii+e+JF7nDrdPu6ZXdjF/
se4I2lIUqrWY6q97X/7HaJe6Uf11x4tMa479C6ZX6I6YaPWP+qtZvSx1x+Fs
3XdPBtLzOXfYTO6q3fqN6dW541JshuHjaqof7kjtXnT42VjWH3T2vX/9/Dfn
duJ/HuAW1d/bNIfFK+2BkpGDnMbZUf/igZr2ghmWVqzf0PBA+d33/WSeEH/z
QMx1vYeL8qn+euCz/uqcX1+Ix3nALO7K+BZ16l888HPhfbnlYfR8zwOXXTdH
y96h/sUDVuVVmWrBrF+L9sCOG4qnXq+h/sUDq52924//I77ogUn+Idyz81l/
leGBjqqRtntA/V9ffAb3856upf7PA9ukfU5c20p8zwOP/HrHR72j/s8DF2MH
xA0Op/7PA14yqxR456j/80CDe1PTjmnU/3liaPgrzZGHqX/2hMPjlL3XxhGv
7HvNj/yq78f4nIYnfp/VSiidSP2zJ8ZYqY5+NYP6Z0/4enj2W+rH9Dw9Efh5
mHHSR+qfPVFg8Uv+0Abic5741/tikEUP45dhnrhYvXlz+zXiiZ5o+q16O28i
68djPdExYeJn9Srid56I4lkWPOlk/jI8wbmvuC5OkeYPTwzc9rF88l02z5R6
ontfx0mnfOKPnpjl3d49lk/zR9/ruP5LioyIp3kitkNv5cadLN7Ovvh3vEl4
7kXzhxd64x9Vz/rO/El7YepRnUN7zxAP9MKKL/3zXY+weDW8MH6nq8FxCZrf
vLBh3NU/6fvZfIS+z89rqJ9jSfObFwKzXMaOTqf5zQvL3/QePkvz5TwvFE2K
v7nGiOY3L6Rnj4ryHknzmxci50sV7HdmerFeqBu29uHPacQP+vTzxW4PTrD5
KMMLw0sUWwzCiZf1ff7kHCNLLZp/vfCMN32/w3aaf73QnWC24LA3mwfrvPD1
g0Jm4iGaf72AjrenYwpo/vXCYIfXRReGEj/wxmTnlN9nF9D8641laSWH5kkS
P/BGu9ouN+UBxA+8UaAx9MbINMqfN0a87H7/7xXNv97o/8BTcYE18SRvWNmO
nfmOy+L188ase9NkA8Mof944YTcqPfsc4xFh3iiZo3a7VZv4izd8Z0054H2Y
8ueNHYlDa3QnET/wxoAF30t/+TEekeEN7ZAX83e2U/76/Ab6u3BMiL9448wV
hR29a+m8lDeSm+seb+AxvTpv2ApKeO5BlL8+P1oXq7/9Y/46vdH4ovjgLEfi
Vz6ojP6bKt1G+fNBeH1mzu23xA98wOO6B5moFrD8+aALSif1E4i/+WBnrYr8
rhHEX3wQWKRfH3WX8ucDJe+i60GfiV/5wHrGgmuTT1P+fPC06sSTvOOUPx/s
vp32/qoC43/RPriqscvozmLiLz54J7Q2tttI669Pr2ZX2rkpzF+GD0xuZw60
jiJ+5YN9YgP9vIu0/nygt61Be/Nvyp8PHNfaPbjbTfnzwfVB0yzO6hG/8oHB
6Yjl65pp/flgW+vr5bqBxCc5yItNEqdJsM9LcdAz3D/FWJf5leagVTTGdNdR
5keOAwULrbtaWuz8nhIHhtMG6s2MZ/5UOVicLtA1/h8v5CBC6ZX1csqnLgfO
vq2KH/93Xq3v91cZKfWfxfJhzoFxVNrg8Ca6Hn2f796pz9vI9Jw5+Dugu9qz
H/ExDiRnWv5LK2Hx8Tj4cG141B0d5s+PgyqbiBvPqpi/YA5udaUflWqg68dB
UtGMggcXmL9QDko6+kVN2UDXk4MFQ/fbi8yYv0gONpluxbeHdH9wwNfeUr8p
jfnbxkHgypYXGX/ofuEgZ/eksOAKdj/EczB85BnpoHC6fzhowTCXX+os3pS+
31vloiQziHgmB7w74+cEuTB/uRxsnBJhJ/+d+BwHcko7h64mfyUcrLS5p3Q/
nngTB/YXAi9qaTB/5RyU/dUa9ncw7V8caHacamj/zupFbd/vdVeUBZgSD+Wg
YqBuziFl5u8tB2P15H8cX031oS9fnfyLxWB6bRxsiGv/kLSS1hsHuwfqRob+
Y/tjDwcvXbRGhZ0k/seFcHB51842pifFheRom8bHn+l+5uLP0dDEGF/mT46L
6o3FDnuuU33hwkPdMzfLj9YfF6GzEjLLHYgXcrE+JCF6VQOrT7pc5Bwp4jk2
0v7JxWedjyEbPZk/cy5K/ghWNI5h/sDFjXsq/YxMWX1w5kLH+BZnxGyqT1ws
Sljbv/8bVh95XGzufdO53IfqPRc7/bp/NjYzveC+768cIbF1OJ3/46JipKRU
8wlWj0O52Ls39+OhUhZvGBfz7uTtLghh8UZyseNZ7NH2FOJrXLybbN6kc5DV
/21c5A8WKNxWp36Bi+LXl0f1rmb+4rlwvjVs6Nkx1D9wodwuURI/gumlcNGY
ZHMpxYfqIRfXC4d+fVjB+plcLiYs97JXkKPncVwUDI3kmSazeEu4KC2o69Z5
xfqXUi4EQcci3UNZP1bOxc3EOK0wC+J3XFhMfJPKqWX9Xi0Xcmm9uQId1n/V
cfE7ptHNbyLr/95yUa5z3Oz4Y3peysWQiFbLAa5Mr42LmPJN25d7sn6qk4sH
Wy0n5q9m8fZwMSfoY/7m/z3/9YV27z+TlhzWH0v5QipmqkmjGvFAX7z8EjnN
KJnpyfnC+4HZBu2N9LzdF2ZZszcdWcr6Z1Vf3Foy1NawkvptXyRVfDHfv4f1
q7q++KwRse9mB52X80VXxR41lRymZ+6LbRUdSeo3iSf6YkR3pt7ej6zfdvaF
bHhMOy+a5htfLAhRt/coYXo8X7iYN0jvrGH9tZ8vvFSbJ6XrsPkj2Bcnf9zr
DIknftb3/uV2zkp9Fm+oL1LGWC2x1qJ+3hc7lIziilPZfBLpixkWrcfiiSdG
++KRzMv+Zx4wvW2+aAzVEazbTbzNF2mrD5zy38jmv/i+3y/o6TQvo/nJFwMr
x8p/ncXmrRRfyBfJqn44QfOoL3i8VcK3hizeXF+UCh7uLd5K85UvUHxU1f8f
m+9KfPEvoaUn4QfNq77I+afcv/AGm6fKfXFhY0P9zk80v/ZdP/kfSk1n2Lxb
64tl1x6771dk82edLya+sXuu+4Lxtbe+kDkZvGWVE/EBXyx+ssfG/zebr9t8
8azavl/xUpp3ffH69/IldjrMX48volY5fHv7g+ZfHo7ULx2t/IrFK8XD56JB
aX/G0zzMQ1Gz8PWTGsZb5HgYO8WxcYk88QUeNFQH34rVY/5Uebjgsd33YD7x
Bh7WOMaodqownqDLg+/Dul+H7xB/4CEjwOzt7FqmZ85DosSbp4uWMH4AHuaM
eS/3JZrF68xDQ3Ne8TpnOi/U5ye1+tWq48wfj4eUJK5E7x7GU/x4WNAiaTxX
isUbzMO/zT3G808S/+Eh7+WQa0FjGM8K5cHuRZe9z3fGW8J40KoKHFfryvxF
8vChPXfHim903oyHzfrJh4yaGf/ZxsPCg6c7TlQQL+Jh/fF8S48lzF88D3fs
DOedNqLzXzwY7XL0VjjB9FL6XkduenY4nXgcD3r+JXcdVJi/XB66h9/I55sz
XlXIQ/vO+YMrPRifKeGh0+LccUlb4k19/pKe7Gl6mszWHw+TFKeO2ixL58t4
+BWwynOACvNXy4MgOHuuxXXiUTxcGSntpZfI+NpbHm5GbBpq5kl8lIcCUzPJ
6HfMXxsPt6ws/506ncTWHw+hi0MlHlkwvR4eglX9h1+IIX7Fx81yq5hOfZY/
KT4sR2trtpkTT+VjyvMxmnHTaP3xcXW8efvcOXTejY+7qQH779uz/KnyscDx
6cpz14gX8rF/XUDq5nJaf3x4j6qv6TAl/spH4KbmOdFrGQ8158NRqeOlcBGt
Pz6G+c9+o+nH4nXmI7b0eWvGKDpPx0f+7d6zyd60/vhQnH4soK2UeBkfJoOe
z7mewvSC+eg+N07mchnxWz60TSZ2XvJk6zmUjyNjBt5uqiWey0dOlId+lwfL
X2Sf/5CQ/SHmxNf44K14ojtlPbs/tvHhWXepIEWN1h8famYZQWHutP74+Oy9
W2HlXOLnfNRkqcx5Kcnu3xQ+TkRVKPu10Prjo2rpjwPCrcxfLh8ZP6RULdfS
8wk+rsx2O5b+itYfH80fJLJ/bKD1x4d1iuiOijbbX8r7rs+i7aKxErT/8eHn
f3lI8n1af32fH1xsfVmbnmfwEZZ/OzS8jfY/PszdflbNvEd8j48dNfPOdsow
vTY+BvUPX9SYSfsfHwpTnGym9tL+x8db9dAHgXto/xOgc3Jhd2Ei7X8C5O26
EFB5ndUPaQEid4vsBBwWr5wAO26f/jrjEj0fEaBOef6n3XVsv1cVYPCEETIp
x4kXCnDBRRQ9IpLp6Qow7kxUxx4+PX8SYIjMi64X0qxemgvwdLZuRnYA8UQB
pg6J/xpsy+qHswC7ShNsuz5R/RWgrdtdsHI90+MJ8OrXMsWArax++AmwcHXP
uDs/qf4KkNLQ/+OyZ8TPBAjesnTG30j2/CxUgO5M1VnD+lP9FWDTH7PFHUdY
fxApwK9DhWbr9lP9FaDEeqfSuhCqvwKknlJ380xnerECOCxe5/VjG+Nf8QKc
MvxXfPsP1V8B/nwZr2tSzfRSBKioeG56gPqXDAEyvm2NnLCI9S+5AkyYt1+7
BvR8UYAOGd9xemtYv1YigH+uU/PvEuJ1AlxKbTM5NJjplffFKy44EEjnEe8J
oPgwWHNYO+uvavvyc2flPB0Z6v8EqK31O7xjF+uH3gqgG/bOsKyT+J4A3xX+
yc8op/6v7/qNKDhjMZj1k50CJK3tqN0wkPo/ATbWKM/9tID4lRCte6Jem0uw
flJKiJi7nVevmrJ4pYVYMU1/66wipicnxEfXmKFXJtLzdSGOGMV/vHWKxasq
RJfTMbPhL4gXCqF5Pl9zOfX3ukK0vD96rbqO+KEQZq02H+48Yv7MhZinHZNe
OJPmDyFMF99vKPvF+JmzEOaDO25fDSe+KITx7Mr+WSY0fwjhX7i2tewY8TIh
quNkZ490ZfEGCzElKnST8SLij0IUWeW80I5j80KoENtm/tp91YR4mhAHHG4m
bx5L84cQx8O9NmdcJr4mxKXKPRclktg8s02IDWuNL+f+oPMSQtT2iM63F9H8
IURv3pSa1gA6PyHEZOnoylnj2LyaIsQHv9D6tRI0fwgRtGT1xUfz2byVK0Tz
P+dJYz4TXxLioUxbcfwRplcixBmr3XfFf4h39ulpO984fIzN0+VCLJ3FPyMb
S+fLhEiqup18egHNv0IMbbg7YWES8TwhrlwPs2jey+bLt0Ksbv/5+VIXnYcU
oj14ZlNmFdNrE+Jvlcrcn5E0/wrh8fruwQU1bJ7uEWLE8vBB9YeI/4mQv2b+
xW0vmT8pEQaUyfce+UH8RQRpB17BEi6LV04ESU+100sK6DyeCEkSGpNWuLH5
XFWErtIHg83diReKEPjAbd2mZuZPV4S1I09d6lQl/iLCy1fT69OIR5iL4CZU
7LTbRjxRhHFz9LjjiHc5izDnTsTYT/87rybCCN8NjZsDib+IUGE7rjOmks4r
iZBy49XmJjHzFyxCmNS4BY2xdH5JhAbDxYqfVFm8oSJs9FOa0jCP+IsIQ2Uq
GrxOMn+RIvDU5keXhdN5OBHaJkxbsz+a+dsmQvbz0s1zJ9J5MRHqLvy7Vh/C
9OJFME4fODJQmvhb32vuhN9fJIm/iLCs7sOJWhCPE2Fr2/f+EsXMX64Ikzb0
yB7VJz4nwsS9l563NTB/JSJMaBRXPv9DvFOEkis1Z9Qv0PoT4UxIzVRRLvE7
Ea7OiX/MUWfn92pF2BAucb48gviLCCai4/0V4mj9iXBiZ0F0minz1yTC61Hj
v6rsYnptIgQfzbiSW07rT4SAccMezBnEeFiPCEaVpzYt6iZ+KsaYjO4Ya03i
f2JYSZi49/tA60+Mg805rWYi5k9OjCFjBC/LfhJfFWN3TGjFME3iL2L03/3t
ud9h4n9iOBzNKRpM5wt1xdjyedZAyTjir2Ls0fqXJE6j9SdGt6zTwxGXiP/1
6b8clfNjDfE/Md7PL4jiuBH/EyPKODnmwgN2PXhi3NrqW90+m3itGL/v9eqJ
m9n9FiyG+p5g7uGTxP/E2LuoaW+/0cxfqBgDX0m/jDtL5+n6/MfI3AypJP4n
RpjWhogFR2n9idGmHX76uoD4nxgaNi6bAocT7xUjU8HbrimL6cWLsU0zXGVE
BPE/MSpXJckNeUT7nxi+7c8LJqfQeTIx5Afk7PzkQfxPjLXa8kNvdhP/E8M7
/feXzy9p/xOjSF5pz9qxtP7ECDQ8U6txndafGOuaC2ULftP+J8b8ifW38vzY
/lIrxs45D5MPf6L11/f9iI0RK+4xf2/FWG2sezKohPY/MfhuHp8OE+9sE0M6
4PiBTa9p/YmxPPlnYrwF8T8xXEfs6OUOoP9P7IcxMh9mdBnm2f4fau7zGA==

              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"\
", BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], None}, {
             
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {0.1, 
                FormBox["0.1`", TraditionalForm]}, {0.2, 
                FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
           
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 0.2}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -159.99}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.0055000000000000005`], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxVmnc81f/7/2UmUhkVSUgyIntzHvY6OMs5ByklKQkR7dJEqURLWkqSNFXa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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\
\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}, {360, 
                FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 360.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.0055000000000000005`], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxVm3lYTdv/xw+RKURESgMpKpqEUC0hUpnKkKmkMmVISBTHGMoUIWOmkG5K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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{-180, 
                FormBox[
                 RowBox[{"-", "180"}], TraditionalForm]}, {0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {-180., 180.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -383.19}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-438.99, 0}},
       PlotRangePadding->{6, 5}], {439.0527628677699, -600}, 
      ImageScaled[{0.5, 0.5}], {312.7018419118466, 360},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {
     InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJw9m3dcze///yMRsoXKKBpKe2nQebR3nX1OZsouMyKF0Nsq+21kZoUkIyuk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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0.6000000000000013},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0.6, 
                FormBox["0.6`", TraditionalForm]}, {0.62, 
                FormBox["0.62`", TraditionalForm]}, {0.64, 
                FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0.6, 0.65}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Prolog->{
             Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]},
           Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
          ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJw9mndcze///wtJZEaJKFpoLy06j/Y6jXNOZ2SkjFIqo4yMJGSFlhHpXUpL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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"\
", BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], None}, {
             
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {0.1, 
                FormBox["0.1`", TraditionalForm]}, {0.2, 
                FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
           
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 0.2}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -159.99}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxVm3k4VX3Y/VUIqZQkjaaQCJnnheOYDs58DhVCKBpMlUZSmlRKkwalQZMG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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\
\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}, {360, 
                FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 360.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxVm3dYze//xw+hkJQyopQmSpK0xLlJ8amkoVKKdrbILpyMUBnJyjxIyUjK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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{-180, 
                FormBox[
                 RowBox[{"-", "180"}], TraditionalForm]}, {0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {-180., 180.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -383.19}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-438.99, 0}},
       PlotRangePadding->{6, 5}], {146.3509209559233, -1000}, 
      ImageScaled[{0.5, 0.5}], {312.7018419118466, 360},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{}, {InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJw9W3c8lv3/lVUJSSRlZ2bvzbHXjXvft6bS3qWU6nnSfBpaVKhEimQlStGS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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0.6000000000000013},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[StyleBox[\\\"a\\\", \\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> \
{}, \\\"input\\\" -> \\\"a\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0.6, 
                FormBox["0.6`", TraditionalForm]}, {0.62, 
                FormBox["0.62`", TraditionalForm]}, {0.64, 
                FormBox["0.64`", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 0.5900000000000318}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0.6, 0.65}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Prolog->{
             Dashing[{Small, Small}], 
             LineBox[{{0, 0.629961}, {100, 0.629961}}]},
           Ticks->{Automatic, Automatic}], {189., -52.09500000000001}, 
          ImageScaled[{0.5, 0.5}], {360, 99.19000000000003},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJw9m3dczW/YxxNC+llFymqotLS3Op/2rrPPycgukkSFECUZyc+IMqIySkZG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              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"\
", BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], None}, {
             
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {0.1, 
                FormBox["0.1`", TraditionalForm]}, {0.2, 
                FormBox["0.2`", TraditionalForm]}}, None}, {Automatic, None}},
           
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 0.2}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -159.99}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.0055000000000000005`], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxd13dczf/7P/Ak2WSVzERpSXuPR3ud6uxzGiqrZcsKKavwjmwyEpFsKbIi
3mQlIyEzq4yUvTJ+5/N1Xe8/fv3jdm7nnPu5zuM8Xs/rZcCICeLR6mpqaq9a
qqn979///29D9v/+jrkfuVg+eHbSNPx9fMm976eoU7dnT4P1//1VuS98mbzT
ciY/X+M++75tzPsx0/BXqXV/dM50v30Kv/6Zu+bPD7cWTZ+G2P/7q3NP8XZ2
aDGB3//KfW5bo513Jk/D1Yr//TW49zT0GzRsJnvv3F8axV3fEcGvf+8+Yf/4
3uqx7H90d9m1eLVrAr//k7vwRdmZ6mj+vC/uedPcZ49WsPfNXamX32wzlr3v
7m1uKn2Ch7HX7C5/87AoJ5K9n+7TtlaVmYxi77e7oFEj51sYe2qYuvqU/9NA
fr0animXnH8mZ78FnvbvWqYm4ferQ2/S8XnDfPjzWsJ2z0iLD0L2NNAxO0rT
XcSeBj5d7b6hXQB7rbBudZ8DHiHsacJs9ffEmWL2WsO6Xdu0PQ7stYFXyuEP
7zzYa4PmCvPqib7stUVZ4sSnO1zYa4dpN70c7lqy1x7nflg0qgew1wHjzuxU
j3BirwMsjso01jmz1xET4sue/fFkrxNa64aOeezGXmcM+T5Xa6kJe1owLFd2
iHbm12th6gn/dnIH9rVg0PBs6hcTfn8XyH42Bg8048/rgroPxy98cmSvK9K+
zjpcMoS9rojtY14YasdeV3SXZbQ2dGGvGxLHOvSba81eN3Se3WXJN3P2ukO2
M7Nmzn/zdUfz+ewvZ6zY644zO9fptDBgrwe6XE3Z7WLDXg+kv21r3deKPW0U
fHotbzRnTxvdh2/u1cKVPW2E3Fj+O8SXPR1Mem/4p8SRPR10qB6SeMCLvZ6I
mWigGxLIXk8cnNhx0qr/vJ4Yub/rWbkVe7pI1k2ZmvBfn3SR+7rLLQNX9nrB
03jX1NL/fr9eWOdQv+2hnL1e0DYv7jhxDHu9oa7R+1ROOHu90ffn5/NLx7LX
B9fkHaobx7PXByfrnz+fFc1eH0we6u92WsFeX3zTSb33eyJ7fTFVXD9ySwx7
/eBuM1AuHcdeP9zKmP36yqkX7n+9fogyyZ+7OFSDvP4Yu3L5MP/WX9z/ev3x
4sS9Pzo3W5Gnh81fWx8yf9OKXq8H06Vfn2+d9cP9r6+H04PuHkmz/kzv14OP
6ZcJ8tmtaX49NHdceOxPh1/uf70BmHJDoyJ1emvyBuBM6OdXXxt60LwDMCf4
0UOs70ffbwCso8pLnC7pkjcA2y9vDeihmvOvp4++nyLGB67pT54+zo6w6CR+
0Ys8faxpt8e94aguefqonnu49XFzPfL00f6kOG97SW/yBuJovd22pEl65A1E
ljjP/vERQ/IG4kyCwcxfU0zJG4idnc/k+LY2Jm8grnb+1eD2wZS8Qehk2eX2
s35m5A3C+8rC+58LjMkbhC/fNnbKemdE3iBoCOtvOg83I28QFAPCZt/sYUKe
AZxuzT2x/wB7BhjnsPBl9gNL8gwwsP8U29AEG/IM8KguLc3R1Zo8A3RJmHWm
1Xob8gwRZFdYWH3PhjxDePVfNK8p25o8Qzy/sjOnd19r8gyxQv5y7JwaG/IM
oZUwbI5zpTV5g6EfPiWj71f2BqPHzrIWx3c7kDcYzbt/9i1QOpOner3WKoGj
wIm8wRjzseFo6ERn8oxw9P7coDOvnckzgjgxrtR6vxN5RhjbKdL7cUcn8oxg
tTHA6MkxZ/KM0H6cWW5BrRN5xvAIvbty9lX2jDE5dp5W33nu5Bnjhf7Uc2m9
PcgzRqsvj1K37AN5xrj1dHzVT9Xzfz0TdE2eH/AmyYM8E2xJTQu2fQDyTDAn
wtDVYw7IM8Est56ix54e5JlAo4XN2nefQJ4pXF8tWLIxiD1T/Ino7p+r5UWe
KfpGSsevjvAmzxQLh4vL9mt6k2eKuveX++VKvMkzQ+riLo7Wp7zJM0Pl+Ml9
+g31Js8MBwzPX/142Ys8M4xoNhOVzGTPDA8GDjdX+LI3BAuOTIucns6e6nHc
grN2/XzJG4LUIfoXN3j7kTcEHcL1cqb98SVvCEq7DzxX7OBHnjkO/tqeeW+n
H3nmaL/LN3uqnh955ggQ2+/2Ou1LnjlWrgixXhTlR545en5bEfnFir2hKPxa
P1B7PHtD4d9vyomnx/3JG4oIz/FWk/YEkDcUBpvdO+uPDiBvKNQux3kbbgsg
zwI3O53NXKEe+Pf1uha49OqRmUFaAPkW6Lh1x/7VpvR+gQXmut47fOhcAH2e
Barf2GQsXERemgUWa/k8Ur/On2+Bl882aa0vDvzrFVmgvLRweGJcEM1jgZ6W
X9vGdAz669VZwFJjzZstY4JoPkuUvdZPf789iOazhEL77KNFhkE0nyUSPDMK
W78KpPksUXUgcG10OnmxlvBNNFqf2p+8NEt86yr7nTOGvGxLnHi7vXZyI3lF
lijd0WHd5xECms8Sb7qIyn6+4fksUTAk/+fueQKazwqLFq7I65UioPmsEBva
/+7B1gKazwp3AmTLJr2l7yuwQtoIb0HTEgHNZ4WITLnm+k88nxVyl0qrw/qS
l20Fn0nnv+lNJ6/ICs3RGyds3cXzWWFW/pbyPHPy6qyg4VYb2vUNz2eNi65f
q7rm8XzWmNXsVzXDk+ezxjj5ivfR4eQJrPEh77vp9XKezxoVC+50XTOQvDRr
GAnrZesseT5rDNL3NA6dyfNZQ5ZdEbc8muezRl52QG9XO57PGr+t98cPPcnz
2SDm0LMZo4U8nw0cJr/U+NCN57PBe1heXJbA89ngTXiGfIEPz2eDB5XKbwMr
OD8bHO2bLPz9nX9fGyS1185X9uf5VO+3XJp/sYT7Z4NR9UP1o814PhvovCge
s9WA57PFjB/JZ0af5f7ZouuEXnYJx7h/tuiVN6hmjhXPZ4sxyqPdK8dw/2wh
/HR64fdIns8Wu/eMCTqxguezRVmPlJo7s7h/tshLTLm7pRvPZ4uAeOlT50vc
P1vEZ6zeoj2Crw87tN2rmbXdkOezw41zkp9BETyfHZI6L/qwOYn7ZwfPPY6v
S3YH0nx2KKia/FP9TSDNZ4f1OWoHH/6i8yDbDtqdnduIt/H1a4eX73a92FVN
11uFHbbrvWns3pLns8PEC15f2uWQp2aP3uP0Ivuu5/PFHoHqf1pGfSXP2h79
jvuWZNvz9WuPrOfjIj+b8nz2mLgxuZfOSJ7PHjO3yra5uvN89lD6eVcVV9J5
VWQP0dnOF4dn8Hz2uLs75cFqffLq7CHJVzifesfnnwOejZ6gOa4/z+cAg+PV
DQ8ceT4HFOxtkSkN5/PPARMHRAhuHObzzwGrpT9/7zrJ558DnjQZlE2O4fPP
AS11rnfTSOT5HLDqVCd57hk+jx2A3p49ssPJq3OASfpuv4jhPJ8jXjUvrBtW
QJ6uIyZPXjipqNmf5nOET+42eY83/jSfI+L31cUUmvB8jljR3LC69oc/zeeI
QJHj4Z2Z/jSfI/IFk4+52fN8jrC7MMd7Zi15FY6IEXVOL+T9UueIJHnPncrX
5Kk5Iehs9rjUT+TpOkFnvc04dx2ezwkeLrVDJy/m+ZwQfzJPOSaT95UTRl0e
2GbLUJ7PCTme/vdMuvB8Tsg9OUTxeiN5RU6wyNCevsqU53PCfWthFw1vns8J
Ap9DbQxn8HzOuD/3X5xpzfM5I2f2mHajynl/OmNGQ5LxWX2ezxn9Tu4wGdvE
+9kZlyMtKwbOo/2b5ow3U+Lbvf3K+98Zw25Oe7e9lrwiZ7SpMqsqLeH97QzP
gL433L6SV+eMoJkFQVc0eD4XPL7vsfcfBXm6LvhQpb1qWAnP54J39jGjLtwi
T+CCXI0Eq3vJPJ8Llmz43fzVlOdzwZrMf3r61vN8LrjW7qmOYgLP54KekyVW
Jat5PhcY5959feopz+eCmd5JHY694/sNVxS8UltcJ+f5XDG4pG7TyUaezxUO
K6Yn/Kjm+VzxcFDlNL1RPJ8r7qR1G3oxiudzRefChsWNjTyfK/5YnH4UPJvn
c0XP4P4rHJ/xfK6437dr+67+/Pu6YuT7I4c8J3J+bpiX5ywp7sG/rxvWrpD7
ZuVz/9wgvf7AcWcs/75uODp289vDDTyfG9TXlC+qtOL+uWHydL0z52Zw/9zw
IW3qxH3m3D839NGcOGX+Te6fG6I0/qSpLeXr1w1lXvWfE3fz9esO0yemHmrL
+Pp1h86tl538tfh8cceD+4tuzjvM54s7JP2cQgOd+fp1h93LpB8bi/h8ccec
3Z4hvS/w+eKOi9qigoYcvn7dYWGc+TlyPp9/7lC3UtRP3c3nszvUmnr1vn2A
9wfw1nfhYZdi2g8dgNpLe1IfWfM+Vj2O+L2/5UV6vyGgEzhcUzuY9wsgVVMu
rXhAHoDMTZ+z9j/ifQPkbgq/eu8c7acwoHjZo90er3h/AxOml5oOHRHy10sC
UkcYfk0eHkLfF3hwafA/WfEhf71M1QecuHy99GMIfX+gpGF37szUkL9ePmC/
Tssl6E8w5QFYNmRDvJK8MsCpNPP77s3kVQAWIYa3jVPIqwFWtv3pnX0rlPIC
RuxOfR9QJvzrfQTW3OgfKr8gpPw8sGLcsnvLVc//zc8Dq5fLxvzSElF+Hijo
d7r44W0h5eeBTwl16YKV5Fl7YOWvlMOHqsmDB6reG2z68Yo8gQcEe6Y/NqoU
Un4eiLd6O67zYhHlp/JunRrzcqyY8vPAG62vPY7OE1N+HrgfsPrs+UQx5eeB
hutpJ1ddEFN+HjjnFjR0xAox5ecBsXrElH7+5BV5oHfGMJ/zqeSVeaCka+81
tTvJq/DAwXs7Ugpnk1fjgaMX1v02dZFQfh74Z0Py/SsDpZSfKp+OKR1bB0kp
P0/o7tnTeFZPSvl5ok9t38aSDCnl54n4/foxYUop5eeJOecLrd+1J8/aE34N
scHtbMmDJ+LOXx+7aiJ5Ak+o/ZRnBtmTF6byxy9du/sDebGeCO6kVb6gSkb5
eWJJdI/6xLZyys8TAbssdl6/LqP8PFGhrZ1q6Cqn/DwhGJu2a14POeXniUmT
djxbcJG8Ik/c2fYwuvKZjPLzREvXlv6Th8gpP094n1xcVv9aRvl5YlHu034u
m8ir84TQ2uP8pEQF5eeJnH/nP0/ZqaD8vBBdrdnROU5B+XnhpOX6iDa3FJSf
Fz6NO5bsc0hB+XlhZurvWelx5Fl7Ybz7r3G/ZpAHL6jpHDxWcpE8gRd63giu
KJ1HXpgXvj05MuOUgZLy88KPgIzoo7eUlJ8Xuq16J17VKYzy80Kdq7lx9FUl
5eeFUd1fK7Lswyg/L6xuOpHVQSeM8vNCfJ7nn+43yCvywuA5Mx91f6yk/FTf
d+izr65mYZSfF/oUx2v3f6mk/LygdB/sVziVvDovmH5vX6b2M4zy88I127QT
zweHU37emOM50sS2gbwOqsdjD426IQqn/Lyx+mHBj2Fm4ZSfN+wblmHTW/Ks
vXHb9FLn13/o+8IbpUvXdV+JcMrPG4v25dTd1SAvzBuBNwrHbBpHXqw3sgat
NZxcEU75eWP2/hExlbU0X5o3XizoPrm2mLxMb/wuzYos7RxB+XnDadzL/odq
ycv3RvNUg0dOe8kr8sZIp09zfa+QV+aNgAd3Um43kVfhDb2CVt17lNN8Nd54
UKbXsscv8uq8sblxdr+XbhGUnzc2xO01rrSOoPx84GH//eVm0wjKzwd110pf
D0mk+XR9cHxdSeZFqwjKzweXWq23NuhInrUPvva/EOII8uCDK/0vrPKwIk/g
g8TIf4409iQvzAeTZXVVHjbkxfqo7v833TeJIi/JB3GO/f5NsSAvzQftHLv+
UzOcvEwfjJ1ZnHBnHOfng41nFd932ZGX74M95R0+mxqSV+SDaOXARbsTySvz
wf1JVhvb65NX4YOfEx/Of9aFvBofPFtwuiTKgrw6H9z8re2f5Mr5+WCWXfni
ADXOzxcnL0zr0C+S8/PF0bq+r7XtOT9fJGTM1zjbnvPzRXHoiHtvdTg/X8yQ
29W/9uf8fKE5p/W9+GfcP18MCjl8Hg3cP19kzrXJWtGK8/OFRbqzhs9b7p8v
ClZeWLjnEffPF+EVCye69eb8fOF2xajR5Tl52b5wjfv4ZWEl988Xe40bH6b/
4P75YvPLE40Ot7h/vgg0MDtfsIH75wvPysVhBke5f6rvH+Mz6/hJ7p8vRvbG
laj55H30xVnzLlvNuc9qfnBSs7jw4Ah5HfxwWW9tc8U/fP364e3u3Lm/VvD1
64dPd0yOZZ8jz9oPFxy+/1kcTB78EB9cvWtMNOfnB5u2L+fcTuL8/DD+8ON2
y8P4+vVDQ9/j0n3WnJ8feuZ7Z+Yt5Pz8cGiDU6sFAr5+/VQb6kjacyfOzw+l
c8Yn7Ink/FTe0B9TZnhzfn7oM6Q8svw7nS9lfrCItzl3S4/zU91H94CnsC/n
54cTB2rzGuv4/PPDu4k6zb17c35+WDDZ/P4Kbc7PH8VFJfM83/L554955qtm
FX6h81nXH6tCHXRc+nJ+/lixaX9Ufj6ff/5YVN9T1+Isn3/+cMm48CSzmjyB
P3qHFe62PEJemD/GHhd0G7mY5lPdlxc4PD3Y8jl5Sf4wu377vOEu3h/+2Dtl
X8C5HPJU/298OHumvOgE7w9/GHbZuj4ln/eHP1z/9SnoLCWvSDXPBeH0Temc
nz+ebbedvC2F94c/nPQeXNAIIK/GH8ITonM5sZyfap4+ky3+Teb9oZrXyT6m
UkieWgA2ntfcNS2G8wvAuFnXzj+Zwfmp7tsD9wRq9iDPMAAPtDrGZZlwfgGI
CRuefsKT8wvASLOUPXF6nF8Aet1Kf7a3ifZbWACyjg/bXhnI+QXA/8DWlQY9
OD/VY1fnuTu7cH4BaKnm/8rQnPMLwEf74Iv99Dm/AJj4LT2xo5z2eX4Azpln
+/dow/kF4GCG/+OOLTi/AOy6pbfrCO/zCtX3MfxxQXKJ928AwpsG5y9qw/mp
3j+5y5z8KtrnHwPwKdquW0kj7XO1QJhXalQcbsX5BSJ6y/DUxw/I0w1EZW03
m7b/0nyGgcg0cjA685k860A099uTZHWbPATCtVv6bNMtNJ8gEEOEQcXadzm/
QPgMiDAuvMn3L4HoU55Zp3eW718CMbOju5/9B/LSAhFa/mPNy7acXyDOnD62
Je46edmBaKMdmfztK+cXiKO9n+8Sa3F+gdA+a+49/7/7l0CMsPx0P6CI8wtE
UcSOshWduX+B6F7rJIx8QF5dIJafiWyT+J7zCwRejZxYZsP9C4J89LirfpM4
vyAcdU3oO9OY+xeE1V16OphN4f4FIdciY1/9dO5fEHQkDsd2OnP/grA4Z83U
vQO4f0GQht96fXs+X79BeBmorMwB9y8IzwVNwZlTuX9BCJ0y6MnjGu5fEKrn
x4aYOPH5F4QpgzdvadHE/QvCzKl1/vP9+fwLwvFfurkb3fn8C8KEVlkHi5q5
f0Gw2lj3bsB7vn6DcM5Z82SAkM+/ILjFvtT+1ob3RxA0j4fcqlHw+ReExu1T
DP3f8PknQF198fgb/+1fAd4HDasv4X2uK8DT/tqyH5N5/wpg03p64sNRvH8F
aPQJkfxvP/7NT4CykpHfT+nw/Yvq/7kXutnNmc73LwIUvE0+M3QI718B9FL6
JyxexvcvAtxLfp41NTiS8lM9tpmzqO+lSMpPgNpFEqMPsyIpPwGsUmaObnoS
SfkJkNnb8F1cdSTlJ0An6VpTlwzyygRoi2WXQ+aRp/oP+uYiwwur68mrUX1e
q4Fd32WTVyfA5RFWXz63HEb5CaCc7dzW7Mkwyi8Ym1vsSn8UF0X5BWNqadSl
Fj2jKL9gzBtY0zdpThTlF4wlF1pVJyRHUX7BeL/PocnEKIryC0bx2l9Dy3uT
JwjGFM137tszyAsLhvpJTxt9R/Jig/Euxik5cSt5ScEw71W3NigrmvILxsVN
h2J3aMVQfsHoMbFCcOdGNOUXjIhNdw/Z6sZQfsEIdG80WtYnhvILRt6kjBXv
6sgrC4bldp3eYdejKb9guPRaWX+8fwzlF4w2ZQfOjf4cTfmpvv+rl5+OG5P3
MRi+x6MbvmyLofxCMKz2cuLpJpqvQwg6N9gdqrpMnm4I5haaqnX+TPMZhuC3
r1dhmz/kWYcgJctuWOFt8hACB7MFFSvKyROEoLur/ZPPP8kLC8HpkB0brz0g
LzYEpvouXVZrDKf8QlA9KTVryszhlF8I9N98mW16YTjlF4LBA6xT1XYOp/xC
EKB7QGfvpeGUXwjmf4+fJ68hrygEz30OjD94iLyyEORsPpPsu4W8ihDsLl6l
ZXuTvJoQ3DC9GXe3hLy6EKzf9qr3o7vkfQxBz7yWJQk+Iyi/UDwP2ZnSYukI
yi8UuROmH5gxaQTlF4qBlbKOt1XP/80vFO8rLO7Myx1B+YWiOOCOXdMs8hCK
whSNnkviyBOE4mi7t5uka8kLC4V5XK9tT1LJiw1Fi4W9pgzYTF5SKL6lOcX6
fycvLRTDB6wdc9ZuJOUXin9HdvsQ13ck5ReK5Mnbjq6zH0n5hWJWs+3y9gEj
Kb9QhPqHVMUYjqT8QvGh0tdtazfyKkJxQdzz4wh38mpC8VGvaFGYEXl1oWhS
OxSy1oe8j6Fo/tNh79XF5KkJoTdibFTBMXq9phBrzPf/OZpDfgchFmi/znl4
kt7fTYjXx3QmbrxAn6crxF2tIuOD+eTpCVH71d9jxHryDIXweKXer/EseWZC
LJ+3pM3jHeRZC3HEcK94zVnyHIUYlfb47cMG8iCE+PaZ1f90HPXX8xXi41aN
4vGN5AmEcF697Xgv7VF/PYkQL3aNSJnRfRT9XkKkDqkQtf9CXowQVyWLTwua
aL5YIaakTXlk13PUX2+sEPtMJ6wb/JHmSxJio26SUVdN8pKFSPDcJWw9YBT9
vipvTW3rGEuaL10IjVlJB290IS9TCGGC7RdHD5pvlRDPk3OLn1iQl636fJ9p
Q4fokJcrxDz1ibMLepOXL8Sx64+K1JzI2ytEf5chzcO7kVckxJzRjvXLdck7
ppp/3523C83JKxNijN2bei0z8sqFcLzY2by+D3kVQmRXXxm02pO8KiGu/zYQ
xRuRVyPELg+df69qk1crxOBep5zeGZNXJ4Ts0Nh9vYzJaxAiw6Kh6nJb8j4K
8SbH4qdVN/K+C9F+R432QD3y1ES4dq+wZ35b8jRFWNfiXn54f/I6iDDlrnFO
XwPyuonwWRm64EE78nRFMF70zNCwFXl6IqTcK3VrHEieoQjb9WeNcvrB/RNh
QuaFgDdN3D8RWpYHbH3yi/snQrS7crHuL+6fCJ++nlt65jH1xVeETT21Vql1
ovkEIqzyv9Y/9yt5EhFC1A5EbnhBXpgIG/XaD+nYxP0T4dYTnempf7h/IsQ0
jNT2vkjzjRUh6nDN0cpb3D8RHFo65ZU8IC9ZNe8wq+U6l8lLE6FXao32iivk
pYtwvml9+OknfN6IUNda/cSucvJWiaBh9eek7AyfPyJEzMi/M+ouebmqfAOH
Nmkd5vNIBG8TiXTSDvL2quYrvGTe4jCfTyKkvvZ54nGQvGOq94+c51C0ks8r
EVpcc2mRVkpeuQi5ISH/6Ozm80uEGeJTXXZmk1clwqLMz979t/F5JsJJ72PS
34Xk1ary37cpa+UUPt9E+HP5SnTwIvIaRLib/sixcCmfdyIUhq9S7zaTvO8i
zNuod/nEJD7/xPjefMS01Uo+/8RoVMhHXJ/K558YF5almu9I4vNPjEnrtz3d
tZDPPzFW1St3Lovl80+MAm/Z1Z5SPv/EeOMlmfUylvsnhsEfRd7BKO6fGPF3
FqsP8+T+iZEZdTOpkD2Isd85U1St5P6J4WW9JTgvkM8/MdykJQvEUu6fGIZh
o9b1iuL+iWGV5LRimz73T4xoPadKY2funxhhm818Trlz/8Q4WhO0R8uU+ydG
5x7L11v34f6JkdJWKbf04f6JoR54uLV0MPdPDP8XOc5xxtw/MYqH/Tqyyp77
J8bHYTvurhzA/VPlHXElZa4m90+MAzXrbd705/6pvPqkE07a3D8xHg1dP7bp
B+3bIjGWqscMDOjC/RPjxO6bL8O7cf/EWDZ739oEDe6fGEbNy98Wd+H+iWHj
+CIpQ4f7J8Zlo913t76mfV8jxk6jRWFrftI+rxWjcOXTefma3D8xDp6yFzS/
p/uFBjG6DrTb2fIBzfdRDI00283m7bh/YlS9kEp1Gvn+RYK+tlZ6ah/pfkJT
guClU4bkanD/JEhzUMavb8n9kyDXcLbPmXt8fyPBvuPvb1r+IU9PApfHg8fu
/sH3OxIs+jbod8hjms9Mgil5FU5F9/n+R4JX2g1Ll6px/yQQXvvU6vgzvh+S
IDFswFO97+T5SrDpmPjNsg7cPwkG3i60auzE/ZPg/a8Ot7Z/4/slCcat3N+x
uhf3T4KD1U8fTm/P/ZOgZbctEfff0nxjJTiiZRbbS437J0Hh6Yl1Oztx/yT4
7GP3u+kXzZcmwZ3a0Ce3BnD/JDBaG3vKwIf7J0Flcci9DG/unwRFbuqXV/H1
li3BlSvN0oIo7p8EDSVtn+/z4/5JcPeGbt0lE+6fBJcz1W3SBXz+qebz1Q/u
Fcj9k6Drj+SNdnx9lElgd/l4edUM7p8EjQeWL/Qv4f5JkHJ/W9bo/dw/CSx0
ewnaHePzT/V9NNptrr7B558ExT5Vv/bx+VwnAR6+uv8rm88/CW5tOChf/y+f
f6p8BdKfRux9l2BEu1LF2hN8/klxoPPQ84fVeP9KYVdZHzNSxvtXCkv30bts
/Xn/SlHUtud2QwXvXymGxox/eGgi718pNGrlzxUi3r9SDF7sMTHFljwzKQwa
Pl6oGk6etRQRa35UpMvJc5QiVrfZ51Q4eZBCEVvkW3uA7/+kmBRt4ne462jq
nxTT7StD8zRHU/+kyA0/N9Sx22jqnxTx9r182liOpv5JMcrNaKVMazT1T4q1
uV9/FXzg+z8pRLUnBK37kZckBXJmZ4zQIS9Zio45SzQNe5KXJsXzM//szJlB
XroUesPNVj94RvNlStF+dHel6CF5q6RI//K03Yan5GVLsWas6J8HmrHUPymG
h/5pu6+OvHwp3n8p7BJSTt5eVb7qn5rS35JXJEV/5azmTU3kHZOiS1DTEaNX
NF+ZFAP0prxQhMZS/6TIMs6pTz8VS/2T4nr7aB1FWSz1T4oVCXtvbT4RS/1T
5f9p3Y3DdTRfrRRTbx1YXXSRvDopkrXumFTsIK9BCvmh9MwF5eR9lOLnvbNT
ParI+y7FJ7l+kO058tRk6Jw8KLvZJI76J8OAPdHPZmTHUf9kcJ5e6G20PY76
J8OID1klKWviqH8y5KXUH2hRHkf9k6F9zO+TznvIM5QhNfm3Zk06eWYy2Gc5
rzPJJc9ahqUBvslHj5DnKEPt26TrdrnkQYYtX2RtUlvGU/9kKLb6vrdhTDz1
T4atoe5twlPiqX8yPLBd6ekdF0/9k+HUzz5HDm6Ip/7JcNdsr/Wg+eTFyvBu
vamkPIq8sTIs2N/9yLpJ5CXJIFG+m39sGXnJMugXvdiwLYm8NJUX0KVyyHXy
0mU4e1nTYbVZAvVPhjl1H7QmI4H6J0PS/eN5Vw0TqH8y/JqREZsenkD9k2Gi
ffcOdd4J1D8ZnpcOv9xbn7y9qs9XqFm9tSCvSAYr8ZSZX0LJOybD06DTFs+t
ySuTYeiXEfaPF5JXLkML2ZDU+9fJq5Bh5MzXO0qfkFclw42d88bWXCSvRob1
OVb6a36QVyvDytIuezKfk1cnwzyDlHfXzpHXIMPl1JKO7lXkfZTBddC11C2N
5H2XoaBN6sXD1eSpyeGTlvhQpJ1I/ZPjhv/U8qfBidQ/OTosyfweLk+k/slx
WKf442qvROqfHHpfLr7sPzGR+ieHRVxDTLSCPEM5Otr59/JyIc9M9fpLTy/N
DyHPWo6DwQH76qLIc1R93pn8QSYh5EGOtisfzR0/lTxfOWZnFuyevok8gRx5
o+9lXV1HnkQOLDG6nbuKvDA5NvaNUzMsJi9GjoLEIZet15MXK0f6oKUnzs8n
b6wcRxye3azYTF6SHP9OP7AkMpu8ZDlWdvR9sWQFeWlymFcu+PAtj7x0OfYe
LbhZUkpephz+dVGXhuwib5Uc3YVfRj8qJS9bjt0zrdpnXCQvVw6vkgwd3b3k
5csx/dDmsbZbydsrx9RSh/DN/5JXJEd7247PU7aTd0yOsNdjitfnkFcmR+ly
6f3Q/eSVq/LX73Cm/hh5FXJ0tnWze7mBvCo5RPc6DaouJ69GjqbmB1mfj5JX
K0egeKGk5Vby6uRYcc2ysyyPvAY5fkV0/7b9DHkf5Vh1r7wsZwV531V5rT3v
cYvzU1MgcuSbmv253D8FDCreFGID90+BU4vHdX66mPunQIZzzatnB7h/CpzO
U1vTZw33T4HaNYc6b0rn/ikQ+27Ui9bZ3D8Fomfstytfxf1TQJAYaTluPPdP
gWBPfZvoWdw/BdotmF/zdC73T4E+LX88mB/P/VOg093dcaPncf8U+Hxr5c15
87h/quczpOomidw/BXIjXp27F8/9U8DR/v206gXcPwXMdm2wuCzk/imgEf5P
5fNQ7p8C3lFLA7MiuX8KrN578fc2KfdPAcuRufOynLh/CmQNPhkqiuf+KZAZ
Vv1vSTD3T4Evie8b1oL7p0DUiWnl34K5fwqENW5+sEzE/VNgxYFtx3r25/4p
UPl7wdM/ltw/Vb5vwvYusOH+KaBe3C96XR/unwLpPdTtYoy5fwrsStrQdbUN
90+BiBZbatv14f4pENQhqe2GPtw/BcKNNa97WnH/FDA6XmX1/A+ffwokqmf8
MmzB/VOg8Uerf5Z24v4pUF1Sp+/VkvunxI4/+V/VX9J5qqnEp39+TLfQ5v4p
UT34YpPWTzpPuylh4HTiy9v3dJ7qKvHgYrQw8Dedp3pKZGWuGrBUjfunxJkW
7WrrL9N8ZkrEmYue+zwnz1qJltcsjAc/J89Ric4nB1+3riAPSshnaJ8+Vknz
+SpRu1+ttPML8gRK9KtftqzpCnkSJTbcvv5d7Tp5YUqEFTgujn5MXowSmy5/
mnC1mLxYJbK/nK4IOETeWCXe2g7NWnmWvCQlhH/iHJuLyUtWovCAXpsOG8hL
UyIp0+Ly3n/JS1ei9KZufO1+3r9KLHoj3ZK5k/evEsNCO3Wez162El9dTg+L
Kub9q/I+9tnfM433rxLp1w4bJefw/lXi3ZZ3pXU5vH+V+JKwbNLADN6/Sjxd
98r7WArvXyVyWmV2vZHH+1cJLe9Zp4+l8/5V5f3I+0tpFu9fJSZe9U6fvIn3
rxIHWsa5uS3i/atEn0sDnX9O5v2r6oOof6LdMu6fEuHBkq6+c3n/KiGd/SG+
YDTvXyWMvnt+Xz6b928YIr2OPD2bmoD/BzYhtAM=
              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\
\\\\\\\\varpi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}, {360, 
                FormBox["360", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {0., 360.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -271.59000000000003}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
         InsetBox[
          GraphicsBox[{{}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
             0.004583333333333334], Thickness[0.0075], 
             PointBox[CompressedData["
1:eJxdm3k8lN/7/0chSaWkaB0qlK1kLcupkFBkbayDQiottEk17Zv2HUkqVFpV
KDKhaF9o0ap3UUmrNlJ9X/fHdX5//PzT4/m47vs111xO5jydm074DK/JbUQi
0bu2IpHw7///lbxH+CpwEK1OaLe2x9/iVr7qIG+XHBIzXFM+7H9flQ6iyac6
Ze7oJ2+tVzuIZm78dsytv7w1pcZBZlAliSseTNe/cpBredQ/dDeVR/7vq85h
c+7dh4cqh9L97xzS75e27H1hLr95Q/hqcGDllQFeYmvK++ww83Hb049OW9P1
XxzulHe/aSC2pfxGB5nJhwHq6g50/zeH9D8fTngkMXq9Hw6i8PMHu20aSXm/
HMRjsz/5LxtNeU0O0u/jNrhOdKS83w6sf1TKgGNOlNfiMHN06dROY8ZQ3l8H
9SfObetNXShPxGp6DTm9pcmFrhcx0bUnW2/luFK+ApOr+yh73XOj+9swUaXl
qK+p7vR6bVnN5Gt6xWbjKU+RydbELi+e5UF5imzmi82X9IZ7Up4Su7P4XI7V
N0/KU2bqUw8t3p4+gfLaMfmIh3usSyZQngq7s2DksivLvShPhdUsO77Dz8Sb
8tqz9D6bn63e7U15qmzmu84eX5u9Ka8DY/3tEl++86E8NSZ/+m2Q4ihfylNj
TGpy+vwzX8rryGSShmkPkvworxOT6SxZbdPoR3mdWfrRwJtDdP0pT52x2Se3
Jn3yp+vVmTyjsLJm8kTKV2eyzxPmjj42ke7vwuQVKwr/mkjo9bqwdKe/me3f
SiivK0vf86mf6vAAyuvKpNcj7qk/D6C8rkxsKO2wOiyQ8jSY/PK3b2G7AilP
g0mjxjy3/xFIed0Y69y365ndQZTXjck22fcreh5EeeB+S85bdgymPE0mF+nL
zXODKU+Tietl4a+6h1BedyZqY7ZZc14I5XVnLOT5g03qoZTXnaU79O5ycUYo
5fVg8pPJKm4rQymvBxMXjfri0lZKeVqsRrvdhVPDpZSnxTwvT7fxcZFSnhZL
71QWazlRSnnaTDZypG70CSnlabP06VH/vZTzvJ6MhfVf1/47z+vJpKJeqi3W
YZTXk8kW+h5pPy2M8nox2b28KOvIMMrrxcQZgZ7BR8IorzdjofMH6d8Io7ze
TPrxYGR5Oc/rzUR7dg59cY/n9WGMvRjToBtOeX2YrGVYUqQ4nPL6MuncvSv+
+oRTXl8meqe9smRnOOX1ZTUftaN17oVTXj9Wc1RR21zO8/oxaenS9yKFCMoT
M6lps+9ujQi6XsxEF5pu/hJFUL6YiV0rstu2i6D7Ud8zvZv1+Ah6PTGrsbzz
aZc9z9NhYs0zmvJZPE8H89OufF/A83SYbMDSgZeaeJ4OS1+9tnv8C56H+t92
Zkt6TaI8XVaTtHd88sBJlKfLxMsN905TmUR5uky2qF//XuDWPF0mvasZEDV2
EuXpsvQZfUZ8HsLz+jNxTF6+RhjP689EPXqWfT3F81A3eyKTf+N5/bG+4zM0
7vO8/kx6tHd9U4fJlDeApS++ZFiqMZnyBjCRetsjSZ94HuqPt+74+4bnDWA1
WXMP99GbTHngeQ7TB7fneQNZjft/W0zNed5AJj+fKruwfjLlDcT/vymyL3cn
U95AJuoc8OjCSZ6H+8vSWNBLnqfHREueBL59z/P0mHzYqV99y3ieHktPqH2d
fpbn6THWYGwc9YXngUMi9va+z/P0mfhAi3rTL56nz+RRH0u/e0dSnj5jQfuf
rgmPZK15qPcNs/NdEkl5qEdZvDruH8la8wyYKHnF0LvOkaw1z4DJTA4vKI+N
ZK15BoydCtqzbFEk9YfrlS+2bBgbyVrzcL22X9wAKc8bxER9St6OcOR5g5jc
98AdvXeTKQ98a+aAi3snU3+DmOz6ueTDZyZTHu4f8mBg6LbJlDeYyeIsTack
TKa8wUyusv1E1D6eh/qeKQddzvI81DdEPJ++hOcNxv8ne/Y8iecZMjbgXlPi
PJ4HninddKwfzzNkMt2i9aurJlEe6mNKu75+OYnyDPHzP6Fb2uVJlGfEZNEt
fRMOTqI8I8baXPWrLp1EeajbvNxw8yHPA7/TLD9ygOfhepd1BdpZPM+YsYJR
bdy28zxjJvPOsooZzfOMmbyySC2wOYLyUO/2YPvPPxGUh/u7pi3+VhNBeSZM
Flx59mV+BOWZMJHk9oWldyIoD/Xfy26WPeN5qH/6/C8vi+eZMJavMP9PBs8z
ZaK7jUfqk3ieKZN/ag6sdOZ54K+ze3UU8TxTxj6HDo78HU55ppiHxT2H++GU
N4TJi14NzM4Ob71eG7zkWkrGuXDKH8JkK1wbVPPpfnfUb6+7djAhnF4PdeW7
RlmzKE+GenyJ1ncvytuD+s3UhntalJeL+tPmyLX3wqifIYyZ5V0tKw9rzavD
9R1dDYo3hlF/Q5ns/p2CVWFh1N9QJnq70D05Ioz6Q72ncs5Db8pzR93PaVZB
e8qLBBeH7lVRoDzZUMZM3pesfCyl/nD/kiDT0gwp9TeUycMrwucESqk/8IQq
p+1uUuoPebsuLv/1OZT6M2OixGszt6eFUn9mTHbZdvPfFaHUHzh3ja6JTSj1
h+ulwU8V1oVQf2BFnTTZwhDqD+zoe8feIIT6A196cuZzSjD1B/74dYWqejD1
h3yTDQYnHgdRf+DBg4YmqgZRf8OYzOrDG7WSQOoPHPjv6uAVgdQfWFWhsKht
IPUHjpOdGuwdQP0JdTXPYbYB1N8wJto32cbxhoT6A1vlJRj0l1B/YLXorh8y
J1J/4HmuicfNJ1J/yBva48ubaf7UnzmTbd7d2VLHn/oDryydN7HAj/ozZ6IN
xqnVIj/qD/WbY83ur/Sl/sBXR3QudvGl/nD9yAODLu7zof5QT/V1zfviTf2h
/ig6hW3wpv7AydIAt0Iv6g98Pzu1l7EX9WeBn492FtevTaD+LJiouvuYEvMJ
1B/qO8Wzrvh5Un+oR/VbpK3vSf2BHeWa+4w8qD/wsI12N7PGUX/gu0qPo2e6
U38Cx654utON+gP3CN/ovm8s9Qf+mzZL77oL9WfJRHmD813lY6g/8IjmuNWW
ztQf+O+x64OuOlJ/Ql0+93yQI/UH/jEnp7RoFPUHvlfZN911JPUHbrPVaJAX
o/7ALhIn6X476g+8s5f45Inh1B+4TGKm9dSa+rNiopwOzX7GltQfWN35vVea
GfUH/jXRaML6odQfuCbqbe1DY+oP/PbnUqsJ+tQfWNrxaJ9wXeoPLM4+MSu/
D/UHTo+N6ZysSv2B2WvLred+OrT2BxbpBnnNe1/c2h/6vHM95L25euvnqzZ4
846FOuLe9PkOll/4FhfUr/Xz2x1ccWbnw3I9+rwHZ3+5uCPWqHV/IAM/alRY
qz+EPq/BqUEJkQ/NWvNywWoVmZMHWdJ+ADwkv+0TJevWvDqwlkWXttXDW/NE
Nky0+6Px9GH21B+45kugdoAD9QfO7z/e8Buj/sAmK85VbBlF/YHDM8zWnRpN
/QnXu5rNX+VI/YH77nyhs8CZ+gOn94x4M2UM9Qf+qnhoyC4X6g8c/TooWuxK
/Q1nooAzbUfFulF/YL+/UwuL3Kg/sDhDO2bxOOoPfPzM8ZzS8dQfeFqayYgU
D+oPvE9fIvbjvgtOnPzA04r8Nhes1bW/ceoE6g+8a5Lhm7Fe1B94x4p0A5E3
9TeCiWI6jqx1I9/VBu9Sazx0kfst+Nv3/hrLfag/sKwk4ftPH+oPLOkVc8nV
l/oDJ35x2NTFj/oDmyyuUtpOfpsL3rhSVKHuT/2BQ+NeHi4mv60D9w2WmDpM
pP5smej5bK2pkonUH/jAje+LO0qoP/BVpeeiFAn1B9axjiyslVB/4BlfX+aY
B1B/4Mm/09Z35D4LLp53ev848t1ccPK/zLhngdQfuHxVZPVs8ts68J3ve0PK
g6g/OybSyJ1iCt9t7Q/s+Wd81g7uu+Dt+xeN/RBM/YFXjTy2QIP7LTj2hMem
meS/MnD/F4UNfbjPgvcrZUW7ku/mgl+nRDo+5z4MDrm+LFmffLQO3Nv7yktX
7qv2TLa/YvSvQPJZbfCJ+FWW2dx37fHz7ci6XYXkw+6o20/MuyvnfgtWyDNY
9IPyZLh+TPvc5SbcZ1G3cXk7aRT5aS7YomluxDrur+DGokkxcvLbOnC3aLuT
1dx/HZjIZ+4m60+Up+3AZAGrtAwNuZ+iHpdSvtyI/NUdXPLx9q8B3G9xfWhU
ap8g8l8Z2KSLg2Ei91lwzPmw5UmUlyvkKedWVnIfBqfMPjRAk/yzDhx4aIap
LvdVxmQZ72vDLck/1cADl6cmRZGfajMmWvi4Q1kA3Q8dki0M19s2lvst6i8O
xActojzYu0xpRf3FTZTnjvqDubp391CeBHWpjfLBV9yHwX92GGweQj4aB14w
uOy0JfmqDPdrLLZY6Ej+mYR6nYKtxyzuk6h/Xr/GL5B8MxP1SwoLP4+kvFzU
X9sfuTCD8uTg7MJ5JYu4z+L6pHbFPZdQXjW4i7f90RuUV4frQ9dvma5DvtcI
3jg8KFif++BIJnIuPh1iSL6oNpLJlr2p05SQT2qDd86pTrMn39QD59dVrevL
/RH3129VueVIeQxctqWm2pfy3HG9dI6O2jjKk4DHX9uvt5f7K9iid5PlD8qL
w/299rr6K0TS/FBvJ2orbaa8JPCXzed6GnGfxPX5JbaRXchfM8H2o58UNVBe
Lq4fObXfXVXKk4NV411O9uc+i+tvXexr3IXyqsHTteJXhVFeHdjK1sOW+2gj
eMD3N+VDuK+OYqKE42OHjySfVRvFZGNe1iaqkj9ro94xv+m1DvmwHlhD/tLN
hfstuKdrTMlQymO4/1qnntadKc8drLtRsdiA8iRgx13TPB9z38T9wQti2ywj
H41D3eD6jm2TyVdlqK/2iJi/kHw2CfxZ70EXxn0X1zeny45NoLxMcNEDr4S5
lJcLvnCzgxLPk4PHRcun2HA/Rt6XtQo7fCmvGvU9j7ZPVaW8OvCjc0G6eeSj
jWD2oLbTNu6ro5lonf2CF9nks2qjmWxW4g7dKeS72qhHX7E6F0f+qgce0m6P
0zbut7g+0Xjl7mWUx1B3PqVx3IPy3MGdI95u53kSXL+oRTxPl/sw+OD8kGUP
yEfjwA77Vnc4Rr4qA19LOdZSSD6bBG5+mNJnPvdT8ItutikLyV8z8Xqag94b
bKW8XHBxjfu8RMqTgwtvhyo7cj/G/YGxsc1+lFcNtnnS45gm5dXh+q35P2ff
If9sRL0weuzdA+E0P0cmq793QzOb/FbNEfu1awn7grgPg2sO9dknId/Vw/X6
DhfsI7gfgweF7LwykvIYOPj9Vg1l7stgw4VO/TtSngR50zJ2h9znfop6+8Pn
FLaQz8ah/qmr8pQI7quo55/TPeZDfpuE+tpHPY+3JR/eg/rL3xfdmslPM1GX
rdf58ZX7LPjZv073L0ppfmCX8dsSVnK/BessLdi9kHy4Gvxz4puc/+e74HGP
71gqUF4jeMUrr6NHuf86Yb1YJeh6kd+qgbfVePc9S/6qDZZ0+fd8C/muHtjn
QlapJITmBzbs8O/8pWCaH1jpQrdJU8hv3cE5yxwPWATT/MBmTz4nFZPvRoLb
PT8Z2S+I5gf+cShvVGUgzQ887Pz6PoPIb5PAUq8YzcMBND+w9/4BGtPJdzPB
iUsfOCoF0PzACcpDLjEJzQ+8tsjurLqE5ge2OzjVPn8izQ8ccO7Iew3uu+Ca
UOv78/xpfuCHneprDbj/OjORwtLCzSPJb9XAjhNSB9T40vzAc2al6y8j39UD
+095UV7rQ/MD16ztHdjPh+YHtipRyW7jQ/MT7vcN/DzFm+YHrpA8qDpFvhsJ
vr/k7mIjL5ofOOzR1cT9E2h+4IYbfpU3yG+TwNOWDTww3ZPmB956OSr5lgfN
D3wlVSHIdDzND9wzcq2V/TiaH1gl7sWKNe40P7CRxeUZza40P/DFRt2oVO67
4KBeVQOvuND8wAclv5d+cqb5jWGimQ1dFR450fzAihovVd840vzAN4yOd1k5
muYH9kw7fA6fY63zA6sdcf0gfG7+b35grW6Ju9870PzAv87ef3jbluYHvvNB
4d5y8t1Ige+FBS2ypvmBayzm124zp/mB2a+gtKdmND/wZvPM+qlDaH5C/35t
xukPpvmB00uq3BYPpPmBxTFDddJ1aX5C3pojZrE9aH4C1y7a27U9zQ8s25r7
tvt38l2h/ru4i7EC7V+EeuKArtVdWz/PRS7If3HrTqdetH8Rfq8wxaDnjP60
fwFL1UsrXQfT/gXsOTzV7YAh7V/A8mWxB9oPbc1j4Pn/ng8T03muu3D9gfyN
Hpa0fwFXrJ+zz4x8NxJco9b7gT2d58aBtdTVX361a82TgWULlmKbQPsXoT7W
wrVmJO1fwNZ1u6eJRtP+BRyk+Cpn32jav4CnDdi4OsypNU8u9FdS/ybNmfYv
4G6bJJbzxtD+Rbh+XreSr9x3hf6lH8cGu9L8hNdTttf1c6P5jcX+0lZddtWd
5gfWWplQMno8zQ/86+GogSnku3rgcFsfTSVPmh94olKeZZEnzQ+cOcBj+jDy
W3fw9rEHM3ZOoPmBPzuHFq8l340EG9Q8iWvwovmBr5g+672K/FcG/rrv63E7
8tskcJXnt4hzPjQ/8FzZg7CX5LuZ4OGXdVrO+tL8wF2H9r493I/mJ7yfZY/s
NvjR/MDRmwM/dPSn+YEDzOd/fcB9F5z6NknTmM5vG8G2VQ5fK7n/uuL9u618
F0l+qwZ+1OtGtww639UG+0leabWl81w9sKVKl6GnAmh+4LKEy3OV6LyWgcVb
Y1zsyW/dwZ6qs63ryYclYLnZ1tcB/DwXfOdEt/JLQTQ/8Gw1n1JpMM0PvPGe
xKuM/DYJ/M1C89FTfr4r9B/51mwK+W6m8Hojl/i8DKH5gWNMT7S0D6X5gbtr
30+04H4LVvs45dFH8uFqoZ/ba4Z05L4LftjGY7Yz+WwjWOe/8Ww99183/PzI
fRR/nvxWDex1t2FrHvdh8MaiHYvakJ/qgU/lLF+vx89bwVtnH+5lQL7KwBPS
rJ4PJ791B9sbfc3dSP4qAbcv7O6/mZ/ngpduONv1OuXFgVWm1Je2574KXv7E
MciBfDQJXKA2aMtQ7q/gkfbJ2vPJdzPBc6V5b9dynwX7Zp6ySKQ8OXjTjxWP
13O/BS+adGtyJeVVgy8kj1eooLw68Jkcj4A25KuNQv/LD3Vz5v7rjvtXr3Rd
zP0XrJOQFRjN/Rc8YdTTBYe5/4Jnx1fEn+D+C9aOn/1rB/df8CX/1WvTuf+C
H+zdcuUF919wld1As2vcf8HPR+eFtOX+C/526fR9T+6/4ICDeu3Wcf8Fu64K
+TON+y/Y+s/8psPcf8Fnh62aeIT7L/jNhBjPNdx/wZ+SlNokcf8FLz137VU5
919w/23lG45w/wUrZSmLX1JeI3jfGNdHltx/8bke2OZw9mzuv+ATeqNiPLn/
gj2GVxxfy/0X/DGo9tta7r/gbIuyDeHcf8HRruNzQrj/gndure2czP0XvCxt
58H53H/BtQeKlxzh/gvWDJ+oqxRJ8wMvf7xayYl8NQn8U3nnMB3uv+AFohn3
fbn/gsOqBoYHRNL8wC7B3Z4PoTw5OH1wmZEe91+w5NXLZWHcf8G5VgkPGfdf
8Lpj/jbTKK8RHBAbm2/F/Xc89rdLnL41kg+qgUs2JV7qxv0XvGH1kvu15IN6
4H/GaYaP+fkp2Nyidn0b7r/gqAqLoi7cf8HP7fZbPSS/lIBZ1a7ZX7n/gk8m
pOTd5P4LXu41LjeO+y84dlzAGWPuv+A978LnjeH+Cy67lJXXh/sv2DvUtLI9
91/w9aEzVU24/4L/a9dH0577L1i2Zc4GRe6/4O/NyhE9uP+Cl9pk6fzk/gt+
Uu1yLYP7rwfypow9HsT9F+xttsNiOvdfsLnuciMn7r9gjZEWGwZx/wUPPt6x
2Zn7L3jnxtdW3tx/wWbFfVq0uP+CfR9ra/bn/gt2L11W14by4sCT5t3pnM/9
F/y+ftbAOO6/4J4dPrskcP8F/956d9I47r/gjFcpbwy5/4L7aKibMe6/4GkL
qoJGc/8Fn5yRn6zI/ReceNFOU4X7L3j+8UFar7j/ggMKc5QOhtP8PLG/s/T5
GEp+qwzeX7j0egj3YfCU+vYxA+h+DXDMLKmhiPsx2PZ903MVyhODF457EfiH
/FYPHDvzavhZ8lcj8Cy/vISz/PzWU/h9uVPn9eSzNuC2h5pHeZH/MnCg36Sa
jpTnDB5xrV8fJX7eC4545lJ4lvzUW7ifFWzaSj4rAauojTufRP4rBZdH27SZ
Tn4bCT69p98HbfLhaeA5o3NO9KC8OPCPisjr1XS+uwD83ybzNn7kvzLwg4KQ
N7fIb1eBXfbY1R0Koe83ODrY+fELOr/dBj5zX1F1H/nsHvDxuSrlM8h/08G9
G8It/pLfZoLjM36negW15uWAz+2eOpeR7+aCO2VfOPyMzncLwOPLBhrbkv/K
wb9yvf7JyW+vgFPrfFhYAK0fsLXbu5t76Py2Eqx46eYfXzrfrQY7uw1lfya2
5tWA3w6Iz/bmfgs2CorMuOPfmtcg9Lv3fWw6911wgOJsv/Z0vtsEdkw/MyPI
j9YfPNPTu2bpT/JbZfCNKwPUbX1p/YFTv51OOEi+qwGO7eRb4U7nu9rguuz0
T5e9af2Bu9a12fuR/FYPrBe8XCXXi9Yf+NuTfV9HkO8OA1v+yui2hM53bcB/
7fdGPPek9Qe+Ios1TKTzXGdwQ8G1l0oetP7A88ur+pmQ73qDt9t1qB1B57sS
sEGxa8ebbrT+wOYth7fbutL6E+qP3zz6NJbWH3hSd5PbU8l348BvPWcN++JM
60+4XtfyYr0TrT+wrWLOrRQ6z10FVpyq2q9lFK0/8OfIFBudUbT+wLKWWOlL
RutPmP+XH6lO9rT+wCrG6x9V2NL6A8sVf57OHk7rT3i/H4emBlrR+hM4IFbz
kjmtP/Cae8eU2w+j9Se83n8xFVomtP7AQ/5Of9B9MK0/sPTs6v8KyHcrhdc7
8GW+cT9af2DWJA343oXWn5DXvfvBv51o/Qm/pzBr0Qh84tC6/gSuaLgbpEif
twIvWS1b1rX187kJLGY/ezX1ov2LF/K/zBrnMbD181oZrB5x89NzA9rPgGVn
3TxdTFrzNMAVB5+cW2tG+xuwOK8l08C8NU8MPtlL4jTSkvY74EdOvhcybFrz
jMDpZeMHdeHPL4OtVYdEldq15tmAz4S/u13MWvMY2LH+7+6qka15zuBvg8tS
v46i/RE49e+sNwvo+WVvcEv3FYo/nGi/BJ7YwcxqhHNrnlSo10YEf+fPMwv9
lR/b7je2NW8a+M7IdaMdyXfjwLaHxlwcSee7C8Dm+x9v0BvXmicDx4+5qvNl
XGveKuH6p21PO9Pzy0ng4Y2+OZPId7eB/3ZPLizn57vghIMprwbR88rpQp5d
4+jfE2g/JswnUvXmYnp+OUeY34bvntXku/h/LbrWcnXObjrfLQA/GJ6/aCg9
rywH3yiyPX6U/PaK8P2Oivkdwp9fFua5qMSvkXy3Euz6+v2JrnS+Ww3+VfbP
soz8twa8fYTmuTDut8L8+y0qPk/nvQ3C+9HZ1aUT913w5l9P9nyk890mcNkm
r7kj+PPK+Ll1cknNxRt0nqsMVtycvWE6Pa+sBt7q47TmKvmuBthI38SuNoDW
H3hdVteFh8h/xeC04b4T1Mhv9YT6mWRTRs8rG4Ev+kuzDpDvDgOPCk1bGkw+
awOufzoxczv5LwP7KJ/5bUR+6+wtfP/3zzsUQusP/LmgvMM78l1vcFC7wPge
5LMScFn6+Zo88l8pWC/0v8IPobT+wPMur61QIH+dJrz+KufPduS7cWB9f8Oj
88lnF4BtWjYO3M7Pa8GvZJ7Vz8iXV4ETQsdeUid/TQK//ZQXoE9+ug3svI1N
GcPPd8HsprTzCvLfdKHfokcT1pHfZoJHDO5xYC3l5YBf3z5adJWfB4NPpytu
fEN5BeDN91x123BfBXffm2g/lnz0irfw+4J4rZXcX8Gfqp6k8fPbSvCVwOSM
49xnwXtsNyc/pbwacPYitUP3uN+CH0gM0isorwGs6lkXpcx9F+zysvpJF/LP
JvBTtaY1Btx/ffB+bfsMm0U+qgxu3mAlLuA+DD6z6VrHc5SnAW6psVas4n4M
PivfYdJMeWLwzTk2Oa+5L4Pjtt2OuUd5RuBRP3WbVfnzx+DtT0sPdST/tAE7
xv/Z3Yd8lYGvr+5XG0M+6gwucNsTeYH8FfsAUdrKmi1nKM8bXNItcPI1ypOA
LcRx3T9RnhR8P8Jm2z3+fDL43JHSr/mUNw1s7VTfUs99HGyjX/GhgfIWgMfH
e11r5H4OnlPbbbsT+egqcKfqLe4p/LwVnJr7s24n+ek28KoecYoZ/HljsJn2
p4ar5L/pPsLzTpE5RygvExzWWK69nvJywBFZX4+f5eez4Ib4POciyisAa+7J
f1BAeXLwvw57lTqRj14Bu87ZOzyS+ys4f27++2jy00rwieIDxdHcZ8Ezrkxf
P4X8skaYR6mmy3zut2C9wvHtfCmvAXxMbPpiHvddsJL7o2dzyWebwIXTvcwT
I2n9+eL/u0ptuSmd7yqDJ37IqHrIfRic/Mg77Tr5pAZY3zzvTxX5oja4U770
cTr5pRhsl2nz+Dz3ZXDGd1nuc8ozAvfesje+hPszONK9xD+T8mzAyiuvHy2g
PAYOtvZTjaY8Z3BW78F2GpTnDm7qeGDOH/I/b7DRoBXTOnDf/l+etsdd8ksp
2HVLoHot90dwyIvu/ylR3jTwrmfrDT5wnwTfyDD3KCf/XACe9+mlw1PKk4HV
y54VbqS8VeD9gSn7HMhfk8DHZ85v1qG8beBjHulSE/48tNDvVL2cj+SX6eCG
4vHWv7mPgte/Xdxdk/JywP8FZjc0cz8FZ179eOAm+WcBeGzghMzn3FfBG/z1
QnZR3hVwVGz0ifHcX8Htu9Qnc9+tBG+Ji0ox5T4LNsg6NbQ+nNaf8HppURGf
yFfrwEcnqQ75S77aIHy/XapNn3LfBa8wvB99hHy1CVy0f8HWU5Qngocor6nU
iOf+C04eY7HbhPsvOLZII1WF+y9YqcPl0Bb+PDL4dYK5/mnyVTHY5uCVRye4
/4I9vizxOMH9F2zuXhO9mPsv2FHD67c791/w/jWDpjly/xXqo3rd68L9F/x5
c4z/VfJVd3BQVOepB7j/gg9c3leUyP0X/LjiTNdh3H/Bp0tq6/S5/4Lfyq/U
aHD/BWeeWnsthZ5fjgPvlC455sr9F6xWMOKfFvdfcI2xSvJx7r/gdbsH99fg
/gv2uxifdZP7L1jlYNECS+6/YPuITe3z6XnldHBZyb7otdx/hbp7h8HDuP+C
7x1bkZJAzy/ngl1SiirGcv8F3zHu3OYPPa8sB7vbpJ2M4v4r5IepPLnOz2/B
KzQ7TlrF/Vfof0nHS0f5eS549mBTDVfuv+Bu1YcLm/1p/YF767svmMn9V5jP
DKeqLHp+uRHc4vK6FHNoXX/C96t/WZYa919/7JdbRskk3H/B8z+oat+m81s1
cLzu8tVB3H/BZfeVZiym81xt4f7IXT0Hcv8F996YbXGc+y/4zrOcmg8TaP0J
eT1C8oL588vC9betQ/ty/wXn+JVERnD/Bcs7dvokpfNdZ6E/s3rlFeNp/YFr
HAq/PqPnl73Bsk2vdxxyo/UHnrnxr/d1V1p/4JMBNn9X0fluJNjAw/6yfAyt
P6Ffz5jVkjG0/sCfResea3D/BWtt3XttqSOtP6HebGc5ls53Vwl5F6KrJnP/
BbOFpXfD6PnlbcLrDzD2b+9A60/gTsa3rtnS+gOrq4w6l2JD60/ov+nzgRJL
Wn/g9FuiEXctaP35C88TBFpFm9H6A4uf6z/XMKX1J7y++NwsC0Naf8K5/5Pf
P8UDaf0J9WN9/3r3pfUn1Nfe2Z3fndafMM/sh5/U2tH6E+rmJ6zmvS5uXX8C
S/VTzJqLW9efkHerIqSwC33+Cjxl5smzfWn/J/SvFLhbawB9/mJdixd2npuh
T/s/YZ2PPptcaUr7P6E+80/O+aG0/wOfLD64YaA57f/AM1WLJRKr1jwxWLqg
Lko8nPZ/YNax0rB5OO3/hPrmS+KN9rT/A2sldh2Wzmj/B56/K3XLevp7XTZR
+Pn0us9Tep7ZWairNW2TOdL+D+yZYLB4qhPt/8DZ3rEDHzrT/g8s21h9ZTr9
va4UPHHSrPH8fDcSvHtX0athrrT/E97/he9LS+n55ThwusKyrBvutP8T3o/k
lfUO7r8Cv3ZWmOtB+z/h+iuP6008af8nvH7bkjcl3H+F96MsXiyj89w9wvw6
x7zR8GrNSxfyrI4qWdH5bqaQ133t/c7etP8T+guItc6k55dzwT5dbLcr0Xlu
ATi/fN2RJdx/hfvVZq4K9qX9H9ixXWzTWe6/4Bv9F60LpueXK4X5VM2/0Iaf
54JtX/U74UZ/r1sjzKt9X49D3H+Ffi+8ehVOf6/bADY/lDWlgvsvuGbdp9cd
6Dy3SVg/Baryc9x/JZhPfMI0uwD5/wGAex0c
              "]]}, {{}, {}}},
           AspectRatio->0.2,
           Axes->{True, True},
           AxesLabel->{None, None},
           AxesOrigin->{0, 0},
           DisplayFunction->Identity,
           Frame->{{True, True}, {True, True}},
           FrameLabel->{{
              FormBox[
               TagBox[
                RotationBox[
                "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\
\[CurlyPhi]\\\", TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\varphi\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
                 BoxRotation -> -1.5707963267948966`], HoldForm], 
               TraditionalForm], None}, {
              FormBox[
               TagBox["\"Time (Jupiter Periods)\"", HoldForm], 
               TraditionalForm], None}},
           FrameStyle->Thickness[0.004],
           FrameTicks->{{{{-180, 
                FormBox[
                 RowBox[{"-", "180"}], TraditionalForm]}, {0, 
                FormBox["0", TraditionalForm]}, {180, 
                FormBox["180", TraditionalForm]}}, None}, {Automatic, None}},
           GridLines->{None, None},
           GridLinesStyle->Directive[
             GrayLevel[0.5, 0.4]],
           ImagePadding->{{60., 12.}, {41., 8.}},
           LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
           
           Method->{
            "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
             Automatic, 
             "DefaultGraphicsInteraction" -> {
              "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
               "Effects" -> {
                "Highlight" -> {"ratio" -> 2}, 
                 "HighlightPoint" -> {"ratio" -> 2}, 
                 "Droplines" -> {
                  "freeformCursorMode" -> True, 
                   "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
             "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.922526, 0.385626, 0.209179], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.528488, 0.470624, 0.701351], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.772079, 0.431554, 0.102387], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.363898, 0.618501, 0.782349], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[1, 0.75, 0], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.647624, 0.37816, 0.614037], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.571589, 0.586483, 0.], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.915, 0.3325, 0.2125], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[
                0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                AbsoluteThickness[1.6]], 
               Directive[
                RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
             "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
             Scaled[0.05], "OptimizePlotMarkers" -> True, 
             "OptimizePlotMarkers" -> True, 
             "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& )}},
           PlotRange->{{0., 100.}, {-180., 180.}},
           PlotRangeClipping->True,
           PlotRangePadding->{{0, 0}, {0, 0}},
           Ticks->{Automatic, Automatic}], {189., -383.19}, 
          ImageScaled[{0.5, 0.5}], {360, 106.6},
          
          BaseStyle->{
           Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       ImageSize->Medium,
       PlotRange->{{0, 378.}, {-438.99, 0}},
       PlotRangePadding->{6, 5}], {439.0527628677699, -1000}, 
      ImageScaled[{0.5, 0.5}], {312.7018419118466, 360},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}}, {}},
  
  ImageSize->{
    UpTo[600], 
    UpTo[700]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.880458501622456*^9, {3.8804590900449057`*^9, 3.88045910914351*^9}, 
   3.880463473724465*^9, {3.8804635725783663`*^9, 3.880463721526573*^9}, 
   3.880464092132769*^9, 3.880464242291375*^9, 3.880612991819686*^9, 
   3.88061312321214*^9, 3.8806555390538597`*^9, 3.8807027605280533`*^9, 
   3.8807034762182627`*^9, 3.890982096827306*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"c72d24a6-0b94-49ac-9b51-db54fa0941d5"]
}, Open  ]],

Cell["Combine the x-y plots.  This is Fig.8.17.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, 3.880462891878394*^9, {
   3.8804634457063847`*^9, 3.880463448195674*^9}, {3.8806141679440327`*^9, 
   3.8806142112342987`*^9}, {3.880614288681053*^9, 3.880614293899702*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f3307f04-fcec-4c7d-969d-3310e9423893"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xyA", ",", "xyB"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"xyC", ",", "xyD"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"xyE", ",", "xyF"}], "}"}]}], "}"}], ",", 
   RowBox[{"Spacings", "->", 
    RowBox[{"{", 
     RowBox[{"0", ",", "10"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.88045957252564*^9, 3.880459597439735*^9}, {
  3.880463754828467*^9, 3.8804637817946577`*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"eca90e2e-6a81-42f4-b7d6-13e1bf1b0b76"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.0055000000000000005`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJwtWnc4lt8bf2QrhRJCRH2VVfZIziOUVCoN2XtmVlaI7L333nsTKjo2lYak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          "]]}, {{}, {}}},
       AspectRatio->1,
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           TagBox[
            RotationBox[
            "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
             BoxRotation -> -1.5707963267948966`], HoldForm], 
           TraditionalForm], None}, {
          FormBox[
           TagBox[
           "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            HoldForm], TraditionalForm], None}},
       FrameStyle->Thickness[0.004],
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{44., 4.}, {41., 8.}},
       LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
       Method->{
        "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.528488, 0.470624, 0.701351], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.772079, 0.431554, 0.102387], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.363898, 0.618501, 0.782349], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[1, 0.75, 0], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.647624, 0.37816, 0.614037], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.571589, 0.586483, 0.], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.915, 0.3325, 0.2125], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[
            0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
            AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
         "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
         Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
         True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& )}},
       PlotRange->{{-4., 4.}, {-4., 4.}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Prolog->{
         Thickness[0.002], 
         LineBox[{{0, -4}, {0, 4}}], 
         LineBox[{{-4, 0}, {4, 0}}]},
       Ticks->{Automatic, Automatic}], {180, -185.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.004583333333333334], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJwtV3k4Vd/3vvdwZSxjKiQSmUpJ0UetjQzJlOaBQoOSpFlIRCiFCoUIkczz
rHPMU2TMPM+ze83j/d7f8/zOP+dZz1p773XO2utd7ytmbmN8EyORSKNMJNL/
vQmOszlMd2lA+v/HX9PjqcIiDQ51dI9Pb2TB36Cn2fvkZkFExPdkH3MGPMlb
9u/ypUHkw40cVqscyCOnxMn70EBOr2GmnbUUWvfnXHJ5PgvHrgwqhr0vBf+n
LXhODg1C9j6V2ONQBBaRFPdDQAOsCWOTSqmCa05hdw/n0qDgmYtsrFotCPmU
3FGupcHz04O51Oc1UM7k2GaxSIXpy/Yz8tR6KEgmIhf4GX6hErszk21w0rfM
7KYTDbj3Ox7wM2gHe7e841ULVJD7vG4is68d1Kxye4ucqTA/dj5SbK4LFOqS
msaNGfkcsRlx9e0Bp9hf129QqXA4t3Ah9nkX3O7mS93EQ4UiC/saLK0Hnt+X
eEw7QYUbczfYksz64PHBxO+vA6jwU+tKi59YH/D9ORbxIGUG7M1exGXG9gFd
c4Lt4vkZ0H/qze47NAQfsyr1zpTNQLeZkb/s9DAc9ik8Yf1oBu7UP7ik4DQM
L/i/VmvfngYjSS6Z7KwR6DQvOHrk0Azwzz0Y+eI1Bn9HZCdE1GbgUsSZwFyh
UdgfbaDQfm4K7i1250/ljwJxuae2hTIF3zyTVvd9HodvNmbcjT1T8LovxPhL
7Tj0zRHUD06TIPOdqnzwwjgsfdix9JU2Dr+6trmbyU7DkYLin+A4Ac+PyVw2
fzcDoXIyLzTPTQDLj55Rb70ZWKcY6HvGjoHwwk9WJfcZuHorjxXqxyC62/tj
QyAV/NVktVUSxiHh1ZCGMRsV/nLMGHI4jELmE0qE58QM5N7TSBd7NQJuu7iE
O4sYdRHZ6ZmpNQq8exaE58VosM3Tu7DbfwTmWMyPUEKpYKHjZDL+bAgS8hcE
K0VmgUPTYrr08RBoWXtv5rSZA0m1oBGRLIZfgiNNUm8Oqk/9uDiKBkFR1kfQ
S3EOZPT0yw9/HQDWvwPj4//Nw5fSDI23i4PQ3/xo2W9mDgYEzQ9YbB4Apjdz
3EnP58BlNUr1mX8f5Cg7OAqKz0MgXk7fuaMfeHhPfs5JmIfS/WY9nOL9EKaW
r39UeB5qBqUpurk9kHpDNqRcaAEUemuk9BR6AN1l4V6IWgTZw4sHpjJ64Hbq
6cvhKYsw7W1f32PUDetvmqS0byxCz47Tr2e6OiDq9QN2+vElGKiMV+/f3AO1
gr8aN6EliKe4M7850AntkdtSzD0XodzlovKVglbgrD799fD6IsQ++Siho9gG
N8/IPGYNXwKxLeEDQg/a4ZTE1iw58SUouKdSZPzlH7yf1zTkSliCIPsb71KJ
Rvhgd2La++wKrM4Wvkjh/gfOL+XIx31WwEN/F1wZaATOLTlvQHoFdjhNhC0O
18H3s5XK639W4OCOSXPuy03wKYbNbphrFVKWP+ukmzXAhcSHjncUV4Awl/l0
LvMvXIpX+2Nox9gvcfD88Zq/4OYbUma3ZxXYzC9Kksj1ULF16wmXohVAgfd5
b89WQmKahfDPlRV48rdbZfBVKXzN3pg+G70Gf1hfj3s8qwDWr+HTnazrsHyO
y/teRzlU322djg9egy1OvpMW1YVwZ6771QX+dTDedOl0OFslWI5evqXntA5d
LDdfHM0sg/xNQ+2qn9cgd9OOwJ9CBdDg/tyiLm8NfpcZqiWyFcB6wcSTW5br
cCL/1/tdDJyiclMy10XWwVLh7FhcVh549dx+5SO5DvK5j3uOd6bCzT20yYq6
DRislvkX15kDa6f5ROtO0MGPJnvuuGce/PnhwzXdtgEVfHIdGz7J0O+yOdRK
lQ6s3hcqAssI0L0b4lSdSYcbjtsN47bhYBVZuN2qbAOmC+c23INSYcWmNkV/
aANkRfVDUyPToL+G29DPmw5k2YuG6csEmCAax6AuHUJ+p21rpKeAuWkgh7Ae
HaYnDrjfTfgJ4Q4e2c3PSCh3iDijV5EGD7rkX19NJKEVaW2p+cgsQFKaT4Ne
kNBGw9MPz84mgvq+RlnpeBJ6JbZkQKgUQL+IxRm3fhLadmqk19eGALEPxZ62
90hIczZ4+UBdJqhkZvawviKhoD9OHyYCcqF+LxTW15PQbq67x82flUDT8MVC
kygSmvx7xRGa8oASeSI/NpOEvsiTPhMoG0g78ioVX5FRPqu/o5BDIZRYfVQY
jyajtiDXya9CJbDs2xy2zZaMmsb6BNt5CsEzXrqHI4WMco/btkTrVoOL/tfV
HX/ISOrRLgUFoz+gaU1sdr9CRqORaoJH71bAys+tcpftyMiCt+ToL6tq4M/g
P7irlIyYJJM4pZrrgemr49R+xvlsEgW9OvQaMJ86JdKWSUZrn35cbKDUAjP5
AvnvHQwF2n4b8khsgNCe9Ezepxji+09CNE+gCWavh3SPKWMIf1pbOZPdCJV7
RNyNfDG08s1wYIGrHcoJvRsejzH0t810/cCpNvCpWJYa48MQufEQl9gko3+F
HwgWqWLIJjDi9nPdTrAx2War9xxD8dabvov59ECU9d/ySk4MfXfpz2TW7oIz
Owa/2ztg6HRcZfqTCz0wYesyMEpiQgnbJR4I3u2DwdefyL0DGLLcrfgqEOuH
1ddVIdsjMcRhxckxWdUPU843y1/wMCFtBc4bXu1DoPHu60LnTwzZPTnuqmk5
BNKHbaO9zDFU+qHUdefoEJxtcjA+6o0hZYHyAHejUTjxLyWk7weGLguHBKZ9
HIMs+it67nYM2csObxNvGgXjO/mOJb8xVBdg/SJ6bRzuu0Tc5V7B0FEWTR5H
likYWPJxuZnE+J6uLunse1OA1fbYbLLDUOhTbbbbBjNw7OrRrbQWDGW5mCUe
u0UFRaP3GZNSGNr8VFb4uQYVhAoqm8owDHm4X7UUHqHC6fmly4/EMSR9XaW9
ymQWdmyVL+FfIKMiH+n2PQ9m4Xqrl3zDEzKikgtOzGfMgsor7DuVER/leIXL
knMedI9Hs02TMeTGNNqt0TMPQ+4lLm0+ZCT4xMswlW0BzlDPvVR9REYvLA5J
tNctwolvEic0XMhIuFtN1nD/Ehj6i8Qn5JDQh7FVzeVTS3C/9bmkTCwJBduz
fOMzWIYgbf7jP3+Q0M6CO+TUjBXIiWr+JSpKQsv6dE6S8Qq8NSlSC+uiw1NH
/Tdbz6yCj0fsoyAjEkqsStj639s1oFfdOXAikQ5zNXy2C2zr8HGkZDs9cgNM
apUcFm+vwz+mZ5GZ8RuAJwZvLzSmw1QseydTFAOveoqKBwTo0KWUe/DfvTXI
PxHvuexOh6zME3+vnViDxFfvYzmvk9Bi4ZD5jrRV+O3N0rD2h4Se227Dm7hW
4HbbYFhEGAnljJ95V+21AvXvdx3SNmb0hV0yTfbwCpz59mSbTDoZhTQ4rJ+v
XYIZDqdr0hVk1Ji9PZHctggsIyKpzscwFH5by+5kH2O+aSsdrqjC0PUjvfVZ
tfPw7F9j1dA3DJHOJm182DkPfwUEs1mXMcRYUcYcPwcUb2uByx5MaD9ZKjjt
6Sx08UjEnbNnQqHtyges66nwL8LhQMJPJjSgMLhu/o0Gz344/axRZEYEy/Lv
LUCFk8+nBHL0mFFufayx24tp6HVOlNfWZUbDe/enhG+dgpnMzeFbMApKjeV7
8K1hAkynbwj2DjAj8cE3jzkfj0DE5dssEy3M6MJCXPbDL8PwsOZj2ksVCuqI
cnl6tWIQiP2FWKAbBfmyMMcJq/aB0dN9K+JiFDSdlrcxWdQDWcdJm0pCKWic
11jqZmkPVKssZxysoKCGzqUdNfJtEK1jphgaTkFCB/eZuGNNkPyf62G5ZAqq
yfs6IaDZAFWfT7YJ6bCgG+YfWy8blIMY+y+3vfkUdG7GWvYdUy74fE6/LdNI
QY6Pwf6VcArQh3w8nvOyoLIVm+XPu7zxMMce0+VJCgq82OFYIFyALx0w8Rxk
5PNt12LdMVIeHn5r+oUaOwu6755Pa5gpw89lrLbq/qWgE46j16h/63H1HnpS
oAcFcSZeZc6/9A/n8cv6OFFMQaLBTE5rJi248mMjR/48xv87u1dQk9KLu13x
Hn6tSkGzXq9iz0z24qdUJTjYzlHQTdfg5+vp/fgpxVN75vQoaGjftT+L2DAe
ZodKzAhmdG3qkQ/X21F8ebfhZXIjMzrlGBT/SW8EH0o84NZUxYx0Qsu7LbdM
4LUG5+cqjZnRS33rh9vsp/AX9hn3PHiZ0WVXsZf/PZzGb+1V/NdjzowiWqi9
HuUzeB3V7/2LBCZUdrzdOfsnDd9/k/epiA0T+vg72L67noavHt3XLHyDCb07
eZRNhj6Lb/rssL2DwoRKjp2vKvSax/2V7jg73MAQv4/nzO6gedy20lMp4hcD
V/fWvGeqnMftlYOm78kzcPIR+fDMvUX8pttgHD2SjFQuWSxqci7hewKDvxh7
kJF9qf6VP2eW8IZyxUNLX8gosSTp3keuFfxFiu/evXEk1C0j/fxvwgoedSUp
sPojCW0/XHZelW0VpyTkY7cZOGApf0ApV2MNP8prxmloQgeBVy3c69rr+IGL
NrbbYzbgnp3o6adn13Cns395NRk8pNCppuTtg3W8/Z/O/J276zAiw5G39cYG
3rKW+tqfgSeiahMJXZ4beFuWXM2VwDV4gd/l3D2ygcet5q23561CAavuZksT
EjF1a1az6/oKbDlZpa5ziEREBDlmiEquwJqj1VtlZxLxIeHAxFaVZbCg28oE
MJEJjkaNU9yMvp/pDye93UYmTJRli9KmF6E2prtxyYNEfDIQYaszWgTjoxEW
T1TIxPRsoojk7DwQtq+vbL1KJiy4snlNrObhxPY0jQo9MpG8kJCR5j8PjVk9
ni/DycTphBlL1vFZcPvs8rdYBSNupZ1+YGEwC1uVrvkNTpMJ5SOuHdReGjD3
+UxwnMSIe3J/pB2yqBD+iWCe9McIo96njT8zZsCxs+Ui/T+M2DDV8eH/jwpf
DTNncibJxHqxX95u9hn4Gu87+dMWI8a0FZaOzE8CRT+3kf8CRtAUHW1df0yC
nkGeoxLCiBpn+5v8CQz7+PH+xTyMyBS/tXf7wihUXhkQa+jECPpjmcryklEY
l84nMmIwQk7/1q//vEfAq9I922QVI1RzRsnx/w3BA7eD/Z/ZmYjd9J/YO7NB
YH6s03PlOkbI+ArYSDP0zgEXntNzNzDCSWjrWdvCfshvKTvT8AMjngnandtr
3cfQda/3nLuDEX07E7505ffBzfbG6bcmGGG68tr7vkIf3CdHyk+NM2yHSwdN
FLogfCKXPpSAEVbiNn5X/3TBD+zik5/fMKJ/6cGeWEoHzE8Z+e1ux4iM0d9e
JnItcFDm90EiCSOapDmzTsa0wE+HFwn/9ZMJ/Vt7C2r3tcEmzKXrrBhGaLw4
df2HahMYq1fUHZLBCGUmqaPvuBvhpMV/R272kYlPN8k1Zt+awH10TjdqlEwY
1RMpx542ALdMosPfhxgR7xaDr9yvgaWDY5E3mDBCSDG2i1OzFpRrf5JucWBE
6x6+8LVtVWBRYUW/qYQRg+KDw9SKEvD0US5Z6CYT28PKHvcwVYIWXzmX6hYy
YRmXsnGsvArKC4Oy91mSiUTnAtvJoCKoGxZ6wmREJnQ/DQ8vJRcBj7OrVT4L
mXCcjqi0FywHjb98OGUXmZAxsL7xKq8Q9rPmHWQPJBMOwrsruw1zYWkP9+EH
jPutr6a82cuWgKIiZT3ffWTiXmTx2cqzmXDGJcBW7xSZeFdZEfpCMRkS+cJv
uraTiNbEyrdGyflgvqBUsIePRFxUcHbaI0fAtlNxQyKPScTrjVPGCkdS4fWt
P+U79EmE+Mop04zRDMCymLlFKSQi+OhLToFeAqJjfHZNS5OIO9c4pwz5MqF0
7t3TdwEkYoKXtCv6ajIktf82nOUlETHdX1qiYrLAX6O1ZEKeROis1s150ZPg
46y15ZImiVh+97iMpSMWaojQu78/0/HKBjOm4m958HMqPzOYawP3frl7r8de
AtYFdvYOV2/gIZMzb90fpUPhcKdQnP0G7iW1tPHSOBf0DzxE90bX8R32b67m
cBQDzm10IfDIBj7GXiNiyYaD6wnC6hk7HRdMTS99BrnwRmyaj53CWD/L4nLc
rBCEnMt0Nilu4OQtoW4xWjgE/CBfdLuzgdvybpdZfJ0PX7FTNjEP13G2bZkS
C86lYKKXJabXu4oLXsHPR6ZVQNC9yPsbH9fws/+u8fGNFgNH/UJGoOEafmNm
qqj5WDlUit+9JJmyiif+0nM64sPQn+fbXt+aXsU3u1ormD3/Awa117kelK/h
m5xQ4dnblaDr8WqH5p9VvFpp3rlEthaCb7p6POtcxfe/v3buY3cNPOVf7dWR
WMNDN/arHemsBlXXE5/eaKziopd1nToT6yEl0SSl2G8ZP8uTeIsLmqB8S5Xw
UYkVvKG/rEdqUwOYSKmfcSCt4FvS4h1G3BpB3Omth+rpZbz19KVzb3xbYOf3
eE3PW8t4wdkKmipLC9zd2ZhL0V3Bj6CDl5We/IP7Tc7z8xbLuGawzvWa3lbo
omXW9cEynnfl7KN5hp54Hb6SNu2/jLOb/Lc3UbgVXpEcX4z1LuHmBrWd2eYd
8PKR9zs6zyI+FuHnqLDWDV5Fjlk+Vxbxy9a7ry6QuoCrZnd+z81F3PbCJfeE
2S4oPUN5HBW1gPdtyW2X/9QLpi1Wp01fLuABXJSy2KleqL8Y6PjIbBG/1qbA
xVPSA3MHS3V7fy3gflsuk2Jf94EoqfWg8NEFnKSvJ7SboUfsfLKtGj4t4KZL
rqE7bPvATLyfs0tkARfWiliT+NEPPKs/NmkencOLGlCG279B6KYRyvl8c7id
Qn/HBeFB2NU2fKzu9Bx+pU5zbU5qEPp63r1h853F/W3DjpWLDoO45oGuUuFZ
fHvHyMFW+RFor+kXfTAwi5uJKzaFpDD0Tdj5XVwvZvFrY45FBlIjYH+Phiem
03CZxxdbEiVGgafXrqBkgYZbhOguSvuMwLnAxLWQChq+EHCwx3fPKBzxN5pr
WpjBE0M3+Y/fH4eegkTrbyoz+I3sR6eTFMZB29T5onnIDB7auFeHmxgD6cWe
Q8kT07gi+5vzEYYTICU0IexqPYXbrgQG3iFNgUBZloiH3TR+2cCuFD2ZgC8n
n9GuWk/jQRUbyofVJuFtTIJW3NVJfOue7wmJ4VOweiFDn3Z7EufgfBz6VXsK
5u5zlbZ8mMRZo6WC6sSnIFu9o4TyYAyfbpJx7uaagY6Alpbi+GFc1CnLc0hj
BtpPrpm+ezaCj6yZli6nTcMTtRAbsc/DuBK7co/KqRkIPV5VxBQziP/xug0N
56hwpmd7Y8rwIL7e7d3MlDMDIXSTY03hQ/i7Kr2LcdEz4JBjN7/15gDeIn66
Tt2SCoeh1UOe6MdpNXHSnI+ocE4ksElafgCnLRs/UmZl6LVPl5Kr53vxGwrp
VuXxVDjLn7r2RqsDRxNJ6l5HaLDZ2oX/9VQHzhKrfz/qNxUaJLtuHD/ZgZ/M
CH07X0SFrbpG0SLaLfgzqbr9gn9oEPXuru5qwz886Iv8l2BPGoyL/qedcq4V
Xyy7biKwTgW/k2wsP1404TurHO85fKFBsam6SnpGPa4is/mk3gCDLwRqOWdZ
NeB3XH+l7tWhAZ9QqOHTg3X4GWnZb2OPaRC+oK62b1MBvjvJd9lNbhYwfeP5
9+r5uKuzGbm1hgY5Lydfupb+xs0d+ud5bWhgF2evXiyfjJtYf9oedmQWrp5b
Si/e64sLHCFf1bw1CzJJj3kvpcTjk9KSvDyvaDDJ+keFfdAPt/PtXe8toUFq
yJnOmPkI2HV+J8d/aBakSyPDMxp/ANdZ9vF3yTSo2CI8reYeBR6GTSFyV2nw
Zcrl/LBoKRDSsbs+kmbh4tHQh4aG1ZBOkwmK7qLBdec+vwrvKiD3bo99pkqD
7wdJF7oG/sIeHvY6+mcaOPzO/WxyohGsqp7ySO+dhTI5m0efX9aDzEf7GOpu
Gshzj6UsdtdD9ydjEcoSFUS9pWUV+JvhUlu1Fo8dDVqUFRoLr7XAgv7Jmz9k
aeCdZUM6btQMkf35dtOM+2DD7s+/t6QTHo+0/JbHqUDxLTN6U9sLnyjnp6K6
qWByQYArwKUXMvalsnyTp8KzxoFw1u5eiGjwo+lQqCD3xo+/YusA8Oxn+tj4
lwr/nT7ldm6jH445v6vnnZyBG0837UhV74fm9Ae3XxjPwLPHzNfqhAbhVsem
aeOEGVjOvfrtg9EQGIxcISBtBjw+rr7qCR0EDt+G9sEr07AfeKgz3sPwSDzD
PlJlGryTS7/jGuPwQOIh8DVOQxw5/EKhzTicscpy9oqfgmYbV2BVHIcP6X7I
//Uk/AzlsxZmmgR+GrX+Cs805Dl2MPNUT4LFpLJ/0fgkfLwee+Ca9QSEbz+8
Jsw/AYHdR51TUichX3nuF4vWBCjVO6ZoqU1DduqfH6ptE3Br0Kgy+M8UtNza
8bYgZwyeXrMR3HV3GhQV9NhTqkfhgRaHDn8KFcptb9/b9nQMHChxj0kiNHia
ZG8pWDwK5vpW++UbqQAlzuESwiMQN3NUWfUmDVzyR5+LoFE4z8Iu5ig5C4IV
HksvekegheNE1eAZGrw/MyFVnD0EN7S/LR8OpkEdV39P1MUhWCzwfsFiPQtp
+w3oN5SGoUNkU9SOu7OwS4/eR3o0COGHNt3bdXAWmozVdSq7++Gj3te/IYLz
ULEnocX29AC02yuZKDTPQ0tp25WYnQNwhtexPsd9HvRjwq69MOmD845cw1r5
DB3Qa3V1caQP1MdeXOBOW4CvTpN3Dur0w8Dit1L/YUY8ah+/JNwLhtIFrNWt
8xBnbmAQpt4D2RmfWLy+LoD6itbBTvleyOIRNOqqWQDt/nPKh1h7oF+ni/uX
+gJ8VFr5OMHZAbU/HU+2TyzCv3P+qtu0OqA7t13gyvQSfDx/3VsspwOOVOnm
G6QsQfP+Y5a231rBd6aS6VrIEuxROHw80b8VVKXkvvhGLsOHtZpHfG/boW/W
KmBpYQlS5GnvuXybQVepTKQ5cgk6zxz0v3uqCUxebZvi01mG5kF3AaA0g97H
HncUvQzPugWN1Tb9g2GrieGnc0sQYnbDgNOvDsbiBFJuX1kBVODGYH914B54
WmDRYxXePHhxi/VyPdzN+6EtYLkKA6+qtpB6/gJZ9nCgyJ5VsPf/dqXhQg1c
l7uyq1JyDbYrdvo2sNSDaqrX5eOBq6CTX2nadaga+NU02BNFVuE/kRFfAaNy
OB4/4tEfsQplZoGoM7AKJDEfS4edayA0ulT+rqUKBA6JmF40XQWnW2dZYssK
gSlD/i/Jl7G/3JkeyegCMLLliHndsA7DLr89XAaLIVdJ0n29ch24D71NqvYp
gJekvUyvH6zDedVLAm9FcMB4vax/WG6AtWZwMVd4KZRePVIyRV0HFcWUpN39
BNzK7M3mM1uH5hsnhX+kZMFWJrFNhU3r8FjC7IN3Gw5N8o591Vc3IDP3v4de
lQXQmhh3bu/XdTDtCJrmF0mBspciMRVpGyDR0ndd9FcSfCd2jYkt0yE1ekm1
eGs2qE+mukSs0sHp3hsXLlI6iPHZmPp8pcND/q/sh/ekwJ+rlZPndEiIbvYy
Pv9QAQRxuu5s4SChBS+uubDcLLhr8VyY7E4HkVwr+p6AZFjxSgwLXqTDLfGX
X2VDc0Ao6FDpTSChSBmmgM1bCRj5o3YsPJUOB4qNjpYeTILxPu4H96xJKKCU
hSneNhnWZ3dr+LGQ0UzrZq+dI7lwv2N7YSUTGZ0YUVyPi8qGo0JBXtUNJDST
JnTQ+EgOROt1ZmqeJaOVCrTzcl8JTKSM/BLaREbNUYHbLfECKKhNj5EsJ6Hi
4qGOr48ZfNo/Z/oXY7/bZmb6Er0lIDfs9dUAyIjlX1DGUlQ58G3Uk77Wk9B5
XkEb5aUC0DN6XdH9goxsiOiHtSPFIHTBbfemDTJKTVXtQgz9tZQ17205QUZv
8q4VTz2phM9pc5KNBWT0QUSj/nZRNQRIfrr3XAtDlkXzGtelGoBjU23S0TYy
8js9d+GETR0cEsn+LBpPRjF3RNWeOtfBYrbG9mrGflU6KQn1MU2wgF+f3sWH
oRuRe52ePPoH2YpP5yfCyehkrp/mZsacuk/KOcl/A0M8OWVbeP9rhv9ifdSz
cQythtjJbwpugwqTvdMBfhhqThbwfmbWBkWCzewpzzBECaDXOSp3weBRlz2v
pzG0/53K3kt1PRBVdVtd9DrDX6Xvo6bSAzsVqCYfdTEUv2PziuFsD0zTUkY1
PTD0T+zIfsVP/XBbfsVTxxVDrFflLv281g+rPWnMHXswNOy5mNp/rB8Kgi35
Oicx9I2Zfrzg7iCobXOO893MhOYD77f7cQ1D1/UiJ44yDO3KvhFoRxmGX7s6
BBMKMOQk/vVkjMwYYM+dq08wMaHP1jnuZVvG4ba13z3cDEMX3jrnHh4bg8py
euwVcww9ePNfxzmbCTj8N782+QOGZN6p9fadngbb1eAgQ20MedD6bYOcp0D/
/Gur8d0YGtRyXrKInAbTBDNjiWIMSbgqvnnNRwURD74ZPBhDNkcWt9zIpwLS
5hNBqhhqTyL7fh6jAklv+VLqJQxJpQ1KebTPgg2nWVK+PIbc2cqtv3TOgqHB
Q8rmEDIy97jIe0JkDjRq9l7njyajF2F6w4fQPHifkYlzjCGjsWpWFQG7BTAK
qnMJ5SOj8ns3f5xmXoDdqil4qz4Zkc6+GDLYtwh4+MUOnvdk5OxCS5gxXoLD
/gn1i6JkdLxhovF03hKcNZ6Yn8sgIa/vw52nLZdhblOx4aUxEnp2ZnN7M88q
1Hr/CfpyhIQy+fqOtnasQMkr31rdBDoD5zQ61p+vQpS0/OUDkXR4wu5Yq9W0
Bh8aRz+0CNPhVLLNOqvpOtjmntYZ+rQOx0Dw6l+GLfi8fveTzxvwu4U0PFey
AZbpjk5X+DZgINrm2+/3dBDYcdFtpXkN0ivV54Xy6PDyTh1LIgN/WySJvApv
EnJanQ1l/m8NZGbslhWGSKjd89DpwUMrYHSFdUipnYSAUqu/o2IZ3vzUipFi
/AcW0y2NF+4sw2gtutTG6IuWdD0WG/kl+Fbl3H61hIwOaSy4zbIsgr3fhQv/
yWGo/HmQ8jSxCNo+J0RmMzA0EU2+nG25AG5YRYt5B4aO/toyep5nHhbkpFUX
ZzB000rtyO0fc7A53MbG4C8TaoZDV3MTZ4G/hd1cM4gJvWF9qxExSYWk9zuw
jQwmZDn9WRzzpkLPSpfAHQVmNHvEQpYaOwNfGnk+xL5mRtFv5DpyGXwmQ1RG
f1CRGS2un57MtZ+ErUmXT6NaZnR/aaJQIW4CfJaUc7yZKMipj/zY6MgoyMlu
1yqkMqPk+x9aaL1DMPTuWvKufRSk9+f9KyUGX5P+6Bvtkk5B5qU9bwq39IH2
gPZJDn0KKqduypWS6gGutgM8wq4UhBwOdTvWdAJriWsGfzsFzdROJLdvawGp
1u/uISkUdMlrXOcCUQuC1id2Z0RQ0N19vXdcTjRAg70G1zIHC0om8+8vkaqE
kr5jmNYQBTkcM965rpMDmypCp0VyKIgjfC1WPjQGKg9/bifkWFDBhmiha4I7
GEXEx9esUBBmZnk6Nq0AP93N/Z84I9/GIdZvPxaL8Qqb2LilAQpadrqxR0Si
GleYu1OyOEVBd+J8bP1/NuHiNAn127coyOPVIXYJn1b8YMUWWgkj31fenhUu
gS14wunk0fhwCrIN3/5SdF8PPh6k+vehOgU9PoN3Wfn14T60kCFzcQqy6HmI
2bzrxztPGhrWeVKQNbuddogPQ5+t5181rGJGNu8ufV0JGMXDD9oHP0xnRt9H
/ytTuj2G6z9fXT2TzYyMgx/JtfFP4upzHeta15mR9Z2LeyuPzOA1vf+tbO5h
QoMbO/pSOqbxP10v7+fJMSNb6yaeOzUzeNw1N/H5NCb0e2dwFOkWDVd3fuV4
8QQTct/EvVOEbxbHBwoCBXWZkGmY9N9H9rP4zFBY6vwRJjS8vWvlbsg8/qMk
3TTrCYauzJGWeObncclRpZ6WuwzcNWzdWh22gH/YyXZIgoEzE0GmbIfYl/Au
98cGAe5kZCen1HKUexmP5P2yP+wmGeVKeuykiy/hRe7d6r1GZJRUsCX9et4y
Xp82qqUVS0LfRVyNxX6t4NsOcF3da0hCKd2u7KXDK7iZXqZi+gMSOrhRXz0Y
sIofqvunIfKGDoEf8dQiy3X8Rny3e+6PDVh955bYJbeOm2/NX5Rj8A7uO/VF
I1s28CMbq8365uvg56V6/44KHW8zGj04x7YGAtIxvElKdDwjbPbt2K010PP9
qToftYE7HJcwlb6+CtlhAZ+XuUjEO1dL5ie7V6D6lpdj10ES0aNwTfrA72UY
pzrwTSuRiNkOZEPqXIbLGZGMipGIwTLKEenhRWD51sg+s5dMpPz2LfTwWwRV
mGX9xEsmrqBPXdvoC8DKoX9Bzo1MzOgkaK/kzIPuXNgurxYykYQJs4x2z4EM
uSrK5QqZsL629jlSex4ezvuy1r8gE7JmhZ5bmmZh+m4Sr8EgI94wRuHVEA1y
t/Xrvq0jE29LLg6ea6FBYm7RgY9NZMLjCQ/L9FOGrijjt6G+wYje6/sPP8ye
ga/Z2/ndLDBiS9f5DZXwGYj8ZulZboMRJlb+F/K+TgPRqb/pSxVGlHEFf1kS
YeBGDHukazVjfSXb5W9VE8BiXb9rhQcjli4HeBE9E9Chpsbe9oJhh/NbbeUc
g/6hykvXP2NEadZDVtflEej0Xm4rYJxXHuJWK3B1FEoMQj/3O2BEQv159w8v
hkGSxi3GKsJEmPxU7u/WG4T9CXtpEUkYocfb7mEoOQj1M3vHApoxYvXbtHPe
iX7g2Nqw7RY3E9Fs9Dru5u1eYKPJhVwuxYjzlaXJYagPKj/ExIxxYcT+lNrm
JftesG/u5sbeYsQv0/usIRZd0C74zu6BFUZItq/VFBV3QvixblENRYwYl06/
eJ6jG7b5m5dilhgh98VDK3miFZRVDsiifxjhtu+gcZZ0C7AYGLAfuYQRkSBq
vSW3GV4Gjle+88KI5OYLTbqCjdB/ixJ0NBwj3sWevSa2rR5uze/DybswwmKw
J0xTvgnO8S7uZPEiE995C1drgurhLFXuN77CqK+Vl+HR6BrI/JW6+0Y+mbiB
u+SFzv0FXuqCsoMnmbh+jP1rO4OfBZ8spIQy6ltiTq4p21wOxfdtsdUtGME/
Tm4N1SqHlBMjjavBZGJe7/3m0cdlAKrSJ8YayESPm5xQlGgB8E8uT/rXkImr
subHfx0l4JPRW4OdMmRC47Wf1JvaMtA/WRPNkkciYtVpR6skC2F1Uzi3myCZ
8Gn7sXI9Kpeh78DO/g+JqCgTOpXNUwCGcwKk8VASEfbJqnHtv2Kw5JChDKyQ
CJfhRw731dPAtLeNZYGHTPA+psceNckG8XMObUfjSERTxA4w/JMFJGPLpPJ+
EhHwdTXn0UAcpFMeUXf9JREqXX8e+lGTIOme6lbJ7SQiOH37578DBMzVtxty
uNLxQ8JST9SfZsI+4y+2xTwkou55PVl+OBkS9tZkuDH8yeh984xiLjTffRRq
pkjHWT+3rvPpFMBIaZyu8AIdn2T/0f7zQxLM/gsaMmEiEV6Hg1CSVhb8HUz1
OKNFx9OfVL4XTM+GZPsEea10Ok6ZPyFw4G4y+J7dYafsRsf9JZgr3h3MADPn
hufZHBt4tzkt0lmqGEpOP9Y6YLGOFy+F8BwTYuiluc+fqzbW8fbs681eR/Lg
SXTqX5brDD/THqw5pghGq3xtOljXcRFW4p2STjnQPB/3+Zav40l7fHsLLhDw
GH+726h7HS/0bTo/GFMML2+cBXaBdbz/V1H0ZHEptHwdul7gtI6HBknLiTws
ggvX8W1rJut4RAjfpS6eUggxFE6jDa7ii1drfv379BesLr91SNyxig+fc4lb
3F0NN+L7WyTwVXz39vqpM0pVwMS2K4157yruSdP0GPCtBS1r7ZP3clZwqxSN
kaNvGsDs7acPzjdX8QuuMgXp/LXw3vp8Ev5tFSfMC4orGHrWhayyyyJ7BX9i
4HDPfbgBYneIJlXzreJJxMo/7bB68D782YqPm3E+z2jyVEQDiA1bbdX8tYx/
0vmnO2fVAjEpr4K0vyzhp/RKssk6LfD8kK6Dy4llPNo/ss2Arxk2/bzqbkEs
4VURfLpRA63Az+ROYd+/hH8vSjxu6t0JiuvTRo8Sl3Ae1f/C/lUw9EYqHvZy
xzL+YIL4OUzqgDpJERWF7Ut4dIL13nuZXcCkp5Zurr+EO+uuHBSkdULpm4nS
pPtLuEA6WuU42QX88RNiEfsWcdGj7f9uXO8FFTe0tbNgHleVbKl6u9wLWa0s
CkpmCzjpa0rqDcVe0BbQ5N5BXsDTy6/KC53rA8PrY3UF2vN4bcjrPMUnA6B4
22Nlj+s8vvOT++27vv0g22Dc9EJiAX8tsuFxmGGn2bInpwrO431DB1g2/zcI
geL9Nx+zzeNLxaJqhw8Pwi68p+bNSYb/xJ39ITMDDP4f3Slyag7nbKk7NFQx
BPNxUVHYaxp+7jCtHm0bgV2iHQeix2m4AS8mLX90GNJ+koKDCmj4lipAbd3D
4NKl/jd+jIpzVRR2XtoxBiVHBQ0M/lBxfjOdlg/DoyD40jiKz4eG97eYVLbJ
jEIqj2nowDcqrtSk9GSxewxyFM+lgBIVv5B9YKz67DhMLbfHfnek4nq7L4tw
Jo6B+qG3951aZ3D0UHSvxeA4tD5b62r+NYn/s/SUPkVMwuEn4+a3Qifx3gnP
fSWkSdBO3CtnVDaJNyxYJpmyTAJTyl5XGt8EXu/GlLzIOQ3zDYOlB7jGcXv9
yZ39sdPA/sxm5fj7CXx7hPTXmJNT8HqxYa/GsXF8aM+/V35R03Cf0qmdGT+K
pyuEDc+cmoE0LbGjmZvGcIW0L6sdTdPAHT2lUuM2iovqZy6wCc+Ah71OMO4w
iC+NfhzNEabCkCj0flYawMUPW94un54B6ZqGhud5A/i+g/vrEyJmoFW4tkPM
oB/3VPhFPXiNCiuZEwLufr34c80VITYeGmzoE1+qI/vwCs+Dmi1HqFCULqxU
p9iHc/9JpZm5M+zWsby5bT34ltc6XunSNLBknZYk93XjryMqOE8NU2HcFK8W
5+vB/fze10hGM3j/VrXkbtVW/MKjxcz6FzQYHViznZhrwAMen3OTDKSBpPy8
Lb9QE05X+dySto0G2+zeMLfoN+A6WqyN2rdpUKfgpvJVrAa/0p5jxHphFo6+
EKgZ3/MX51pSN7b/RIMjLe+Z9rjV4lFsmx2P3aTBWR7O/A6hcjyiiOmz3qZZ
mGqO+yf5uxgv/BT9XJt5Ft5JWrTPeZTiLZfOvHzPiFfUPP3o+1w2nvbktPO3
ZhrYFrWntVj6wKxLqN0EzML9th3HMlbdIOhD8pYvaTTwb2+f8PryCezcVubU
3tIgZYTb5+77dNAI4H3A4KVgv9YjVfQgF6prmbIEGOc391MO71NOgTsVpcUs
12jg6D+xeNuHgMrpKNncGob91nH/Q9dSmDXLEYrbMgvX3hkIDAqWwMvd51qf
qtOAlYmitNOjAuwUhg78UqaBa5milLZpE7y7uKWou4gG16WvLD/79Q9ym55x
11+mwa7rx6NU5f8Bx8Cqh9sfKpRZGV0tvdMKQW9/LDG9pMHj7ztnd//sgG2R
ps/YntPgg+yBkUt9rQADWTUL9lToVJpN4RHogM6f5yUTP1KB5c8jXc6Wbsia
Eyr8t0GFPbnnW1iWusGS4pQqqkOFne+21Lyd6AbFgiad5wUzUHnIvD9ZYAAC
LJ7z7FeiQvoScy8vPgh9ePvLJVYqGKhWs1qeHIQtCjdV9TVn4FYgt1XxviFA
E3ttD3nOgIwsJZXNeATevZz5NjwxA8+pE+b2CsMQQLsudfvXNNj7/oxpvjwM
mhu2kT3s09DTG5M/rzEK1o3E5kOj09D/jWS2q4eBAwPNGX95puHmGuVwxO5R
SOaUmqHDJKQN7C9YfzoB90Ofzzd+mYRzjZcc1LdMg7jORML73Ekw12DCirKm
gHr2akSV4gTQ+ZKtt/VOwaDyb6uiynEQ+6R35IX7DDw9tXOVJD4JYjsWyOwn
ZiBpi2i7m8Q4KHNGsUsy+hQ43r9QaBqFWs9MfSkGj424L1/w2XYMhlifxL3U
YOjfA9oeM6fHoNN44eFS2QwMrQCHAOcIPLAu0nvQQ4W95qVCr7KHQf3IMJbr
NAtMko7knQoj8Imz9lWKK+NeWZ3SvbE8BPfy6x49Oc245xl2SuSaQWAWjVN5
fnQOolT0NYyvDoNs8F8s8+wc5AXE2fK0D4LDxEac669ZuPvGIKd96wBw/au/
lKEyB3ca8jad0R+AxY5w0svhOai8m/P1e9UACIQM6aq8nINRmuse77t90BLc
yLQPmwdPCw9T7de9cP/ye7agigXopHZ+fLW9DySuOX25zLkIrxw2X7lxpRfK
j17aV5uyAOfyJZdZXLrhl5a/6q6zixByEgu4Ar3gzvx+/n3hIiw8Nu/MuNgD
mT50iaHhBaBgVNOYog54oJS021aJoVPOV4/2WHfASMHsnw+Ti5BPaRWgqXcB
LdhL4Ef8Igz1d4wnDraC6SIf55vMRchh24SY1JtBcAf5dIDrMrySsztnYtEC
0rcf3eskrYC4Z1ZSRVczcGpdvBX4bRm0pPDQd7aNECzyqq97cRmeb6+LOMDb
DI6Rl5t0IlZANk+6p83mHzTwbKw0py2Dnwj/CtmjHtSyKzFqJSNeZvjefFId
ZFtYjns5rkBULvPTKc5GEGJXsPCyXAE5j8N6V+7Uwle1vJunRFcg+DPXb4Hv
lTBC4eFm71mFko7RUyXJf+AEb12L9ps1uFQh/Mf/UjWMZ6qFpkmvQd5aWM69
uVK48OpjXYXBGrDtcU08llYFh6/9cR7fuQ5hS1/jnl36AxFxsWttsmtgY/Dr
l7poCfTzeBtTdq6Bl03uv0GJIljTFYv2LV2DnYoNb19Fl8P8XWeh6do1OCFN
jzTtKISKrZcPfL60Blh3FuawkgWNj75vfcC5Af8m+D5feJQPb8qftewp34BS
qXP7pUsIiHbbXRT1ZAM6OL/om3tkgIlHZMlvxw3QKvZ5NKnK4OvtT8NkrtFh
aW/d5uuKhSBmWD6ne3cDPJhvxaYkZ8InXdkeO4MNOLnvS6jGjzSQLdTdvmNm
AyIrvY+75xFQFRM1ELmJDmbqF1uezWcC53iB+dlXjHj+ZtvBtGh4jR1sc9vK
0OWjpzeuPk2BE8e70iofkdDgs+41anUW7GuMCVbVIyGVg2TvB+8SoVFXKqVd
n4RO3Ws9PnMoD3IDry4a/CYhsavMu81iCFDIZjVJRCRkwIvLruZmwPlA7z07
DpNQ3pk9lkLcGeDiM0zqcSMhjZsT8CKsEMYt/C3tvEho5LZWqsDDPBhevycd
aEBCV5ZtVbb/SoXdY9Lr+RJk1GSdcPPQ3zz4OJ69mvCYjFaovGpW1oXwoz01
OlaHjBY8akPOl+RDwKfBtFtnyEjQd8A66k4Z8Oz4w6GcQUYhAsYfvuVUwGPb
F1eGFMnotoQWd0JWCbTv7FYfOERGF7S+s5vpl4H8Ny8H19dk9PzYWkubaC1w
jmi0PX1CRvQitt0Br6vg6vydr2UGZLSaUWf226cCfr7XULotiqGIndkBvJy1
UGU3UnX3DIYMLfqlXLTrgcp/WyxWGEPrXyw0SrfWgY54zxlRVQwxix27t6/p
H2j9m2e9bochgfUbCWK2zSCbllsjuUhGLdLnNVR1/8GHotPlS5swVMrWIX7r
egu0cvuRHxhi6Kp4RGywcSdoRPlqZG/H0J7cXQHRiW1wxed5kYU4hoRMD6uo
OLXDr8K0F5OtGPq+0yaDO7KboY/Jnvz9GHIWI9fFD/SAwh2FbWUhGCowiAHP
yh6gySX/uN+BoUkbvZUqtQFw1hU4l1CHIRWltugr8gPgIyV3yskEQ/0vR/e1
yA1A/Kv+rAB7DCXxH9m5a3UQGoTOyfPEY2jnxPnaJKMRMFSWsTiOMHTptuY9
X55h8BlVT9X2xtBUzun7dt4jkKNP5R/nZEJsA7b0p41jcNfgy8sfPRg6cWdC
czluHFrYE71CPmEoo+wiXdN5AmwtH9yPGcdQ8tnoFonhaci8pfM33AFDdebr
tka+0xBS2zUfL4UhR/KfxEsSjLnietGNVRtDViybRv0sqfC0i8bErYuh2Q8f
+NXkaCCRrBN2OIGMHEhZJ+8y5oaoWkH+a0a+Y8Q2saTtsyCePVXoZI6hcT4b
4RO75yBRraK4iYQhNqUX+7xuzcG+hEv6W3LI6OzxV0vpHvNglry0aTsLhixP
OcVsjl8AFk+mBs3jZJS667g9yXcBTLF+E+vNZPROW9coz2ARDPZ959bYTkaL
FKk3qSVLkBCj9SqqloT2/p7dOde2BCPv/ZqHVEmovZ/L0kJ9Gea9Sexfmklo
Kv2k0pXvKxA6J+tr6k1CZg/MpZtNVwEm2bxmWUjozLr3zdkPq6DDLZ6qnk6H
a31vY+quroPTBtdKoz8dGtiFkulB67Bw/m3Ata510FS+cYK1YB2Sjr80HYxe
BzxnUdTnzwbwI3fxn6brUNuYczaWnYSEJPV44vkYeOjE6in6gw4n5S2uVUSs
QhCkfYs2I6EUJVKV9K41EE/kzPg8xsijUHMXS+8KWCaTjl/YSkbsp5jvbslZ
hk49dTdNRt8KC2amUr8vw4mCY4ETchg63ydiwXNyCaI3j3xiWiKjmy/8XvNt
WoTYq4nzBxQZdY4TEP2SswB7pH1uVBZh6NZ1QwmiZx5UFHjZCS4mlDIsxCPB
Mwe9Pfd9uAcwFHb5+UcJrzmg1h75FvieCZnvYf6j2jQL7k3L25armJD6Hf/f
xYgGQsuHb3VWMqGHsoeYTzP4BU2jO5p+nBl9jD77DNtGhQtnHR6//86MUNza
Uabvk7Cz8PGnuBvMqNMsB9ttOAFvbZ02rWQyI+U9y4sHWMeh3cFsXFuSgu6J
W715LzQCrodLjbypzCjtC8dTu4kBYLUW1uNg+Dv0gnlFjg9B7HQLJ78XBYl9
tPzZOdUHV01VvDEHCjovgQ8El3eDWJhVPlhRkCXn86yvgp3w7OqbzcXcLGh3
um2459NWEGpn/RuKU1CuWqyzxHgtPKgK3hcQR2Hg2O1D+tY1kCpcvPn4PAVJ
eiKna3ElUFWWxETawoK+Pm78bEKKhYu78KR/fhQUt6dPArH6AdFh1HmBgwVJ
l4luNz/9EESOhJGukVhQMumACf1wPv7r19bFt9kUpLm77GULrQzP26RZ+Z6g
IF+TgK6mJ1X445chEXzSLOjYEt1NPqAJ557keWjiREHHbksb7uBqw3+/kIhm
f0dBqtRzJoHPOnAiTOvDl3AKYucrmX4t24t/CTDe/EyPglbR72jpyAF8qFqP
TYRMQQov6jS83/Tjr4x370jSpqBmOy75raZDuE2rmq15DzNyDOmsv/BsFMfh
rF+1BzMS+/7ew6p7DG9ae1wikMOM/gbmcx/DJvAn+27rVtkxo3v/jkuynZ/B
/c0vX5ujMSHs+bC68scZPJ4QmE5cYEJtQrseCLyk4hk1R1UEi5jQ2rWHTPI8
s/gD+SivYBFGvCef3rnVWTzpdUxXphITUjj4KSzuEsOvHDstRmZCv1meBt2T
m8eNM/ZJhNtgyIN1i8EFkQUcf3X8WooshgI2nbq3+mABf3JkJM7qBoZsmh0e
d7xdxLuSf618+UBGTlLKhuwiy3iTRgjN05CMtkQSITaSy3hdZxFQZBlz8M+B
62onVnCFS9VebbEk1JTunKP9cRWnqG0//nELCfWzfW7R0V3Fj8WFrq6dIiHe
jCe7pOxX8a8H7+ypsaDDw7+jexr61vCDEUu8H09tADkn1vTdsXU8SuKwtBUf
g6cYtsXq3VvHvUXVvqvQ12H77RKuB5x03HJbj8W7HWvAt+Pt8+HrdHzveDDH
i6FVyBaX8+ILp+NfaJ7/mSuvgr761dATl0nEfxv8soK9y5A/dW7eKZlEeBLH
/CIMliHdMfjZ0E4SwWXSrmFttgwtAw/ZMkNJxBkYd902wuC5EQ+nryySiImH
HRNO2xYh4EOcvMgMicAHzgboSi+Ckpe/kcxWMtG5ba3jlPICVHvVPDozSCa6
7d++i2HwcLd93NVs4WRijeOiZVbCHKy0xl+M6iETr+l/jgYlz8Ko1096izZG
vAs8uFhjRQNjlsrw+8oY8aatyns9gAZ7w96rqH8hEzJU8Y77dCrwto6plBzC
iMtXpBR/x84Ax7OuZS1VjKgYqr9fdGwGzmZe+4sJY0Q/8734IasZiJfZm3Dr
BkawN4xy9MdNQr7LWUHrUYwY/RxgI+g1AbFT7nkGbzGCdLm6UKtuHJrtJJoP
NmJEwciotIP/KIypLrUqsjERdyf52jKHGHpmNUdcLhgj1uyz3b8IjgIP5/Yc
RUY+ug2szKYLQ+BnV0XljceIhuNcfwroA3BuMLtJwhkj9mzVTVDvHQDlzBbf
CFOM2B3H0uK5bRAGPuhu7CvHiMgwZrvTYb2wTcmf+984RpSbnF+796kX/J8R
v7O+Y4TVtWf1S8E9UKPWVpk2iBH/A/9pK7E=
          "]]}, {{}, {}}},
       AspectRatio->1,
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           TagBox[
            RotationBox[
            "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
             BoxRotation -> -1.5707963267948966`], HoldForm], 
           TraditionalForm], None}, {
          FormBox[
           TagBox[
           "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            HoldForm], TraditionalForm], None}},
       FrameStyle->Thickness[0.004],
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{44., 4.}, {41., 8.}},
       LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
       Method->{
        "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.528488, 0.470624, 0.701351], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.772079, 0.431554, 0.102387], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.363898, 0.618501, 0.782349], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[1, 0.75, 0], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.647624, 0.37816, 0.614037], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.571589, 0.586483, 0.], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.915, 0.3325, 0.2125], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[
            0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
            AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
         "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
         Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
         True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& )}},
       PlotRange->{{-4., 4.}, {-4., 4.}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Prolog->{
         Thickness[0.002], 
         LineBox[{{0, -4}, {0, 4}}], 
         LineBox[{{-4, 0}, {4, 0}}]},
       Ticks->{Automatic, Automatic}], {540, -185.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {
     InsetBox[
      GraphicsBox[{{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.004583333333333334], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJwtl3c81e/7x81jNRDJiCSRkFLR4H4blZSSUZGQhhUq+WiQzBQaZIQS2cmo
zOI6Vvbee89zcI5znGF+/R6P3/uf9+N+X/d1va97XffrKW3jYnSXjYWFZYad
heX/3tbu9yuraNWI5f+f7D2jyO1jHXKdMaYnduajvSufSLIejYjplFHYGvEL
7XAt9Du4pQb5RXTSeO1/oYzxbtoupRqk3ZSYShrCI722Phfu9CaEL2a/VfQU
kOw1LsHTU3VIJh5Ji5v+RrVvrd7cVfmHOFCjYd50MTKtVPEl02rQLYENyeS4
cnTlP+Oz5hfrkNi4y2nWMUCtaJl55EIl+sIbn28WW4EuZ5UMlQpXIJ50uArD
LciH+WRmq1A16rVhU3tT0oZ+cVpofLKqRKYNGdWH11pQbGjPpZfceDQU7hEx
ZtaOeEk/ao1nK1CWQIKp2ItOdFgieLlutRL57SrNTLnShrCF5y5Cp/6iMtdL
5Et8behL4paLF+wL0S21Gh7+K53oY5n6hPcMHvlvZVfai+tEqyOuy0868lFP
nbpaVk87sthpOeAa/gPlbnO/+l21D+lwyomX8GSjHJHXNuv7h1E+jRTpnvAT
id5YqrzNO4QunWyd1pkKQ5NsSCS8chAx535Wqcy/Q/Zd+efld48gYddvCwT+
7+jnECXs8ZVhVGM/9x2jPUWDY40+qoQBtN5boKP7OBkCbaelHdeG0AzeUnv/
nQgg53abpM4No0SVBO4N9U+QJjvsx2c9hGJf7h+JU82Fit+6mNaBEbRuQP8T
8ugPVBcrpa59GEd2EwGXOS7kgcV77xf+UhPoYdZ/F0wOlEDdahGH+/Zx5LDA
G3VGqhJo4y9QgMYEqtff6/xSGw/qg20pSnkTqEilf/DxTCmUdVw2reoYQ1a/
4zi479WCxi/aE8r3MXRh/5WTxfz1wHllIfgH1wSyPF3/nBBTDTlCLfmO1uPo
hzunvnV3E8i0qv6tJY+hQ/SnkSPRrXDrF8d2cdkpNLzvRE5MaisoTe39kLR9
BknG3woLfdcKv37+2tO/axpJqAwO3Q/sBJaYPsd05hR6kTl44MRKB9SfTH5w
1WoGvdXzLLVLbYem595udS1TyOPGv3MWV7ohpItDusd/EsUkZ/M7Xe4DauAT
4aL7U0h/JUt/LLwHdrKXFFR2TKG5FA/3PKk+SLYdihrXn0Tl+EJlkZJBsO64
Rn1oM40c+veQOQ2GIZwvL3/jIAGJD1napz4bgvNE02fp0gTkKd8WNiY9Ar/F
hPl6yDPowSS1NfrgKPhq1qu+Mt20U5YMBYnDkH7dh/Ne3iw6GMnQG6aNwMU/
mbp6JdPI8q5jn/XKGLQbxdHHC6ZRbLVOYO/MGKT/vZQtUTeDSr8F62s+2Gyr
ZJoIX55G3y7xEC4HTYDp685WUsc0mr7TrVQ8MglF/s8ub+snIG2Jd2+doyYh
tltzOzCJKLary998cRJOKgZB4wcCSmHnc+QfmIb9ArLZQmJENL/1Gq7lzxSc
7mb9eOADEYHEW3VmzxRkVHyxKXoyi4K23Pq83DwDH/Y2zd0OnkGLUUc5cnNm
QceEy+hg5CzySfxV+DZwBkQklngeLc2gtO9vynkNCBBq3LvhJziD5hxfBDIq
iFC9vXU+uo2A0kJrR+bU5iBI2uTynd45tBqhbqBbRoT45qR/v1aIqGg9Noq7
cB4eQYjlB2ci+nGbNf2A/jxYNw3UXMmaQ8xDDTKB0XNwTCrKtHiGgOa7uHR2
HFyAoE8WnicsZpE+RZJ/+3US8FrIzxxZmEXJDxcO80UswE8eKlvaOQLad/zV
YS4NEtgRy7fdCJ9BccreKQXbyKCc8dYrEU9AmtQeTqlIMtypf/wm+eI8srsU
efvTUTJcEzRzdDaYR9eDuOWVx8mQ/zVNVYBrDhEu2ogf3bMIvOWcwzLB88hq
IPvjPW8y4H0lzSjWc2ihJKSejWsR/rxeOM3lQ0ACOife0GYWYV/wpPXfQALi
C0t/Wfx5EWz4GIJqQUTkEZ4YbPt+EdJPmuI4C2ZRLtmzqdeTAqePKr+pUCSi
wR0E4e0HqGCTYl9cQ59HkQt+P7jbKCDxumzPYtsC8koVsNmymwrSvRP1yVbz
KMp56umNfCp4BwftVf67gFhMZdvqFynAFx9mOKe7gH49PGTapU6FhYywDlOT
ORR0LX9bkugSiKZ8qBhYJKIVx4C6eOEliJVU2/NYex41il9t7kygwjPTLeZJ
/4gove/H2cLPS2BSmnKrMGIOle2yip42osFX5uW72zESckxzVRSRokHL7wLJ
SA4yes+SFU4RoMEFkZjHWfdIqNFAAm81RIOjI6lTFXMkJCmM3yvCR4Mjocwb
Z3BktPNEQXPUbhowxPa1zIqSUHbCodRUAg3c46ynlRIW0Kcnb9CfXXTIGbER
+BxAQgsCheHxd2igqvLw/nleEkprqevuMKdDyiuu0z4aJCQ60/hFT4gBOaen
ss+WkBF33hHNzyt0KLZ8d2qjZBHJH1y11Muhg1nQNpZAo0V0lrU6f/E1A37m
OZg/Ll1EZw6dzlxMpcOty6cL30lQEP3g7tC1CDpc5H/3/sy5RSTBXxJRdZEB
l59+Id5mX0RRY1dpVYEMYPHI+z1euYhMDM+8jf5Oh4cuIfsoPovoQobXTZFw
Bvw4eh23lL7pb1Y2wbjCBH/jqSn8aSqqZpeS8VFnwtyvONeM20tIhm3weHsF
Aybk46SZsktIynK/WWIwE/IF09+vf11CHfymPXMhDNAXnklSlKUhlc7wlsp7
DCifabsvf38J6bifLJhnYYL+XoUnZ84vobtPUmSFZJnQ8+eBttl+GpJfL9ao
3s+AVd844WBWGnJ9/J+DJQcTzpJN1XcZ0tAW4rl7xD9M8A1yPaDPpKNOicE4
5MaED+GzLQsqTMQjerNPf4wBjc475VsFmKjfvi902osJqg+X8s9XMZGms41h
11kGtL9p/tNksIwcPgfB5V0MGFI53Xg0j4mEdkqJnwpmAFJ0iehsZKLS+Y6+
TjsG3BDdbdjbtozKEnqbgy/R4aXHz2fxictoizULUX03A1ZS42UPGa+g32sR
Jv4ZDLD+ViiQzr+G5vZv/OfDzoDPNqGjVPV1VHX+G/mOJR1ObNVayJFZR12K
lpYun+mQjDXesEYb6M2tiSAxcRqofCB+U36zgWj2ZlzpxCX4SyQ/XpPaQLs7
c782StLg2o6Co8uvNtBd1bD1XLcl4BGo35JtyoJdP1D4fbc1FZwGk71V97Fg
ydrfPh7kWoJnf51WaOUsGGGZlj6+eZ4Sa2b3WnxhxXhfObyRmaGASuGXpMnt
bJgU5bja8DkK3DhdNkTnZMNeH7K6NFO6CF0vcOFjlWzYOMk7ZGIPGUbYGr2S
09kwyZH2fpdJEuh3qH8vC2fDVveL0dwSSXDcdMhVlsSGMYVf+m11modQO2Nc
gDM71klM766ZJ8Iiiu/gVmDHciv82Lxs5mDODZ8axsOBBcuQVyvDCbC0LHzM
tIADW89OeNVnOw3KLa2fGBMc2KpOcMDRq1MQahuViJ/nwM58f6A61DEGEiNS
r9984sTe1Tg4CMiNwFZzq5WJ05zYNGkq8SU2DNG7A7/V6XNiarR8Hs60fjhg
kDoSmcOJtYlTbuuzt8PCcffeHU2cWPGFbV6HlNpgt9qz0BXgxMz+ObjrWTaD
9MWbXPT3OCxe/VLs39NloHdjHSvswGHT5XZvWkMSwSqUvv3vDxy216smke3A
Y8TroHHUcAGHtS5M5pYo/EPPKt6NFVFwmNtEAKLtaED59TE/OINwGPmxQLT2
sVbE86xEmpqIw1YHmaYyzj3oPMva/oRuHNZvies80TmM7FL2yDoY4zA9i980
is4IuuVMaTAsxmGsjlecidPj6Mya4RNeTi7Mben4bSOWGXQhrT372x/c5sij
3uQEENDCpIZlihkO+5Rj6bohuIBetjj4OaXgsKam23GpyWR0/NyH7V0tnJhr
2JarZ+8uIodtAv3WPpzYSe1XybOjFBQZu4Ot5QEntpiVnPdSnYZaew4GpO7g
xCTy1I3yOOko5VyDodN1Duyz2bWILCMG4s3WoVYBB9bRya1b+ngZjZwKKE1B
HNjPbWx6DcsrKORVb5mNHzvmaTR+12ZqFdW31OzKOciOFQURZNvjNhC71+18
oxw2LD/jWzOIs2AKejNJ5T9ZsdGc9T18sSxYeTDZVfsqKybGqVNn682KSVac
K9poY8EsrqUq7rZgwxJ7sv+WPdpAXF3hnxTt2bD9aWuVQaIbqIwu4Zd1jx07
cOjUlx7xdfTtU8hb+20c2B+8sNIv1lV0pQCvvG7DgblQZQxPnV9GKW3/9O22
cWLi3u6G9Egm0rFvCNlZzomZb516L5dMQy+9089z13Bi+GdUL/zFJRTtp3mw
1QSHTThcACcqBeHujz54u4HDeCW/rd2tIqPQNop4O2mzzS3bvdI+j8aChIw+
23Jhma77cOqO82h4GzbqPs6FRfr7Pj5uOIPuJizoKixyYd3yt3fml4+jX/M6
Z36xcmOXLUOPlS2OILE6/majGm5s/E5gEeuHPuRwu6IaZ8aNyf5dU5fTaEEl
Wpfnk5w37eLe3sF9VaiK11rEPpcbcwpllPO/+o4MVk6Y5qZyY3OtYWP9KyXQ
aBcRrHmKG5O4Uj1cUFUBi4VWiX+SuLETe+Tbrz1vBT7596InrnFjVKPGBMaf
frhtEm20n8mF7ck/T/jVMgK0waPTB4S4saDoiWP37cfha0bL5aohLmzZUdKB
tDALTuMuzzW1uLC1gAbrk/vnQM3E08NLgQszx17mFl4jgdE8OYjRj8OCW9o0
BSoWwS2nf3ELHw4b8Dyx/iiMCrsTy0OucuMwUmkWhdZDBZ6hNFbZYE7M8ui7
QaWXdPAnb2vZXcOBPfDTqKqWZEL0LuaKpQkHxvM6a6uswjL0l9n0/TPgwBjj
b0RvH1uFAaVcbtJOdqypkCAmybUOXnTSh+lMNkylTO3+o+l1+Hfj1IuK/WwY
8czJg6+tWPADiV0fr2iyYtvO0tWXNFnxFNlzlHS3zbpKmUBRMqx4M9nclMe6
LJipfry2E5EVb3vr1UK/9Toy4JR1/ZDEhr8cKx1cWL+KpBx2td+lsuHFX8Zh
l3etomurWv5uN9jx8iUjwfvtl5EFS4pi+FMOfIx+6cNaKwb6bTTs0nCfA08/
mRXoqUtH+1rvGDUvcuAXyuqIN6yWUJgzPc/7DSc+te3K22faFDThF+U78pUT
n/n9d/3HjkXE1Z8lOH6WE781Mkjm0CIJea89albeisPbxk38bm+ZQ58vnr1d
LY7Dm5/V+iX9moDGbpjUjUnj8NsvbLfzIc2gcTWPlvdJOPyeuMmn9efH0ciL
Rz79Czh8dYAO6dGNUSS+9iTVrgqHH3728/lD6UE0vLXQSVCKC2+5XM6T19eB
DAJvnl7dy4X3Oay/Ayfago55cL975oHDrx8y3DL5tQn5CZxxX4jB4Y0j80uQ
TyG6yx6z2JeDw0eQRqUyj4SizvmbfTF2OLyzcMS0hFsUSAn9iH96D4dX2Hj+
nkujGM54QEH3BA4fZHflBI9WE+TV9PQsm+Hw4wruIur5reB350q62S0c/nk5
MeXwWA8sZcf/Ur2Oww/9mh7XNB6CIyWBdp2Nm/Mjzep7L3II9ndz2ovROfDr
jwbZvLpHIL3qwl12A058iGHYtJH6BDy9mNk6PMyBZ9TtnSq/Pgkrr0zuqwVz
4G0U4s/Pqk5BxZJMuUcSB941dfzaMRECHMGEaIs1HHhqsce3Nh8iXMcNSh8W
4sB72doYvr01DxeaJs/I7OHA3zh3cTnqMwmgpFCjvJAdb+9Ty/5qnAR+ZuIl
cWNs+D2fKG/gHgkuSJlfczRmw0+PB3qmDpLhOUdwwpw7G14lPsIvJWMRihI8
ni9OseKzP/0wXPu9CA9uGi3/zmHFt/4RXjffQ4ESoS/qpzbtqR5xt+5PU2Ej
PSZEL4EVf4cUOx9cQYU2LZkD5fKs+AtLvBWLf5Zg9WbSwooUK/5+g0I6w4cG
zY8O3pV8yYLPtbL1qt5FAzmKvkOGygZ07bpt9fj5Eoi7BYnV1KyDZ7LB6eER
Gji+G2t2/LwOL6TOyrJy0SH4G9tP8dg1KN4h/UqxlAan1ichz3cNxhb7brSd
ooPbgu20wrZ1CJHq5Tvry4Ct2PCp8Z1rUP4phWrCtak/f4+c3Z26Cgz9jbcv
RxlAdJT48+zpKqTTiq6LCzIh9tEd+tr2FShj2rh/vMOA5P2VgorXmaCXaWd8
tmHz/wHXV3RdmFC7xdTPe4kBV/kjklX5mSBLsNw3+JsBzyzXv3/b1IkWmN0x
pzMMkFBSPlfrzoBO+X/XKOWbelaS2vBWiAnp4gTi5GcmKGpTaFe3MMCxQHf3
2DIDcCXbY40odHg2toWQkcMEt0Rly2vVdHhkzNN//jUThlwZeg7WNLCOH3+d
UrepV2VqQkwaqOBqXnm+WZUBrGFfQ/pllqC5/jBZRpEJp6NW7U7VUQHrUJaW
yt/M64rYtxJFKmjfYZn+rciAxYnW3cIfqHDehNK9+wsD1sUPl41rL4H01Ov3
YRgTJFhOWDOuUuGx97JdjycDHJoSDZPuUuFiwhD3WWEmrPfv0zh0kwrNv8l7
Cc0MEBeZonryUkAPerKNNnlFqqzFTfsDGcLaCpoFbOlw3/W4yr5lMlzZ/R92
4hwDLGnLJJcGMrA6P77TjafDq8+iRxK1yLCk49HxRYIOHZ7OB4fxZLC6HELO
eUiHuu4cLOftIlzUqRo15GPAzeL9Uq/bybB4Pe7yowN0YC8QMB0fJkNPRMeR
vfF0KO9T2aoruAgF6w0a8/Z0uG5x5i1thAQpy3K1lT9pcPBDMtlgYh5OHng/
sD68BJ7XIvdRghZgYV1lajibBqPy9/4LL1uA50nrUtNqNBDZMciXmTgPLTOn
/N78twSNFkGab5MX4OnatOHer0uwM2k4cR+Q4NybXuV+fRok/znvKKpPAvHj
pjL+15aAn1ug5IgiCZQcz/i9jluCB5rn2/MTSHBd6N8dodDNePVPz3YbLICO
wA0zq0EqqKRb8w04E4HF7Mmd6E29zf9edNdaOBGGu1zNPSKo8DZCdfyz9xwk
N/2oOXyRCk/tjx3uv0gEPo0vz1udKHDFkCPJT2wO4s9aFnbfoIBWsyYSllqA
9ywNojt2UWH53zY+r9l5wNV9Uc1Vp4AjL23/J+l5OEx85sB9hAKy52Qcbvou
gKv3+LufFhQIOfzKzfHgPERn8Mnxfl8E/kjVdPFLBLDodn84lEaG69+Pej9O
mQUz+8rkr1yLcL3OW+/rKSII2ff+E9myWV/SysakBAnQtcOq4KMEGZ49a6UV
uRBAWWn0YyieBD1xbk96n8zBj901/hxuZNh24dfPol3zoMJuv59nlAQS06kF
r2uIMKEbr3zUmQSkguZIlbPzMLGPcVK1nAQcEj6lybVzkDNuPKC8lwRcn+hG
N7cR4Fxgg7K14zxMCWgP17vMwLeKQ7t95OZhiefBOV89Aqh5WdzEjc/Dnsla
/9jXs4A/L7cmuHcO8pz68g+fnQWvZM4OrIYA6xEJodH8RIimvZBRqydCm6vu
bS+PObgaeEvk5xciqFoN7/HnIwLjsNY57dFZmHxicjCSew5UtBIuyjwnQCf1
XxzBfw6+JrsI3vo9C3Kt+R2yhwjw5vhEUZzUDBQbXHsamjkNvIMidedKp8Db
mucn//ZZ2Pt8b/G2sWm4N5I5qqoyC/x1Y4uXU6bgWdCPHx/0Z8AhJSbdvnIC
ZtVkYlo9Z0GNeT4ilWsSqm6Jjf15TIT7O0S+CrZNAod++qGpAALsOLjb5mnV
ODB4EyaDHxEg+pKoDsffcfjTIDQWl0mEZKOeMJ+KcVBKpgorHSCA25HCSrVb
YxAr1jWosHsaLphF9xUbj0Cpz3Db6tFpGJIOf5oiMQpB86Yjdddm4IhM2Dms
eQT28rC/fK04DSy74qXPuw6BXtPXqx9dp4E51zTxi30Q3i50vrjoMQtkXOeB
jjPDkCXRSbv7aRY079ynzaYNgBuPsO6i/Qy8Nrt6/4NnH5wU3YN3/DkLkRf3
3D8U2Q8MyRfltuazIPH7xrNir16QdVwyvWI8BcKL0Ydcozph/72Xz4/nTsBh
f5G4BFIHtFMO3MvSnoILKl86z+t2QamY19uzgZNw2CNS+2R/G8Qnt4ktVk2A
pJdy+c/wZuByVN3HdXYK/ASlOhaftkKPMVmA9nwabsxI19Yda4Usg3HBG8RJ
ePM783v5ZD082XUtvNNoCj4m6tS1TDdA45nINt9t01BwMW5wbksDPHy9O8yz
fFMHqO1YvXmrCgTFS3y+FI1CCcf0+3SsFC6IcCa4+Y1Bs5r/w51ilRDwCr0L
aBkDmW85of/syuBL9hYz/fujcNrGUdJt7RdsPf9ETLVlFEJleWdNs37Bn3FN
n+DYceDO28jqU/wL//rDJ2z/jgHnLO3Go6AfkFbtbGdXMwppin//vRJOgCCZ
taP8vWPw7PzXfpbzGZCez+Bamt3MZymEw1fvC+Slv7KRKhiEj85ZSXvTP6M3
0U/ufvjdD4M273V+b49AbsLNR+tmBuFNRFtv4auHSFh5vd8nqh9Yj14Xvied
iczOJws+auuF/R2xIdqJBeimVpliedcAcF7yP3TF/Tty/PZhS0PaIPDOjHiF
cOSgZz2609sV+4ADfqSOBxQjGnGxPKa1D1S2zyuznSpEx7Wc80hJ/dA6+j0z
BAqQTrut8VBbJ8jXPnowIl+KyJTu4SvbWsC3hMxrvlCB7D5f60yMbYWHvLve
nXPAo85ssYqoG61gPqNi/CeuDPGZU24HCTXC2ZQWp51StUjmS2nejcwm0M6q
/bf0tgrtIXXlj+S0wjENiT7Zq+UoaintuzBXM0QU235Molejn3+66dUy9fBs
depFe1Qtyie5mB/GNwFf2muVqhf/ULy+jKHPw1qQYl+p/FpVhTzNjo1pOOZB
XHBSd5VPA/JduWN561I2PCffe8guUofmE5YV5svzIDIweUaysApNqP0poDen
gDV70CW+2QYUb//Xfy/re6hwOCA4Id6MXHJP+a8pZEP5+N5x86s1CMysH2f+
yAKPV9Ki3Ry1KCyyJ9o8ygOapk43K802Ip5l3RnWXSGAX75XHLpWi3bx1pix
NUZBY/RkoVB4NZr9vfu/atHfqCj4jk7H4zoUtvvZOv1NBVLLOG3mca4BKU49
Mmf/V4q+H6pUBucq1Hvpky5rcBn6Fy8VuOZcjcTYzilYpdUgt5CkbVW6jWjF
9K9vtloVmvNLasw/WoMCcof4lG6UocdIfWRauAKdWVoRsa2vQmIH37V9UahG
FuvYHa7YOvT55WzLmUvV6Lpe4BPrr1VonnT3prdmGeL4sXXm3noDSnhkmBIv
VYoO3C2Va7reiSIq+GbCeipQzfaMX0FPupD2yXA+qmQp+urb5ZjQ3oGmHBja
mQEFSLHpqoHm+25UlWGlnJtQioiu+hnH+XuRaLiUT7FsKXp4KWyX9K9OdPzh
REsR+olalSrfpc53onouNffHW3KQyKUHQqzCveiRlmBqgGcBWsLKYrlP9yC+
Rqrll8RUxOo5PmYS3Y2oz5YfTDeHIKvDxNfFt4YQs161H+cXieQ0Ihf39o0g
My+BPQ2e0cggupXdkXcEeXpr8lq6xMHaNvmSC3tGUAj7QHPLo0/Ak8NWe69s
FMG/SaphkSui7Hd9lBYzgjJEDVZEj6WBrePLDLzLMEoYStz+Y0cB5I/FtqxG
jqCUtyPEdbsc8DEzqN6pM4pUQ1bkH/Hlwpx8+NmwpWHU3Icpns4qheXRN3HL
46NIXtTjl8CHChi+VOJyVXgSsSWWDDhJlsHZuoLlwDOTiCfO2eKHRBX4Xrqi
4awzgdhI+Ve/HaiHn847p+0TJ9F1ibjkLM4q2PamuCImbRJxY0WpdXtq4eJt
crVZ1Tja9WBD3lOzBXZfP7hW3zWO9JLtP7x71QJ6wk29ryUnUdTer1oqCs1w
dJ/jqSapCRTp8dTmuEI7vKeN4E32T6BnYyNLCkWdsD5p0MnpOI1u7oj4duJu
JwjF7BvX3eTM3NiO7xNVnfD+lvyGbs00ei7npPizvhcefFjs3libRq0p/1EI
T3vgWeVtITvxWSQ3KDjH0dENXpnbVH30p5G88+c9iZX9oCXyRuit+hQq6VWL
PKY9BJI/4h0L0TSqG9JQjdcagJYd24rvnZtGsfQn5IrsIdAOeyp3fWoSOaWs
a3B5j4AF61bWXXdm0LVq0bUcbBTe7HE56ThOQFw8n65vLRkBKj64Tvc5AYlJ
f7tBdhyD39FRxndfzCKR8FT/W/Qx2OgzypdnEFDnh4bn1v2jEKZ6JLd3YBbR
Fw4tpKqMw407qj//cc2gspx4jvdCkzAfvYjjPTOD5q0+vrL7NgHt8ju/ru6f
RQLxP/WyP01AjXlC4XmXacTg4Yp//3UKhrz4ijuiZxAqulsRMDUND24Y8sv7
E9HMP3Oih/00ZJ79FsJ7bA6dkz86yik9A8wbyXFHiwjI1VKrOL54Fkom2nL3
5BARNVjDKfv+DPh/O9ayEUNE9XelSE6EGfA9o1Hn7zGLTOQynjGmCYA/dkTo
z+AMOpH5t+jlTSIES3R0XFybRQ+ebn3GdZMA0+BgqtczgzL4XGXSrOagh0Ok
aCRuBvXyFy38rp6H5H/jkzu8iUj6i2+Mbv88fB/ae2/pwDxqeR3iJJwyDwsv
iIqRdCLSXHLPunp1k3frn16RYhLRYVE196y8BdhyiZByvH0Oych9Lz3nuACi
OVaa/9oJyGzRXXkqlAQvfwcWyoXOooNKFzJ9FcjwdeK+QLwzAfmfzJsV8CGB
Uz+uTFODgJo1jh/V0SBDXrzmM5fVGSS9xMOXvckxl/XYOH4GE9E0fW1oi9ki
sLtIDIx1zyOmg8LNxE2739Of+7ss59GJoZXX7v2LkMHLah8TOIcefD7tP1aw
CLNvvkD5yjwSEuC6HqKzCH7siiovbObQhS+9LMHERTi3tHtlpIyAupYiTF7n
UuDPIUONQ0eIiJ1e6kGS29T3w61q6x1EZOfioW36jAK94/MB/GIEFMqxfCRT
nwqfZ6q9Bk7OoQRurYvaQ5scmPZfi9bIAsLvdmhrdd7kwOK+bHUxEhp3sNHf
yr4ElT9yeneR51GDVYXuKfUl2PHPJpV4iYQkT48/nwra9A8945r0ZgH5zoZE
f2FZglLZtaa6ujl0qSnY0L5zCXS1Qn/cHp1DfDzOV/g9Nv3tC9o+8i8gdZPa
TKb9Eow4ZW7HXZlDz5Xc5JgGNNAzix0e5F1Akeza0SIrNCA+Zbvqt0hCRrpb
TINDadBpSFu86EpGv8QkWIY6aBCVoXH2YSMJPUggyW+co4O2QLCIWioZ8bg1
zy/+R4Powle+kdZk9M72hxoVTwMhCZvUkVck1D2kbZsXQof4tOJntV4kJP1w
HhO5QYfR7LvCDxEZKW8Xa7Bco8EeR5MY8CShMdsznUuzdHgXK77tqSYZXXRN
VxuKZwAV1xAoBouoKjgpjQVjwAMe977lFxTkHG07SddhQLqQ19GdS4toZn9E
TM8mn0NiXIloJwUxAmhiXv102B9i+dijlILE2emv6rgZIGZe5M6xsYjIVx49
OI1ngIdSmNMcCwVFtFbPy4Zv8rF2H2vwIAUVJUzJIa5NXo9OEBnQpKAtCgUX
OxcZMN758nsODxUZazUpzqUyQfGlzs3Kz0soTD/nvstxJki7q6DbvjQUWMHp
7MbPBG2rr5b43TRkMHFLN8CHCWfU+yuHpOhIiYdvZ/YDBmTqH37ZuJeOclXe
k3yDGDBkKGnvsOnPev785c/STBAS9zOmZtCQ/t5XX7VaGPD4eavax1Q6+uf6
erlIkQHqCv5/j0nQkb1YzV5jXia8e/55z/Y9DNRXlXnvUxIT+iLf8lz5x0Sy
O1eFFdcYcILCO/Di9zIqVAhZbt0cfzDpfXjmw2WkQneeVxpnQLvcUwnqrxUU
y+YiKvuDDq1p/Zy8ySuofsOabe0vHV4ePy+cqb6CTq6f6nsgzgD7iypsxG8r
yIL7uc1RJzpI/V5svZa7ipJV99Gc2mnwTnlNlHZwFUXGlD6A93Q4KuvjYPFh
DZ3wuGQn2kgHpZ3tU12nNtBf7uEJiQYaGDFHQ4o4WDCRHGY39pYGwfr9J9aI
G+gR9bm4zhYaTBVIBDHzWbAQL49AvX9UYM5IW4WHsmBr7LTB2TIqaOqdvSj8
ggXrFGa8igcqrEtdevO2lwWTQ7pnOtwpMCUvpaF/lRUzinnn5itFgYItB2va
JVixEJWEh30hFLAK1NNo32DFSL6ZGhwcFHhwC/b8LWHDilxW03RSyRDVtHKP
c5kNq7m/YTDqQgb+TIEGte3s2D2BR/JmrQswnRB84DeeHXO9RLtN+DQHPyd3
dRHd2bGLFxn+efJz8I6Ni9z7hh2zq+J6MTpMgJNuArhcVg7sbGnQ9ce4aVhg
Oj2qPsaBmW4jHyBucgx9d9PDhZMcWP4LK+yXzxRI06a3mOzhxE6V2/Zqho6D
Zl+BcGkEJyYnKntnIHQECHkyJbfec2Jcmrq7BTOGwfy0kQZlihMLYvDdkPrY
Bbr2acdUxXHY2kTSIM+Ndli6P9RVUMeJJeurfEJ/WyB9dsX4L5MT44gWZN3+
pAo0S8oWi2/gMD7dxjeyRT/go7iLngQPDrvA//K6cNoPWL4THNLpg8MeDO1Z
xot9RmqN+7Iyt3FhO4zGtkb7lqNiX5nvSlu4sJGn71qyihvQ2E7iyL1GHEb9
tk2ysKQdHb4pUTNzgQtr/jJRdqR0AGW7x7Rhf3GYFHtb7GnDYSS3p/7Koi8O
S/wpKnN2eBSdDhDq0knAYXYqpk8tH06haAEib0E4DusZl85RDZhBOZKvP29Z
5sSEuy+07d68V/xuHALXSBx2UBH53CtYQE4fxsdY3XGYfbSMze/NOnZZYSTB
n8GJ5fxoPV3zdRH9tjpMXv3Dian0KJo13lhC2U7ZWcGJnJjzxlv2u9Y01F9o
YuBUwYGtunUPx1rS0RPLKPwmSGH9zaPs3UeZKO4JnDl7lQMTeTojW2uzgqic
75RTA9mxqfj/8DyfVtCG+u4MLgt2TOJAtHXLpzUU77zVy+cMO3a1MlRSznED
ZT8VuNDjwYYtsy1PETEWzOz4KNHkDytm77zcxkdkwVhr37OhMFaM8wBb8ujm
Ps39dTUs6S4LdnUr7OyUZ8PYy7p/RT3dQB2CNrG8DWxYcGdz472362hMp6r4
Sj47Nu0hqIhfXEX/rfOUHcFxYPKJ3+v8Q5eRNL+Bdfp/HBjzwPv+flhGB/Yw
3J30ObE/49NaY38ZSJnT7JjnD06MTM95+vgdDe1vEVEwneTEdE88wx1WWELy
t83v6k7iMJPXPpx38igobZbH5Fw/DpOo8Qs3nNus719ZG8r5ubC7973sqv9b
QDbXDlmcieHCLvMtnzs8Q0C/zCd6Ate4sMDdmn4N/pPo7D5+L/3szf4Nrhoz
duNIc1CzK/wmN7aF30fuzNMRdNB89ZmcOzfm8yS8Tt20G+nFsW2dv8aNHWL4
eAu6NyNWsZ/u+z9wY/siRbyGrlchgQMyBXpD3FiB05pCdH0osJi1Nvy7xY3t
DHPaFvH0L9yLF4g+5seNebR8WrUPrwOjro6/OyK5sfizljr2qV1AdqHfGRDi
xrg/HxN5mDoMmVP3Cgd2cWOGvErvz4uNQB6bxuN+Hm6sWdDN7vqPSSjIkBC0
8ufCtO6E7JocnQVniRfKcopc2IqZRHdE2ByYT20MD9txYQa0Y+TVfBJ0Oxrj
Cjxx2Fds7L9RXQq0JSS7PVbAYX5JAy1HDKlgWWr08eMMJ/ZLLrT3hhkNWEwk
vbQvcGJ3e2TXG9MY4ByfcOf2cw5s7MgpEb89TLCafaCq7M+B8RUuGK8lLkOO
0qnOF2nsWNRSx9vMv6vA6vwkLZewuT8qUfDxwTXoENB+FBTHhrW/e/L4Yt86
uGj2wjVRNkzuCURKlbHgUX3W91/crNhvvMjTr2yseF7+tc83Y1iw0l8KNbNJ
rHjWYH+D7VkbiNXvS0iCDxv+5o/lMP+3a+jI+yxxHAs7fuutvpw8yiqy3lZd
uKWEDb+Sau5FebSCnLT1+al4dvydtEC3jxZMpOWc7qkhyYG//dlSVEmEgeiF
5/gjLnPg5eSp2z+70ZHhsveRQ0QOfKlpQftgLhUZmKu1rIdy4ndSJ4/qfKAg
CqNZPSWIEz+4YXsod9siklj47qS1E4e/rLCT707/AqoRZVm96IzDhyx0Ev6L
I6KPmULus1w4vOIrrduHqAS0HKLudFQdhy/3Fb7+SXSTS/ae3V8chsNLMHkf
+U+OIYsSaVueJzh8nzHx59KJUdR8ovLA+BscXiHOpglaBlFdXMv36ONc+McE
Ae4QrQ7E/+eCw5NBHL5FtrlMK6QFWUR03A5aw+FTxOqt24bKkUIA3rNSngtv
5lEskX83GW0rVNj+tweHv7KuXnR9IRS1Kog6Ge7A4YntR/BNTzOgXkPQ6Zc/
Dr8uteTW1/4P3Hs+RTdp4vAc4xHrX/ob4NOOb2/WmZz4aReOKaOLLfBOO3VU
QwqHJ7BIThaI9MKdePrxUWscvpD+KmjH6gCIJ3CRP5Vw4o2Hn34qMx4BwS02
hQPdnPhm/VMOiYXjoC+nbBP7gROvsjXY/47MJGjPKPm11XPgd628+7jjwwTg
rpnvLL3Ige+3PTmlIDMDfWSFbzmuHPhpj6OmKacJsGQ/+/zCAju+YP3Ep5/N
BNgSkKRSXciOf+Wuv8YpOgeXzKQrxmjseO2zt2PfR5NA+Mr4l7xv7HijGw4D
6VkkUFQ4JMuiyY7P6pge2TpHhvk9JkW1yux4uTzxvP75Rfi0fuunWBgbfi2A
xfhXySKEyuaouCez4mHmjPSY/SLgCgssQt6z4o2t386b8VCBn4f46Ls5K55D
US677AoVnDLyv/wcYMH3nE2sr8aoYHfC9aBzEwv+44Ui8hG+JRjuvK6ezM+K
Z3+i+Q42z51x6tJtfScW/ElquBpOgQY/glvvrhmw4AsEvOaUNekgVHec5C3K
gv/a6kTQ/48OJxOcrr3NWoe3Uq2BMr00OJFs4vuQtAqK/Xt7N7JpkFukZKin
twZNZi8dDQbpIChEFdL3X4UXr/gkv6TQgWV2L7dU/Qrkvfkq1m1Ph1M4ZFa9
sQIsaqs+qboM2PnfPZ8Dj1fBr1E7gDHCANzk0tUqkRUoE2brdf/KgLYshlGE
6gqcv/OCpPKUCXF/JDqW0pZhTiY5Yk2BCVsszjSaiW1+rz0m/dduU193//DS
jaID7xP9eLkbDBh8ck5XSIkBl5KUtM8pM8Hvcu0FKSs6vCDKKpRlMmA76+j2
+nEatKjsqntlxgAN2/COyat0EM51DdTajD+Mzpz/VkWHGM/3mta3mBCzuqLZ
H0yDS2cIO2M29erDK0m43kEasOdmKjfnMkGHperh5Zs0GDwwPvv7EBNI73+Y
C/RRwWjJ/4euDQMEs9wq+19TwOSAMN7mIgN6/xT0V2lQISyFtzeNygCFV7ol
HJt2laufje5dYkBVzdvbW49TQBm39ZPNOB3UzvnY1LdQABanTaxiN/NN2uYi
Z0qF0G2Ys/pPBsR8t352SpsC1oG/918+xoDi4Kp2mxwKTHJcreir2uSRVLuO
7dcpoNbYOc12ggEfDzvq2RDI8Ohf7IWWTf3bptoadTKTBKKF/2VyH6KDy2H3
7sAHZDhvNtCd1UYHeYvP1ypnSOBo8lrXYzcd9P0WQsXjSaD2ISVMNIoGttvM
+HyNyMCjF9MSokSHijCNKwGbXNtFsH/UZkKHqibu09e2kSFB9bK52jca5F+z
r3niSYZz32S3Ju2nw6GT4VkC98gQThHXCU2ngeDOcXZXYRIcsTUbfzSzBGLe
nhPWiXOw/9DpM8WbfKh2E2f8WnBTt749+kdLkgaSFj/2pr+bBzYL4rU45yXo
pf0Lpw3MgcCOV2sWlVQQ9y/v59daAHu9jidBB5dA9mRp7exjEhy6TAri89uM
99qx5Zb7AkiKm/HgvlAhNvSVQiUbCdK8HzQc4VqC+X1IiQWRYL9wbOR/+Zvr
evTn6ecq8zCuFr9yn4UKaqc0xSgvCfBSVfmmizoFKgmYn4sfEfpbZLySFilA
v8Cf97KMCHvuiaR02VKAXKtSnLJZV6I8Do+GRCyCjS+1KnmDCFseVP/W+rsI
johxIIA2DxOGi/FbDSjgV/jE7Z70PKyWaH1kXl6E/6QHeT7xzkMx90mvbM9F
GBHLCH9zYAEqXvx3XP3RIuzrkSs8fXcOdsidz2KUkKFx9ZrSk5BZ8P0vUNKh
jARkctW/kzALbSYBCysmZPDLDlDf0UMAfvG2pTAhMuBbc+935c5CcklsIa8M
CSbqlvsUHhGAek9JJYe4APoxAafPvZ2Du/8yHW1TSPDx8qNAaugciNCd7Wu+
LQAPOuU1k02ES5VqbFOHF+CPnfyOnYfnAV3Df57ctEccfXC1TnMOorCH+wf0
5yGK567AkPUsiMUJ7UrRJYKRZLu9ucsMnGn1q1MIJ4LSRICxgAIB9p446Kg1
vDmPosM+VQqzMOEO4sylWUgatP0Yoz4LiTJDJJHRGXBnO91+4jARCj2q+m5J
EqBHvfwDJjcHyXrVjVTjWQggkP7W/CWATzpe8B9hGv5zjx8I5ZgDb6f+xfch
M5DlbDa3vGsOegWtCKRX03D+8UX1MM9ZWBAX+TxQPQn3t0zkmFpNQ4abQ/Lz
mQkoaJrYJ84zCwWZGfUvBiehzKR5/FTBDHDUim5YXZ+Amz6FCS/ZZqC2V3XE
7NMYZMlHmzU+noU7y+OZ146Pg3b7getflIlw67DF2sC7cbiZa8GaOzMLdQ/k
9nq9GYUBk3saIRgBsr0cnEr/joJ0lcPBIk0imHZmCC17jYJu9tUHJddm4QGt
rPjAlhGYeTPi02Q5BRRuUHptPQhnn7zk+sU6De/uMil6+4dh8vg6148/0/D8
dKfdV44hKNPxXUCvp+D42STHkYZeGIk8ybODfxoOyIT1iO/oBb+r9QXhwrOg
v6a+b+udfribdC/u2a8ZEMmSyrg11w3Kd25ynqubBtabW+4N3ugCFrmL9/9u
9vcftfVgmHSDp7GWyVGzGbD2UpMginbC5Tn354Z7J2HjZHCZFEcrzAlfgRXu
CZhus8FeyrfCnfUzZw3dJ2EbJ/u935xtkPPjxULa8wkYEkq/SvzYCMWZeMvV
ic15ajGxQaw18JCxoq8XPAm8O9vrh+MbIO2ZGzXLfArMwjWcIgPq4LzULXJC
8QQEfU3XePW9Avw98nYIW0xC9i6voNZr/6CQpFov0D4JCS+ukqN7K6CcGNfs
qzwODU9P8EQmFYOUff5VBdsRIIVs9GUI/gaN+lv0NedRKLNZIcqw/wWbKyX/
Uu+MAr8+8QOj4jewR7lyq28Mw34jTPAkLhROHtJ6aP9lBNhbd21cS4iF/NuH
J9S0xiCO+92Qes932FOcUJLEOwq1rV3bsnp0EOcDncAskxGwNVej7zj9Fg2M
68jcMB+FVmyEw8/sAXQ5pr7cyTUCotFC21mlItEH8dUY7811MxzwdlvR/I20
rRsvf0rvgRcFe6lyUtnoXsAT1bkXffDfTeWalaU0hJfyHTVq7IbKOJ7IP+V/
UDl/Qyr/7S4QzJ53ZDEpReemb6Txx/SCV9MsfzYjD8nu8yVkJPZC8Ifoyx0n
/iLJ6q+/lTW7oOL27ZjAtHJkKDB7keN4N9wfXS59BHh0QrJre01gN+Q81sOC
yvDIfMP/B4tQKygKXlnOaKhEbvqlPn4bNZDz+mnMD4Nq9Pq5bXH0hwYQS937
63dMOZpzNhvs4qyH375czsGh/5BipknQd9dK0JCXfpv0uAGNH+8W5t9VDU+v
1vVte12DcjKz9+1crAfHjwP3dmz/h2YEEloUW//BIww9F6utQ9W6ngkHisth
Jy9zG/flehRzqq5h7UoVnFEdmHx9ohplFzjOBNji4UOw9xbh9zXo88lTz0+I
voLOY5/DFOob0VFK8gUObVPEpiQ8/cauDoU7Glu27v4I4nIGJ/QDqtElruNB
X5xi0bTOTOwxriakr7idL2BLOtK/bFuCq2pCrT4hzPNPjJBeromNcXE1mkjb
fcrlTiCK5CRzNEnVolutB6MOPclGCZml143NG9GRSMm8L8LpaI/nluOYTw3y
3Oeh1CGYhl7p5anvPlmFDHu27JC2rkDNVeXDMtdr0WmDY1EqJg3oZcSXM4/5
61CAm68+UbQWAY/MNq+FCrQMK58oRXXokB135b3Wf4iec8HYRa8FnRWdzjAo
qUPMfiXPoeFG9Geo7y17eCUiXJd5z99fi8KO+n1I3F2K1r6YnP9p3YwG+7bU
Hb1Vic6SmhRjm1tQFNP72nfNCuRvsZ4U59+EyiTuPMRH/EW9ZupqpjVtqPxs
uq1ASBHiOPht1Qjfiz7bUlQbwvCo9XksWVK1D6l62lO/1OWjgPOaeO+iHsSM
+6i10pSJ4u8dbGSr7Ee2E5mKeslFyIJUc1L89QB6rMpJ9v6Yh3hiA417JXpR
W6CQhKVPNDpZkKrU2dCLzqvoMOzWYtBeg0v6H/EDyPXSAl/EwXRkJ8tsoln0
Iwn5jNLABQdY/nzcLsmhHzmdXPQ+dCQBEqzc4yfyRxBptAYffC4KKv5UPb3s
MYYkCwOC/SU/w32m94JmwChS3uZ7i6KUB6ZcmS5aPaMoSn9li+3xn7BktUes
9+I4EqzZr56+Mx2GFjQOinePIvNCN8Yrs78wF1DwxmNkBLGyTv/8JVUOt495
En9KjaG/jzR085pLoGun49x1zzFUEnam+XZlGdgL7i+IURtFKeZpXi2+NfDW
8mvu4IdxZGLb8zyVux5Gco2GdJ9PoRsZVns8h2tgL+fg9kcmU2inzQudwsEm
OB0mWSriPIl8weDBYFMLhFvbF2KLU8g5r/bxz0+NYFzK7LrmNYVkLfkKLvu1
wHTq42tqGRPo/pDm+sbrDugzGbliQ5lAri/WpC7qdIBb8eM5I5EppLuvhP76
QTtMXbpvcKFuAv13lnDWMqYbgk4q1X+7Ponemf80FBHsg6nAjD7h8BnU1cD8
+ehuL/SuWu1r/jmL6kQTLtSa9MEVg65lbfsZ9G4hUHHHoSE43vo6UYAxg1ZN
alS+qg/AgZMhWg3Zs+hwhte3w4YDUGEyf6381zQy6un5NpQ7DK8ZcubWw1PI
qt2a+3jqCJynfBTUWJ9G1RLxdokxw3BzL1VMIGoa2Y8iDfqJUQh9SHE2DplC
q4YqQo/LxkD3HWeHgfEserkrkHhQZxwsX34cCHhJRCcFwl3GBscg/0PVgDkQ
NlXMk/OvqyZgYHdqhi8/AaX0LuyYrp4A3fP78q89IaLmY6ZO1+fHQYmVo5aD
Ootsfm85eNFrEhyiVnykL80gJG/R0n1kGvZ6z8tL1s8gk+/PaUN2U6Bu27sS
ajOLJidkundMTgHLoaMCazHTiCPeJsa5dAZUb558yrCaRTM5D1tCiLOwv/C5
1SeJOZT14+rkxYuzgFwvxAbfmEMd3N1/zzsQYND5z+6MeQJq5vwZvhJEhNSi
w/hbp+bQSPfDlCA1Aky0zwbIfySi1cSq/x7yE8HS4kWDZMAs4mScodSxz8MS
tczI+vQsEur4sRa+Pge/Lf6W6ZkQ0E5x1g/lN+ZgOUEdGy+dQbvko8UzHRZA
xfPEI4ULs2jobdfl7rskMCSmHgpSnkNWIGdwR4sEMtIVEtOO8+iDIF9AiCkJ
Sv1O89qtE1HZl6982VpkkPIZf9oVPYee5bgW/YoiQfbV1G1vJ+fQQ9PYm3Kp
JBiOePxSqImA7kYd7TwaSoYP3wdfh4zNoqPZZ6J0yGSQOx6wo5ZJQOSbx/9E
XCDDmTPZHawHCUj0MKvT+olFeNhQ2uUdN4t8XFNV1TZ527No3POuwxzy18yT
Pi1Egbvfvb2P3llAcWaW/wU1LkIkZvfN7ek8mn5+7FNzDQUqLig9xOnNo21s
7zVyLlPgidvJwrcWC2ijNNzFnp8C51Vz3017zCG5pRjRxnYKRGSKQdghInJu
8LIUc6VC3dhAgA7HHEo/1pZkVkQBu2Xr6qOCc8j4aGN/9T0qTOR8O3asjYDO
iTlfjJBegkntFy777s+jAb+HDu0BS8CcZM8tdSKh1dHmU+I7lmBs8L56pCEJ
HfvBM7U2uQTCC9cT9g0voKlBA/aY9CU4fbl1yrWYhJovGCe4HVqC0dSOmiHK
AtJ7ENiEr12CqVyLOgPveXThZovHZ18ayBXkfGnauYDodyo/O/UtQaBx9pXZ
jgVkuNH1VvYUDRp4HVckL8wj/hktO0E2OjwmjrmnWWzGby3i2x5MhzSjakn9
AjJ6otxyUg5Hh/Nr3zpfEMmoq9aqLiWODs0ufxgsD8lI1u8yw/sDHbhi0JXf
douoA+e33jdLAxfB3Z4LrWR0J9Kg5/5tOvxlcV8LkCKjwY8JL1LFGRChryXK
ZUVGBR+LFfX86LA3ZSQpcYWMat9/fKKVRIc/xrbLlcfIyIR9/chVt02+tvRj
4XRYRClJNnnsW5igpTfetzBIQXPVzzJ9njBgt/WjHcmXqWhA4MMQ1yADGn1V
/40MUJByJ0mwu5sBzrubA24yqcgw/Aj1uwADrOFDyLo/Fe3/0iL/5wEDvH4d
5v9OpKBDPRp3OnYw4YV9sugWDSr6H3Xni/0=
          "]]}, {{}, {}}},
       AspectRatio->1,
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           TagBox[
            RotationBox[
            "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
             BoxRotation -> -1.5707963267948966`], HoldForm], 
           TraditionalForm], None}, {
          FormBox[
           TagBox[
           "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            HoldForm], TraditionalForm], None}},
       FrameStyle->Thickness[0.004],
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{44., 4.}, {41., 8.}},
       LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
       Method->{
        "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.528488, 0.470624, 0.701351], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.772079, 0.431554, 0.102387], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.363898, 0.618501, 0.782349], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[1, 0.75, 0], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.647624, 0.37816, 0.614037], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.571589, 0.586483, 0.], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.915, 0.3325, 0.2125], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[
            0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
            AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
         "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
         Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
         True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& )}},
       PlotRange->{{-4., 4.}, {-4., 4.}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Prolog->{
         Thickness[0.002], 
         LineBox[{{0, -4}, {0, 4}}], 
         LineBox[{{-4, 0}, {4, 0}}]},
       Ticks->{Automatic, Automatic}], {180, -555.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.0055000000000000005`], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJwVV3c81d8bT+Qr0aAooqFEg0olSkcaKE0lRFmFqFRWREOUmaIIyczee77t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          "]]}, {{}, {}}},
       AspectRatio->1,
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           TagBox[
            RotationBox[
            "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
             BoxRotation -> -1.5707963267948966`], HoldForm], 
           TraditionalForm], None}, {
          FormBox[
           TagBox[
           "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            HoldForm], TraditionalForm], None}},
       FrameStyle->Thickness[0.004],
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{44., 4.}, {41., 8.}},
       LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
       Method->{
        "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.528488, 0.470624, 0.701351], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.772079, 0.431554, 0.102387], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.363898, 0.618501, 0.782349], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[1, 0.75, 0], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.647624, 0.37816, 0.614037], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.571589, 0.586483, 0.], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.915, 0.3325, 0.2125], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[
            0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
            AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
         "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
         Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
         True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& )}},
       PlotRange->{{-4., 4.}, {-4., 4.}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Prolog->{
         Thickness[0.002], 
         LineBox[{{0, -4}, {0, 4}}], 
         LineBox[{{-4, 0}, {4, 0}}]},
       Ticks->{Automatic, Automatic}], {540, -555.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {
     InsetBox[
      GraphicsBox[{{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.004583333333333334], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJwVV3c81f8XtkdWRJQGRRoiSiX0vsU3FJEUmYWoSEKKZFTSIkpJkZFRooiM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          "]]}, {{}, {}}},
       AspectRatio->1,
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           TagBox[
            RotationBox[
            "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
             BoxRotation -> -1.5707963267948966`], HoldForm], 
           TraditionalForm], None}, {
          FormBox[
           TagBox[
           "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            HoldForm], TraditionalForm], None}},
       FrameStyle->Thickness[0.004],
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{44., 4.}, {41., 8.}},
       LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
       Method->{
        "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.528488, 0.470624, 0.701351], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.772079, 0.431554, 0.102387], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.363898, 0.618501, 0.782349], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[1, 0.75, 0], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.647624, 0.37816, 0.614037], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.571589, 0.586483, 0.], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.915, 0.3325, 0.2125], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[
            0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
            AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
         "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
         Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
         True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& )}},
       PlotRange->{{-4., 4.}, {-4., 4.}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Prolog->{
         Thickness[0.002], 
         LineBox[{{0, -4}, {0, 4}}], 
         LineBox[{{-4, 0}, {4, 0}}]},
       Ticks->{Automatic, Automatic}], {180, -925.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.004583333333333334], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJwtmHlcTP/3x6emWRKFipAUbUrZo837TQsRbZQWREgKUdFCUmihUGm3JG2S
lg8qqXNFi/Z9E+37vq8z87vfx+M3/8zj/bjve+ecc1/nvF/Pkbhww/ASN4VC
6adSKP/7jg012JYhxIsp///JTgj6ywnmxclSJ+Jetn+DTasDHt225sUvQzZM
D7RVw83atFNZy3ixcrBxzFzRH8jo+VQ4xM2Lt0rfjm3naofDHVd0vER48Zew
kitFf3th1yvn0FFdJhYU3PVSTHUQPvp3ewgoMvEBw6n0S+tHYUv3aTvlHgb+
xn/q01aVCfiQ9Hn0mAgDv9atf9qTMgW6YocaXP7QcZCCj9xV+jT8zNG6FG5P
xzY2PA0arFl44XSvzOolDdMXE9udKAtw+U5Km84iD57jLzFZMF2E9DiPFFYr
D/ac7pKItGBB+8zPo28iqJgyazyml8+BrS4xA895qbhsJ3H06lkKsUPukOZe
a24sobnmXdk5LiJXQVyp5SIX3uvKZl04w008F62XC7OiYPn4ElvTm9yEVZfV
bx1xCg7/+tBOejuVGFv/UM+/kIXeGXs7KlN5iORWtZDRv4soJ2rNp8bzPMQ6
vQsel0sXUHKXsflsBQ8hcodhtntmDj0y7Q96OUsj3qu+GOlzmUF3kh//Mpik
ETwRb0Uc+KdRaEClyLgbnbCWyj0zUjGB/i3eYCivYhC0eT+LExfH0AdZjuqi
DIOYDFARvKc7iuyuqBdP/aITp68u/6XeMYAaZqk8X7wZRNCWNxu09vYg/5T0
onZyLVLRMn78dCdaVzAq++gxg0jOeRM0zN+Ott+QqeVmMwi+J6JO8951SELy
wrXo3UziFKs0tv5TJXoWSTFqW2IQq/lT+A5s+4HMzh/auajGJPg8PYb+C38E
ffTAxb51TMJdi32++V4GOIX+519vxiAyOmC6NpwAqegUX92bDKJBcs+EXHE1
cJmuEoggr4/F3XJIuNcI7/jXvGfP0gmzMzg9UKAFcuqiA6R76UTcyClVu/ft
kMHTOCmoySAObNPd+a65G57eNPQT9qMTwq4q1D0zveD4zNfzmwedeFqydk6C
MgTdBkdEBA/QiZtb91+6eXcEPGu7FNzcaQQDXo14ho3A1t3LRbgjeYiYOsF+
RvoYPHgm9kGwmodQJcZabPUnwI+5eURyNw9hwZue9rh9AvZdtz5rXEElHuT3
2zr5TELhEYPXqQ1UQsrDxSYmZRp4LrF2KWRRCXtbw+DgXTPwiI8+KDjJTZTN
lVlE281CRb2r39lGbmJl9tVla3LmoEJzYVR2KzfhNSh+8WTWHCBFm47YbVxE
iOOL3N26c+C8Kn0qI4lC2NjKpd9Ymofj8pqZyS8oRHT4GD3eewFizO1ufynj
QMumhAr3FwuQJJY/ZXSOAyX2v8uF1BdBTFh6Ni+CAyq6Ix8f9y7Bj1dOct6u
bDCSKNoM8Utw7kq2uWAsC05+VLftL2MBhRV2vVScBdrW3H+t5NgQyye3MH12
EbbZFPAKvWeBvTu/zYFr8/Djtk6p9D4WpKVJLBNVngejDY9W7o5gw4+tvxg8
9+dAMXLU9oMTG/YG7ze/5DILvweL/UI12TAtut9F5OYsGBLLT5VzcWCvNwRu
zZiF0kWjOcMxDnRdtduVqTMDpXb5o0JeHHiof8CEi38G9hGN1QP7KUT/c4VK
puk0bHNrm88WohDIP/525ZNJaOGpvKURzIEjdjejb1eNw3unJd61xznwaPnd
B9tWTUBqfEfkuAyFCGhs23tDdhyunBduqanggKJoquhmtzHIO2u868wzDuik
DpSfzxsDy9ds7dVbKYTUzI8Ng/Rx2GGXaCJEzom0t2+VD54YhSS5ikOJkhTi
vG9Yk1rAKDysVTon94hCGD1i7GrlHQGZdIu87CMUQlJhbemDFwMglapilclN
IQq464oDA3rByPGTe2EDGa9Nj8zwnT5ILHu1VK1HIVQm+e+ciu2BzRm/uhSn
OKCNiSu3f3eDS8mqZTOfOdArwNE+RfSAS+fC2BYVCqE21tr1T7cX3ApyyrNO
UIgLfDa8WjVd0PplaV5hNYXQ9aYvW3DuBvv/rr3tsKYQ7xVbX56mdUGgkIiS
xm4yv9i9vLYpbfDc9GRtQR8HvG75blo3+Qfun5ktmgUO5GwMZh8S+wfHkgS5
+JQpRNiDRwa+/zVD7iNqnmM6B3aspCzXedwEwZHlSs/vcOCnf/nGitE/wDmr
6mwjQsYzzmgY3fwXtqwy83HcQiH0uvYIo7hGOGRwwt6GfL50nr2X48lmcC6N
Hjqwh0Isu/r7smFmA1Txn3g1uYpCePhvMmxWqYLgnTyzat84oFb9jSErXwQ3
XocaBHlz4P3Apa3j70oh+hhrxaeNFOJTim1685kCONo492HiJgd2TzyspJ75
Bdp/eJ8uU+GAp9ER4zOpv2GdjcX04WEO8PmG6Dw7UQpVHyanLvJQiJ7LjQuV
cz9hZU6dnuo1DpiYjRoc8SgE984bNIYAhdBgh2iPTeWBx56Ac2e4KISrrGkm
IyoBBg51WTqmcYBnuZhxk+5bNNtW9eQPeb8QithYc/UwCF0Yhag1FIK5gnZR
JjYOdV3fHcd9lgP6d8tnC/VTEK/kh5GvMhwIc5tB978FIoewYDHnOg4U2hpL
Hd98GZS8n/xuZ3Mg2cTQ7JPNJ+R3T3Pd1RNkn09Pi769Eo1U3IvbZsj4RRt+
rdfJSEVvpn5M3V1O1rNCbTZuWz7yUPoisKyNA7MZXMLc0RXIZXJ6A9uPA8Zl
tzr/rStF2+7dznKWoxBd74umSooq0buJk1ka90l9mooZKKyrRlg6vKT4KAfk
1h53H6oqRzuKaoMfT3IgcNJug79lKeLq3bPvtCCFaBJKa7i5sRqllic4X7jI
gWPfztEHoBI5fhrSLSb7NTr/COddajUqsX9+yGwXhXgzGcdTtrcJRedtUjcW
oxBrYnboz77+h+6q7VRuaiLzk6DeuKH9F0V8crG2MaQQByWXrtaubEP2Tf0V
xnkc6Dyg/fFBcxvq6/1q0PGCA1u+Bchs3NOKtszQG53XU4iOc8cibpn+Qy3v
hYcVdlIInkLJKo197UhpOnd9ZSAHokw/7fRNaEOrn3wOPbSdQpyxPrPFtLgd
NVZ+66JepBDNbvo3R+S60fNRFlwn+0vKZzL4x2wvuv5aSy6Q1PcLl7PNP716
Ufcdz8C9ThTiot5MhrhqP5qz5vdjk/q6+XFf+MyaAfQ1+3A1k/Qd4Za9gYrc
/Uj/DTTnKFKIDDMNd6mxPvTGbgtlluzHm49Zt313DKJJA7mfr8h8ntq4bChN
HkBcvLYbr5P7IzsKX7ZpDSGTgNgKBWcKYS0QFtBVM4oGar4Tl4+T8yDV2KTg
1Djq8HydOCFM5it5TSFu7zhK499gOW5MIaSx+tk3ZyaQn7d9QSrZP0IB9fFq
uRNoosawHV0h3+dxluf06Qk03W3CH9jNgYu7p4d+hk+ggCtlHt2RZDyZzeMn
2idR3R4z/00VbPivfLVgYsgkyjG/Wv3Ul9R/SW0ff9kUmrXSSD5J9svCzoy+
xOQZ5Huw5ON1aw70/BemtZ8xhz6p1UZEctggoLrChot7Dv0a5ufbvMQG8xS5
J3+C5lGPw/GdKUksuDA5u/w7zKP1xP0TGwNYoChkU7gydB5NaD/eI17Egnv5
Qfw1agsIXV/Vpt2+BHm62kF7wxZRrucuO/kjS8D5MV/39/AiksyjfLOqW4KS
D0O733Kx0LcdbiOUgSX4zl7PldPPRrHpVWaLiYvwn6h8Xt4iB6EQj2deJosw
ohz1mhAmfV/MZJS03gLoPzi+0LtAwcOHgu7ms+Yg+fTwq6c9FFxasdlV48cc
fLi+6nHhEgW3XNF89ctuDu46rRlN8OTCdxQu8OcmzoBKppb/MTo3zj5r/8f0
9gwsTxHUraFxY7emJnkzvxmgd7fnzTKpuMI7QVDedRo2e1yjBtdS8Y3WcNU1
FZPg8lvh9TVhHvxw6PprebtJ+MrI/Zl6gwe//Lb7c5PoOCTAnsfbuGh4IUxm
jyZ1DA4FjAw+r+bBM/kHFNULRyDYK9liZCUNNx8L3kVVGYKKop7ciPc0/GX1
jcztH3rhgL+kw623NLyNTyVrdWAv9FikRx0VpmOHsPNyzuQ5sppr8sLVHjo+
G2r2/e6Jdnh+Sq8uXJWBXaWx9H2+Fqg6WbBJW5aBV0Zrj/8uqIeOiemEcyUM
3Gv9tqTMogisTpzpWevLwDtD679m3CZg/n5fyqAVA9+J6vl4IDEe+reyy+/F
MLBTrITWZ/dvyGEk/qjxPwYW8JJ+TI5AlNZ/virtDAPr3Hha/966En2de/Yl
ax0Tlz2g6b170YQkPdRXeGkwcdeJS6/vH2tHmwSM7O/PM/C+RpfzzNZOlNZy
V8qAjEdB/uEc+2c/mkm4cO3MOAM/ibv7pa1xCIkoblt+ZCsDz0/aZaadH0Vr
zU6bSnIxsMm3LXOJv8aR19hI3sIIHV89d+/hqMMUMn/PaX94lI4vdA3v9mdP
IdttIZYKYnTcGT/gMaIyi6y+eznrydOx/sLD6DW+82if00gT9qJhdcfwD6Mb
F5HX8HM9RhEPbnFOMtv+cwmNmqD1PR958IBEy445Kw6iWZxTM/Kn4pvZxiVb
VlPwudQf27pbubFL9gOx6nYKnptOWlFlx43NAg63r+ThxhPhUucCE7iwqeDR
RX9vbvx+1QeWwQ0KjreOXjUvTcWlPzP+a7lLwX5lqSrsbTzYeVXgB5dxNpIV
e1E6R8bRm9yW+C1hCd25NFKarkDDJVo/QyslFlGpvukzSSs6/tduqf/4zjxi
yR/NU7pLx4duSlWlRcygnDudBPGXjp9ckaq9tWMa/SvM0fN/wcBn1W/0/FOa
RMNWByTs1zPx64KArBD1MXR967MRYoKBLzvF6HQcGUH7aT0x14GJ7w51LCmc
H0BNLdq3RqaZuIV6zGwwvAud1f72c26CiVPcChLo0m0odLaHFnaKFxufDha7
eL0ZVXVK0wNJftUOyM9MKyxEEXXnsxwwL+5cfFC8se8zMrzvmr/fiRez3n75
U38lARS+age7vODFtpduqO1aKIUrEiqtsjy8+PUpMNqS0ggRHdKsoL28+My4
oIVK/h/4kEEQb/l4sVNtC2QrdoG/ylbOax8m/hc9+9mupQ86y05vH1Bm4r1S
NeM9q4bg4bbTpsieiS9+2f4+LXkMQk/r75i6yMAp67Yu/OCfBDz+2+3RBgam
wXkhxfApoH4yi54h6Lj3dLjEInMWFo7fiK5aoGHqR80QrpB5yMb+2b8P0fAw
7ekpgb55iM16A7qraDivx45xxnAJNlV89FgS5MEqusf8kmzYMPNYz232GBW7
ag+bZKVwYL9JpEoOixtf/xjbWuhLITxDhPv42Fz4x6b24GvTXMR2u0+vhIS5
8DGZ8WcGe7kJ79ntGTccSH1ppnr+4KMSMiH1N072sBF4f8ghpqhEoG1/Xa/3
EorpMzv/S5OHYOVmMtYyl9DbOeXa7STvDok0/fsaM4/qujunsBGN8BYV2xDq
MIvCr1wXUn1DI1J3PdmyuHYGibBkE5630whJd9PP1zumUNRgw2EVgk7w5Luc
D4dx1PRoY0LEFJ0wUZF3y3cZQ29KjjVHb2cQw45pO/zThpBVHXxek8Yg3ill
1s7k9aKvLcxOt1oGIXd7UjxZvBuJ3UzwLd/PIFb6G/4OeNKBUn1OpdDKGcSA
dvbaI6+aUYtEQv5sJYOwTd192d2wFindtljnmMQgLufcXzciUYm0ndZMDTQz
iKjnoZqudzNQT3bMupcWTOLJ8eLTie+eQyQ3O1a4jLxun2gVYJALl3je/Bxe
ZBDuLgJ/36VUAu/m8osv/zII5ydx2Vl59bBb4KxBoRKDuOj+4J1lSAOsXr9f
qPULnVh2+WHPVo82cLa1XdfYQydcOhMdPud0wpeHe/2HrOnEWcvsAF77bjB1
jN/zWZ5OROxJ3eD/pRd07Txe5VyiEy1TwcdrR4ag0eBdqeQSjWDOrv9PQnwE
7o+cEnkYRSOO0xxeXvw3Btai6QejHWlEd/N8VoLBBOyMunipKp+H2HEZnx33
nYCrKxORZgGVcBBoUYmunoCL8vw+H39QiYTzmX0xNVOg4TzH4dWjEjf6TTy3
2k3Dm+hTHt353ERm1zP1rvJp0Ei6MbA1gZuI15oL0T0wC+l1MtNSBdxEePyV
oIKnc7DreZwU0c5FPAx1HPZhzoNn5CTz3S8uIrZKTman8wLE69n4F2hwEVYn
1i0tJi7ABT7zQ1uMKIRsetWbnL0LILc0fjyuhQ1ln399fz6zAOVCq4PrSN8s
p9wtkEldghNunN9L+Sw49EDywoXJRZD1OpuluoIFUX5Vd5Lll8Dh2H4vNSkW
sHhtOiTiWGCtpu2gOLIEy8LyLHfmseCdol2xtP4inHtX0jBtzAaDZqacAFqE
q61qaVdlOVCtm7jevHEeJjbzJg/GsMFj6lih6/AsCD+dyJ4lPaKezE+3lMwZ
+FgeZyk8zIbbT4de+PXOQLnbgdojqiSni64vEw6ZhuHxOymyDWxYFl1/1+DI
NCzkhlul8pN+NiejReDNNFzRV+6ulSX9mhb30VHhaXildjNGuZwDHX1yyV6z
k9Ct6/NQg+SlozLnihvHSR/w3/CLKHPS78UnWdjZTsB6m+237vBTiLEnkw8O
R4xBsZmug6IRB/LUjv/urBmFeP2MXET6/W1PllvJTI+CovuUyMENFGJgnZnu
8cxhqOgI7a1P5cD6HNMnbwvI9Wslpv8EOUfcvNfaEiOw6vbIsUY3kucKAmb1
nIehHmf8PLeOQkiwJgYquYeghBJe/9WK5Il5pefFa4aggUPxP3CV9K/qGcYi
/P3gdk9AbQXpt+NXyf41jOmGn1keZoeDOKCJqUMJrV3w6atAxTlN0l+vf3vx
3GwX2NqVykyR8fGv9DrrzNsJTdk3rtfGceCQ9rk1id6dULTn6u+mMZIn6+75
PfrUBd+T5taqkLyb26/zQOJWJ4hI6Oi3kdeze7MVOZc7wOl8qSL7AMkrx9+o
Cyd1QOKs3au/5Lo1SE44wqEV7q3e0POFzCfU8bfj75FGiHZKLpcleS7gkqWA
en8DxFnNJorJU4gdin72CXqNkJFadk+a5PUrPIu1lJxaeBHpvOcjyXePH1ob
05Tr4boew2DhIwd+GGlqJGU3woxITKO0GoVo3OD4auRpPegyH19LIfP/tWtJ
ejqzFnDi7Aw3yW+MsPSJxbQ6CLJ4KihN8lVWm5H4iaUKyBbs811DpRBG7q5W
/Ed/wmeZ+LyTWhzYVWKwT1XvB6R7/aT2ryT1cQu9fv4rD84Gzqju+8GBDfun
5go1MkBIV+WYIaln138KM20bcoGa3JzNcOZAsUJt0C2NX/Ail6vSneSxuO6H
HYEPCFgtOCj724wDGqPvN4UfzoKpXw67x2s4MJPYbhFblQt7kxU3bl3iQIyP
w6Pn1Gg49HjaZDc3yceDRySPfk5FH6KuqYTrcMCplL7lzfsvKJbtejicj0Kc
SudbsfAyDemumXmuQXDALvvt6LXjBFJd1tbgvoUDzx6ctJIJy0JJ+6+Npzpw
oFLkvrhZyCe0r4Tr+2+S7+R3plXqc31FYe8q0QYyvnVJ24oPdeeibVcPBRUW
cABErP7lK2WiYqaeRS2NQlApYhunVQpRHI/IrwsbSX1KCIZfnq9Cer31fE8f
cUC+vVSgIKgGNW/9815FgkLMHMtEf5yqkXb87hNJpP55+6t/7fKuR5e4vfJr
DDiA9n6xyG6sRc3WHe7qMRxQsDZbWeZYjUReSW7xIfU9qdyjqyBVi/B77i9q
JG91eb5wt/xcj3J9djc5DXCgQTZiR+1MLVp3NcJfVIrM55DzuqWUZjSzVi+d
Q/JckNL9+ndhbaiUI3wxp5cDx2U4Nj3B7ShtVGs48SiFWLXplmTKpna0OnBK
5hD5vs4M3zuoZ9GJlPIsxCzDOBD8IDpaPrgDVWu6ME8MceDyPlb+mZft6Nep
GIfLuhSinWpftT6sA1GEB+wSvnJgr35WTSZ3F6r2NdWkrKAQ3yLO3Nmn0Ynu
lznGpxyhEI+tp7MfnOxB7eNRjAVXCnHs2D9/t/R+NDi0/K4v2Z98qR4NGhUD
6JFJt99HOwoxrbsx4UzSAJpwKzr2jZw3XC1yc9vFh9EvxXj/THK+hF15Upt0
eQgZKZtp1ZN66b/5wWDixyDqelzukXSYnBdx41WlksOI2bXDu8qH1Lf3jvqh
kBGUccNXZN8iB+pFj+xo2DuC4FOeR4cGhcBbVGxulY8h0wXGTp4rFGLjt9Kj
Jf4TSAdbfRea5kAmV3Ghj+gkml0MkHfWohDsLdkyf80nkfz2QlokOU80XfcI
bomZQpfP9tWmMcj63WdKC56YQowT2lU7DDkg4Jz7dfDQFLJvlC21J/n8bI1O
1ms0jabMEt83HWFD4sq976OappH26RORCzVskGiu3dkrQPocqWrBzSRfZ8+P
vxWemkVCh5obZvdyYCFo0oP/v3nEa+JQJLSbDbuRyDZDmQXkK3zq8PcoNjwQ
7l1RPr6A9ulJ4ttbWNDndSY1hr6ENiW2RYYELoGN/gnebz8X0YUTh2znUpeg
SNTycPj6JZS+i/ep4ZkloK+UGuy7wkJshVNfTzSQ5+vnx11x0Sy0fl6aP/P8
InDt6LUvCmCjm85Gc0dJ/s1e3XDSVouCP0wPX5p/uwCGc1GLX3m48N6uGmWq
7zwMGXefadnChVXkz7ju158HsEmaZXVw4VzDtns7TWfhRsk99ioRbjznZ0SV
LZ8BC67v11RXcGMVTcGw0nsz0LS98sqgLTeObTg5E7h7Ghg7Y+6ar6fi40UK
Lz43TQKxikp/PsGNH5TcUJXmm4KM9688wsqpeFPFL/cxrUkYd0ePxEk+8hxb
5STpNA6Nm2qilIVpWNKM9V3y3hhcDa2/t1qKhhtLFH1DPwxD4lRv7vAiDduc
ZEY2UgYgONXnSzjQ8GP143xRT/vAjZq0MF5Dwzf7efvdzXug7VKmI/swHW/s
uZHWHNwOn3+qGZ0NoeNzNe0zd7Xb4CijKKrHhY5/uKv7p+7+C2ui4WgVyaMv
X3iK1/DUgZBy14D1Dwaewny2cnG/gSf3c2fZJwauuDjP+vTuByTVSRsV9TOw
4sdthQp7PiCqg5eMAx8TV+m468jeJ5DdjfvBZe8YWOJO3LNrJ4uRjPXxFY3Z
/+Ppf/Eaj+tQsAAl8+gkAw8toWYum1a0wL5ZP3iDgTM2jIyFZbUhtZs2b80r
Gdg8Y2ls7cpu5MkfOnJfgIlf7g/yMq7vR6dvuvuq5TDwUkGIlzvfMErtsGRf
OcHAv487S/yXOIZs469e+xHAwNMVhbtW0SfR8dICpdq3dOwTnJzwa+0UcngS
/e2ZBh1/6QiNFRmeRl1+3eJoHR27vsxP934xh2xNjPfxhdNw5LR1jJ7XPDrX
3P9UtpwHb3d8u41PcxG9Cnvg18xHwzV5+4rxaxayrvm1mGnKg487njpnrMtB
BXsxNdCVik/YbNzipEbBLZMli83LqDi4SeiR7BcuXBTp7yZ1kBv77rkmZc3N
jbmvSmS07ebCwidXXNWI48Zb+qYqbiRTcKrAkZWBMVTsdBhSuZo5aPFqm3zS
NfJ3Vll/2SDNQgnndf2EX/HgA/YhuQd+LaHEsHcWjbE0nP1ZcYv93ALiV1Uw
26RCxxTt5p6rDnNI3azD+aU3Has8TLaZd51BH4ztK1LNGdhIxZ8WeXganT1r
yRVMMPC1XUTAp7pxdO4r60Z+IwP3/8h/JndsDN3ZccnkixUT/wwodf+PGELt
zyxZvn1MXGactvu5ZC9y3CmWXviGiSP1XFZmpXUgX+6x5x4qvNhqgav4wtM2
tELgpOpJO1487NRlHvO3Fi0/1V4VeJRcq/npKssWoJZHCmp3SR7mfnunaW98
OvqdiW8fbOLFgXZzTs+5AZICafu0FHmxt4b4f+kRlWBuG1JXr8SL46xPa60a
boD+dwaleaq8ODQoyTDmSDvIuNDCt+Qx8Q7p9zNYohfyvfR2KjgwcerKd+Ln
+fsga/dal6fXmdhutNu4YmIYuiX11W7/ZmCu9QdFVt8Yh4iaWFqKJqlTqwhm
rMgkXNlhRdXSY2Dr0IpMxuQUnLpkEOpwgY75Mxss2cvngFDfc2Y/2YfFj7Oz
D0iTXOBV/n7+Kg1XX2aqHD2xCMx7d+R1E3hwnPtwUFouC3bIe8TcfU3Fsu5x
fcMJbHgiv2y47jEVC/zn8+0/8pyUXVti2uTKjffRJCwX13AR5q3T2Wp+XLjZ
21X0QCoX8e4Sr9xbKhdOfvvIKHo3N7FZ0c7miw0Fs6tFdIXuUQlzia3REZvY
KJMx9hKKqcQ1h2HNt/1LyKPr15WoSzzE25XHprMnF5BndVlLhhKNSNtyni15
dw49jJCnrPlAIxo9v4j/tp9FEjG77tiepBH6h2PlH3yYRu/VbnqvPkonwpSe
rffcMYnW7jj48GwAnZjQGpc1CR1H2518Bvd9ohOXrYZuqj8bQ1MHaLVWOxlE
ZEDw2E7KIJKuCmm7Vcgg+J+rflol3IfeRuyxUI9iED2iyXVBml1oVciDUAov
k8jt2V9R+/Mf2rfCecBekUm4cft8Ts9pQApvVWtEExjEuBzftWLvOhQk8eq3
5X8MIn2r04Yvq/OR7cRQFK2DQewtSkFdDz+iLrs6C55XDEJhp5/XwbJHMKas
j+1fMoiTWh+8mutygLI7iPmfIJPQoGz9VppYBZGnfHMWfRmET87e/6Il6sGY
2vLmjQ+DmDY5tozz6x8k7g28L+TEIGR7Z5M/l3VA2GO5824ddOJPypvu3IBO
4Nk2VfSXTSPGfA/czzjeA6/YvkpBR+hE2RVLpTvqAzB+JVDKIp9GMNo6PC+M
DoKY681H8RdoxFPHIN+XjsMgfPmk325bGiEeQDyopI/DIUr4p4YbNGI7XVVU
pmsc8sLXuY7F8RDbfK2WHVGZhIHCV0GHQnmI537BPVsap8BD7supr9w8BPur
qr3qjmn4+rTPbp8AlYh1P7RTs3sKrNOM2ns9uImzLMvFZbkzEF90b1OGAzfx
oNao8vqzWTgXsM0msYiLGFBn/nMomgU3zbcFDY+5iC/bDYwk/Odg35W195/E
cBF/+UMUFBwXYORuq+AyES6C6LG+u//SApw6rRLa8Z5CeA3tHZdJW4ROm6gy
5QsU4o5G974I3SV4WCwwaMjHAXMnxfzsjkWQe2v96wDJt+es2r4dCF6Ekum7
SwnVS3Bwf2n5zvUsKGpqv87LWIKXT9ftbBNlgZvJ5dWnpxYgPf+7HcFkwY3f
/W2TdQtQ8ldoitXFAqEg49ykVYugW9tvOTPIBkYB43PN43l4uctIxvcDG1ir
RjR4teahlsbk3ZbOgQcfivnGHOeAtd0iYNqF9O9izG0Sr2bg95HK7QYdbJiO
sDPpIuv67bHZyINCNmzMUQ57vHEahNgCOsGlHNh6JTXvP4EpIKp9PA+f48Dq
Ub2rpmcnYVWqzcO9ezjgHkRbGxwyCfb738RfIXmhJq5//t3PSehvzf3duY9C
iP/ueJSnNQEyaacietaSdfqefdv60gQkPxGwECD96dwLofWpd8YhYelp1H5y
/7v7i72fzo7CLxn9n7FVHIibghJ/6yHwV/s+XNvCgTs1YWP1FsPwW84vQoX0
h96RRue+qwyCl4WRWCk5V86Ku25Z7zgA+WXLuRk5HFizpH27y2wQzn1Xspg5
RiHsBKw1ymIH4ZTcs/hY0p/fXewV3kHvhw8vEzZ0kv43Y6XDRdrXfrAZ55g2
u1AIl3CTH2FNvaDxjKL/SJVC3Fe68jjCvgtS/fz+k/zHgX+r9Q/v7GmH+yeX
R4mT/tXmRnTTFF8nvCnykM9SJ3m75c8Ka0Y7+I1QNZRJftq83fFadnQbfPpk
bK4YSebjlkH0VrbDHxUb/aK9JO++MYo5urkD1O4bdX7ZQiF6TAvMj0a0Qnt2
ln4qiwMnJzoujkMblIz3UZ+Rft9ZS83zKesv6F4QWVAgeelPiM+qDZcaQKo3
YGAxmQPRty37RIhqKLKq6wkn66HavGeby746uKTKfaCN5JGgCnFnnetVkKD8
WEr/NgfSvmhxnrEqYbReMKb2FAdE5BrYRh9rwK+xi53ATyHSrql/HLCvhXTN
CunEOQ7w5BzBzpsqweHhwbhQMp/vqcJMfZ1qUj8L+v/jv2feG19rSpaDn0xg
lgjJd+81BlHV7h9QuHkF/0bSnwchr6Y4nArvbjkcOxHAgd+7ulqGxL+B77Gg
0zSSbxoZQyv4o+PhmTDX2eXHOKCtl9916Ol7uPBQi7pNgeSBLain3+8LlOr/
FHQd5sAn7jrPtcuzwN+L0+jRwIE+5ez+5RNvoS9n49P3FzgQkldyXfxEGjh1
8RyTI+Px+DuWc1EsBFbaxRRrkOuZaNf37vs/I9FWz1W34km9p9QQF87/RP6e
ckOPyPjgPOZVfJGDDHl2TaoIU4g8/nLnfan5iLpmSObTSQ7c2FfXfyG7AA0t
skLy9nPAQuwcZor9QLI7CWEg+VT+kkisTGEuKj7qGTZD8t7GPGHVVcGF6Eh5
YPqR8xx4uvNDwFPbn6h6wvl9GNlP4umKFi3LfqPoAY35IZJ3v2iuEHxDq0GD
C0JJByc5YNV2eE6suQH913XgihPJ00+szfvy2+rQVJDDR3ElCqHdyj/kbdmE
6nw4drVPOfBfuR3bSqwZbTh8cd9+R3IemJ99Ke/UgCrcvPUKBSkEbc272GNV
9chgoUIniFwTR57vH6P8QXZ3xSsP+pF6Ug5feLClCf3XkICukjxcVGOxki7a
gvRDh8+xDSlE51PFvYVW7eiMksZmPQUyfmvLV3r9nSjUOVReaCWF4D79Us5p
SycKoLys0zhHIax8Q78sE+xGH/uviMmWc+D0x1qdqz7diM+Ew1uQTfJ8uNja
drMu1Oc1dNFzF4U4sXbDlhfHu5C9q/UWvq0U4u9cAL3fpwfxRGjlXSf1XrJN
fUAsvRsFjz/L/LyfQuzYlha33qMX0RNkvd/eJfl9boghszCAjkfeeuZFzoNr
I0HmmS+GkWKs9uVweQphURZ8e8+yYWTYNfHN6jKFqJzUUbK3HkWRbpLfdvzg
gKTbt6pHDaNIla7w3iqDA6VLXBG8IyPI6en7OhOyHu4io1kWZqOIhlZM/e//
lriin/Pne8dQ7CZG4m1LDtzbafDs9YMx9Pem64WzpL6/K8cTEVnjKHCbukGS
GTnPlnUVqAdMIt3LO68zmCRvHzX3qayeQqrfCgfe1nHgkdFw5PLPU0iyWpim
08EBa653HvxKM2gmR8V6ayYbKAzRaF/9GWSQ+i44MJ0N+0r5jNMFZ9Cr4qSJ
W6s4cETsUv6y9zOo9HqN5TzJw/M/Ys52j8+i0RfUI1INLCiMNfmsETqLVprw
7LBzZMPSw60hagfmkdeu9QObfrDhGad5+qDkIrJWledvSGbB5SsbiqpVllBG
surSi4cs2Jm46uLH00toh93ni/tzlmDxr3K9qwgbpWeKpD95sgheZolWLfMs
1PLp/PWTtxbBY254uZ0AG2W9Uy8wPbsIV7TvnDLk5aAN9HCvzc3zcKpZ74H0
agq2vqfj9S97Hr6ev/w9jJeC97rM0q+uWADCTKNzMy8X3urUwBKxnof+4R8u
bX1cmP78Z9be3lm4afvRL0OdG3c/rL6alzELLENB7PGUG785oyR69ec0vLcy
A0U1Km4tCcms+ToFmLfGynQNFcdW2vc26U/B097qaUM9KjZ/J85OsZmEPTNT
gtzDVHx6djow8fA41GcOtQmu5sHlvZdsG86MA1cDYc/rwIO/YJen8ZVjsPWU
0i+VCzTsN1Fza0hoBGT8JtdqD9Dwr8pRZ87fAQhySDb7OUHDYueOhmas74d+
d9O02nA6bv1qnLK5oxMSbCV0D0fQsXynXtitZR0gOMzxvO1Gx2cqFbxNuNrg
0slnd1uL6fj9UWm/vzUN8EOMEN+vwsCurJsSl2sqIWz77UXvRjr2yJfPGywt
g5dnXsZpRzPwjbXw0679O7xckbOCsYaJ9TSEfj5rfIWWjt5qDFzGxLszPx6d
dv+O5KQ9HCNJHh4Z6FMI16pC41t+nNpnycSbCznJ3XmNKNhqz50Rkn9Fz3B0
/Y/9RRX6+7ROxjOwjTjbddWpDpSgJG7nV8TAx1QraXK9vehE+19PpjsD12zQ
i+Q+1I9WnN8mEKfGwGKBL8O2MIbRDqcowaj3DJyU8OR15fwYWnILUrQ4zsAn
m4RWmjdPoI07Apenf6PjV+F1ctcOTyHkd8U04wsdv9wezXfcfBY94/6Gorjo
WLkubchGZw4Zrbv+4oEJDRNj3HnuLfPogKCxzgpBGt64y3Capb6EGm+Nb5l+
w4PNDpoV6c+xUI3hmRUBnlS8b89KqcVeNrr8+326VyoVV1w6EfjkPQXvrO+p
YZC8u3z79FLIAy5c/ndtoRg/N049ohhWyuTGG47kqUboc2Fq5MUFdU0qrn7z
3MGljYLvi5TcZ/+i4l2dj7qe/GEjjbda04928uAXK/MnAt6w0ErKt8NGDBou
DTh8cE50CV3uE/Su6qPhXRbOhSlB86jb3qdYqYOGlZNejRJ8c4ie4Vi7t4qO
T2l+dZPvn0FdDrs/vr7AwH7Ndpdqd02hkDGbvVqvGfin/fFcl55xFHxONn6J
wcSbss7GrXo5hn4pfrTUKWHiM36bm9iJA6iuO4TGfM7E54Ol9jn+7EEeR2a3
Pxlh4ryhACNNcl7fqlu9XfwML+apz5S8WvAHDanOjRM7ebHsZDXP37gKVL20
1JVpzIvDmc+zqx1LkDnjkNTxSF6cutrdlHAIQy7mX/7pkve7bl2/6fKyPLAV
M4hQl+fFJXo36Vt0K6ExWFtCMJoX90iv2OYj3QQHe40erR9i4kVtfl6jHx1A
7754XimTiYlHTxNKy7qB9ftxZXksE3skN2x6ljwA1x2awgaVmdhh0yETazQG
utJNW087M3C83YlmZ9Vx+Kp7KTkyjIGnG/V2FOpNgpvlw3PPW+i4WqC0QWx8
GhYl7hRtladjt5cHOsXez4LXi+HjDoM07F8ry9O6ah4kbYcfHzhPw/uMhi4M
kj7f04jpHmPFgz9TtJZCDrFAauxttPUEFXefwDKSKziQO/naemk7FbdZoZ68
OAoxfEjp5ZsV3Pgy/UVM3wUuQp+ZVHbgJxeuHM4b/36di/hjnC70somCQwLr
1+cncBNHFq7cv/GQg1qs8bOvalRCUaWA9Zmco4tcu277vKMSlCSBIRNtFvIp
WJ+x6M1DZHk9Xb9ZcQFNTT3cLLKLRsy7CKn19cwhWc3OudV3aIQie7J1bNks
cin9xeujSCciEo6e9QmdQhtMjbNQEp0ITl63f1v1BCo7VLq/X5dOVGx4V9jc
NY44zb6CXV10wm8gTXaz0QhSbm1PWVBhEN4nD1UapA6gC3T6A3t1BtHV/iXq
6p0+1MpwoXu4MAjnAqMOk/FO9OIjdqFjJrF/d8On36x/SMxkMIS/iUEURKa9
6SltRBJaeTekJJmErR3+fiGtHFnLvYoo1GESglei/IZO56DRFK1lnt0MIufl
1l/aWl9R/3RmQLUxgxj4O/l87OhHUOFsz/yXxyDKuf+I3hEuhFX7XBOKrpC8
HUX5jzlVATTJ0b6YvQzCfMfoeh2XWri1p2nazY1BMNfmh16htMHlc0sQdIpB
+A4eoXh8bYc0seL5/BE6sd7aM+ikRzeoBb5zMR2kE603le92K/fDF+OaYSlb
OrE1S7RZ/uEAFO4sDItwoxEfHj1N3yo1CBaeH4UTrtKIr8ZGUw4Zo8DToiXi
Kkoj3l1NOD1YPAaz6/QVVr/kIVJWJ+3kMx+H3d5b5+rteYiH6flptOYJsCF8
lQbf8hAzWQE5V15MwbWlNpPfv6nEGyetV+7bp8ELJqLc46nEtVuFZqyGGfii
pynITepjucPu3uUOs8CJ41ddMuEmatffK4iWm4WTV+aZile4CIeloc3rqHOw
Q3nlp5sBXMSGldbaUYbzkFovtFy9nUL0buNOF3Gdh7yb1QOrSe7JkUu+31A+
Dw+2Gm/LdCM55mbs+QuOi0DJO+jw9hKFCPHUDGQWLQL946lLXus54D8ZkaPl
tQSSQUU2yfNseLimdNmZRyyw2TggJhbKAtvrz3cgGRZ4zchGPXy/CDJOJ+38
yP3r3zEXL1ouwPr135ogkQUhoimHVrovgPSb3T4uwmy4b/ji3zGJebgov1w9
vIoFT5a/+uzyfQ6ql/5TvijOhtOfzWdTuOchqiq3SMGHA8/76a3dZ+Yguf1X
lLQIB8Tv5ZtsUZ2FB3sPOKxu5MDot8LvJkKzMHXXxHh0HYUwPP5Z4+jdaTin
SplvDSX9Z+gF5Q+vJ2Fh+54+mUY2qMSKilUuTICCtUBLA+nnOpeo5RWtE2AO
3TVSraT/zhN4cyd3HIRjGCPe1zmQMhdVsitrHLrox3yGCkkeMnnz5rz0BBhU
p86H2FEI3Rt8Hm8MxkHbcUtfPun/al+wVdU/jsGfTkmXIWsKsezPz+Olj8fA
J2jsoDBZ5wf3ngm/qRsGHcXd1j2bKcShrQoHJS0GIEqrf2PeY9Jf6tmlJbf2
Q9ZHuXAtkmfPyBzOS/boh4U9ul+LRSjEwjL5SykfeuHZ5wmNpHQOLFQadtyS
7oPYW1anXy2jEOVfDzc8VegHlbvfNfc4UQiDs3f+6/XqhTox0c0/GBRCiOXn
F1TaA+duVgS6WlAIB5G44cvRPRBrWze+jfTP5o4fy8o9OmHHuEpjkih5/1u3
Q4HqbdDGSSmkeHAgeHv6ZXHxNmhlNB46dYBCNIgff6f+uhUmqsuMpMh6flUw
ObLtegt8f7ZqPNiFAwaZdR1TvP/g5WWda8/aOJBqc1N9hWwbHBxxE3yuS+bD
sEtafeQvZCx6UA+ncWAxLXn7d6MWiG/8ItpP8sDAwS23+a1aoPTWrp/BJA/7
OQ2XbDpZD6LUIEEHbgqhbx2ZKC9QCbGV8Xdun+BArWZ3SSFXJQi+4rd+JU76
/4mv1aKXKmDrLQ1TdiYH3ohmPqXq/IZg/gZm+h4OJN6yCM5QKIPyxFU976I4
UDHdp51G8nKueVmzsTSFWK7B9W1zdCk4HNhov/IcBzxKuJ6f+FEMuwI+hlQu
knx2ScFm/88SsB5TrXIheT7fQk9esgUgln/trgqSB/es3ssIzIyCGe1OTed9
ZF9RWj5elg6HbWH+tOWrSD6YdVBrF4qAP1IrRcxfkXp8ckdRqSgMyV72pOeu
4QBbcqVeIOEBDS18jnR3DnArrosNfBMPVUz1wN41FMLXO6Y66pAnJHJnp+oi
8pwauf86YcgLGT+/P6xD8sWDFUpv/v2zh/kyZQic4cABt5fq1VZf0elj23UO
knz80/XfIyKoELk8zbugY8yB2yqHCPfcIuS1JmDIcgOFMBGoTjqzoQjpH5ET
6CP5yGTPRZY+bwUyUfzMF6lI8qZQrdO54WJ0dzrYw/glB0ZEFJ0VdAoQi70u
WZDUt699qNFkYTGaSLomdpJ8vukKJ9N/PWXove0179/dHKhrPbpc6msJylL1
5Dwj+TRBxjq5urgGRZ4+d2OPIoXIfzLcsyTSjFbvPGx/M4Hcf+yka+C6P6h1
Obr4P/0FHhqsTS1oRg0R29+YkO/jxQknwc+v/iGJKZ8lKXsOLPt7nT/+Qwv6
4aUjY9PAgYupl7Q0Y5uRzi6ZYz/J+/uokbWDtL8oal71yB+Sh1/l5P7xGvqH
NtP7BGWXU4i43WblFwb+og3H1h9VV6MQ6ko/9tXzd6Cp1+HfO89TiPuSWd8e
nuhGxX3vN3qQ9bS/eDbrAKsbCf5QerHfhkKsuNbgY8noQZm2vgHDZD1lTzs4
iEr1IcW73mv1SL7dZXncmo56UYbjO53rZP9++92w6sqjHlTVVq42r08hrj50
royc7kUP+dVvyERyYHfbu0sO7D5UQDl8bXwthfgRrdA6+LMP8V9uSBE3oRDj
PNohqRuGkCn706rrdyhEgflcoYvLKCr3uPvUmKzv/bqxeCPxMVTT2vpW4AaF
KEkN/mt5aQxVjT77Y8hFIZQTM+uXPMeRaOLC5Jd7HFCQS/Z/JzqOtifHFiX+
44CAvYq11dIYKlBKYrqS83Zxi9vt4NFxVFB4uRe4OfDx3PmR8YsTSFmQ78ye
OA40if7+sjdyAskmLa+5LUYh/A2sKoZvTKETI0PGU8IUYnu1J+uT1AzavhjM
TNLhAMESaVrrOYP2yVHWqzRxQOhzpbqx2ix6v83pmnoAG0rMpPZsQHPoYYOp
gBB5nghrcNp+jsyivJGpjO8mbGjaaDj3QGYOWV/5HDu/j1xvMrqUfnkeOZk2
eW9uXgL2MXn/K1HzqGbnjoLr91iw4aqsZozdAmrkrVOWmmPBrYv5OeIXllDU
nTPZC8os8L5T56o6zUJPBERNnDWX4LDLSYN9u9noYFGbfNvJJaBtNepcCuKg
bOoRX+7gBZDopP/XvZKC5coOnhjavACGw/4529gcRJ/4ot+1agE+KZ2/OalP
wehanO2RzfPwrfSPqzydC7+0jH/8sGEWji1q5d0epGDxb3QZOpoDCYWfy+W+
cmG9qD8WqxdmYf7kvo1m8dw4VpytymM/A2YZJtl8u6m4z6hUf9R/Gix/uJ7u
0qLixyFNpiG2U6BZzx80K0f62sgEZfvICVCqufrq80oeLFCXKXhh+QQEfN5w
V1qCByfLRm6zNxyHbKs2qf8ieHDxXtz+IngEHiZTovrW0fDMA76JO5uG4U/V
fwoPZniwiL/R2ifXhkCzOl5WaJSGxwadbAdU+uEs/c7E7Wd07GJqtsP3YDdY
O2aWE5/o2Dxn8SDnbSfcCEm0neyk47/HLNo9/FpAp6R1csScgcVFh0srNjXA
BG1EJZuHgY0tfKW/KtWAYDjHNUWegaOtQw9O5xWBq995zaTnDJx+a19Knvpb
sFUrW9FiwcCNdqeDNYQewRrN1nh5klfzTQ89TLiYifj+McfqSY64+W2XfoRi
BdpK9xksV2Jim2vaBw6n16Mg3ZFVNwcZODFa+Okvzb9oMfy6TKghExc8ZmX3
K3ehuwExodo5DCxzlifC0qwH1RcNjkbYMnCWxturKlH9SHF17cxNewZW+8y9
FFI8gvi9A4Ve6DKwFSV/4EL7GFph4rxT2IeO2xsY3rlbJ1BSe6S4OZ2BPRXy
JJXjp9Camwdl5DLoOL6iLjL06wxas1fKMpqfjrX2GDknzc+iyiO5JzziafjR
a8mZyKUFpDRsaGx6joYXlCt5HkguIcdZfz4hAx483aBX0GLNQsX8UjHio1Qc
itupu+9ykM6z5HUurlQcbvtKLbmVgt2DD0qJ2HLjm4ODJmn8XLh4WNM8ex03
rtG/urhiFzfuL3ET+vCBC6uwK/vqhKjYZ66WzzaMgnUCeWbOR1HxgsS6mkuH
OajhEP/x8+d58A4cnTVyl41CtGfOpRvQcEfuhoBG+0VUJRNjputGw4/HPQdl
m+fRbT/LYQEZOqYz7ry0NJ1DpafrNgou0nG5tvI+V8YMSgg3eH5hNQPXWB0I
4rKYRKf+3hOTiWFg1iED86qhCWTr8atKHTOxl9+d7Zskx5AjreuqoR0T61+s
GhzZOojiUkVrhkneNag4fKmxsBc5eyczP9jz4iVZYof7QgfyOTrfEcHPixdF
VvHmfmpGevdPX9qqxItNS/uPZQvUIt3o8bEbvrxYerNR8bPnv9D6asWUEk9e
fIm6wuKr8jv4ovNsrcEWXuy+kKr+kP0VziUzjn/z48Xz6uuHbVIroLFMrthn
Py+2TVtTOb7rDxDyUokLTUz8Noa9UfZVO2gJr1iru8TEEeeLd67t74I4w2s7
t79i4tC9a/SEVg9B7IRHQMAyJi6uOu33IHcEZFdX/LjTSebvxHt4p/c4jPs2
39JyZWCV7cofBLSm4BT3OfG4p3RsYvgk5K3YDLQyfxcl+9MxQ3lnQdf0DEgo
e1yyaKbh0dLo29vL5iHuOfu8FxcNa7xbYmc+WYRplTShH/d5cO7EN4nvZUuw
Zm3SmuLDPHiRaOYwSZ/z3fzqgMswN76fe8ui0JFCSEYdYFVd58bdby9u/rWW
i/A96rQ/OoULj8S8SfMW5SZyd8lIu72gYIWs7ReaZrgJ05iVKls+ctD9t1kl
8mXcRMtnl2HJl2yUXCgqLNdCJTxULwsisSX0J1NHV9yVh7DTy+M5YbWAFELD
D4sU8xBN7I61ibfn0dV7YnxyJ2lExUjGN82mGXTQ6a9j9Gk64Sm/Gmbo0+jL
SaPWi9p04nTKU6NfZyfR2rOHqyb/0onGDkvTJvKcIry71D+dZhATU+tHWl4M
I/7jv/MrFBiE6ojhRbdHQ0jq8sfcODEGEZPHv2ejfC/ytazJvPaBQcSPs+n+
jE4kmtG98XEIg7i7s293mFcbCi6fmMx7wyC0vx/YZKzxBz0WudrqrMokYtVS
b9x/XI4eLN5dnc5kEiMPOxSr9uWj+ATL7h98TELj0fZkR7FXaHei4o6te5nE
xQfvnd8czYa6ab0D1/sZRIcdNS7Y5xe8lN2497kQGR/f9+vBy8vh8seRzJFr
DOKPzImNsvcbgfXoU8p+Mt5VKsbBNNI3L/us8s0mn07cFzcTtL3YBsYehS2T
5XTCYrHjax9vN2z2KfMSWc4gLAS5ripX9gIXp/Rp+2E68X/K3wRF
          "]]}, {{}, {}}},
       AspectRatio->1,
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           TagBox[
            RotationBox[
            "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
             BoxRotation -> -1.5707963267948966`], HoldForm], 
           TraditionalForm], None}, {
          FormBox[
           TagBox[
           "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
            HoldForm], TraditionalForm], None}},
       FrameStyle->Thickness[0.004],
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{44., 4.}, {41., 8.}},
       LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
       Method->{
        "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.528488, 0.470624, 0.701351], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.772079, 0.431554, 0.102387], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.363898, 0.618501, 0.782349], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[1, 0.75, 0], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.647624, 0.37816, 0.614037], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.571589, 0.586483, 0.], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.915, 0.3325, 0.2125], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[
            0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
            AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
         "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
         Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
         True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& )}},
       PlotRange->{{-4., 4.}, {-4., 4.}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Prolog->{
         Thickness[0.002], 
         LineBox[{{0, -4}, {0, 4}}], 
         LineBox[{{-4, 0}, {4, 0}}]},
       Ticks->{Automatic, Automatic}], {540, -925.}, 
      ImageScaled[{0.5, 0.5}], {360, 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}}, {}},
  
  ImageSize->{
    UpTo[600], 
    UpTo[700]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.8804595992358627`*^9, {3.8804637587437067`*^9, 3.8804637831851377`*^9}, 
   3.8804640935909157`*^9, 3.880464243461755*^9, 3.880612993351815*^9, 
   3.8806131245918427`*^9, 3.880655540005777*^9, 3.880702761441443*^9, 
   3.880703477121902*^9, 3.8909820974912558`*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"0281d0e9-e7b9-4891-a638-4f336ff11366"]
}, Open  ]],

Cell["Combine the x-y plots in a single plot.  This is Fig.8.18a.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, 3.880462891878394*^9, {
   3.8804634457063847`*^9, 3.880463448195674*^9}, {3.8806141679440327`*^9, 
   3.8806142112342987`*^9}, {3.880614288681053*^9, 3.880614293899702*^9}, {
   3.8806144133161373`*^9, 3.880614424131011*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"64d9ee0c-d598-4afc-8a69-f09daf7bfdba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"xyA", ",", "xyB", ",", "xyC", ",", "xyD", ",", "xyE", ",", "xyF"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.880459613225431*^9, 3.88045962913421*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"f8f1ef90-a4c5-4ae8-ac40-2ea044fc7812"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwtWnc4lt8bf2QrhRJCRH2VVfZIziOUVCoN2XtmVlaI7L333nsTKjo2lYak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      "]]}, {{}, {}}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwtV3k4Vd/3vvdwZSxjKiQSmUpJ0UetjQzJlOaBQoOSpFlIRCiFCoUIkczz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      "]]}, {{}, {}}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwtl3c81e/7x81jNRDJiCSRkFLR4H4blZSSUZGQhhUq+WiQzBQaZIQS2cmo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      "]]}, {{}, {}}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVV3c81d8bT+Qr0aAooqFEg0olSkcaKE0lRFmFqFRWREOUmaIIyczee77t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      "]]}, {{}, {}}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVV3c81f8XtkdWRJQGRRoiSiX0vsU3FJEUmYWoSEKKZFTSIkpJkZFRooiM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      "]]}, {{}, {}}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwtmHlcTP/3x6emWRKFipAUbUrZo837TQsRbZQWREgKUdFCUmihUGm3JG2S
lg8qqXNFi/Z9E+37vq8z87vfx+M3/8zj/bjve+ecc1/nvF/Pkbhww/ASN4VC
6adSKP/7jg012JYhxIsp///JTgj6ywnmxclSJ+Jetn+DTasDHt225sUvQzZM
D7RVw83atFNZy3ixcrBxzFzRH8jo+VQ4xM2Lt0rfjm3naofDHVd0vER48Zew
kitFf3th1yvn0FFdJhYU3PVSTHUQPvp3ewgoMvEBw6n0S+tHYUv3aTvlHgb+
xn/q01aVCfiQ9Hn0mAgDv9atf9qTMgW6YocaXP7QcZCCj9xV+jT8zNG6FG5P
xzY2PA0arFl44XSvzOolDdMXE9udKAtw+U5Km84iD57jLzFZMF2E9DiPFFYr
D/ac7pKItGBB+8zPo28iqJgyazyml8+BrS4xA895qbhsJ3H06lkKsUPukOZe
a24sobnmXdk5LiJXQVyp5SIX3uvKZl04w008F62XC7OiYPn4ElvTm9yEVZfV
bx1xCg7/+tBOejuVGFv/UM+/kIXeGXs7KlN5iORWtZDRv4soJ2rNp8bzPMQ6
vQsel0sXUHKXsflsBQ8hcodhtntmDj0y7Q96OUsj3qu+GOlzmUF3kh//Mpik
ETwRb0Uc+KdRaEClyLgbnbCWyj0zUjGB/i3eYCivYhC0eT+LExfH0AdZjuqi
DIOYDFARvKc7iuyuqBdP/aITp68u/6XeMYAaZqk8X7wZRNCWNxu09vYg/5T0
onZyLVLRMn78dCdaVzAq++gxg0jOeRM0zN+Ott+QqeVmMwi+J6JO8951SELy
wrXo3UziFKs0tv5TJXoWSTFqW2IQq/lT+A5s+4HMzh/auajGJPg8PYb+C38E
ffTAxb51TMJdi32++V4GOIX+519vxiAyOmC6NpwAqegUX92bDKJBcs+EXHE1
cJmuEoggr4/F3XJIuNcI7/jXvGfP0gmzMzg9UKAFcuqiA6R76UTcyClVu/ft
kMHTOCmoySAObNPd+a65G57eNPQT9qMTwq4q1D0zveD4zNfzmwedeFqydk6C
MgTdBkdEBA/QiZtb91+6eXcEPGu7FNzcaQQDXo14ho3A1t3LRbgjeYiYOsF+
RvoYPHgm9kGwmodQJcZabPUnwI+5eURyNw9hwZue9rh9AvZdtz5rXEElHuT3
2zr5TELhEYPXqQ1UQsrDxSYmZRp4LrF2KWRRCXtbw+DgXTPwiI8+KDjJTZTN
lVlE281CRb2r39lGbmJl9tVla3LmoEJzYVR2KzfhNSh+8WTWHCBFm47YbVxE
iOOL3N26c+C8Kn0qI4lC2NjKpd9Ymofj8pqZyS8oRHT4GD3eewFizO1ufynj
QMumhAr3FwuQJJY/ZXSOAyX2v8uF1BdBTFh6Ni+CAyq6Ix8f9y7Bj1dOct6u
bDCSKNoM8Utw7kq2uWAsC05+VLftL2MBhRV2vVScBdrW3H+t5NgQyye3MH12
EbbZFPAKvWeBvTu/zYFr8/Djtk6p9D4WpKVJLBNVngejDY9W7o5gw4+tvxg8
9+dAMXLU9oMTG/YG7ze/5DILvweL/UI12TAtut9F5OYsGBLLT5VzcWCvNwRu
zZiF0kWjOcMxDnRdtduVqTMDpXb5o0JeHHiof8CEi38G9hGN1QP7KUT/c4VK
puk0bHNrm88WohDIP/525ZNJaOGpvKURzIEjdjejb1eNw3unJd61xznwaPnd
B9tWTUBqfEfkuAyFCGhs23tDdhyunBduqanggKJoquhmtzHIO2u868wzDuik
DpSfzxsDy9ds7dVbKYTUzI8Ng/Rx2GGXaCJEzom0t2+VD54YhSS5ikOJkhTi
vG9Yk1rAKDysVTon94hCGD1i7GrlHQGZdIu87CMUQlJhbemDFwMglapilclN
IQq464oDA3rByPGTe2EDGa9Nj8zwnT5ILHu1VK1HIVQm+e+ciu2BzRm/uhSn
OKCNiSu3f3eDS8mqZTOfOdArwNE+RfSAS+fC2BYVCqE21tr1T7cX3ApyyrNO
UIgLfDa8WjVd0PplaV5hNYXQ9aYvW3DuBvv/rr3tsKYQ7xVbX56mdUGgkIiS
xm4yv9i9vLYpbfDc9GRtQR8HvG75blo3+Qfun5ktmgUO5GwMZh8S+wfHkgS5
+JQpRNiDRwa+/zVD7iNqnmM6B3aspCzXedwEwZHlSs/vcOCnf/nGitE/wDmr
6mwjQsYzzmgY3fwXtqwy83HcQiH0uvYIo7hGOGRwwt6GfL50nr2X48lmcC6N
Hjqwh0Isu/r7smFmA1Txn3g1uYpCePhvMmxWqYLgnTyzat84oFb9jSErXwQ3
XocaBHlz4P3Apa3j70oh+hhrxaeNFOJTim1685kCONo492HiJgd2TzyspJ75
Bdp/eJ8uU+GAp9ER4zOpv2GdjcX04WEO8PmG6Dw7UQpVHyanLvJQiJ7LjQuV
cz9hZU6dnuo1DpiYjRoc8SgE984bNIYAhdBgh2iPTeWBx56Ac2e4KISrrGkm
IyoBBg51WTqmcYBnuZhxk+5bNNtW9eQPeb8QithYc/UwCF0Yhag1FIK5gnZR
JjYOdV3fHcd9lgP6d8tnC/VTEK/kh5GvMhwIc5tB978FIoewYDHnOg4U2hpL
Hd98GZS8n/xuZ3Mg2cTQ7JPNJ+R3T3Pd1RNkn09Pi769Eo1U3IvbZsj4RRt+
rdfJSEVvpn5M3V1O1rNCbTZuWz7yUPoisKyNA7MZXMLc0RXIZXJ6A9uPA8Zl
tzr/rStF2+7dznKWoxBd74umSooq0buJk1ka90l9mooZKKyrRlg6vKT4KAfk
1h53H6oqRzuKaoMfT3IgcNJug79lKeLq3bPvtCCFaBJKa7i5sRqllic4X7jI
gWPfztEHoBI5fhrSLSb7NTr/COddajUqsX9+yGwXhXgzGcdTtrcJRedtUjcW
oxBrYnboz77+h+6q7VRuaiLzk6DeuKH9F0V8crG2MaQQByWXrtaubEP2Tf0V
xnkc6Dyg/fFBcxvq6/1q0PGCA1u+Bchs3NOKtszQG53XU4iOc8cibpn+Qy3v
hYcVdlIInkLJKo197UhpOnd9ZSAHokw/7fRNaEOrn3wOPbSdQpyxPrPFtLgd
NVZ+66JepBDNbvo3R+S60fNRFlwn+0vKZzL4x2wvuv5aSy6Q1PcLl7PNP716
Ufcdz8C9ThTiot5MhrhqP5qz5vdjk/q6+XFf+MyaAfQ1+3A1k/Qd4Za9gYrc
/Uj/DTTnKFKIDDMNd6mxPvTGbgtlluzHm49Zt313DKJJA7mfr8h8ntq4bChN
HkBcvLYbr5P7IzsKX7ZpDSGTgNgKBWcKYS0QFtBVM4oGar4Tl4+T8yDV2KTg
1Djq8HydOCFM5it5TSFu7zhK499gOW5MIaSx+tk3ZyaQn7d9QSrZP0IB9fFq
uRNoosawHV0h3+dxluf06Qk03W3CH9jNgYu7p4d+hk+ggCtlHt2RZDyZzeMn
2idR3R4z/00VbPivfLVgYsgkyjG/Wv3Ul9R/SW0ff9kUmrXSSD5J9svCzoy+
xOQZ5Huw5ON1aw70/BemtZ8xhz6p1UZEctggoLrChot7Dv0a5ufbvMQG8xS5
J3+C5lGPw/GdKUksuDA5u/w7zKP1xP0TGwNYoChkU7gydB5NaD/eI17Egnv5
Qfw1agsIXV/Vpt2+BHm62kF7wxZRrucuO/kjS8D5MV/39/AiksyjfLOqW4KS
D0O733Kx0LcdbiOUgSX4zl7PldPPRrHpVWaLiYvwn6h8Xt4iB6EQj2deJosw
ohz1mhAmfV/MZJS03gLoPzi+0LtAwcOHgu7ms+Yg+fTwq6c9FFxasdlV48cc
fLi+6nHhEgW3XNF89ctuDu46rRlN8OTCdxQu8OcmzoBKppb/MTo3zj5r/8f0
9gwsTxHUraFxY7emJnkzvxmgd7fnzTKpuMI7QVDedRo2e1yjBtdS8Y3WcNU1
FZPg8lvh9TVhHvxw6PprebtJ+MrI/Zl6gwe//Lb7c5PoOCTAnsfbuGh4IUxm
jyZ1DA4FjAw+r+bBM/kHFNULRyDYK9liZCUNNx8L3kVVGYKKop7ciPc0/GX1
jcztH3rhgL+kw623NLyNTyVrdWAv9FikRx0VpmOHsPNyzuQ5sppr8sLVHjo+
G2r2/e6Jdnh+Sq8uXJWBXaWx9H2+Fqg6WbBJW5aBV0Zrj/8uqIeOiemEcyUM
3Gv9tqTMogisTpzpWevLwDtD679m3CZg/n5fyqAVA9+J6vl4IDEe+reyy+/F
MLBTrITWZ/dvyGEk/qjxPwYW8JJ+TI5AlNZ/virtDAPr3Hha/966En2de/Yl
ax0Tlz2g6b170YQkPdRXeGkwcdeJS6/vH2tHmwSM7O/PM/C+RpfzzNZOlNZy
V8qAjEdB/uEc+2c/mkm4cO3MOAM/ibv7pa1xCIkoblt+ZCsDz0/aZaadH0Vr
zU6bSnIxsMm3LXOJv8aR19hI3sIIHV89d+/hqMMUMn/PaX94lI4vdA3v9mdP
IdttIZYKYnTcGT/gMaIyi6y+eznrydOx/sLD6DW+82if00gT9qJhdcfwD6Mb
F5HX8HM9RhEPbnFOMtv+cwmNmqD1PR958IBEy445Kw6iWZxTM/Kn4pvZxiVb
VlPwudQf27pbubFL9gOx6nYKnptOWlFlx43NAg63r+ThxhPhUucCE7iwqeDR
RX9vbvx+1QeWwQ0KjreOXjUvTcWlPzP+a7lLwX5lqSrsbTzYeVXgB5dxNpIV
e1E6R8bRm9yW+C1hCd25NFKarkDDJVo/QyslFlGpvukzSSs6/tduqf/4zjxi
yR/NU7pLx4duSlWlRcygnDudBPGXjp9ckaq9tWMa/SvM0fN/wcBn1W/0/FOa
RMNWByTs1zPx64KArBD1MXR967MRYoKBLzvF6HQcGUH7aT0x14GJ7w51LCmc
H0BNLdq3RqaZuIV6zGwwvAud1f72c26CiVPcChLo0m0odLaHFnaKFxufDha7
eL0ZVXVK0wNJftUOyM9MKyxEEXXnsxwwL+5cfFC8se8zMrzvmr/fiRez3n75
U38lARS+age7vODFtpduqO1aKIUrEiqtsjy8+PUpMNqS0ggRHdKsoL28+My4
oIVK/h/4kEEQb/l4sVNtC2QrdoG/ylbOax8m/hc9+9mupQ86y05vH1Bm4r1S
NeM9q4bg4bbTpsieiS9+2f4+LXkMQk/r75i6yMAp67Yu/OCfBDz+2+3RBgam
wXkhxfApoH4yi54h6Lj3dLjEInMWFo7fiK5aoGHqR80QrpB5yMb+2b8P0fAw
7ekpgb55iM16A7qraDivx45xxnAJNlV89FgS5MEqusf8kmzYMPNYz232GBW7
ag+bZKVwYL9JpEoOixtf/xjbWuhLITxDhPv42Fz4x6b24GvTXMR2u0+vhIS5
8DGZ8WcGe7kJ79ntGTccSH1ppnr+4KMSMiH1N072sBF4f8ghpqhEoG1/Xa/3
EorpMzv/S5OHYOVmMtYyl9DbOeXa7STvDok0/fsaM4/qujunsBGN8BYV2xDq
MIvCr1wXUn1DI1J3PdmyuHYGibBkE5630whJd9PP1zumUNRgw2EVgk7w5Luc
D4dx1PRoY0LEFJ0wUZF3y3cZQ29KjjVHb2cQw45pO/zThpBVHXxek8Yg3ill
1s7k9aKvLcxOt1oGIXd7UjxZvBuJ3UzwLd/PIFb6G/4OeNKBUn1OpdDKGcSA
dvbaI6+aUYtEQv5sJYOwTd192d2wFindtljnmMQgLufcXzciUYm0ndZMDTQz
iKjnoZqudzNQT3bMupcWTOLJ8eLTie+eQyQ3O1a4jLxun2gVYJALl3je/Bxe
ZBDuLgJ/36VUAu/m8osv/zII5ydx2Vl59bBb4KxBoRKDuOj+4J1lSAOsXr9f
qPULnVh2+WHPVo82cLa1XdfYQydcOhMdPud0wpeHe/2HrOnEWcvsAF77bjB1
jN/zWZ5OROxJ3eD/pRd07Txe5VyiEy1TwcdrR4ag0eBdqeQSjWDOrv9PQnwE
7o+cEnkYRSOO0xxeXvw3Btai6QejHWlEd/N8VoLBBOyMunipKp+H2HEZnx33
nYCrKxORZgGVcBBoUYmunoCL8vw+H39QiYTzmX0xNVOg4TzH4dWjEjf6TTy3
2k3Dm+hTHt353ERm1zP1rvJp0Ei6MbA1gZuI15oL0T0wC+l1MtNSBdxEePyV
oIKnc7DreZwU0c5FPAx1HPZhzoNn5CTz3S8uIrZKTman8wLE69n4F2hwEVYn
1i0tJi7ABT7zQ1uMKIRsetWbnL0LILc0fjyuhQ1ln399fz6zAOVCq4PrSN8s
p9wtkEldghNunN9L+Sw49EDywoXJRZD1OpuluoIFUX5Vd5Lll8Dh2H4vNSkW
sHhtOiTiWGCtpu2gOLIEy8LyLHfmseCdol2xtP4inHtX0jBtzAaDZqacAFqE
q61qaVdlOVCtm7jevHEeJjbzJg/GsMFj6lih6/AsCD+dyJ4lPaKezE+3lMwZ
+FgeZyk8zIbbT4de+PXOQLnbgdojqiSni64vEw6ZhuHxOymyDWxYFl1/1+DI
NCzkhlul8pN+NiejReDNNFzRV+6ulSX9mhb30VHhaXildjNGuZwDHX1yyV6z
k9Ct6/NQg+SlozLnihvHSR/w3/CLKHPS78UnWdjZTsB6m+237vBTiLEnkw8O
R4xBsZmug6IRB/LUjv/urBmFeP2MXET6/W1PllvJTI+CovuUyMENFGJgnZnu
8cxhqOgI7a1P5cD6HNMnbwvI9Wslpv8EOUfcvNfaEiOw6vbIsUY3kucKAmb1
nIehHmf8PLeOQkiwJgYquYeghBJe/9WK5Il5pefFa4aggUPxP3CV9K/qGcYi
/P3gdk9AbQXpt+NXyf41jOmGn1keZoeDOKCJqUMJrV3w6atAxTlN0l+vf3vx
3GwX2NqVykyR8fGv9DrrzNsJTdk3rtfGceCQ9rk1id6dULTn6u+mMZIn6+75
PfrUBd+T5taqkLyb26/zQOJWJ4hI6Oi3kdeze7MVOZc7wOl8qSL7AMkrx9+o
Cyd1QOKs3au/5Lo1SE44wqEV7q3e0POFzCfU8bfj75FGiHZKLpcleS7gkqWA
en8DxFnNJorJU4gdin72CXqNkJFadk+a5PUrPIu1lJxaeBHpvOcjyXePH1ob
05Tr4boew2DhIwd+GGlqJGU3woxITKO0GoVo3OD4auRpPegyH19LIfP/tWtJ
ejqzFnDi7Aw3yW+MsPSJxbQ6CLJ4KihN8lVWm5H4iaUKyBbs811DpRBG7q5W
/Ed/wmeZ+LyTWhzYVWKwT1XvB6R7/aT2ryT1cQu9fv4rD84Gzqju+8GBDfun
5go1MkBIV+WYIaln138KM20bcoGa3JzNcOZAsUJt0C2NX/Ail6vSneSxuO6H
HYEPCFgtOCj724wDGqPvN4UfzoKpXw67x2s4MJPYbhFblQt7kxU3bl3iQIyP
w6Pn1Gg49HjaZDc3yceDRySPfk5FH6KuqYTrcMCplL7lzfsvKJbtejicj0Kc
SudbsfAyDemumXmuQXDALvvt6LXjBFJd1tbgvoUDzx6ctJIJy0JJ+6+Npzpw
oFLkvrhZyCe0r4Tr+2+S7+R3plXqc31FYe8q0QYyvnVJ24oPdeeibVcPBRUW
cABErP7lK2WiYqaeRS2NQlApYhunVQpRHI/IrwsbSX1KCIZfnq9Cer31fE8f
cUC+vVSgIKgGNW/9815FgkLMHMtEf5yqkXb87hNJpP55+6t/7fKuR5e4vfJr
DDiA9n6xyG6sRc3WHe7qMRxQsDZbWeZYjUReSW7xIfU9qdyjqyBVi/B77i9q
JG91eb5wt/xcj3J9djc5DXCgQTZiR+1MLVp3NcJfVIrM55DzuqWUZjSzVi+d
Q/JckNL9+ndhbaiUI3wxp5cDx2U4Nj3B7ShtVGs48SiFWLXplmTKpna0OnBK
5hD5vs4M3zuoZ9GJlPIsxCzDOBD8IDpaPrgDVWu6ME8MceDyPlb+mZft6Nep
GIfLuhSinWpftT6sA1GEB+wSvnJgr35WTSZ3F6r2NdWkrKAQ3yLO3Nmn0Ynu
lznGpxyhEI+tp7MfnOxB7eNRjAVXCnHs2D9/t/R+NDi0/K4v2Z98qR4NGhUD
6JFJt99HOwoxrbsx4UzSAJpwKzr2jZw3XC1yc9vFh9EvxXj/THK+hF15Upt0
eQgZKZtp1ZN66b/5wWDixyDqelzukXSYnBdx41WlksOI2bXDu8qH1Lf3jvqh
kBGUccNXZN8iB+pFj+xo2DuC4FOeR4cGhcBbVGxulY8h0wXGTp4rFGLjt9Kj
Jf4TSAdbfRea5kAmV3Ghj+gkml0MkHfWohDsLdkyf80nkfz2QlokOU80XfcI
bomZQpfP9tWmMcj63WdKC56YQowT2lU7DDkg4Jz7dfDQFLJvlC21J/n8bI1O
1ms0jabMEt83HWFD4sq976OappH26RORCzVskGiu3dkrQPocqWrBzSRfZ8+P
vxWemkVCh5obZvdyYCFo0oP/v3nEa+JQJLSbDbuRyDZDmQXkK3zq8PcoNjwQ
7l1RPr6A9ulJ4ttbWNDndSY1hr6ENiW2RYYELoGN/gnebz8X0YUTh2znUpeg
SNTycPj6JZS+i/ep4ZkloK+UGuy7wkJshVNfTzSQ5+vnx11x0Sy0fl6aP/P8
InDt6LUvCmCjm85Gc0dJ/s1e3XDSVouCP0wPX5p/uwCGc1GLX3m48N6uGmWq
7zwMGXefadnChVXkz7ju158HsEmaZXVw4VzDtns7TWfhRsk99ioRbjznZ0SV
LZ8BC67v11RXcGMVTcGw0nsz0LS98sqgLTeObTg5E7h7Ghg7Y+6ar6fi40UK
Lz43TQKxikp/PsGNH5TcUJXmm4KM9688wsqpeFPFL/cxrUkYd0ePxEk+8hxb
5STpNA6Nm2qilIVpWNKM9V3y3hhcDa2/t1qKhhtLFH1DPwxD4lRv7vAiDduc
ZEY2UgYgONXnSzjQ8GP143xRT/vAjZq0MF5Dwzf7efvdzXug7VKmI/swHW/s
uZHWHNwOn3+qGZ0NoeNzNe0zd7Xb4CijKKrHhY5/uKv7p+7+C2ui4WgVyaMv
X3iK1/DUgZBy14D1Dwaewny2cnG/gSf3c2fZJwauuDjP+vTuByTVSRsV9TOw
4sdthQp7PiCqg5eMAx8TV+m468jeJ5DdjfvBZe8YWOJO3LNrJ4uRjPXxFY3Z
/+Ppf/Eaj+tQsAAl8+gkAw8toWYum1a0wL5ZP3iDgTM2jIyFZbUhtZs2b80r
Gdg8Y2ls7cpu5MkfOnJfgIlf7g/yMq7vR6dvuvuq5TDwUkGIlzvfMErtsGRf
OcHAv487S/yXOIZs469e+xHAwNMVhbtW0SfR8dICpdq3dOwTnJzwa+0UcngS
/e2ZBh1/6QiNFRmeRl1+3eJoHR27vsxP934xh2xNjPfxhdNw5LR1jJ7XPDrX
3P9UtpwHb3d8u41PcxG9Cnvg18xHwzV5+4rxaxayrvm1mGnKg487njpnrMtB
BXsxNdCVik/YbNzipEbBLZMli83LqDi4SeiR7BcuXBTp7yZ1kBv77rkmZc3N
jbmvSmS07ebCwidXXNWI48Zb+qYqbiRTcKrAkZWBMVTsdBhSuZo5aPFqm3zS
NfJ3Vll/2SDNQgnndf2EX/HgA/YhuQd+LaHEsHcWjbE0nP1ZcYv93ALiV1Uw
26RCxxTt5p6rDnNI3azD+aU3Has8TLaZd51BH4ztK1LNGdhIxZ8WeXganT1r
yRVMMPC1XUTAp7pxdO4r60Z+IwP3/8h/JndsDN3ZccnkixUT/wwodf+PGELt
zyxZvn1MXGactvu5ZC9y3CmWXviGiSP1XFZmpXUgX+6x5x4qvNhqgav4wtM2
tELgpOpJO1487NRlHvO3Fi0/1V4VeJRcq/npKssWoJZHCmp3SR7mfnunaW98
OvqdiW8fbOLFgXZzTs+5AZICafu0FHmxt4b4f+kRlWBuG1JXr8SL46xPa60a
boD+dwaleaq8ODQoyTDmSDvIuNDCt+Qx8Q7p9zNYohfyvfR2KjgwcerKd+Ln
+fsga/dal6fXmdhutNu4YmIYuiX11W7/ZmCu9QdFVt8Yh4iaWFqKJqlTqwhm
rMgkXNlhRdXSY2Dr0IpMxuQUnLpkEOpwgY75Mxss2cvngFDfc2Y/2YfFj7Oz
D0iTXOBV/n7+Kg1XX2aqHD2xCMx7d+R1E3hwnPtwUFouC3bIe8TcfU3Fsu5x
fcMJbHgiv2y47jEVC/zn8+0/8pyUXVti2uTKjffRJCwX13AR5q3T2Wp+XLjZ
21X0QCoX8e4Sr9xbKhdOfvvIKHo3N7FZ0c7miw0Fs6tFdIXuUQlzia3REZvY
KJMx9hKKqcQ1h2HNt/1LyKPr15WoSzzE25XHprMnF5BndVlLhhKNSNtyni15
dw49jJCnrPlAIxo9v4j/tp9FEjG77tiepBH6h2PlH3yYRu/VbnqvPkonwpSe
rffcMYnW7jj48GwAnZjQGpc1CR1H2518Bvd9ohOXrYZuqj8bQ1MHaLVWOxlE
ZEDw2E7KIJKuCmm7Vcgg+J+rflol3IfeRuyxUI9iED2iyXVBml1oVciDUAov
k8jt2V9R+/Mf2rfCecBekUm4cft8Ts9pQApvVWtEExjEuBzftWLvOhQk8eq3
5X8MIn2r04Yvq/OR7cRQFK2DQewtSkFdDz+iLrs6C55XDEJhp5/XwbJHMKas
j+1fMoiTWh+8mutygLI7iPmfIJPQoGz9VppYBZGnfHMWfRmET87e/6Il6sGY
2vLmjQ+DmDY5tozz6x8k7g28L+TEIGR7Z5M/l3VA2GO5824ddOJPypvu3IBO
4Nk2VfSXTSPGfA/czzjeA6/YvkpBR+hE2RVLpTvqAzB+JVDKIp9GMNo6PC+M
DoKY681H8RdoxFPHIN+XjsMgfPmk325bGiEeQDyopI/DIUr4p4YbNGI7XVVU
pmsc8sLXuY7F8RDbfK2WHVGZhIHCV0GHQnmI537BPVsap8BD7supr9w8BPur
qr3qjmn4+rTPbp8AlYh1P7RTs3sKrNOM2ns9uImzLMvFZbkzEF90b1OGAzfx
oNao8vqzWTgXsM0msYiLGFBn/nMomgU3zbcFDY+5iC/bDYwk/Odg35W195/E
cBF/+UMUFBwXYORuq+AyES6C6LG+u//SApw6rRLa8Z5CeA3tHZdJW4ROm6gy
5QsU4o5G974I3SV4WCwwaMjHAXMnxfzsjkWQe2v96wDJt+es2r4dCF6Ekum7
SwnVS3Bwf2n5zvUsKGpqv87LWIKXT9ftbBNlgZvJ5dWnpxYgPf+7HcFkwY3f
/W2TdQtQ8ldoitXFAqEg49ykVYugW9tvOTPIBkYB43PN43l4uctIxvcDG1ir
RjR4teahlsbk3ZbOgQcfivnGHOeAtd0iYNqF9O9izG0Sr2bg95HK7QYdbJiO
sDPpIuv67bHZyINCNmzMUQ57vHEahNgCOsGlHNh6JTXvP4EpIKp9PA+f48Dq
Ub2rpmcnYVWqzcO9ezjgHkRbGxwyCfb738RfIXmhJq5//t3PSehvzf3duY9C
iP/ueJSnNQEyaacietaSdfqefdv60gQkPxGwECD96dwLofWpd8YhYelp1H5y
/7v7i72fzo7CLxn9n7FVHIibghJ/6yHwV/s+XNvCgTs1YWP1FsPwW84vQoX0
h96RRue+qwyCl4WRWCk5V86Ku25Z7zgA+WXLuRk5HFizpH27y2wQzn1Xspg5
RiHsBKw1ymIH4ZTcs/hY0p/fXewV3kHvhw8vEzZ0kv43Y6XDRdrXfrAZ55g2
u1AIl3CTH2FNvaDxjKL/SJVC3Fe68jjCvgtS/fz+k/zHgX+r9Q/v7GmH+yeX
R4mT/tXmRnTTFF8nvCnykM9SJ3m75c8Ka0Y7+I1QNZRJftq83fFadnQbfPpk
bK4YSebjlkH0VrbDHxUb/aK9JO++MYo5urkD1O4bdX7ZQiF6TAvMj0a0Qnt2
ln4qiwMnJzoujkMblIz3UZ+Rft9ZS83zKesv6F4QWVAgeelPiM+qDZcaQKo3
YGAxmQPRty37RIhqKLKq6wkn66HavGeby746uKTKfaCN5JGgCnFnnetVkKD8
WEr/NgfSvmhxnrEqYbReMKb2FAdE5BrYRh9rwK+xi53ATyHSrql/HLCvhXTN
CunEOQ7w5BzBzpsqweHhwbhQMp/vqcJMfZ1qUj8L+v/jv2feG19rSpaDn0xg
lgjJd+81BlHV7h9QuHkF/0bSnwchr6Y4nArvbjkcOxHAgd+7ulqGxL+B77Gg
0zSSbxoZQyv4o+PhmTDX2eXHOKCtl9916Ol7uPBQi7pNgeSBLain3+8LlOr/
FHQd5sAn7jrPtcuzwN+L0+jRwIE+5ez+5RNvoS9n49P3FzgQkldyXfxEGjh1
8RyTI+Px+DuWc1EsBFbaxRRrkOuZaNf37vs/I9FWz1W34km9p9QQF87/RP6e
ckOPyPjgPOZVfJGDDHl2TaoIU4g8/nLnfan5iLpmSObTSQ7c2FfXfyG7AA0t
skLy9nPAQuwcZor9QLI7CWEg+VT+kkisTGEuKj7qGTZD8t7GPGHVVcGF6Eh5
YPqR8xx4uvNDwFPbn6h6wvl9GNlP4umKFi3LfqPoAY35IZJ3v2iuEHxDq0GD
C0JJByc5YNV2eE6suQH913XgihPJ00+szfvy2+rQVJDDR3ElCqHdyj/kbdmE
6nw4drVPOfBfuR3bSqwZbTh8cd9+R3IemJ99Ke/UgCrcvPUKBSkEbc272GNV
9chgoUIniFwTR57vH6P8QXZ3xSsP+pF6Ug5feLClCf3XkICukjxcVGOxki7a
gvRDh8+xDSlE51PFvYVW7eiMksZmPQUyfmvLV3r9nSjUOVReaCWF4D79Us5p
SycKoLys0zhHIax8Q78sE+xGH/uviMmWc+D0x1qdqz7diM+Ew1uQTfJ8uNja
drMu1Oc1dNFzF4U4sXbDlhfHu5C9q/UWvq0U4u9cAL3fpwfxRGjlXSf1XrJN
fUAsvRsFjz/L/LyfQuzYlha33qMX0RNkvd/eJfl9boghszCAjkfeeuZFzoNr
I0HmmS+GkWKs9uVweQphURZ8e8+yYWTYNfHN6jKFqJzUUbK3HkWRbpLfdvzg
gKTbt6pHDaNIla7w3iqDA6VLXBG8IyPI6en7OhOyHu4io1kWZqOIhlZM/e//
lriin/Pne8dQ7CZG4m1LDtzbafDs9YMx9Pem64WzpL6/K8cTEVnjKHCbukGS
GTnPlnUVqAdMIt3LO68zmCRvHzX3qayeQqrfCgfe1nHgkdFw5PLPU0iyWpim
08EBa653HvxKM2gmR8V6ayYbKAzRaF/9GWSQ+i44MJ0N+0r5jNMFZ9Cr4qSJ
W6s4cETsUv6y9zOo9HqN5TzJw/M/Ys52j8+i0RfUI1INLCiMNfmsETqLVprw
7LBzZMPSw60hagfmkdeu9QObfrDhGad5+qDkIrJWledvSGbB5SsbiqpVllBG
surSi4cs2Jm46uLH00toh93ni/tzlmDxr3K9qwgbpWeKpD95sgheZolWLfMs
1PLp/PWTtxbBY254uZ0AG2W9Uy8wPbsIV7TvnDLk5aAN9HCvzc3zcKpZ74H0
agq2vqfj9S97Hr6ev/w9jJeC97rM0q+uWADCTKNzMy8X3urUwBKxnof+4R8u
bX1cmP78Z9be3lm4afvRL0OdG3c/rL6alzELLENB7PGUG785oyR69ec0vLcy
A0U1Km4tCcms+ToFmLfGynQNFcdW2vc26U/B097qaUM9KjZ/J85OsZmEPTNT
gtzDVHx6djow8fA41GcOtQmu5sHlvZdsG86MA1cDYc/rwIO/YJen8ZVjsPWU
0i+VCzTsN1Fza0hoBGT8JtdqD9Dwr8pRZ87fAQhySDb7OUHDYueOhmas74d+
d9O02nA6bv1qnLK5oxMSbCV0D0fQsXynXtitZR0gOMzxvO1Gx2cqFbxNuNrg
0slnd1uL6fj9UWm/vzUN8EOMEN+vwsCurJsSl2sqIWz77UXvRjr2yJfPGywt
g5dnXsZpRzPwjbXw0679O7xckbOCsYaJ9TSEfj5rfIWWjt5qDFzGxLszPx6d
dv+O5KQ9HCNJHh4Z6FMI16pC41t+nNpnycSbCznJ3XmNKNhqz50Rkn9Fz3B0
/Y/9RRX6+7ROxjOwjTjbddWpDpSgJG7nV8TAx1QraXK9vehE+19PpjsD12zQ
i+Q+1I9WnN8mEKfGwGKBL8O2MIbRDqcowaj3DJyU8OR15fwYWnILUrQ4zsAn
m4RWmjdPoI07Apenf6PjV+F1ctcOTyHkd8U04wsdv9wezXfcfBY94/6Gorjo
WLkubchGZw4Zrbv+4oEJDRNj3HnuLfPogKCxzgpBGt64y3Capb6EGm+Nb5l+
w4PNDpoV6c+xUI3hmRUBnlS8b89KqcVeNrr8+326VyoVV1w6EfjkPQXvrO+p
YZC8u3z79FLIAy5c/ndtoRg/N049ohhWyuTGG47kqUboc2Fq5MUFdU0qrn7z
3MGljYLvi5TcZ/+i4l2dj7qe/GEjjbda04928uAXK/MnAt6w0ErKt8NGDBou
DTh8cE50CV3uE/Su6qPhXRbOhSlB86jb3qdYqYOGlZNejRJ8c4ie4Vi7t4qO
T2l+dZPvn0FdDrs/vr7AwH7Ndpdqd02hkDGbvVqvGfin/fFcl55xFHxONn6J
wcSbss7GrXo5hn4pfrTUKWHiM36bm9iJA6iuO4TGfM7E54Ol9jn+7EEeR2a3
Pxlh4ryhACNNcl7fqlu9XfwML+apz5S8WvAHDanOjRM7ebHsZDXP37gKVL20
1JVpzIvDmc+zqx1LkDnjkNTxSF6cutrdlHAIQy7mX/7pkve7bl2/6fKyPLAV
M4hQl+fFJXo36Vt0K6ExWFtCMJoX90iv2OYj3QQHe40erR9i4kVtfl6jHx1A
7754XimTiYlHTxNKy7qB9ftxZXksE3skN2x6ljwA1x2awgaVmdhh0yETazQG
utJNW087M3C83YlmZ9Vx+Kp7KTkyjIGnG/V2FOpNgpvlw3PPW+i4WqC0QWx8
GhYl7hRtladjt5cHOsXez4LXi+HjDoM07F8ry9O6ah4kbYcfHzhPw/uMhi4M
kj7f04jpHmPFgz9TtJZCDrFAauxttPUEFXefwDKSKziQO/naemk7FbdZoZ68
OAoxfEjp5ZsV3Pgy/UVM3wUuQp+ZVHbgJxeuHM4b/36di/hjnC70somCQwLr
1+cncBNHFq7cv/GQg1qs8bOvalRCUaWA9Zmco4tcu277vKMSlCSBIRNtFvIp
WJ+x6M1DZHk9Xb9ZcQFNTT3cLLKLRsy7CKn19cwhWc3OudV3aIQie7J1bNks
cin9xeujSCciEo6e9QmdQhtMjbNQEp0ITl63f1v1BCo7VLq/X5dOVGx4V9jc
NY44zb6CXV10wm8gTXaz0QhSbm1PWVBhEN4nD1UapA6gC3T6A3t1BtHV/iXq
6p0+1MpwoXu4MAjnAqMOk/FO9OIjdqFjJrF/d8On36x/SMxkMIS/iUEURKa9
6SltRBJaeTekJJmErR3+fiGtHFnLvYoo1GESglei/IZO56DRFK1lnt0MIufl
1l/aWl9R/3RmQLUxgxj4O/l87OhHUOFsz/yXxyDKuf+I3hEuhFX7XBOKrpC8
HUX5jzlVATTJ0b6YvQzCfMfoeh2XWri1p2nazY1BMNfmh16htMHlc0sQdIpB
+A4eoXh8bYc0seL5/BE6sd7aM+ikRzeoBb5zMR2kE603le92K/fDF+OaYSlb
OrE1S7RZ/uEAFO4sDItwoxEfHj1N3yo1CBaeH4UTrtKIr8ZGUw4Zo8DToiXi
Kkoj3l1NOD1YPAaz6/QVVr/kIVJWJ+3kMx+H3d5b5+rteYiH6flptOYJsCF8
lQbf8hAzWQE5V15MwbWlNpPfv6nEGyetV+7bp8ELJqLc46nEtVuFZqyGGfii
pynITepjucPu3uUOs8CJ41ddMuEmatffK4iWm4WTV+aZile4CIeloc3rqHOw
Q3nlp5sBXMSGldbaUYbzkFovtFy9nUL0buNOF3Gdh7yb1QOrSe7JkUu+31A+
Dw+2Gm/LdCM55mbs+QuOi0DJO+jw9hKFCPHUDGQWLQL946lLXus54D8ZkaPl
tQSSQUU2yfNseLimdNmZRyyw2TggJhbKAtvrz3cgGRZ4zchGPXy/CDJOJ+38
yP3r3zEXL1ouwPr135ogkQUhoimHVrovgPSb3T4uwmy4b/ji3zGJebgov1w9
vIoFT5a/+uzyfQ6ql/5TvijOhtOfzWdTuOchqiq3SMGHA8/76a3dZ+Yguf1X
lLQIB8Tv5ZtsUZ2FB3sPOKxu5MDot8LvJkKzMHXXxHh0HYUwPP5Z4+jdaTin
SplvDSX9Z+gF5Q+vJ2Fh+54+mUY2qMSKilUuTICCtUBLA+nnOpeo5RWtE2AO
3TVSraT/zhN4cyd3HIRjGCPe1zmQMhdVsitrHLrox3yGCkkeMnnz5rz0BBhU
p86H2FEI3Rt8Hm8MxkHbcUtfPun/al+wVdU/jsGfTkmXIWsKsezPz+Olj8fA
J2jsoDBZ5wf3ngm/qRsGHcXd1j2bKcShrQoHJS0GIEqrf2PeY9Jf6tmlJbf2
Q9ZHuXAtkmfPyBzOS/boh4U9ul+LRSjEwjL5SykfeuHZ5wmNpHQOLFQadtyS
7oPYW1anXy2jEOVfDzc8VegHlbvfNfc4UQiDs3f+6/XqhTox0c0/GBRCiOXn
F1TaA+duVgS6WlAIB5G44cvRPRBrWze+jfTP5o4fy8o9OmHHuEpjkih5/1u3
Q4HqbdDGSSmkeHAgeHv6ZXHxNmhlNB46dYBCNIgff6f+uhUmqsuMpMh6flUw
ObLtegt8f7ZqPNiFAwaZdR1TvP/g5WWda8/aOJBqc1N9hWwbHBxxE3yuS+bD
sEtafeQvZCx6UA+ncWAxLXn7d6MWiG/8ItpP8sDAwS23+a1aoPTWrp/BJA/7
OQ2XbDpZD6LUIEEHbgqhbx2ZKC9QCbGV8Xdun+BArWZ3SSFXJQi+4rd+JU76
/4mv1aKXKmDrLQ1TdiYH3ohmPqXq/IZg/gZm+h4OJN6yCM5QKIPyxFU976I4
UDHdp51G8nKueVmzsTSFWK7B9W1zdCk4HNhov/IcBzxKuJ6f+FEMuwI+hlQu
knx2ScFm/88SsB5TrXIheT7fQk9esgUgln/trgqSB/es3ssIzIyCGe1OTed9
ZF9RWj5elg6HbWH+tOWrSD6YdVBrF4qAP1IrRcxfkXp8ckdRqSgMyV72pOeu
4QBbcqVeIOEBDS18jnR3DnArrosNfBMPVUz1wN41FMLXO6Y66pAnJHJnp+oi
8pwauf86YcgLGT+/P6xD8sWDFUpv/v2zh/kyZQic4cABt5fq1VZf0elj23UO
knz80/XfIyKoELk8zbugY8yB2yqHCPfcIuS1JmDIcgOFMBGoTjqzoQjpH5ET
6CP5yGTPRZY+bwUyUfzMF6lI8qZQrdO54WJ0dzrYw/glB0ZEFJ0VdAoQi70u
WZDUt699qNFkYTGaSLomdpJ8vukKJ9N/PWXove0179/dHKhrPbpc6msJylL1
5Dwj+TRBxjq5urgGRZ4+d2OPIoXIfzLcsyTSjFbvPGx/M4Hcf+yka+C6P6h1
Obr4P/0FHhqsTS1oRg0R29+YkO/jxQknwc+v/iGJKZ8lKXsOLPt7nT/+Qwv6
4aUjY9PAgYupl7Q0Y5uRzi6ZYz/J+/uokbWDtL8oal71yB+Sh1/l5P7xGvqH
NtP7BGWXU4i43WblFwb+og3H1h9VV6MQ6ko/9tXzd6Cp1+HfO89TiPuSWd8e
nuhGxX3vN3qQ9bS/eDbrAKsbCf5QerHfhkKsuNbgY8noQZm2vgHDZD1lTzs4
iEr1IcW73mv1SL7dZXncmo56UYbjO53rZP9++92w6sqjHlTVVq42r08hrj50
royc7kUP+dVvyERyYHfbu0sO7D5UQDl8bXwthfgRrdA6+LMP8V9uSBE3oRDj
PNohqRuGkCn706rrdyhEgflcoYvLKCr3uPvUmKzv/bqxeCPxMVTT2vpW4AaF
KEkN/mt5aQxVjT77Y8hFIZQTM+uXPMeRaOLC5Jd7HFCQS/Z/JzqOtifHFiX+
44CAvYq11dIYKlBKYrqS83Zxi9vt4NFxVFB4uRe4OfDx3PmR8YsTSFmQ78ye
OA40if7+sjdyAskmLa+5LUYh/A2sKoZvTKETI0PGU8IUYnu1J+uT1AzavhjM
TNLhAMESaVrrOYP2yVHWqzRxQOhzpbqx2ix6v83pmnoAG0rMpPZsQHPoYYOp
gBB5nghrcNp+jsyivJGpjO8mbGjaaDj3QGYOWV/5HDu/j1xvMrqUfnkeOZk2
eW9uXgL2MXn/K1HzqGbnjoLr91iw4aqsZozdAmrkrVOWmmPBrYv5OeIXllDU
nTPZC8os8L5T56o6zUJPBERNnDWX4LDLSYN9u9noYFGbfNvJJaBtNepcCuKg
bOoRX+7gBZDopP/XvZKC5coOnhjavACGw/4529gcRJ/4ot+1agE+KZ2/OalP
wehanO2RzfPwrfSPqzydC7+0jH/8sGEWji1q5d0epGDxb3QZOpoDCYWfy+W+
cmG9qD8WqxdmYf7kvo1m8dw4VpytymM/A2YZJtl8u6m4z6hUf9R/Gix/uJ7u
0qLixyFNpiG2U6BZzx80K0f62sgEZfvICVCqufrq80oeLFCXKXhh+QQEfN5w
V1qCByfLRm6zNxyHbKs2qf8ieHDxXtz+IngEHiZTovrW0fDMA76JO5uG4U/V
fwoPZniwiL/R2ifXhkCzOl5WaJSGxwadbAdU+uEs/c7E7Wd07GJqtsP3YDdY
O2aWE5/o2Dxn8SDnbSfcCEm0neyk47/HLNo9/FpAp6R1csScgcVFh0srNjXA
BG1EJZuHgY0tfKW/KtWAYDjHNUWegaOtQw9O5xWBq995zaTnDJx+a19Knvpb
sFUrW9FiwcCNdqeDNYQewRrN1nh5klfzTQ89TLiYifj+McfqSY64+W2XfoRi
BdpK9xksV2Jim2vaBw6n16Mg3ZFVNwcZODFa+Okvzb9oMfy6TKghExc8ZmX3
K3ehuwExodo5DCxzlifC0qwH1RcNjkbYMnCWxturKlH9SHF17cxNewZW+8y9
FFI8gvi9A4Ve6DKwFSV/4EL7GFph4rxT2IeO2xsY3rlbJ1BSe6S4OZ2BPRXy
JJXjp9Camwdl5DLoOL6iLjL06wxas1fKMpqfjrX2GDknzc+iyiO5JzziafjR
a8mZyKUFpDRsaGx6joYXlCt5HkguIcdZfz4hAx483aBX0GLNQsX8UjHio1Qc
itupu+9ykM6z5HUurlQcbvtKLbmVgt2DD0qJ2HLjm4ODJmn8XLh4WNM8ex03
rtG/urhiFzfuL3ET+vCBC6uwK/vqhKjYZ66WzzaMgnUCeWbOR1HxgsS6mkuH
OajhEP/x8+d58A4cnTVyl41CtGfOpRvQcEfuhoBG+0VUJRNjputGw4/HPQdl
m+fRbT/LYQEZOqYz7ry0NJ1DpafrNgou0nG5tvI+V8YMSgg3eH5hNQPXWB0I
4rKYRKf+3hOTiWFg1iED86qhCWTr8atKHTOxl9+d7Zskx5AjreuqoR0T61+s
GhzZOojiUkVrhkneNag4fKmxsBc5eyczP9jz4iVZYof7QgfyOTrfEcHPixdF
VvHmfmpGevdPX9qqxItNS/uPZQvUIt3o8bEbvrxYerNR8bPnv9D6asWUEk9e
fIm6wuKr8jv4ovNsrcEWXuy+kKr+kP0VziUzjn/z48Xz6uuHbVIroLFMrthn
Py+2TVtTOb7rDxDyUokLTUz8Noa9UfZVO2gJr1iru8TEEeeLd67t74I4w2s7
t79i4tC9a/SEVg9B7IRHQMAyJi6uOu33IHcEZFdX/LjTSebvxHt4p/c4jPs2
39JyZWCV7cofBLSm4BT3OfG4p3RsYvgk5K3YDLQyfxcl+9MxQ3lnQdf0DEgo
e1yyaKbh0dLo29vL5iHuOfu8FxcNa7xbYmc+WYRplTShH/d5cO7EN4nvZUuw
Zm3SmuLDPHiRaOYwSZ/z3fzqgMswN76fe8ui0JFCSEYdYFVd58bdby9u/rWW
i/A96rQ/OoULj8S8SfMW5SZyd8lIu72gYIWs7ReaZrgJ05iVKls+ctD9t1kl
8mXcRMtnl2HJl2yUXCgqLNdCJTxULwsisSX0J1NHV9yVh7DTy+M5YbWAFELD
D4sU8xBN7I61ibfn0dV7YnxyJ2lExUjGN82mGXTQ6a9j9Gk64Sm/Gmbo0+jL
SaPWi9p04nTKU6NfZyfR2rOHqyb/0onGDkvTJvKcIry71D+dZhATU+tHWl4M
I/7jv/MrFBiE6ojhRbdHQ0jq8sfcODEGEZPHv2ejfC/ytazJvPaBQcSPs+n+
jE4kmtG98XEIg7i7s293mFcbCi6fmMx7wyC0vx/YZKzxBz0WudrqrMokYtVS
b9x/XI4eLN5dnc5kEiMPOxSr9uWj+ATL7h98TELj0fZkR7FXaHei4o6te5nE
xQfvnd8czYa6ab0D1/sZRIcdNS7Y5xe8lN2497kQGR/f9+vBy8vh8seRzJFr
DOKPzImNsvcbgfXoU8p+Mt5VKsbBNNI3L/us8s0mn07cFzcTtL3YBsYehS2T
5XTCYrHjax9vN2z2KfMSWc4gLAS5ripX9gIXp/Rp+2E68X/K3wRF
      "]]}, {{}, {}}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-4., 4.}, {-4., 4.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Prolog->{
    Thickness[0.002], 
    LineBox[{{0, -4}, {0, 4}}], 
    LineBox[{{-4, 0}, {4, 0}}]},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.880459630279808*^9, 3.880463790192075*^9, 
  3.880464093746974*^9, 3.8804642435535727`*^9, 3.8806129935221*^9, 
  3.880613124744698*^9, 3.880655540094172*^9, 3.8807027615372066`*^9, 
  3.880703477210231*^9, 3.890982097585114*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"3a9b8542-76e5-4a90-ac42-4f0975eccadf"]
}, Open  ]],

Cell[TextData[{
 "Use Eq.(8.131) to define a function ",
 StyleBox["h1", "Input"],
 " that returns the value of the Hamiltonian for given values of ",
 StyleBox["x", "Input"],
 ", ",
 StyleBox["y", "Input"],
 " and ",
 StyleBox["\[Delta]b", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2f262899-3456-4149-bdcd-7dfa80cf45a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"h1", "[", 
   RowBox[{"x_", ",", "y_", ",", " ", "db_"}], "]"}], " ", ":=", " ", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "*", "db", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "^", "2"}], "+", 
      RowBox[{"y", "^", "2"}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "4"}], ")"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", "^", "2"}], "+", 
       RowBox[{"y", "^", "2"}]}], ")"}], "^", "2"}]}], "-", 
   RowBox[{"2", "*", "x"}]}]}]], "Input",
 CellLabel->"In[64]:=",ExpressionUUID->"3efb73b3-2ff4-4e42-b228-114ae78d863f"],

Cell[TextData[{
 "Each of the x-y trajectories derived from numerical integrations that were \
plotted above crosses the x-axis at two points, say ",
 StyleBox["x1",
  FontSlant->"Italic"],
 " and ",
 StyleBox["x2",
  FontSlant->"Italic"],
 ".  Because each is on the same trajectory they have the same value of the \
Hamiltonian, ",
 StyleBox["h1 ", "Input"],
 "and the same value of ",
 StyleBox["db",
  FontSlant->"Italic"],
 ".  Hence we can calculate the approximate value of ",
 StyleBox["db",
  FontSlant->"Italic"],
 " by solving the equation ",
 StyleBox["h1", "Input"],
 "(",
 StyleBox["x1",
  FontSlant->"Italic"],
 ",0,",
 StyleBox["db",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["h1", "Input"],
 "(",
 StyleBox["x2",
  FontSlant->"Italic"],
 ",0,",
 StyleBox["db",
  FontSlant->"Italic"],
 ").  This is equivalent to finding the quantity -(1/2)(",
 StyleBox["x1",
  FontSlant->"Italic"],
 "^2+",
 StyleBox["x2",
  FontSlant->"Italic"],
 "^2)+4/(",
 StyleBox["x1",
  FontSlant->"Italic"],
 "+",
 StyleBox["x2",
  FontSlant->"Italic"],
 ").  Hence we define a function ",
 StyleBox["delcal", "Input"],
 " to compute this quantity."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880615961301235*^9, 3.880616247668231*^9}, {
  3.880616299524261*^9, 3.88061640906964*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"21bb50c7-f66a-4911-9ec6-d493ff0dea62"],

Cell[BoxData[
 RowBox[{
  RowBox[{"delcal", "[", 
   RowBox[{"x1_", ",", " ", "x2_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}]}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x1", "^", "2"}], "+", 
      RowBox[{"x2", "^", "2"}]}], ")"}]}], "+", 
   RowBox[{"4", "/", 
    RowBox[{"(", 
     RowBox[{"x1", "+", "x2"}], ")"}]}]}]}]], "Input",
 CellLabel->"In[65]:=",ExpressionUUID->"e7e06708-ef39-4ff9-986f-1e02d40596c4"],

Cell[TextData[{
 "Input the estimates of the quantities ",
 StyleBox["x1",
  FontSlant->"Italic"],
 " and ",
 StyleBox["x2",
  FontSlant->"Italic"],
 " for each trajectory.  These are estimated from the plots."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880616422945323*^9, 3.880616453050856*^9}, {
  3.88061652827754*^9, 3.880616535881318*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"49997081-8126-4db0-9b3f-7fe2358c56e9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xvals", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2.07", ",", "2.2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.2", ",", "2.78"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.274", ",", "3.11"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.915"}], ",", 
      RowBox[{"-", "0.452"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.269"}], ",", "3.122"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.95"}], ",", "3.16"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.88062016252771*^9, 3.8806201761010923`*^9}, {
  3.880651932246889*^9, 3.880651939429124*^9}, {3.880703077484837*^9, 
  3.880703084951776*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"7c4647a4-ddeb-4e12-bef0-4f79abbb212e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.07`", ",", "2.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2`", ",", "2.78`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.274`", ",", "3.11`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.915`"}], ",", 
     RowBox[{"-", "0.452`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.269`"}], ",", "3.122`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.95`"}], ",", "3.16`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8804403155414753`*^9, 3.8804640938494587`*^9, 
  3.880464243643704*^9, 3.880612993635972*^9, 3.880613124835762*^9, 
  3.880620181857066*^9, 3.880651942149683*^9, 3.880655540166086*^9, 
  3.880702761576571*^9, 3.880703086275477*^9, 3.8807034772730017`*^9, 
  3.890982097677473*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"52ea1214-a218-40c5-b73e-68c17638ba09"]
}, Open  ]],

Cell[TextData[{
 "Calculate the corresponding values of ",
 StyleBox["db",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880616422945323*^9, 3.880616453050856*^9}, {
  3.88061652827754*^9, 3.880616561006365*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"16b846de-9318-4f69-a944-f8bf51dd9b4d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"delta", " ", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"delcal", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "&"}], ",", " ", "xvals"}], 
   "]"}]}]], "Input",
 CellLabel->"In[67]:=",ExpressionUUID->"98142479-dfce-4e18-b3d5-c70c76419ddd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "3.625681850117096`"}], ",", 
   RowBox[{"-", "3.5791748743718586`"}], ",", 
   RowBox[{"-", "3.691554903073285`"}], ",", 
   RowBox[{"-", "3.446880081565472`"}], ",", 
   RowBox[{"-", "3.5075895522257277`"}], ",", 
   RowBox[{"-", "3.588264876033059`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.880440329101466*^9, 3.880464093928637*^9, 
  3.8804642436620398`*^9, 3.880612993712631*^9, 3.880613124892048*^9, 
  3.88062018477668*^9, 3.880651946196438*^9, 3.880655540177697*^9, 
  3.880702761587829*^9, 3.880703089684471*^9, 3.880703477289764*^9, 
  3.890982097694124*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"f5d74534-5d7f-49d0-bf9b-32f70529358f"]
}, Open  ]],

Cell[TextData[{
 "Calculate the corresponding values (",
 StyleBox["ham",
  FontSlant->"Italic"],
 "1",
 " and ",
 StyleBox["ham",
  FontSlant->"Italic"],
 "2",
 ") of ",
 "the Hamiltonian at each pair of crossing points",
 ". Note that, as expected, ",
 StyleBox["ham",
  FontSlant->"Italic"],
 "1 and ",
 StyleBox["ham",
  FontSlant->"Italic"],
 "2 have the same values (see below)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880616422945323*^9, 3.880616453050856*^9}, {
  3.88061652827754*^9, 3.880616561006365*^9}, {3.8806169231783047`*^9, 
  3.8806169877835217`*^9}, {3.880617034468742*^9, 3.8806170731694307`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0877016b-36e7-4ff2-bf8c-1c0037247005"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"x1v", " ", ",", "x2v"}], "}"}], " ", "=", " ", 
  RowBox[{"Transpose", "[", "xvals", "]"}]}]], "Input",
 CellLabel->"In[68]:=",ExpressionUUID->"31846e68-2167-462b-b576-9dd41bf9baa5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.07`", ",", "1.2`", ",", "0.274`", ",", 
     RowBox[{"-", "0.915`"}], ",", 
     RowBox[{"-", "0.269`"}], ",", 
     RowBox[{"-", "1.95`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.2`", ",", "2.78`", ",", "3.11`", ",", 
     RowBox[{"-", "0.452`"}], ",", "3.122`", ",", "3.16`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.88044033987285*^9, 3.880464093950583*^9, 
  3.8804642437489023`*^9, 3.8806129937330503`*^9, 3.880613124910429*^9, 
  3.880620197157879*^9, 3.880651957600972*^9, 3.8806555402275143`*^9, 
  3.880702761665434*^9, 3.880703098822542*^9, 3.880703477327194*^9, 
  3.8909820977521057`*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"39f138d2-3220-4619-8d19-5a4129dfc8fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xyd1", " ", "=", " ", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"x1v", ",", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "6", "}"}]}], "]"}], ",", "delta"}], "}"}], 
   "]"}]}]], "Input",
 CellLabel->"In[69]:=",ExpressionUUID->"40672437-d360-4c9e-aff3-8e282089e169"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.07`", ",", "0", ",", 
     RowBox[{"-", "3.625681850117096`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2`", ",", "0", ",", 
     RowBox[{"-", "3.5791748743718586`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.274`", ",", "0", ",", 
     RowBox[{"-", "3.691554903073285`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.915`"}], ",", "0", ",", 
     RowBox[{"-", "3.446880081565472`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.269`"}], ",", "0", ",", 
     RowBox[{"-", "3.5075895522257277`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.95`"}], ",", "0", ",", 
     RowBox[{"-", "3.588264876033059`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.880440357136701*^9, 3.8804640940197277`*^9, 
  3.8804642438435183`*^9, 3.88061299379716*^9, 3.88061312496859*^9, 
  3.8806201972762117`*^9, 3.880651957705982*^9, 3.880655540240937*^9, 
  3.880702761676468*^9, 3.880703100489821*^9, 3.880703477345063*^9, 
  3.890982097766081*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"a4e53ff2-7ec3-4738-bccc-e6c26e3b886a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xyd2", " ", "=", " ", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"x2v", ",", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "6", "}"}]}], "]"}], ",", "delta"}], "}"}], 
   "]"}]}]], "Input",
 CellLabel->"In[70]:=",ExpressionUUID->"5a709a0f-551c-4c58-a842-e455ce87fd20"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.2`", ",", "0", ",", 
     RowBox[{"-", "3.625681850117096`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.78`", ",", "0", ",", 
     RowBox[{"-", "3.5791748743718586`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.11`", ",", "0", ",", 
     RowBox[{"-", "3.691554903073285`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.452`"}], ",", "0", ",", 
     RowBox[{"-", "3.446880081565472`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.122`", ",", "0", ",", 
     RowBox[{"-", "3.5075895522257277`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.16`", ",", "0", ",", 
     RowBox[{"-", "3.588264876033059`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.880440367893496*^9, 3.880464094037279*^9, 
  3.8804642438622837`*^9, 3.880612993818142*^9, 3.880613124992321*^9, 
  3.880620197341158*^9, 3.880651957777409*^9, 3.880655540291603*^9, 
  3.880702761754602*^9, 3.880703107822242*^9, 3.880703477384082*^9, 
  3.890982097824286*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"35866930-2721-4bca-af1f-7b48f7c1f63d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ham1", " ", "=", " ", 
  RowBox[{"Apply", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"#1", ",", "#2", ",", "#3"}], "]"}], "&"}], ",", " ", "xyd1", 
    ",", " ", "1"}], "]"}]}]], "Input",
 CellLabel->"In[71]:=",ExpressionUUID->"8dd16f4f-a8be-48f9-9d48-a5519bb5e487"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "7.317750077283372`"}], ",", 
   RowBox[{"-", "4.458605909547739`"}], ",", 
   RowBox[{"-", "0.685164486507565`"}], ",", "0.5623293370119238`", ",", 
   "0.4124026847859471`", ",", "0.692562966942146`"}], "}"}]], "Output",
 CellChangeTimes->{3.8804403798755207`*^9, 3.880464094107009*^9, 
  3.8804642439334717`*^9, 3.8806129938823147`*^9, 3.880613125035345*^9, 
  3.8806201973592*^9, 3.880651957793313*^9, 3.880655540302576*^9, 
  3.880702761768985*^9, 3.880703110600134*^9, 3.880703477400313*^9, 
  3.89098209783844*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"46024d1e-87d4-4f5f-9d5c-c940637e6442"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ham2", " ", "=", " ", 
  RowBox[{"Apply", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"#1", ",", "#2", ",", "#3"}], "]"}], "&"}], ",", " ", "xyd2", 
    ",", " ", "1"}], "]"}]}]], "Input",
 CellLabel->"In[72]:=",ExpressionUUID->"b4765884-4c9d-487d-b78c-3d5cfa7bfc9c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "7.317750077283372`"}], ",", 
   RowBox[{"-", "4.458605909547738`"}], ",", 
   RowBox[{"-", "0.6851644865075643`"}], ",", "0.562329337011924`", ",", 
   "0.41240268478594544`", ",", "0.6925629669421483`"}], "}"}]], "Output",
 CellChangeTimes->{3.880440391668817*^9, 3.8804640941230917`*^9, 
  3.8804642439537888`*^9, 3.880612993901709*^9, 3.880613125054738*^9, 
  3.880620197408269*^9, 3.88065195784184*^9, 3.8806555403396387`*^9, 
  3.880702761831233*^9, 3.8807031127294817`*^9, 3.88070347743775*^9, 
  3.890982097895211*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"07e5c71e-4ce6-451b-ba2c-a1f8347bf510"]
}, Open  ]],

Cell[TextData[{
 "Display as a Table the calculated values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    TemplateBox[<|"boxes" -> FormBox[
        OverscriptBox["\[Delta]", "_"], TraditionalForm], "errors" -> {}, 
      "input" -> "\\bar\\delta", "state" -> "Boxes"|>,
     "TeXAssistantTemplate"], " ", "and", " ", 
    RowBox[{
     TemplateBox[<|"boxes" -> FormBox[
         SubscriptBox[
          StyleBox["H", "TI"], 
          StyleBox["1", "TI"]], TraditionalForm], "errors" -> {}, "input" -> 
       "\\cal{H}_1", "state" -> "Boxes"|>,
      "TeXAssistantTemplate"], "."}]}], TraditionalForm]],ExpressionUUID->
  "3567b580-2100-434b-8127-f5d0274b9b7e"],
 "  This is Table 8.7."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.880618273874311*^9, 3.880618348860763*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7ad9a352-21a0-4f0a-b6df-bc48969eb210"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*StyleBox[\"a\",FontFamily->\"Times New \
Roman\",FontSize->16,FontWeight->\"Regular\"]\)\>\"", ",", 
        "\"\<\!\(\*StyleBox[\"b\",FontFamily->\"Times New \
Roman\",FontSize->16,FontWeight->\"Regular\"]\)\>\"", ",", 
        "\"\<\!\(\*StyleBox[\"c\",FontFamily->\"Times New \
Roman\",FontSize->16,FontWeight->\"Regular\"]\)\>\"", ",", 
        "\"\<\!\(\*StyleBox[\"d\",FontFamily->\"Times New \
Roman\",FontSize->16,FontWeight->\"Regular\"]\)\>\"", ",", 
        "\"\<\!\(\*StyleBox[\"e\",FontFamily->\"Times New \
Roman\",FontSize->16,FontWeight->\"Regular\"]\)\>\"", ",", 
        "\"\<\!\(\*StyleBox[\"f\",FontFamily->\"Times New \
Roman\",FontSize->16,FontWeight->\"Regular\"]\)\>\""}], "}"}], ",", "delta", 
      ",", "ham1"}], "}"}], "]"}], ",", 
   RowBox[{"TableHeadings", "->", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*StyleBox[\"Plot\",FontFamily->\"Times New \
Roman\",FontSize->16,FontWeight->\"Regular\"]\)\>\"", ",", 
        "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
OverscriptBox[\"\[Delta]\", \"_\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\bar\\\\delta\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", 
        "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
SubscriptBox[
StyleBox[\"H\", \"TI\"], \"1\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\mathcal{H}_1\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", 
        "\"\<\!\(\*StyleBox[\"Description\",FontFamily->\"Times New \
Roman\",FontSize->16,FontWeight->\"Regular\"]\)\>\""}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8806170137951307`*^9, 3.8806170167491407`*^9}, {
  3.8806170909750557`*^9, 3.880617156405408*^9}, {3.880617186496612*^9, 
  3.8806172080954*^9}, {3.880617243136774*^9, 3.8806172549412727`*^9}, {
  3.880617432422461*^9, 3.880617448397476*^9}, {3.880617587468012*^9, 
  3.880617607458143*^9}, {3.880617638448042*^9, 3.8806176601993093`*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"74b3dcf1-118c-4f6c-9db4-b6a5bacd6b5e"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"\\!\\(\\*StyleBox[\\\"Plot\\\",FontFamily->\\\"Times New \
Roman\\\",FontSize->16,FontWeight->\\\"Regular\\\"]\\)\"\>",
       HoldForm], 
      TagBox["\<\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[OverscriptBox[\\\"\[Delta]\\\", \\\"_\\\"], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\\\\\\\\bar\\\\\\\\delta\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"\>",
       HoldForm], 
      TagBox["\<\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[SubscriptBox[StyleBox[\\\"H\\\", \\\"TI\\\"], \\\"1\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\mathcal{H}_1\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"\>",
       HoldForm]},
     {"\<\"\\!\\(\\*StyleBox[\\\"a\\\",FontFamily->\\\"Times New \
Roman\\\",FontSize->16,FontWeight->\\\"Regular\\\"]\\)\"\>", 
      RowBox[{"-", "3.625681850117096`"}], 
      RowBox[{"-", "7.317750077283372`"}]},
     {"\<\"\\!\\(\\*StyleBox[\\\"b\\\",FontFamily->\\\"Times New \
Roman\\\",FontSize->16,FontWeight->\\\"Regular\\\"]\\)\"\>", 
      RowBox[{"-", "3.5791748743718586`"}], 
      RowBox[{"-", "4.458605909547739`"}]},
     {"\<\"\\!\\(\\*StyleBox[\\\"c\\\",FontFamily->\\\"Times New \
Roman\\\",FontSize->16,FontWeight->\\\"Regular\\\"]\\)\"\>", 
      RowBox[{"-", "3.691554903073285`"}], 
      RowBox[{"-", "0.685164486507565`"}]},
     {"\<\"\\!\\(\\*StyleBox[\\\"d\\\",FontFamily->\\\"Times New \
Roman\\\",FontSize->16,FontWeight->\\\"Regular\\\"]\\)\"\>", 
      RowBox[{"-", "3.446880081565472`"}], "0.5623293370119238`"},
     {"\<\"\\!\\(\\*StyleBox[\\\"e\\\",FontFamily->\\\"Times New \
Roman\\\",FontSize->16,FontWeight->\\\"Regular\\\"]\\)\"\>", 
      RowBox[{"-", "3.5075895522257277`"}], "0.4124026847859471`"},
     {"\<\"\\!\\(\\*StyleBox[\\\"f\\\",FontFamily->\\\"Times New \
Roman\\\",FontSize->16,FontWeight->\\\"Regular\\\"]\\)\"\>", 
      RowBox[{"-", "3.588264876033059`"}], "0.692562966942146`"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"\!\(\*StyleBox[\"Plot\",FontFamily->\"Times New \
Roman\",FontSize->16,FontWeight->\"Regular\"]\)", 
       "\!\(\*TemplateBox[<|\"boxes\" -> FormBox[OverscriptBox[\"\[Delta]\", \
\"_\"], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"\\\\bar\\\\delta\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 
       "\!\(\*TemplateBox[<|\"boxes\" -> FormBox[SubscriptBox[StyleBox[\"H\", \
\"TI\"], \"1\"], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"\\\\mathcal{H}_1\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 
       "\!\(\*StyleBox[\"Description\",FontFamily->\"Times New \
Roman\",FontSize->16,FontWeight->\"Regular\"]\)"}}]]]], "Output",
 CellChangeTimes->{3.8806174495254917`*^9, 3.880617834806081*^9, 
  3.880620200769664*^9, 3.8806519578983793`*^9, 3.880655540530086*^9, 
  3.8807027620166397`*^9, 3.88070313082406*^9, 3.880703477464099*^9, 
  3.890982098082242*^9},
 CellLabel->
  "Out[73]//TableForm=",ExpressionUUID->"bb7562c0-9816-41ac-b78e-\
aa80341db129"]
}, Open  ]],

Cell["Define the plot axes.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2587d068-9f50-4e9b-9e5c-73f753bd2965"],

Cell[BoxData[
 RowBox[{
  RowBox[{"axes", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", "[", "0.002", "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", "4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "4"}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.88061836719106*^9, 3.880618379776417*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"a9e82b83-0193-455d-a52a-b7aed8eca606"],

Cell["Calculate the contour plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.880618406205469*^9, 
  3.880618412295705*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fc53b249-79fc-40a6-8f99-024066edf4ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp1", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"delta", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], " ", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", "\n", "\t", 
     RowBox[{"Contours", "->", 
      RowBox[{"{", 
       RowBox[{"ham1", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "}"}]}], ",", 
     RowBox[{"ContourShading", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRangePadding", "->", "None"}], ",", 
     RowBox[{"ContourStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "color1"}], "}"}]}], 
     ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xylabelx", ",", 
        RowBox[{"Rotate", "[", 
         RowBox[{"xylabely", ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotPoints", "->", "100"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.880440528808*^9, 3.880440544210415*^9}, {
  3.88061789507059*^9, 3.880617898083796*^9}, {3.880618033487549*^9, 
  3.880618075232192*^9}, {3.880618114607197*^9, 3.88061817375272*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"0430b546-2d1e-4c30-8286-b2dfc1164b37"],

Cell["Display the contour plot with axes.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.88061841754526*^9, 
  3.8806184245346947`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"28bb0628-a0a3-4993-bbda-9dc654ac314c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"cp1", ",", "axes"}], "]"}]], "Input",
 CellChangeTimes->{{3.880618429097892*^9, 3.880618435290038*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"34d0c090-377b-45e0-b0f2-4dfeeeab6178"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx03X/Ivv1d1/G75bLW2vohWWQus19WFkYsY7EZYzEWIxmKNDJprUwzl2Wl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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl0tlWjmEch+G3SKIoyhgqEfnKLBQlQ9jsEDoADkmTShNlHiMlUuZ5VklI
VFIkXGu1ca37/3vevr2Siw4XHgoLgqCOU6Eg+M7UjCCI4Ir7Pvvd93SdXtdU
XUG5e5uuJp1V1HoLab0u1xx20Gnv1EQWsZjZxBFLhe+feEqu/Ux7+UAxu709
1wd84SUHvL3SZbqUJUzYfxlkmh1Jk3u6HtcMPaFj3CHcPq9DRLlncNU9Uxs0
Uxv1F3eZYl/SYaLdMVxzz9KTulZ/6x/GSbKTSeGNfVBfaz+PecIebyX6kT5e
kOctn118tmuY715APPNIYCFHfMvSdt2it3Wr1ukazWY7HfZR0twrueXerA/1
Ec38ZIQfXGaj75vYwE37PccYoJouyrjIPn9zQds4y177nJYSuMP4556rc1jP
Dbub03zjDD2M8o4qvlLJW1oo8LvW0OT/63/4cnpi
           "]]},
         RowBox[{"-", "7.317750077283372`"}]],
        Annotation[#, -7.317750077283372, "Tooltip"]& ], {}, {}}}], {}}, 
   {Thickness[0.002], LineBox[{{0, -4}, {0, 4}}], LineBox[{{-4, 0}, {5, 0}}]}},
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->{{-4, 4}, {-4, 4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.880618437617608*^9, 3.880655541204567*^9, 
  3.880702762394985*^9, 3.8807031442044287`*^9, 3.8807034788078337`*^9, 
  3.890982099044552*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"54470c85-79b3-488c-9270-0d69986c161f"]
}, Open  ]],

Cell["Calculate the contour plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.880618406205469*^9, 
  3.880618412295705*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7eeb342f-3dcf-4a54-a849-6c389d54a8d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp2", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"delta", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], " ", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", "\n", "\t", 
     RowBox[{"Contours", "->", 
      RowBox[{"{", 
       RowBox[{"ham1", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "}"}]}], ",", 
     RowBox[{"ContourShading", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRangePadding", "->", "None"}], ",", 
     RowBox[{"ContourStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "color1"}], "}"}]}], 
     ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xylabelx", ",", 
        RowBox[{"Rotate", "[", 
         RowBox[{"xylabely", ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotPoints", "->", "100"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.880440528808*^9, 3.880440544210415*^9}, {
  3.88061789507059*^9, 3.880617898083796*^9}, {3.880618033487549*^9, 
  3.880618075232192*^9}, {3.880618114607197*^9, 3.88061817375272*^9}, {
  3.88061845824199*^9, 3.880618463566103*^9}, {3.880618496838936*^9, 
  3.880618497226377*^9}},
 CellLabel->"In[77]:=",ExpressionUUID->"88c40252-2d91-449d-a796-3eff187673c5"],

Cell["Display the contour plot with axes.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.88061841754526*^9, 
  3.8806184245346947`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8e936af1-1c36-4ba9-b823-6bc51dfa8f6d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"cp2", ",", "axes"}], "]"}]], "Input",
 CellChangeTimes->{{3.880618429097892*^9, 3.880618435290038*^9}, {
  3.880618482301344*^9, 3.880618482765173*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"9aca29a6-e098-473e-8e70-d12e656b047a"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx03X/Ivv1d1/G75bLW2vohWbRcZr/sJ4YsY7EtxkIMSYYijWy0VqaZy7LS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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl13n8V1Mex/FvSgoVkRato02hQmRrtUVSqSxTpiKVkWRJ1mpsjSQiRDXM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           "]]},
         RowBox[{"-", "4.458605909547739`"}]],
        Annotation[#, -4.458605909547739, "Tooltip"]& ], {}, {}}}], {}}, 
   {Thickness[0.002], LineBox[{{0, -4}, {0, 4}}], LineBox[{{-4, 0}, {5, 0}}]}},
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->{{-4, 4}, {-4, 4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.880618483548057*^9, 3.880618500690083*^9}, 
   3.880655541498848*^9, 3.880702762786878*^9, 3.8807031518237057`*^9, 
   3.880703479168582*^9, 3.890982099448332*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"d1727a8b-d7a9-46aa-80f1-df3729422c1a"]
}, Open  ]],

Cell["Calculate the contour plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.880618406205469*^9, 
  3.880618412295705*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6123850e-6467-47d2-be9c-08e6adb92cd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp3", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"delta", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], " ", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", "\n", "\t", 
     RowBox[{"Contours", "->", 
      RowBox[{"{", 
       RowBox[{"ham1", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "}"}]}], ",", 
     RowBox[{"ContourShading", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRangePadding", "->", "None"}], ",", 
     RowBox[{"ContourStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "color1"}], "}"}]}], 
     ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xylabelx", ",", 
        RowBox[{"Rotate", "[", 
         RowBox[{"xylabely", ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotPoints", "->", "100"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.880440528808*^9, 3.880440544210415*^9}, {
  3.88061789507059*^9, 3.880617898083796*^9}, {3.880618033487549*^9, 
  3.880618075232192*^9}, {3.880618114607197*^9, 3.88061817375272*^9}, {
  3.88061845824199*^9, 3.880618463566103*^9}, {3.880618496838936*^9, 
  3.880618497226377*^9}, {3.880618544446805*^9, 3.880618551857263*^9}},
 CellLabel->"In[79]:=",ExpressionUUID->"cad9cb21-54d2-4b24-95b1-691d4d853ed5"],

Cell["Display the contour plot with axes.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.88061841754526*^9, 
  3.8806184245346947`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5fd68d20-39cc-46c8-a53d-b3ac969f3c44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"cp3", ",", "axes"}], "]"}]], "Input",
 CellChangeTimes->{{3.880618429097892*^9, 3.880618435290038*^9}, {
  3.880618482301344*^9, 3.880618482765173*^9}, {3.880618557436513*^9, 
  3.880618557886561*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"16b058d1-11c7-426d-bdc1-009245ebb50f"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx03X3ovv1d1/Gr5bLW2rqRLDKX2Z3dYsRSFpsxFsMYyVCkkUlrZZq5VlYa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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl2Hf8l9MbBvBPU1JRRoVoUyiahEKlUprSpKWBEpJNUqFkVKLsFaFkJWUW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           "]]},
         RowBox[{"-", "0.685164486507565`"}]],
        Annotation[#, -0.685164486507565, "Tooltip"]& ], {}, {}}}], {}}, 
   {Thickness[0.002], LineBox[{{0, -4}, {0, 4}}], LineBox[{{-4, 0}, {5, 0}}]}},
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->{{-4, 4}, {-4, 4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.880618559654924*^9, 3.880655541916995*^9, 
  3.880702763207859*^9, 3.880703159666257*^9, 3.88070347956124*^9, 
  3.8909820999010153`*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"79be67a7-8779-47c7-adb5-986e9d267bed"]
}, Open  ]],

Cell["Calculate the contour plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.880618406205469*^9, 
  3.880618412295705*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5814548f-35d7-4b42-96a2-effdc9b04be0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp4", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"delta", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], " ", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", "\n", "\t", 
     RowBox[{"Contours", "->", 
      RowBox[{"{", 
       RowBox[{"ham1", "[", 
        RowBox[{"[", "4", "]"}], "]"}], "}"}]}], ",", 
     RowBox[{"ContourShading", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRangePadding", "->", "None"}], ",", 
     RowBox[{"ContourStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "color1"}], "}"}]}], 
     ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xylabelx", ",", 
        RowBox[{"Rotate", "[", 
         RowBox[{"xylabely", ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotPoints", "->", "100"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.880440528808*^9, 3.880440544210415*^9}, {
  3.88061789507059*^9, 3.880617898083796*^9}, {3.880618033487549*^9, 
  3.880618075232192*^9}, {3.880618114607197*^9, 3.88061817375272*^9}, {
  3.88061845824199*^9, 3.880618463566103*^9}, {3.880618496838936*^9, 
  3.880618497226377*^9}, {3.880618544446805*^9, 3.880618551857263*^9}, {
  3.880618586507509*^9, 3.880618593376865*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"71d1fde7-4afe-427b-9e0e-431aa0976535"],

Cell["Display the contour plot with axes.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.88061841754526*^9, 
  3.8806184245346947`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0f5344b7-d75c-455d-9651-a00f71905771"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"cp4", ",", "axes"}], "]"}]], "Input",
 CellChangeTimes->{{3.880618429097892*^9, 3.880618435290038*^9}, {
  3.880618482301344*^9, 3.880618482765173*^9}, {3.880618557436513*^9, 
  3.880618557886561*^9}, {3.880618599572565*^9, 3.88061860009699*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"54d223c1-e9d6-49d7-b727-b11dd8b8fde9"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx03X3ovv1d1/Gr5bLW0m4ki8xldme3GLGMxbYYi6GMZCjSyEZrZZq5LCsN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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl2Hf8l9MfxvFPitKgKRmRUSKioalFKhUqRUUaGqIimwYhZCV775JVIiuj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           "]], LineBox[CompressedData["
1:eJwl0ckug2EUh/G3l2JKJDQhKCsrV+AS7EylCVokVGItkaI1b0jMS0NivhpT
SyUqJcTvi8WT55z/e87Jl3w1fSO9yVgIoR8PbegIYagzhHR7CL9cJ1tOhLCC
JRSQR718jdexik1soEG+zY+8xU/86VZ3VwgVzrqf4Wb9JBe9F2UlLKobcWzv
BGXZO3KyJpzLLvAhq2DaftydKe7Rt5qJ6ef0Gd/+He3L7u1kZWlZQT/BX97u
5LcY1+flY1yV38iuMRPddW+Wy94vZW98xS08bzbOwUzVzKv61FuJzzjl3igO
1UfYwwH2MSxPYlf9Yn6Hn6Nvc+dHXqtewIB6ELnE///5Ay2UV8E=
           "]]},
         "0.5623293370119238`"],
        Annotation[#, 0.5623293370119238, "Tooltip"]& ], {}, {}}}], {}}, 
   {Thickness[0.002], LineBox[{{0, -4}, {0, 4}}], LineBox[{{-4, 0}, {5, 0}}]}},
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->{{-4, 4}, {-4, 4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8806186007720337`*^9, 3.880655542238381*^9, 
  3.880702763555069*^9, 3.880703167051127*^9, 3.8807034799886827`*^9, 
  3.8909821003073997`*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"12be36ef-4177-45fa-a779-d1ac1623af95"]
}, Open  ]],

Cell["Calculate the contour plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.880618406205469*^9, 
  3.880618412295705*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4f18c2c7-d9b1-4242-b778-d39e9cea20ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp5", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"delta", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], " ", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", "\n", "\t", 
     RowBox[{"Contours", "->", 
      RowBox[{"{", 
       RowBox[{"ham1", "[", 
        RowBox[{"[", "5", "]"}], "]"}], "}"}]}], ",", 
     RowBox[{"ContourShading", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRangePadding", "->", "None"}], ",", 
     RowBox[{"ContourStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "color1"}], "}"}]}], 
     ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xylabelx", ",", 
        RowBox[{"Rotate", "[", 
         RowBox[{"xylabely", ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotPoints", "->", "100"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.880440528808*^9, 3.880440544210415*^9}, {
  3.88061789507059*^9, 3.880617898083796*^9}, {3.880618033487549*^9, 
  3.880618075232192*^9}, {3.880618114607197*^9, 3.88061817375272*^9}, {
  3.88061845824199*^9, 3.880618463566103*^9}, {3.880618496838936*^9, 
  3.880618497226377*^9}, {3.880618544446805*^9, 3.880618551857263*^9}, {
  3.880618586507509*^9, 3.880618593376865*^9}, {3.880618633314581*^9, 
  3.8806186417305393`*^9}, {3.880618725285316*^9, 3.880618744976735*^9}, {
  3.880619768954075*^9, 3.8806197696604767`*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"f2c22431-043b-4903-a35d-2788cf02a268"],

Cell["Display the contour plot with axes.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.88061841754526*^9, 
  3.8806184245346947`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"45ec1b39-95b3-4feb-920d-c3727fd599c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"cp5", ",", "axes"}], "]"}]], "Input",
 CellChangeTimes->{{3.880618429097892*^9, 3.880618435290038*^9}, {
  3.880618482301344*^9, 3.880618482765173*^9}, {3.880618557436513*^9, 
  3.880618557886561*^9}, {3.880618599572565*^9, 3.88061860009699*^9}, {
  3.880618647491399*^9, 3.8806186479249277`*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"27b496e7-05cf-4e02-ae29-5e76511db869"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx03X3ovv1d1/Gr5bJsuW4ki8xldme3GLGUxbYYCzFGMhRpZKO1Ms1clpWG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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl2Hf8j9UfxvGPJKP8pEElyqyIygyZldGgIiFURimriTKjqbILKRpKob3T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           "]], LineBox[CompressedData["
1:eJwl09tPz3Ecx/FPLiSVUpLS0JRxT+kyXDkMcY/YuuvguLERfqup3HJl48Zs
1K+TEh02EV0pIoe1cuOQf8Ahh8dnLp57vl/vz/v7/n4/7VdxdV1VbUoIYRTT
m0PIKg+hc2sI9VtC2FURwkq9pN5b7uCueI58uYd70Y0+3Mcq/Qc8gH48wkMU
6A/xMAbxTh7hQt7tPQ3e916drZcqL8FSpOF2WQiLka5O5Qw+bj5NfS3O8h2c
1rson+EPduXatQJN6nW4a6aY95tJV7fjHnrd97W5N5iKd8V0/H79audH0Wjn
gHyBm+0owbyZb/FvEe+NhLOE3Zf5mGc2mDkoN8k75BHPN6sHeRhDqNHfZG6R
ep5T+CtfNdeGcfk5iuwP/JefcauZMV4t/8FvPJVb9J9wobyAXxiVr+g/5gL5
i/ont9h/w/e18me973qf+Adv5G7fVsoHzOSqu9CJ5bill8OXPJvN1+UsTiIT
N+VlfN55B6+3p0ovQz2nnvWOj5iLvx3f9ZJf4QUmMYGeeHcej3fGjOfO2bfP
nrXq7XZtw1m9vXpr9I7IJ+VG+RRXyid4j1zk/JB8GHV6O/Xy9BLxt+1dSbSX
//8/+AdYwY7H
           "]]},
         "0.4124026847859471`"],
        Annotation[#, 0.4124026847859471, "Tooltip"]& ], {}, {}}}], {}}, 
   {Thickness[0.002], LineBox[{{0, -4}, {0, 4}}], LineBox[{{-4, 0}, {5, 0}}]}},
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->{{-4, 4}, {-4, 4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8806519802113028`*^9, 3.880655542567643*^9, 
  3.88070276391208*^9, 3.8807031752171707`*^9, 3.880703480385751*^9, 
  3.8909821007307043`*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"f5cf8af5-8cc1-40c7-a128-4581dced528e"]
}, Open  ]],

Cell["Calculate the contour plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.880618406205469*^9, 
  3.880618412295705*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"be27fe1a-d290-401a-a282-5065219b390a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cp6", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"x", ",", "y", ",", 
       RowBox[{"delta", "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], " ", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", "\n", "\t", 
     RowBox[{"Contours", "->", 
      RowBox[{"{", 
       RowBox[{"ham1", "[", 
        RowBox[{"[", "6", "]"}], "]"}], "}"}]}], ",", 
     RowBox[{"ContourShading", "->", "False"}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRangePadding", "->", "None"}], ",", 
     RowBox[{"ContourStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "color1"}], "}"}]}], 
     ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"xylabelx", ",", 
        RowBox[{"Rotate", "[", 
         RowBox[{"xylabely", ",", 
          RowBox[{
           RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "->", 
      RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
     RowBox[{"PlotPoints", "->", "100"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.880440528808*^9, 3.880440544210415*^9}, {
  3.88061789507059*^9, 3.880617898083796*^9}, {3.880618033487549*^9, 
  3.880618075232192*^9}, {3.880618114607197*^9, 3.88061817375272*^9}, {
  3.88061845824199*^9, 3.880618463566103*^9}, {3.880618496838936*^9, 
  3.880618497226377*^9}, {3.880618544446805*^9, 3.880618551857263*^9}, {
  3.880618586507509*^9, 3.880618593376865*^9}, {3.880618633314581*^9, 
  3.8806186417305393`*^9}, {3.880618725285316*^9, 3.880618744976735*^9}, {
  3.880619768954075*^9, 3.8806197696604767`*^9}, {3.880619826450869*^9, 
  3.880619830050322*^9}, {3.880619894793932*^9, 3.8806199125526457`*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"12d451cc-b66b-47a4-a7ee-358d11b846fd"],

Cell["Display the contour plot with axes.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8794075687237053`*^9, 3.8794076395489893`*^9}, {
  3.8806183591661053`*^9, 3.880618363964899*^9}, {3.88061841754526*^9, 
  3.8806184245346947`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9ce64f57-dd21-4a0a-a0af-e0004ad11723"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"cp6", ",", "axes"}], "]"}]], "Input",
 CellChangeTimes->{{3.880618429097892*^9, 3.880618435290038*^9}, {
  3.880618482301344*^9, 3.880618482765173*^9}, {3.880618557436513*^9, 
  3.880618557886561*^9}, {3.880618599572565*^9, 3.88061860009699*^9}, {
  3.880618647491399*^9, 3.8806186479249277`*^9}, {3.880619835000415*^9, 
  3.8806198357803373`*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"c9fc21a1-de78-4e56-972b-50ac25e90195"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx03X/Ivv1d1/G75bLW2vohWWQus1/2EyPWYrItxkIMSYYijWy0VqaZy7LS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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl2HcYltMfx/EHhVQoREaktLT3FEUqlEIaipaysjIiDZVdaCGj7IzMlJCk
KIpUilAhqRRKyMzv9bl+f3yu93edc9/3c5/7e871lO9zeedBexQKhXpFC4WT
6xcKjRoVCq2xMXZtUCgcWq9QOKdhodCFzqL3+GdjGXxHzelqW+NKtQvFOsu1
F2spdi+/tfhp/BP5regk6iZ2hFwvtefTefQBvyceju+qOdOYU3CV2h7i3elk
/gT5sjSf3VHNUnZ3NUfje2KdxU7F1WJ9jelDbfgT5cvRQnYnNcvyHHhWrqP2
ZOrCPrCx58Ue/IpqFud34LfDz8QuMt9AasufJF+BFrHPVbOC3QNLmaM7TuZX
piXy5/E/ZZ+PpeV74X38qrRU/gL+KnYfPEi+N97Pr0Yfyfflr2ZfiAfL98cH
+DXoE/kB/M/YF+Mh8hfhFH5tWil/Cf9z9mXufQ0OwtPE2+fePFd9sc/Yg9S1
4V+BZcxzOfbk96Kr2YeKXYUPqm9AnxszmP8F+3JzfolXYAfxM+h84xqJfcG+
Ju+G/xC/MX0pdq3YWvZgY9bhNXhm3m1+E7XNxNayh6hry3+E35yuVfd15hX7
km6SL+vehuL1ct/IXYc30BDqbI7e6k4QX88ekXfKn8pvScPVfIfrxNbT13QS
/2u1I9VuZI9Q8z2OxFFiZ8uNYd9Co+k2upXOEe+TNaV2A3u02vb8R/mn0Dg1
d+cexb6lx8Ta0HixrRkj9h1tpLb8ieI/4hb+D7SV2vMnif+E2/g/0k/51vgb
XfNW1/yZ/aCa7fhQ7k/sMfyF/yjuxMfxDvHp+Dv/adyFz+Bd4jPwL/7z+De+
gOPEX8Z/+S/hbnwlzyT+GhZwJu6Bs/AenIN74etYBN/Ae3Eu7o1v4T74No7H
+VgM38H98F2ciO9jSXwP98dFODl9AEvhEiydb4c2px+4t+ViB/N3+33+o0J6
WdY7HiK+B+6Z+6Ozs6bT38SLYNHcH52btZb1nfuh4vSEWDd6ypxPUzl6xjWP
wmdxOvbE79RupA20KWsofU/8IdfYkp6Xe8UjcCr9mG8y71WsHL9EnjnPSz3z
bjJ/eh49p3YGPU/P8fvgdnU76Gc62vhf8Ek80vfxFJZPj8rvRAflXvJ+jZ1B
5ekFcxyDL+IL2A/70x9qKxi7CyvisXI/Z60b/yL7pfTMUKwCvowv40C8iP4x
7jjj/sZKeJzcDvF+WT/s/vgLvxJ7Jr1Klamm+66S+bK+5GfRKzSTXqXX5C7B
S2kPqqKugFWxqtxv7IHmnsW+GHfxq7HflD8e/0h/FJ/Nvgz/4ldnz5OvgX+n
L4q/nr6I//JrshfI18Ld/CvF57Cvwv/4tdmL5etkvbn/q8XfYF+De/LrspfK
18O9+NeKv8kegkWN35uKUA01DdIH1dTHt6gh1eI3wmX5hvAG4/YWa8z+VKwJ
7sO/Ufxt9jAsZr79aN/cn5pm4s3VNM2z0mdizXE/seHZ39k3Y0n1+1MJqqvm
S6qr5gs8QKxeeq93OjvvO78Tzje2Bc1hn5Dfit6l0fKlxRpkDWJD/Ca/g/m+
zt4n1giPMN8beb/5XXChsS3z/OwT8X16j26VP1zsCCpLTbPO8bbs99iMfxQ2
x++pvutsxKPFWiTnOsPYw2kTf0TWPpWncnIjs77MdTMem3VNR6f/Zx2Kj8aK
dFzGic/F2fnNcVHWQPYR+og+ptvlPsCxeH3uX91m170Ft+A5Yq/Ljcl3QJVz
L+ndOEf89qzvrO3cT3o3viF+Z9Y0HZ97TO/GN8XH4ris57wH81dMn2bfQz9k
fWPLfIvpx+ytead+ozuMrZXfml8TT8LaeKd43bxzqpP3SPXpruy37v1G9lC6
gTZkj8y3LDeE/23OLtg478j1bkpvZO/vemPUlOE3yfkFD6ND6Zbs9ea4jr1W
7lpcl3Ob2Cs5L/C/yrkt94GHm/d69np2SfOOytki3x19LlZcbET2LbpK3dVU
PM8id5ixg9lr0nPVjUxNzj20SmzfnC/S63LWUXcF7UO1ci4y9kr2anYxdTep
udK4FfzK/JXYOb015zX28vyu9FH2GfnrxGfkfGaOPWkvKmPOQfixmqJqrs/Z
yhwf8ivxl2An/gfZw/iDc1/5NvI++YvwTP7zOfdmz6Tq2UvpH/NeLv5cvvOs
C/Xz0w+zB9Of6adyz9Jb/Aryc7Fa9m76PT09e1G+9+wF8nNwUHoozco+IzYb
O/Jfw1+NGaD+0vR2/jHyM7FD3iXulL9Q/pL0afZuz/9fzhlUWf4l2i7eV830
nEXyHZvjRbw4Z/M8K7uc2Iyso+z7Ob/Qn9Q755s8k9yF5nkOB+Q7woHGTk8/
MPYZPCN7Ov4kf4ExA/h92b/lnJSzEx2TZ8LH06+MeyLrkH9AzmU5s1GvnA9y
3pLrbfxjuXb2OrqAP42/Vd1R+AMeiY/QNrkexj1Jp6t9OHVi3fn9+L3Y36j/
NufmnIVpPZ0n/qDateyy+BUehlMyv1zX7ANi++a8RYeKr8EuOQvSaeZ+IOcS
tefw+/J7sFepWU0r6FNaSd3Fl+En9FHOEsZ9jPfhh3ggLs7vgR/gJFyIJXBB
zlA4gTaZp1P2Vdf6J/st7Ss+T82Z2Y/5f2afpqLib4p3zD7O/z37O+0pPlu8
g/iv/J30S857/FfFz8Ad/O05s+Q6+Y7FT8fvXX9s1nzWhtgf+S7wTrGn8Df+
E/hr3gfeLj4tZyz+wziVHqFu5nkAp+RMSvfnt6Cu4k9mPeF0eoqO5D9Bj1M7
82zGTfQ9beNPMO5U/C49MO+OfY/YFrwXx4idm77LHpt7yv1mP8i7zDrL/Lku
PZ79kf8oTaPW5vhW7HD25uxtOZfiKLw5vVXuEbmpVJa+4bfKs7JPxGm0lv0V
bWAPT9+1/ofhsKxJsRvT32kodTL+oVwbH6Wp6e/8x/DG9E52DePL4IM5y+Tb
xXXZo801hd0016c16eO0PvtnenZ6J96fdUsH576yj8jfl7NSxvAPSjw92f1c
TVfl3YtPzjVzfzQlz00P05XmLC1X3fylcBIdkPvgH5gel30Lj+eXxAk0kUrQ
6uyPrjWeXRdXZY9hX2rMfjmfZb/Je8w5Dlfwi7EHZo/B5fyaed+5Pi7LPsPu
J793zhHZ58XHse/ON0HV3EeRnCvyLVAT/l7YM3sDVuUX8C7aLdaY/x+uNM/F
fotL6RKqkrOEmkr4oev8q6Zb9ot8wznn5Awif0e+U7Eq5vkLb8v3iY34f2Z/
U3dhekN6Jx6Lt6opj++bZ1fOPPwx+X7ZDY37Pf0j/S39BPunx+aMpeYoXGDc
r2pG8W/O981uYNxOXCJ/gfoPsXf6KI5QM5J2yD9g7HYczr+fPT7rAz/lL2Z3
S4+Qr2O+DrhI7Fyx97FreijepHZY+of8ZGN/wqFZGzlPyU/EFfxO6Vt0Ar+d
mhbYnJbLLVDXMd92zlOu1Tb7sdgZYvOxAx6Sno/vYHucl76cvQzbYjs6JXNQ
m/Rd8dZ4Mp1IregkKi1+ArakZtSCmlMp8RtyVqMfXX+8e9uWXoxDcr6gcWqK
01L2EmqVfoNd6EDxJuZpSg2pMTVKnxevjw2oDtWjurR/zpJYm6pTTapBJcWP
x7exKs7FatkfcJ57aeOazfAT13xLrEqeW6xpvu/sPeKVxSrlPvh3q2nV4P//
Y/4PUKObJw==
           "]]},
         "0.692562966942146`"],
        Annotation[#, 0.692562966942146, "Tooltip"]& ], {}, {}}}], {}}, 
   {Thickness[0.002], LineBox[{{0, -4}, {0, 4}}], LineBox[{{-4, 0}, {5, 0}}]}},
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->{{-4, 4}, {-4, 4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8806198361730213`*^9, {3.880619888384204*^9, 3.880619890535161*^9}, 
   3.880619924724978*^9, 3.880620231639929*^9, 3.880655542909727*^9, 
   3.880702764354492*^9, 3.880703184462463*^9, 3.880703480772018*^9, 
   3.890982101148597*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"27609e83-4bc6-453a-a627-39f1ba7e8eac"]
}, Open  ]],

Cell["Combine the x-y plots in a single plot.  This is Fig.8.18b.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.880443112383852*^9, 3.880443147952177*^9}, {
   3.880443407582518*^9, 3.8804435309998903`*^9}, {3.880443644204974*^9, 
   3.880443645674123*^9}, {3.880443902400056*^9, 3.8804439042289677`*^9}, {
   3.8804509425799093`*^9, 3.880450974049046*^9}, {3.880456516772072*^9, 
   3.880456577237422*^9}, {3.880456610688011*^9, 3.8804566879378443`*^9}, {
   3.88045916902036*^9, 3.8804592043930492`*^9}, {3.880462746994853*^9, 
   3.880462756268464*^9}, 3.8804627895950527`*^9, {3.8804628220236797`*^9, 
   3.880462822643222*^9}, 3.88046285575877*^9, 3.880462891878394*^9, {
   3.8804634457063847`*^9, 3.880463448195674*^9}, {3.8806141679440327`*^9, 
   3.8806142112342987`*^9}, {3.880614288681053*^9, 3.880614293899702*^9}, {
   3.8806144133161373`*^9, 3.880614424131011*^9}, {3.880703277086555*^9, 
   3.880703278061075*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"63e59254-65ae-4df2-8ac5-4b252a9b99d8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
  "cp1", ",", "cp2", ",", "cp3", ",", "cp4", ",", "cp5", ",", "cp6", ",", 
   "axes"}], "]"}]], "Input",
 CellChangeTimes->{{3.880440608471245*^9, 3.880440651849971*^9}, {
  3.8806199407669497`*^9, 3.8806199661754637`*^9}, {3.880620236928401*^9, 
  3.880620238126745*^9}, {3.880620339783951*^9, 3.880620340277598*^9}, {
  3.880652003285171*^9, 3.8806520043939743`*^9}, {3.880703212065153*^9, 
  3.880703229117079*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"02a70398-2458-4d92-8bb3-aa156557f021"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx03X/Ivv1d1/G75bLW2vohWWQus19WFkYsY7EZYzEWIxmKNDJprUwzl2Wl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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl0tlWjmEch+G3SKIoyhgqEfnKLBQlQ9jsEDoADkmTShNlHiMlUuZ5VklI
VFIkXGu1ca37/3vevr2Siw4XHgoLgqCOU6Eg+M7UjCCI4Ir7Pvvd93SdXtdU
XUG5e5uuJp1V1HoLab0u1xx20Gnv1EQWsZjZxBFLhe+feEqu/Ux7+UAxu709
1wd84SUHvL3SZbqUJUzYfxlkmh1Jk3u6HtcMPaFj3CHcPq9DRLlncNU9Uxs0
Uxv1F3eZYl/SYaLdMVxzz9KTulZ/6x/GSbKTSeGNfVBfaz+PecIebyX6kT5e
kOctn118tmuY715APPNIYCFHfMvSdt2it3Wr1ukazWY7HfZR0twrueXerA/1
Ec38ZIQfXGaj75vYwE37PccYoJouyrjIPn9zQds4y177nJYSuMP4556rc1jP
Dbub03zjDD2M8o4qvlLJW1oo8LvW0OT/63/4cnpi
           "]]},
         RowBox[{"-", "7.317750077283372`"}]],
        Annotation[#, -7.317750077283372, "Tooltip"]& ], {}, {}}}], {}}, {
    GraphicsComplexBox[CompressedData["
1:eJx03X/Ivv1d1/G75bLW2vohWbRcZr/sJ4YsY7EtxkIMSYYijWy0VqaZy7LS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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl13n8V1Mex/FvSgoVkRato02hQmRrtUVSqSxTpiKVkWRJ1mpsjSQiRDXM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           "]]},
         RowBox[{"-", "4.458605909547739`"}]],
        Annotation[#, -4.458605909547739, "Tooltip"]& ], {}, {}}}], {}}, {
    GraphicsComplexBox[CompressedData["
1:eJx03X3ovv1d1/Gr5bLW2rqRLDKX2Z3dYsRSFpsxFsMYyVCkkUlrZZq5VlYa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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl2Hf8l9MbBvBPU1JRRoVoUyiahEKlUprSpKWBEpJNUqFkVKLsFaFkJWUW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           "]]},
         RowBox[{"-", "0.685164486507565`"}]],
        Annotation[#, -0.685164486507565, "Tooltip"]& ], {}, {}}}], {}}, {
    GraphicsComplexBox[CompressedData["
1:eJx03X3ovv1d1/Gr5bLW0m4ki8xldme3GLGMxbYYi6GMZCjSyEZrZZq5LCsN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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl2Hf8l9MfxvFPitKgKRmRUSKioalFKhUqRUUaGqIimwYhZCV775JVIiuj
jAZFKVIRpSSFaFHS73k9fn+8Hte5rvO+x+fc9zn3+X6r9R3WeWiRQqFQYs9C
4bh6hUKjBoVCEzTGCfULhVV1CoXTTiwU2qMN2qEtfpS3pqfiZLxTt1A4hf4g
b0Xf5lvSt2g9562LDs7ZHi85bwt9zXEaf62alY5bql0ntfrr4GfZOWo+1H82
/YA20t8QndSeiVfVddPXFWfwI9Ssddwy7QbqPsn11ayXrZA1k51Fp8o+1neu
47rwnTGK/0Xdcu2T1M3m66vbKFspaynrRqfJejnuvFyXH61ug5rvtVuomcu3
pqfgBu2q6ttoV2tovOiJ/Cb1q9W34w/h29PD9J9GG/B/6f9Jf0f+UL6Hdk+c
je44Bw3lW9X1dR/90Aefu94ZjjncuU6nY/gtatZmvPj5/AXqFtD++Q3yc9HI
uXao+1W7S+6V70qPcJ6zaGN+l/7fcg+5V747PVL/ObQJ/0XGU7u6rCe9kS9g
k2PO47/UHuCaC+lAer68F5o6dg/ZX9p9c+/8ESgq2yzrJ/tKe5BjBuNC9M4z
UlNcvk27f+6Fr44Ssu2yAbLF2hepX0Ivpn3lffIeqGuOwWr68RfSm9WUxBB1
Q/NO638XM1Ba/o+6IeqWag/T/y29JLWy4XQZfym9HJehf94Hx7bEpWoG8JfQ
serK4io1V+f91j8Tt8jKYaRsFGbJPsp7ivLy0bKVdA4/F/NQkR+TeUfn8wvy
HLAff2PmKf2SX4hF2J+/Rf4T/YpfjCWowt8qX0u/5ZdhOQ7kx8nXZY7yP+A2
7YNxp/wurJb9hNtlh+Ae2QT8LFuHO2XV8IzsWWzInMJ4WQ1MlE3CH5kXmCA7
Gm/IpmOzbAvuk9XCu7IZ2C77Gw/IauNT2Wz8J9uNR2R1MU/2GfZAURRDffmC
nJsWpyWwNxpkvOhWWobug33RiF+Ua9LytAIqojH/Nd1BK9H9UBlN+G/oTro/
rYIDcBK/jP6bMaRV8aR2c6zQ/g7VcBiekrXAzXmH6B7m1Q7vzy38WIz0Pq3O
s8Qq7Fazho5T80t+L12X30zvwJ6OP0XN+oxB5hk9Is9Edmqef9Ypupe6nfrH
5Vnjete5ARvV7iXfQIvTf1FcbTvH3K7uXn6mul30ffohPsAd+m6kfzhuE37P
WKv5DyUd3yHvkpqHsl6r201n0Y/xEe7K3KC3YotjS+nfTEvTgr5SWeuc427t
M/Pc+CLaT+ofn7Ulc11WlD6Vccjv5IvRe7BXvkd8cfpc1m/XmYdPMQezMSFj
Qcdhm2uXVbeVlqMl9JXLOuna9+Z7RCvwr+qrgGPy/uW7J/+c3qdmb8zX/gIL
MEVdKVlbx5Wk92fNyXPny9DX9e9L2/H75J1HWbTiy2Xs8CB65n2Tldd+J9fP
3ObPlT+sfV7Wsbyv+DvvqppK8tPUVMycwfuy/egBsl7qH9XuTXfnPc5zy7tM
9893S01l+ljWKlmVrBmyPuof1+5Hi/p9xbAHDs740wvkB6mbzVfFsc75pXwh
vsIiPJFnmPvAwWr7O+Yp7UG0tP4yKIVqjt8na3jWH3Xz8n1Cbed8Qv4kPsv4
0cPp8Zlb2QOof5qWRbnsd+SL6WvyJfTp/BZ8rX0QfRbPYEjuPb8FB+IQVMXQ
rHP0MByKI3I9DJNXp0flG0Vr0hr5Fshr0qP5o+gx9Gh6adY5WivvDj0240OH
Z52jx+O47JVyz7gsexxaH3Wz78GJuFzezf2ejc+zjzA2g2XTshbrL48KOU/W
APq6/Dn6PCrm/rMX0zdRexLm8wvyG/LO8NXzntCL8s7RGnxlegCq4GJ5V9d+
VPsxPJL5lPGXTdH3EP8w9soYyo9zrce15+adcK8D1JTIWGadoSWxNwbKz8oc
0X4g8ylzVc2DGRd57Xwzs5bgwKwReX60SPYXju2StUp7pmwCnZXxlb2q7wPt
D/NuY6f72ZW1OnsVfZ3V3K1+fNYkvKfmnjw3ea3sFfgZGRO8FfUbujvulayP
WQex3bkq6atF7+Tfzpip66Gmk3NMzx6cfzPvAv9Gxjp7rOzrsr5hmqyi7GzZ
y5iaPTH/WnK8gvJ8V30v4qXsKfmXk+NFlOW76JuMF7In5SdnjmBSlO+cPjzP
1+cnZp7h2SjfSd+kzCG+Hv8MLYPT3ePjeXdkT9CaWR9oaf4M9R2zzvB1+Efz
O41FTfyFP9Exe4KsV/puMkZjcXOef54x9nZc+9wXjspamDU4e2e+Q/YJ/An8
/ZlXzlcj33ft32jbvOPZo/Bjsq7T9ln/8mzzbjpufPawao/Entq/0taZM/lO
8aPz/Gm7rNcYxd/O/6yuCF1LC/Q2FHO+kzNG2euovVVWVNaKb8OPcOwP2afh
++xdss+iY7N+qbsl85Y/JO+ivuW0GX0ia5D2gdmHYimaZs3FTY65LmNGT3WN
1riGvxZL1P2TvV/Wf7qYjsncc60babl827BN30LaMGttvrkoiS38F/RE+lj2
ChkjzMfnqJfvBYpkDDAXc1AnzxO73Mu/+ET2MY6T3Y8Rrn2Z+xtJT853DcP5
aWpexxS8hqkYJh+TPUX2f+p3Z011jhv46tkH4Fft9Xg6az0Old2BtbI12XvK
7s7+SzYOq2Q/4g7Z7ThI9j3/HVbgZ/62fPfoUv6bfBdyLv6KrNPG73I6Vs3q
PIPsybJ3oxe6v0EYpX40tmbvxFfWP5KvlL1X9gban+EGx1yfPaZsNv9pxgvf
85dlvrjWcDoi+0XZNfQ6XIuBzjtC7YysT3g3e6a8D7Jrsa/6nbLNshW5d8cs
p1dmXGUX6Ls67wv+4nfw++i/ii+T9TH7A7yXMeAvzvx2PxfRK2RX4k/tv/Nt
1n959jr0bfoW3sy48YMyNx03MM9d9gc9id9Eh/OXZl+mbqvz/J77yvzFFn5P
+SX6i2WcMT3rJBZp98m31Xl602GyDbQpv5Gen7mMJvx6OlR/L/oL/nTeIo4f
Itvt79w/+HXyHpnX+J3/T35x3l+6kV8r74Y12MDvlF+k/x+6nv9J3hmrcw3+
b/lg/dvpOn6VvBN+zDX4bfIL9W+ma7IuyAfxA/PsM5fd90raAd+hMb+CDtC/
jLbml9PP/I7zPc95tHfWVOfrnzGmq5z3WzVtsTTXzvjKL9B/Mv8O/w19m35N
++W5aV/vXG9mj8DP0W6l7wf+N8f2kfXFEtl02WLaO3tW7Tcyh7OnCnmXHds8
98//6tjzZU35qfxXdApdRHvle5z1IN9POiX7S+2e+Zsra4Tf2oTOknWXzaQ9
6DrnPDf7XCzU/7Jjv6Q9+Ze0r8s3kb6S9zj7iKxl+WbJOuLlvNvy+rJv+TXO
10XNjHyf6bvZB+RvLvkZ9Ex0wOn5bmXuy3vkedFvHP+F83Tnz8Fk/pp8U+mL
fLP8PYh2mXPytnRyxkPWBKfybdAap+CFzB91jfWdkDGQtcreLPsGeSP58fKW
shaYmHkhbyivLW8uu4pvlj2evgb57bkH/kp5U/qcvH7W8az9/BXyg+v//3+D
/wMu23dp
           "]], LineBox[CompressedData["
1:eJwl0ckug2EUh/G3l2JKJDQhKCsrV+AS7EylCVokVGItkaI1b0jMS0NivhpT
SyUqJcTvi8WT55z/e87Jl3w1fSO9yVgIoR8PbegIYagzhHR7CL9cJ1tOhLCC
JRSQR718jdexik1soEG+zY+8xU/86VZ3VwgVzrqf4Wb9JBe9F2UlLKobcWzv
BGXZO3KyJpzLLvAhq2DaftydKe7Rt5qJ6ef0Gd/+He3L7u1kZWlZQT/BX97u
5LcY1+flY1yV38iuMRPddW+Wy94vZW98xS08bzbOwUzVzKv61FuJzzjl3igO
1UfYwwH2MSxPYlf9Yn6Hn6Nvc+dHXqtewIB6ELnE///5Ay2UV8E=
           "]]},
         "0.5623293370119238`"],
        Annotation[#, 0.5623293370119238, "Tooltip"]& ], {}, {}}}], {}}, {
    GraphicsComplexBox[CompressedData["
1:eJx03X3ovv1d1/Gr5bJsuW4ki8xldme3GLGUxbYYCzFGMhRpZKO1Ms1clpWG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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl2Hf8j9UfxvGPJKP8pEElyqyIygyZldGgIiFURimriTKjqbILKRpKob3T
0l6aGipKaJEt/Kh+z+vx++P1uM51nfc57vv+3Ofc56ty7yHnDC5SKBTKFisU
OjYqFH5sWChcd2KhMKh+oTCCniU7Gz/JR/KjUL1BoXCObIGaVfLRsjGoIe8k
Xyj/WT5Wdj2OkneWL5Kvlo+TjcfR8nPlj8nXyG+Q3Yhj5F3kj8vXym+S3Yya
8lvoefq64hd9t/KD1U2g3WTd8at8Iz9EvomO4Fcau1n7Rzoq94Jv6hUKfdX3
Qx88rf5i+q28P32Gv4Q+S4837p7GhcJx9FLZc7LfzbHFnFdob6Wj+TH4Sc0R
apebZyy/gl5hzJW4HC+ov4qulFdRV0/9i7J1areZ5yrt7Xl2/Cp9f2n/TMfn
2SUzrrpxDWUvq/1TtkPNTqyW7aI3yG7EGr6G2p+NuYlfS4/hG8sXG7tR9l/1
u/E39uRZp07/P9q/0Fv5W/CLsTWN/VXWHL+hVrx8gv7f6XD3dS2G4VXz/6Fm
rprf6W1q1tHp/HraGrfL1ht3nOxP/lRswPHx8jvyW9K6/EZ5e2xCPX6TfGJ+
A1qf3yw/HVvQgN8qn5RnShvGyztgGxrx2+WT8+xo4/i813neaMLvlE/J86En
8TvyXmInmvG75VP176HN+V25N35axmjfmRp6HvbS3kP/9UyLaBdwp7r7+Puz
Hjyvtz2vcfQd+rfaVmr+Nfdd6vaSncL/I5/Jz0AP7ZGynvT9vIO5V4zQLopZ
2sXoqZlHzUW4W9Y7a0DWh36gf6dsF0ZpF8ds7RK0Ta5T++K8+/QSOkbWny7V
v0f2N/5BSf5eOifXiqLqitC96Vz6iHt8FFPd3ydqp9BP6QBztVWzr/adss9o
EboXiqI0f5/x92eu3I/aonQf+gBdaM7Z6u7B3fg810EHmvd++kXG0y/pIFk7
48pqPyBbRkvRfbEfDuQfoV/R0vQ/GK99EN7QXoKyOAA3yipgvmuoSDuYt5T2
AjyKp1zXW/lN8Sbeze+aPUb+Ef0YH+ZZYGn2E/l39Hssxwr8gBezpuka/Jw9
D2vxsvxPugHrsQkbsVjeL79Z9kb3+wZ/S/ZN13hU3gt+b1RUWwm3y2rmOcj2
xRGyI1EZteT7ydbRKnxVVENt/lz3O9m867XL5Fro/nSK7CC6gT+QlsPB+BiX
uaYT5F2MnZq1zk/h6+ZZ6t9Ia5u/Do5Dff48tdOy5rUPV7OZVqSf4hMMMEdD
WTd109W1yfrjG6GG/m3Zu811Ambqv0ndDDpQ3V/6vlRzN/8FnZX1K2uMo/Md
QiPjTsz7pe9mY2fTQcbuVPO1/rn8V3QOvUt2Eo7la6OxcU1wf56/sffRwcYO
wYPZV/MO0xnGNEcPfh6/R/uE7Md5NnQ5vsXlxrWU9VL3cNZN1hWdwM+nV/BX
5h3MXit7NHuF+ta4kF/IF/B49l3+MTor+wp680/wRfAMJvJPZ7/I/oE+/LN8
UTyPSfxz2Rf0tUVf/gV+73yTMJl/id6r77R8R/nFfDG8hin8q3SOvjNxGf86
XwJvYkn2evfSDm9rT9X/Fr2KP0v9QP49foXn0iy/UX4r/JDfRH/H7C1q3lVT
Eh9mr8N9uR5zfKy9MmuR/kivlnXR10x7P9lJWQ/0E0wzz9LsJ3nvcTn/KT/U
mGvQTdZK/f6ylrQM/Ryf4QF9p6v5UvsnfV/QVXRY9m997bVPQzscqO9bfIM1
Wfdo4d7a0jY5A2CeMefjStfwtbprzTMcF+Xa9HdBJxyirzO9UH6N2hX5rvIn
m698vnN5VvRPuh6tc87LeQ+/4WHjzjDv92p+zx6AP3CdbIC+YdrD89wwFNdk
fee6cn7J2SvnoryzuFQ+mFbNuqNVsoZo//xGtDJ/KT2SXkYvkffPXsRfTCvR
S+jF8n7Zu/g+9HDaN/td3l9agb+QHpZvHe0rv4AeyvegvdATfeTd6fk5S+bc
iK7oLV/m/i6gV+d8ld8NX+AQ/iF5edrKs+qovgN+zb5t/l/oWrTUV45fnndV
ba+839kDczahB9Ezch3yz8z7ORqgnNr69FMcrP1gvju0eb432SuNWZb1IvuK
lkVr2Sn5TdFd/SfGdqVX5EypvTTvefZcPCSrS/9jXHP1pWmL3L/6j+Sd6RA1
x2t/iA9QB/Ny5qWl1DdW3xRN8o6pf19+Tn5bNbW131dzLB3Eny1/T/sdWS06
W1aTvoujs//xx9A39B9F7+ZrpB7V8ABfnRbX38C/tw9tmGdu3rflZ9BL1VTV
fkVfFdqfP13+lnb7nOX5ytov6j+S9uPbyd/UbpNzTvZrz7dpzhtqnsIdap7M
/qOmEmbxR9BFsop0Jn84fT3XjgpZe7KTzfWadqu8c/xh2v9q13PN/9D69Pu8
K3hVX1k1B2B/HMofmPfLv/GKdgv1PflDtHdr1zHmeByHb7A4v6P+MiiN8vzL
eAnNsj/IyuUMmm+7+l20Fr3X/MvoC3kmec/QXW1T/c9rN8kZDA09jwbYkTOD
+hNz/Xw91MV2/i5z3ZgzLK2uZqusKt1Cq9HP8VnWdtZ71nDWd9Y0luJZ/95z
OCjvrHkaGPeMdj06Nd/QnD9wWNZv7l82OfcjOwaHyMrnmcgm5XstOyprRVYW
dWQTcwaQVc9ZLu88jpXdkT7X/RE/KXtP3p2893wJlEQxFM97hyX4K88D23L+
Mn57zoDGbs3ZjN9MV9Mt9PrsmTmv8b/SVfQ3OlI+3r2OouX4g/P3tr6VtAr9
IfstvsNKfkUUy/EtvsEP8muNH2ee4fTErAXjz8QjOZPw8/PN4U9DxbyvOQvI
DqMV0FbeDu1z1s1aoKfiFDTiD1Uz2NyL+K+Ne5QuxAI8lm8DnY8H8RDmYVG+
TdlnckbP+sv7beyD2vvTcSiprgTmYg7KyK5Hce19MCtntPxWsrEopr03ZuCu
nNFlY1DQ/te80+k0lJKNzn7gmhfkO0R76e+ZZ5HfWM3knHUxEXfkunMfuC1n
cWNvpR/RCbSv8aNdfz+6O+so74a+W3KddEfOjtiOm2U35TrlI7P2jZmX726+
OfrPz16Xb0/Wi7r31NyQvweyTmUn5+8k7evQMusx+3r+7so3KvugsWPzTmEM
3pJ3yzkjfwv627CFmuZZQ9nPZX/LuvFzjJuL0fn7w5hRdEnOCOqa5m9Vddfy
nfgRfGfa1bjzcr7Svi57OG3Gd8x7xv9lTJe8bzl38GfSLfxmjDT/CGzO/wHk
jKVvdvYc3IM3ZO1kJxi3Qc0wvg0/PO8jfZ0/mdbm/9A/lJ9p3KycOcz7Gr8p
34l889TVUbdO3bk5E/PD8l3OuS37Z75D/G/6O/Mn5azGN6NN+KbZ6/Icst+a
t1G+QfpXq78me1vOM/7Nofn7Su2M7IFqjlazRs05sk6oL6sq+1F2tXHT1E3P
mci4l/j1au7kG6irpu4ndWfJzs43Od8k2XeyK9VOyXtr3AD8oX8qX1dNZTXf
qxkkfz7nXjoEg/P3obyj2olqa+Xblf0t32nZ5Wpv42/POUftE9mD5JP4yaid
Z4gn5T30P5VvTvYDc15AL0Qv9MZF2QfkZxrfId9n4yq5rmWygdmP8l1u9P//
P/wflOqOEw==
           "]], LineBox[CompressedData["
1:eJwl09tPz3Ecx/FPLiSVUpLS0JRxT+kyXDkMcY/YuuvguLERfqup3HJl48Zs
1K+TEh02EV0pIoe1cuOQf8Ahh8dnLp57vl/vz/v7/n4/7VdxdV1VbUoIYRTT
m0PIKg+hc2sI9VtC2FURwkq9pN5b7uCueI58uYd70Y0+3Mcq/Qc8gH48wkMU
6A/xMAbxTh7hQt7tPQ3e916drZcqL8FSpOF2WQiLka5O5Qw+bj5NfS3O8h2c
1rson+EPduXatQJN6nW4a6aY95tJV7fjHnrd97W5N5iKd8V0/H79audH0Wjn
gHyBm+0owbyZb/FvEe+NhLOE3Zf5mGc2mDkoN8k75BHPN6sHeRhDqNHfZG6R
ep5T+CtfNdeGcfk5iuwP/JefcauZMV4t/8FvPJVb9J9wobyAXxiVr+g/5gL5
i/ont9h/w/e18me973qf+Adv5G7fVsoHzOSqu9CJ5bill8OXPJvN1+UsTiIT
N+VlfN55B6+3p0ovQz2nnvWOj5iLvx3f9ZJf4QUmMYGeeHcej3fGjOfO2bfP
nrXq7XZtw1m9vXpr9I7IJ+VG+RRXyid4j1zk/JB8GHV6O/Xy9BLxt+1dSbSX
//8/+AdYwY7H
           "]]},
         "0.4124026847859471`"],
        Annotation[#, 0.4124026847859471, "Tooltip"]& ], {}, {}}}], {}}, {
    GraphicsComplexBox[CompressedData["
1:eJx03X/Ivv1d1/G75bLW2vohWWQus1/2EyPWYrItxkIMSYYijWy0VqaZy7LS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     "], {{{}, {}}, {{}, 
       TagBox[
        TooltipBox[
         {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.0075], Opacity[
          0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwl2HcYltMfx/EHhVQoREaktLT3FEUqlEIaipaysjIiDZVdaCGj7IzMlJCk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           "]]},
         "0.692562966942146`"],
        Annotation[#, 0.692562966942146, "Tooltip"]& ], {}, {}}}], {}}, 
   {Thickness[0.002], LineBox[{{0, -4}, {0, 4}}], LineBox[{{-4, 0}, {5, 0}}]}},
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*StyleBox[\\\"y\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"x\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->{{-4, 4}, {-4, 4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.880440621837308*^9, 3.880440652646162*^9, 3.8804640971256104`*^9, 
   3.880464246726039*^9, 3.88061299657096*^9, 3.880613127298073*^9, {
   3.8806199350983067`*^9, 3.88061996696649*^9}, 3.880620239770544*^9, 
   3.880620341305931*^9, 3.8806520054633417`*^9, 3.880655542958899*^9, 
   3.8807027644633017`*^9, {3.8807031880685787`*^9, 3.8807032301439543`*^9}, 
   3.8807034808228483`*^9, 3.8909821012256517`*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"044773ec-41f4-437a-8a09-9ad1eaac6937"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1058, 664},
WindowMargins->{{82, Automatic}, {Automatic, 25}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"811eae46-8ff7-487c-a261-0e630279a8d5"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"f9f3d752-5402-4b81-a8ff-9dd01713a6b4"],
Cell[1000, 31, 378, 6, 67, "Section",ExpressionUUID->"31cd5343-8984-4f97-9cf6-28b1dc5d8ffc"],
Cell[1381, 39, 775, 26, 72, "Text",ExpressionUUID->"93f2da43-cf6b-49db-a25a-c6c8249f81b6"],
Cell[2159, 67, 4368, 115, 304, "Input",ExpressionUUID->"1392616a-5db1-4b66-984d-5a0335c49f68"],
Cell[6530, 184, 587, 18, 76, "Text",ExpressionUUID->"5e2e41f5-db7b-434d-9ad0-1c5a56971b5b"],
Cell[7120, 204, 1503, 45, 94, "Input",ExpressionUUID->"15727f76-f1e1-43ca-952b-d268301d2fe7"],
Cell[8626, 251, 585, 14, 76, "Text",ExpressionUUID->"0d099452-0a30-46f2-af6f-659a088a8cec"],
Cell[9214, 267, 5987, 160, 724, "Input",ExpressionUUID->"c0b4869e-7e92-42d1-bde3-9b80b551156c"],
Cell[15204, 429, 581, 12, 76, "Text",ExpressionUUID->"223874b6-2d96-4b96-96f8-67cdd09b0246"],
Cell[15788, 443, 4893, 128, 640, "Input",ExpressionUUID->"84b57475-adc6-480c-86a4-a72be2939c5d"],
Cell[20684, 573, 900, 27, 76, "Text",ExpressionUUID->"3de7be5c-01b7-4a05-8332-3a9f5efc9ed0"],
Cell[21587, 602, 3290, 83, 283, "Input",ExpressionUUID->"b96eb8de-4e05-4c8d-afc2-3902b3ff9ddb"],
Cell[24880, 687, 2363, 74, 115, "Input",ExpressionUUID->"07d5c0b6-c0f5-4175-8546-02adb5b9e0e6"],
Cell[27246, 763, 377, 6, 53, "Text",ExpressionUUID->"29c058af-db45-4739-a260-c62e35f9363b"],
Cell[27626, 771, 315, 7, 33, "Input",ExpressionUUID->"c5778ee3-fb34-48e3-aa9e-efbac61e0c0e"],
Cell[27944, 780, 422, 7, 53, "Text",ExpressionUUID->"dee8a1dc-cd5c-4e82-be18-ba1bcd9a0b74"],
Cell[28369, 789, 1704, 40, 158, "Input",ExpressionUUID->"4ebe036c-3111-4e98-8435-980f046c97aa"],
Cell[30076, 831, 537, 10, 53, "Text",ExpressionUUID->"c3378004-4b37-441e-8ebe-9a77ac1f8582"],
Cell[30616, 843, 1358, 39, 52, "Input",ExpressionUUID->"056d257e-5c90-41d5-a339-c55794f61cc9"],
Cell[31977, 884, 512, 10, 53, "Text",ExpressionUUID->"999f0430-e7cc-4de1-b06b-b957e2990b03"],
Cell[32492, 896, 2569, 69, 262, "Input",ExpressionUUID->"d1f01ac7-92a0-4ed0-b897-6ad99d3e9a9b"],
Cell[35064, 967, 509, 10, 53, "Text",ExpressionUUID->"2e8a5990-ee2e-4c3a-b633-c1093c1610fe"],
Cell[CellGroupData[{
Cell[35598, 981, 1039, 23, 30, "Input",ExpressionUUID->"9b52191a-b163-4099-856a-ef8c39ac1938"],
Cell[36640, 1006, 752, 13, 34, "Output",ExpressionUUID->"6459a239-5e55-4a7c-a2a0-d87ff1183dbc"]
}, Open  ]],
Cell[37407, 1022, 993, 36, 53, "Text",ExpressionUUID->"f96eaf5b-d36c-4e2f-8b57-d3230c47d601"],
Cell[38403, 1060, 12559, 315, 745, "Input",ExpressionUUID->"51350a2c-8804-4876-af07-cbce72caeda8"],
Cell[50965, 1377, 1049, 37, 53, "Text",ExpressionUUID->"7ea46e4e-cf88-4175-966b-c837cc36ba20"],
Cell[52017, 1416, 9614, 224, 464, "Input",ExpressionUUID->"542bd733-4057-4d3f-b518-8aa7ffed0e11"],
Cell[61634, 1642, 705, 13, 53, "Text",ExpressionUUID->"510f47db-ab8f-4014-873c-c0e9edb444bb"],
Cell[62342, 1657, 274, 5, 30, "Input",ExpressionUUID->"d211517e-2ab9-4462-aebb-16e1dddc70a4"],
Cell[CellGroupData[{
Cell[62641, 1666, 299, 5, 30, "Input",ExpressionUUID->"39f248e0-7118-42ec-8beb-2152bcb7bd59"],
Cell[62943, 1673, 193389, 4065, 329, "Output",ExpressionUUID->"e191cfb3-2513-489b-9422-7055e958145e"]
}, Open  ]],
Cell[256347, 5741, 683, 13, 53, "Text",ExpressionUUID->"0bcf49db-b4a6-44ed-b9a8-c36cecffb3f0"],
Cell[257033, 5756, 713, 11, 30, "Input",ExpressionUUID->"94091780-8049-46bf-af12-f944424c8602"],
Cell[CellGroupData[{
Cell[257771, 5771, 397, 6, 30, "Input",ExpressionUUID->"d0043f5b-53e8-4ada-8894-2362e9238035"],
Cell[258171, 5779, 69480, 1283, 431, "Output",ExpressionUUID->"69dddac8-56a7-4ef6-83b9-592160b272b6"]
}, Open  ]],
Cell[327666, 7065, 693, 13, 53, "Text",ExpressionUUID->"eb06b93a-f904-44ed-8d25-cee056b7efd1"],
Cell[CellGroupData[{
Cell[328384, 7082, 203, 3, 30, "Input",ExpressionUUID->"98fc8bb3-b9b4-4def-a694-28959e645af4"],
Cell[328590, 7087, 24459, 442, 401, "Output",ExpressionUUID->"1ea8e1a6-12a9-4532-92c9-38240b531bd1"]
}, Open  ]],
Cell[353064, 7532, 754, 13, 53, "Text",ExpressionUUID->"e3891b8c-c533-407c-a5a8-7a2406a6546b"],
Cell[353821, 7547, 273, 5, 30, "Input",ExpressionUUID->"578be56b-2867-4e1a-b7ea-8aa00ef8f6d6"],
Cell[CellGroupData[{
Cell[354119, 7556, 249, 4, 30, "Input",ExpressionUUID->"6a79d4a4-a722-4f10-89d1-2d8c855eba61"],
Cell[354371, 7562, 191749, 4055, 329, "Output",ExpressionUUID->"bd2a33aa-ce4f-407e-bc95-5abefa9914b8"]
}, Open  ]],
Cell[546135, 11620, 732, 13, 53, "Text",ExpressionUUID->"6a45a7ee-519a-471a-95d5-df350e34df1f"],
Cell[546870, 11635, 266, 5, 30, "Input",ExpressionUUID->"33d2f3f2-3f1c-4d45-a155-ad290268a99e"],
Cell[CellGroupData[{
Cell[547161, 11644, 197, 3, 30, "Input",ExpressionUUID->"67d5eb9b-0a6a-44da-a81a-061f47d14b89"],
Cell[547361, 11649, 70819, 1305, 431, "Output",ExpressionUUID->"4ba50bef-450e-40f0-b451-882415bc9e7a"]
}, Open  ]],
Cell[618195, 12957, 791, 14, 53, "Text",ExpressionUUID->"98406d5b-40b4-49ec-967b-6670a5222fc7"],
Cell[CellGroupData[{
Cell[619011, 12975, 203, 3, 30, "Input",ExpressionUUID->"4ed60d73-d0e2-4642-bbc5-c56cbef15436"],
Cell[619217, 12980, 24895, 449, 378, "Output",ExpressionUUID->"0a303672-cb5f-4d4a-b1fd-78d04361694e"]
}, Open  ]],
Cell[644127, 13432, 789, 14, 53, "Text",ExpressionUUID->"076378cb-11b7-43cc-a850-929a76f96ec2"],
Cell[644919, 13448, 322, 6, 30, "Input",ExpressionUUID->"00a9dc06-b573-4db1-a30c-fd0c79e6bcc5"],
Cell[CellGroupData[{
Cell[645266, 13458, 298, 5, 30, "Input",ExpressionUUID->"c3e26c24-4678-4986-9030-62dcea1c6e41"],
Cell[645567, 13465, 192477, 4061, 329, "Output",ExpressionUUID->"b87fdc48-73f6-4701-b743-6f2428472fe3"]
}, Open  ]],
Cell[838059, 17529, 767, 14, 53, "Text",ExpressionUUID->"6aefa2d8-de2e-40c6-a44f-85cd518bf32c"],
Cell[838829, 17545, 271, 5, 30, "Input",ExpressionUUID->"035ee2c0-f185-42cb-bd20-8ad2df6211b6"],
Cell[CellGroupData[{
Cell[839125, 17554, 197, 3, 30, "Input",ExpressionUUID->"16f013e4-e382-42c4-92f9-f594159547ae"],
Cell[839325, 17559, 71468, 1317, 431, "Output",ExpressionUUID->"49e8d0d7-9307-49c9-b06c-8c35093c677e"]
}, Open  ]],
Cell[910808, 18879, 819, 14, 53, "Text",ExpressionUUID->"b051e585-5e20-4928-8437-275c9a2f3fee"],
Cell[CellGroupData[{
Cell[911652, 18897, 201, 3, 30, "Input",ExpressionUUID->"31a8ca30-d2d7-4b1b-8df6-48fd15deff7d"],
Cell[911856, 18902, 24951, 450, 378, "Output",ExpressionUUID->"affb830f-ef8d-45fd-aafb-c8888a3c53af"]
}, Open  ]],
Cell[936822, 19355, 832, 14, 53, "Text",ExpressionUUID->"690c46c5-db0e-456b-8da8-4885f0be8c0c"],
Cell[937657, 19371, 371, 7, 30, "Input",ExpressionUUID->"629ee2f7-9ddd-4948-bb78-428bc3737601"],
Cell[CellGroupData[{
Cell[938053, 19382, 344, 5, 30, "Input",ExpressionUUID->"ede0cd79-f83f-435f-9ef4-912a171a7952"],
Cell[938400, 19389, 193326, 4077, 329, "Output",ExpressionUUID->"ce15915f-e697-4820-b956-36008917ad94"]
}, Open  ]],
Cell[1131741, 23469, 810, 14, 53, "Text",ExpressionUUID->"115d7290-dee2-471c-a5a3-3fdde75d2bbb"],
Cell[1132554, 23485, 269, 5, 30, "Input",ExpressionUUID->"d3705ddf-7fca-4510-8a93-659664ea076c"],
Cell[CellGroupData[{
Cell[1132848, 23494, 199, 3, 30, "Input",ExpressionUUID->"531e801c-4c08-44c3-b1e9-b599576789f8"],
Cell[1133050, 23499, 70795, 1305, 431, "Output",ExpressionUUID->"b51a873f-3cb4-415b-ba29-57098907e104"]
}, Open  ]],
Cell[1203860, 24807, 871, 15, 53, "Text",ExpressionUUID->"e91bee86-1403-4183-84ae-0d685d41c793"],
Cell[CellGroupData[{
Cell[1204756, 24826, 201, 3, 30, "Input",ExpressionUUID->"0efa79fd-80e5-4d56-b138-2f19d40f8f8a"],
Cell[1204960, 24831, 24720, 446, 378, "Output",ExpressionUUID->"a643adf9-05ec-43a3-93fd-0afbbef763fc"]
}, Open  ]],
Cell[1229695, 25280, 852, 15, 53, "Text",ExpressionUUID->"8e603af6-05d8-48ed-935b-3ace235e720e"],
Cell[1230550, 25297, 419, 7, 30, "Input",ExpressionUUID->"b0b58d4c-36e8-4b5c-8d1f-11d4b8783c7e"],
Cell[CellGroupData[{
Cell[1230994, 25308, 397, 6, 30, "Input",ExpressionUUID->"fbd990aa-6da9-409a-8742-0c500883eded"],
Cell[1231394, 25316, 192736, 4070, 329, "Output",ExpressionUUID->"fd5893c2-499f-455b-a59b-4ba696c0e532"]
}, Open  ]],
Cell[1424145, 29389, 830, 15, 53, "Text",ExpressionUUID->"d0b4f081-8440-4538-b565-cf5a5cbd8be9"],
Cell[1424978, 29406, 315, 6, 30, "Input",ExpressionUUID->"aa977c13-4415-4d09-8074-ca4939d4f52b"],
Cell[CellGroupData[{
Cell[1425318, 29416, 197, 3, 30, "Input",ExpressionUUID->"7f39cc15-6eda-404e-aff4-0ecc53df8fa0"],
Cell[1425518, 29421, 71336, 1314, 431, "Output",ExpressionUUID->"69a4dd33-2f56-48b8-a81f-692ea8f7b997"]
}, Open  ]],
Cell[1496869, 30738, 884, 15, 53, "Text",ExpressionUUID->"4866f574-20cf-4170-a51a-7f534acd8406"],
Cell[CellGroupData[{
Cell[1497778, 30757, 254, 4, 30, "Input",ExpressionUUID->"43fb6112-cba6-4599-878e-419d1df537b5"],
Cell[1498035, 30763, 24780, 449, 378, "Output",ExpressionUUID->"6433becd-994c-498f-b6e4-91cfa392f7cb"]
}, Open  ]],
Cell[1522830, 31215, 874, 15, 53, "Text",ExpressionUUID->"fed2aeec-0c77-4623-85ce-bf7cf6c3666f"],
Cell[1523707, 31232, 470, 8, 30, "Input",ExpressionUUID->"3c473291-d757-4aed-9f94-6612fe8f2f93"],
Cell[CellGroupData[{
Cell[1524202, 31244, 446, 7, 30, "Input",ExpressionUUID->"5cb59276-b5f7-454a-9eb2-4d747b0ddc10"],
Cell[1524651, 31253, 192791, 4067, 329, "Output",ExpressionUUID->"5d2a32d9-6057-4d6c-9654-30a19ed7b481"]
}, Open  ]],
Cell[1717457, 35323, 853, 15, 53, "Text",ExpressionUUID->"b4351781-dcf7-4b5c-b716-49ee93d56f1a"],
Cell[1718313, 35340, 268, 5, 30, "Input",ExpressionUUID->"5c283a63-bbdd-4377-8d03-ca045824630e"],
Cell[CellGroupData[{
Cell[1718606, 35349, 199, 3, 30, "Input",ExpressionUUID->"338d5c73-54ef-43bf-b902-6dad48a45bfe"],
Cell[1718808, 35354, 70931, 1307, 431, "Output",ExpressionUUID->"c6f22937-ad67-4edf-bd26-51bc9966e475"]
}, Open  ]],
Cell[1789754, 36664, 915, 16, 53, "Text",ExpressionUUID->"51a8064c-1c7e-419d-8061-149bcb6d200e"],
Cell[CellGroupData[{
Cell[1790694, 36684, 203, 3, 30, "Input",ExpressionUUID->"eae9bc64-047b-465a-9433-fd8756052ed0"],
Cell[1790900, 36689, 24973, 450, 378, "Output",ExpressionUUID->"ca2b0b0e-2ebf-412a-be2d-3a3fb3066abc"]
}, Open  ]],
Cell[1815888, 37142, 866, 13, 53, "Text",ExpressionUUID->"328808de-df78-4330-b013-1701a3f1498f"],
Cell[CellGroupData[{
Cell[1816779, 37159, 611, 16, 30, "Input",ExpressionUUID->"a678812e-c4e0-4f18-8a27-604403bbd698"],
Cell[1817393, 37177, 1279020, 24507, 717, "Output",ExpressionUUID->"6fe643b1-bc44-4581-987e-a28f7309dc7d"]
}, Open  ]],
Cell[3096428, 61687, 891, 13, 53, "Text",ExpressionUUID->"ab998cd1-5961-4d1a-828c-99e05898f7fa"],
Cell[CellGroupData[{
Cell[3097344, 61704, 763, 19, 30, "Input",ExpressionUUID->"36705bcf-3682-44e0-a7e6-5271f5a5fd58"],
Cell[3098110, 61725, 438818, 7972, 717, "Output",ExpressionUUID->"c72d24a6-0b94-49ac-9b51-db54fa0941d5"]
}, Open  ]],
Cell[3536943, 69700, 905, 13, 53, "Text",ExpressionUUID->"f3307f04-fcec-4c7d-969d-3310e9423893"],
Cell[CellGroupData[{
Cell[3537873, 69717, 597, 16, 30, "Input",ExpressionUUID->"eca90e2e-6a81-42f4-b7d6-13e1bf1b0b76"],
Cell[3538473, 69735, 151401, 2702, 717, "Output",ExpressionUUID->"0281d0e9-e7b9-4891-a638-4f336ff11366"]
}, Open  ]],
Cell[3689889, 72440, 975, 14, 53, "Text",ExpressionUUID->"64d9ee0c-d598-4afc-8a69-f09daf7bfdba"],
Cell[CellGroupData[{
Cell[3690889, 72458, 279, 5, 30, "Input",ExpressionUUID->"f8f1ef90-a4c5-4ae8-ac40-2ea044fc7812"],
Cell[3691171, 72465, 129671, 2170, 378, "Output",ExpressionUUID->"3a9b8542-76e5-4a90-ac42-4f0975eccadf"]
}, Open  ]],
Cell[3820857, 74638, 377, 13, 53, "Text",ExpressionUUID->"2f262899-3456-4149-bdcd-7dfa80cf45a0"],
Cell[3821237, 74653, 674, 21, 52, "Input",ExpressionUUID->"3efb73b3-2ff4-4e42-b228-114ae78d863f"],
Cell[3821914, 74676, 1379, 53, 122, "Text",ExpressionUUID->"21bb50c7-f66a-4911-9ec6-d493ff0dea62"],
Cell[3823296, 74731, 509, 16, 30, "Input",ExpressionUUID->"e7e06708-ef39-4ff9-986f-1e02d40596c4"],
Cell[3823808, 74749, 446, 13, 53, "Text",ExpressionUUID->"49997081-8126-4db0-9b3f-7fe2358c56e9"],
Cell[CellGroupData[{
Cell[3824279, 74766, 827, 23, 30, "Input",ExpressionUUID->"7c4647a4-ddeb-4e12-bef0-4f79abbb212e"],
Cell[3825109, 74791, 923, 24, 34, "Output",ExpressionUUID->"52ea1214-a218-40c5-b73e-68c17638ba09"]
}, Open  ]],
Cell[3826047, 74818, 339, 10, 53, "Text",ExpressionUUID->"16b846de-9318-4f69-a944-f8bf51dd9b4d"],
Cell[CellGroupData[{
Cell[3826411, 74832, 411, 12, 30, "Input",ExpressionUUID->"98142479-dfce-4e18-b3d5-c70c76419ddd"],
Cell[3826825, 74846, 707, 14, 34, "Output",ExpressionUUID->"f5d74534-5d7f-49d0-bf9b-32f70529358f"]
}, Open  ]],
Cell[3827547, 74863, 722, 24, 76, "Text",ExpressionUUID->"0877016b-36e7-4ff2-bf8c-1c0037247005"],
Cell[CellGroupData[{
Cell[3828294, 74891, 234, 5, 30, "Input",ExpressionUUID->"31846e68-2167-462b-b576-9dd41bf9baa5"],
Cell[3828531, 74898, 771, 17, 34, "Output",ExpressionUUID->"39f138d2-3220-4619-8d19-5a4129dfc8fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3829339, 74920, 336, 9, 30, "Input",ExpressionUUID->"40672437-d360-4c9e-aff3-8e282089e169"],
Cell[3829678, 74931, 1165, 29, 56, "Output",ExpressionUUID->"a4e53ff2-7ec3-4738-bccc-e6c26e3b886a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3830880, 74965, 336, 9, 30, "Input",ExpressionUUID->"5a709a0f-551c-4c58-a842-e455ce87fd20"],
Cell[3831219, 74976, 1120, 27, 56, "Output",ExpressionUUID->"35866930-2721-4bca-af1f-7b48f7c1f63d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3832376, 75008, 317, 8, 30, "Input",ExpressionUUID->"8dd16f4f-a8be-48f9-9d48-a5519bb5e487"],
Cell[3832696, 75018, 656, 12, 34, "Output",ExpressionUUID->"46024d1e-87d4-4f5f-9d5c-c940637e6442"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3833389, 75035, 317, 8, 30, "Input",ExpressionUUID->"b4765884-4c9d-487d-b78c-3d5cfa7bfc9c"],
Cell[3833709, 75045, 661, 12, 34, "Output",ExpressionUUID->"07e5c71e-4ce6-451b-ba2c-a1f8347bf510"]
}, Open  ]],
Cell[3834385, 75060, 929, 23, 55, "Text",ExpressionUUID->"7ad9a352-21a0-4f0a-b6df-bc48969eb210"],
Cell[CellGroupData[{
Cell[3835339, 75087, 2246, 45, 34, "Input",ExpressionUUID->"74b3dcf1-118c-4f6c-9db4-b6a5bacd6b5e"],
Cell[3837588, 75134, 3597, 71, 159, "Output",ExpressionUUID->"bb7562c0-9816-41ac-b78e-aa80341db129"]
}, Open  ]],
Cell[3841200, 75208, 268, 5, 53, "Text",ExpressionUUID->"2587d068-9f50-4e9b-9e5c-73f753bd2965"],
Cell[3841471, 75215, 840, 25, 30, "Input",ExpressionUUID->"a9e82b83-0193-455d-a52a-b7aed8eca606"],
Cell[3842314, 75242, 323, 6, 53, "Text",ExpressionUUID->"fc53b249-79fc-40a6-8f99-024066edf4ed"],
Cell[3842640, 75250, 1870, 47, 115, "Input",ExpressionUUID->"0430b546-2d1e-4c30-8286-b2dfc1164b37"],
Cell[3844513, 75299, 332, 6, 53, "Text",ExpressionUUID->"28bb0628-a0a3-4993-bbda-9dc654ac314c"],
Cell[CellGroupData[{
Cell[3844870, 75309, 230, 4, 30, "Input",ExpressionUUID->"34d0c090-377b-45e0-b0f2-4dfeeeab6178"],
Cell[3845103, 75315, 47167, 791, 378, "Output",ExpressionUUID->"54470c85-79b3-488c-9270-0d69986c161f"]
}, Open  ]],
Cell[3892285, 76109, 323, 6, 53, "Text",ExpressionUUID->"7eeb342f-3dcf-4a54-a849-6c389d54a8d4"],
Cell[3892611, 76117, 1967, 49, 115, "Input",ExpressionUUID->"88c40252-2d91-449d-a796-3eff187673c5"],
Cell[3894581, 76168, 332, 6, 53, "Text",ExpressionUUID->"8e936af1-1c36-4ba9-b823-6bc51dfa8f6d"],
Cell[CellGroupData[{
Cell[3894938, 76178, 279, 5, 30, "Input",ExpressionUUID->"9aca29a6-e098-473e-8e70-d12e656b047a"],
Cell[3895220, 76185, 64861, 1081, 378, "Output",ExpressionUUID->"d1727a8b-d7a9-46aa-80f1-df3729422c1a"]
}, Open  ]],
Cell[3960096, 77269, 323, 6, 53, "Text",ExpressionUUID->"6123850e-6467-47d2-be9c-08e6adb92cd5"],
Cell[3960422, 77277, 2013, 49, 115, "Input",ExpressionUUID->"cad9cb21-54d2-4b24-95b1-691d4d853ed5"],
Cell[3962438, 77328, 332, 6, 53, "Text",ExpressionUUID->"5fd68d20-39cc-46c8-a53d-b3ac969f3c44"],
Cell[CellGroupData[{
Cell[3962795, 77338, 328, 6, 30, "Input",ExpressionUUID->"16b058d1-11c7-426d-bdc1-009245ebb50f"],
Cell[3963126, 77346, 77510, 1289, 378, "Output",ExpressionUUID->"79be67a7-8779-47c7-adb5-986e9d267bed"]
}, Open  ]],
Cell[4040651, 78638, 323, 6, 53, "Text",ExpressionUUID->"5814548f-35d7-4b42-96a2-effdc9b04be0"],
Cell[4040977, 78646, 2062, 50, 115, "Input",ExpressionUUID->"71d1fde7-4afe-427b-9e0e-431aa0976535"],
Cell[4043042, 78698, 332, 6, 53, "Text",ExpressionUUID->"0f5344b7-d75c-455d-9651-a00f71905771"],
Cell[CellGroupData[{
Cell[4043399, 78708, 373, 6, 30, "Input",ExpressionUUID->"54d223c1-e9d6-49d7-b727-b11dd8b8fde9"],
Cell[4043775, 78716, 75828, 1262, 378, "Output",ExpressionUUID->"12be36ef-4177-45fa-a779-d1ac1623af95"]
}, Open  ]],
Cell[4119618, 79981, 323, 6, 53, "Text",ExpressionUUID->"4f18c2c7-d9b1-4242-b778-d39e9cea20ba"],
Cell[4119944, 79989, 2210, 52, 115, "Input",ExpressionUUID->"f2c22431-043b-4903-a35d-2788cf02a268"],
Cell[4122157, 80043, 332, 6, 53, "Text",ExpressionUUID->"45ec1b39-95b3-4feb-920d-c3727fd599c0"],
Cell[CellGroupData[{
Cell[4122514, 80053, 424, 7, 30, "Input",ExpressionUUID->"27b496e7-05cf-4e02-ae29-5e76511db869"],
Cell[4122941, 80062, 78857, 1312, 378, "Output",ExpressionUUID->"f5cf8af5-8cc1-40c7-a128-4581dced528e"]
}, Open  ]],
Cell[4201813, 81377, 323, 6, 53, "Text",ExpressionUUID->"be27fe1a-d290-401a-a282-5065219b390a"],
Cell[4202139, 81385, 2307, 53, 115, "Input",ExpressionUUID->"12d451cc-b66b-47a4-a7ee-358d11b846fd"],
Cell[4204449, 81440, 332, 6, 53, "Text",ExpressionUUID->"9ce64f57-dd21-4a0a-a0af-e0004ad11723"],
Cell[CellGroupData[{
Cell[4204806, 81450, 475, 8, 30, "Input",ExpressionUUID->"c9fc21a1-de78-4e56-972b-50ac25e90195"],
Cell[4205284, 81460, 74796, 1245, 378, "Output",ExpressionUUID->"27609e83-4bc6-453a-a627-39f1ba7e8eac"]
}, Open  ]],
Cell[4280095, 82708, 1025, 15, 53, "Text",ExpressionUUID->"63e59254-65ae-4df2-8ac5-4b252a9b99d8"],
Cell[CellGroupData[{
Cell[4281145, 82727, 545, 10, 30, "Input",ExpressionUUID->"02a70398-2458-4d92-8bb3-aa156557f021"],
Cell[4281693, 82739, 411001, 6777, 378, "Output",ExpressionUUID->"044773ec-41f4-437a-8a09-9ad1eaac6937"]
}, Open  ]]
}
]
*)

